@@ -5,7 +5,7 @@
 // Implementation of Exception and derived classes
 //
 
-#define MAGICK_IMPLEMENTATION
+#define MAGICKCORE_IMPLEMENTATION  1
 
 #include "Magick++/Include.h"
 #include <string>
@@ -24,7 +24,7 @@ Magick::Exception::Exception( const std::string& what_ )
 
 // Copy constructor
 Magick::Exception::Exception( const Magick::Exception& original_ )
-  : _what(original_._what)
+  : exception(original_), _what(original_._what)
 {
 }
 
@@ -271,9 +271,10 @@ MagickDLLDecl void Magick::throwExceptionExplicit( const ExceptionType severity_
   GetExceptionInfo( &exception );
   ThrowException( &exception, severity_, reason_, description_ );
   throwException( exception );
+  DestroyExceptionInfo( &exception );
 }
 
-// Throw C++ exception, resetting exception argument to default state
+// Throw C++ exception
 MagickDLLDecl void Magick::throwException( ExceptionInfo &exception_ )
 {
   // Just return if there is no reported error
