@@ -144,6 +144,15 @@ Magick::Color Magick::Options::boxColor ( void ) const
   return Magick::Color( _drawInfo->undercolor );
 }
 
+void Magick::Options::colorspaceType ( Magick::ColorspaceType colorspace_ )
+{
+  _imageInfo->colorspace = colorspace_;
+}
+Magick::ColorspaceType Magick::Options::colorspaceType ( void ) const
+{
+  return static_cast<Magick::ColorspaceType>(_imageInfo->colorspace);
+}
+
 void Magick::Options::compressType ( CompressionType compressType_ )
 {
   _imageInfo->compression = compressType_;
