@@ -1151,7 +1151,7 @@ int main( int /*argc*/, char ** argv)
     // quantizeColorSpace
     //
     // Test default
-    if ( image.quantizeColorSpace() != RGBColorspace )
+    if ( image.quantizeColorSpace() != UndefinedColorspace )
       {
 	++failures;
 	cout << "Line: " << __LINE__
