@@ -30,6 +30,12 @@ $smile->Set(background=>'white');
 print "Transform image...\n";
 $images=Image::Magick->new();
 
+print "Adaptive Sharpen...\n";
+$example=$model->Clone();
+$example->Label('Adaptive Sharpen');
+$example->AdaptiveSharpen('0x1');
+push(@$images,$example);
+
 print "Adaptive Threshold...\n";
 $example=$model->Clone();
 $example->Label('Adaptive Threshold');
@@ -85,6 +91,12 @@ $example->Label('Contrast');
 $example->Contrast();
 push(@$images,$example);
 
+print "Contrast Stretch...\n";
+$example=$model->Clone();
+$example->Label('Contrast Stretch');
+$example->ContrastStretch('5%');
+
+push(@$images,$example);
 print "Convolve...\n";
 $example=$model->Clone();
 $example->Label('Convolve');
@@ -95,6 +107,7 @@ print "Crop...\n";
 $example=$model->Clone();
 $example->Label('Crop');
 $example->Crop(geometry=>'80x80+25+50');
+$example->Set(page=>'0x0+0+0');
 push(@$images,$example);
 
 print "Despeckle...\n";
@@ -119,10 +132,10 @@ push(@$images,$example);
 print "Emboss...\n";
 $example=$model->Clone();
 $example->Label('Emboss');
-$example->Emboss();
+$example->Emboss('0x1');
+push(@$images,$example);
 
 print "Equalize...\n";
-push(@$images,$example);
 $example=$model->Clone();
 $example->Label('Equalize');
 $example->Equalize();
@@ -213,6 +226,12 @@ $example->Label('Monochrome');
 $example->Quantize(colorspace=>'gray',colors=>2,dither=>'false');
 push(@$images,$example);
 
+print "Motion Blur...\n";
+$example=$model->Clone();
+$example->Label('Motion Blur');
+$example->MotionBlur('0x13+10-10');
+push(@$images,$example);
+
 print "Negate...\n";
 $example=$model->Clone();
 $example->Label('Negate');
@@ -353,6 +372,12 @@ $example->Label('Unsharp Mask');
 $example->UnsharpMask('0.0x1.0');
 push(@$images,$example);
 
+print "Vignette...\n";
+$example=$model->Clone();
+$example->Label('Vignette');
+$example->Vignette('0x20');
+push(@$images,$example);
+
 print "Wave...\n";
 $example=$model->Clone();
 $example->Label('Wave');
@@ -362,7 +387,7 @@ push(@$images,$example);
 # Create image montage.
 #
 print "Montage...\n";
-$montage=$images->Montage(geometry=>'130x194+10+5>',gravity=>'Center',
+$montage=$images->Montage(geometry=>'128x160+8+4>',gravity=>'Center',
   tile=>'5x+10+200',compose=>'over',background=>'#ffffff',
   font=>'Generic.ttf',pointsize=>18,fill=>'#600',stroke=>'none');
 
