@@ -166,7 +166,7 @@ typedef struct _BMPInfo
     important_colors;
 } BMPInfo;
 
-typedef struct _StreamInfo
+typedef struct _AVIStreamInfo
 {
   char
     data_type[5],
@@ -183,7 +183,7 @@ typedef struct _StreamInfo
     buffer_size,
     quality,
     sample_size;
-} StreamInfo;
+} AVIStreamInfo;
 
 /*
   MJPEG Information from Microsoft SDK
@@ -456,7 +456,7 @@ static boolean ReadICCProfile(j_decompress_ptr jpeg_info)
   length-=2;
   if (length <= 14)
     {
-      while (length-- >= 0)
+      while (length-- > 0)
         (void) GetCharacter(jpeg_info);
       return(MagickTrue);
     }
@@ -483,7 +483,7 @@ static boolean ReadICCProfile(j_decompress_ptr jpeg_info)
   p=profile->datum;
   for (i=(long) profile->length-1; i >= 0; i--)
     *p++=(unsigned char) GetCharacter(jpeg_info);
-  icc_profile=GetImageProfile(image,"icc");
+  icc_profile=(StringInfo *) GetImageProfile(image,"icc");
   if (icc_profile != (StringInfo *) NULL)
     ConcatenateStringInfo(icc_profile,profile);
   else
@@ -546,7 +546,7 @@ static boolean ReadIPTCProfile(j_decompress_ptr jpeg_info)
 #endif
   error_manager=(ErrorManager *) jpeg_info->client_data;
   image=error_manager->image;
-  iptc_profile=GetImageProfile(image,"iptc");
+  iptc_profile=(StringInfo *) GetImageProfile(image,"iptc");
   if (iptc_profile == (StringInfo *) NULL)
     {
 #ifdef GET_ONLY_IPTC_DATA
@@ -601,7 +601,7 @@ static boolean ReadIPTCProfile(j_decompress_ptr jpeg_info)
   p=profile->datum;
   for (i=(long) profile->length-1; i >= 0; i--)
     *p++=(unsigned char) GetCharacter(jpeg_info);
-  iptc_profile=GetImageProfile(image,"iptc");
+  iptc_profile=(StringInfo *) GetImageProfile(image,"iptc");
   if (iptc_profile != (StringInfo *) NULL)
     ConcatenateStringInfo(iptc_profile,profile);
   else
@@ -999,6 +999,9 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
   AVIInfo
     avi_info;
 
+  AVIStreamInfo
+    stream_info;
+
   BMPInfo
     bmp_info;
 
@@ -1042,9 +1045,6 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
   ssize_t
     count;
 
-  StreamInfo
-    stream_info;
-
   unsigned char
     *pixels;
 
