@@ -897,6 +897,7 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
     */
     image->x_resolution=(double) bmp_info.x_pixels/100.0;
     image->y_resolution=(double) bmp_info.y_pixels/100.0;
+    image->units=PixelsPerCentimeterResolution;
     /*
       Convert BMP raster image to pixel packets.
     */
@@ -1422,6 +1423,9 @@ static MagickBooleanType WriteBMPImage(const ImageInfo *image_info,Image *image)
   BMPInfo
     bmp_info;
 
+  const StringInfo
+    *profile;
+
   long
     y;
 
@@ -1445,9 +1449,6 @@ static MagickBooleanType WriteBMPImage(const ImageInfo *image_info,Image *image)
   register unsigned char
     *q;
 
-  StringInfo
-    *profile;
-
   unsigned char
     *bmp_data,
     *pixels;
@@ -1480,7 +1481,8 @@ static MagickBooleanType WriteBMPImage(const ImageInfo *image_info,Image *image)
     /*
       Initialize BMP raster file header.
     */
-    (void) SetImageColorspace(image,RGBColorspace);
+    if (image_info->colorspace == UndefinedColorspace)
+      (void) SetImageColorspace(image,RGBColorspace);
     (void) ResetMagickMemory(&bmp_info,0,sizeof(bmp_info));
     bmp_info.file_size=14+12;
     if (type > 2)
@@ -1488,7 +1490,7 @@ static MagickBooleanType WriteBMPImage(const ImageInfo *image_info,Image *image)
     bmp_info.offset_bits=bmp_info.file_size;
     bmp_info.compression=BI_RGB;
     if ((image->storage_class == PseudoClass) && (image->colors > 256))
-      image->storage_class=DirectClass;
+      (void) SetImageStorageClass(image,DirectClass);
     if (image->storage_class != DirectClass)
       {
         /*
@@ -1507,10 +1509,10 @@ static MagickBooleanType WriteBMPImage(const ImageInfo *image_info,Image *image)
           bmp_info.bits_per_pixel=8;
         bmp_info.number_colors=1UL << bmp_info.bits_per_pixel;
         if (image->matte != MagickFalse)
-          image->storage_class=DirectClass;
+          (void) SetImageStorageClass(image,DirectClass);
         else
           if (bmp_info.number_colors < image->colors)
-            image->storage_class=DirectClass;
+            (void) SetImageStorageClass(image,DirectClass);
           else
             {
               bmp_info.file_size+=3*(1UL << bmp_info.bits_per_pixel);
