@@ -111,6 +111,9 @@ static Image *ReadCAPTIONImage(const ImageInfo *image_info,
   register long
     i;
 
+  size_t
+    length;
+
   TypeMetric
     metrics;
 
@@ -145,15 +148,16 @@ static Image *ReadCAPTIONImage(const ImageInfo *image_info,
   draw_info->text=AcquireString(caption);
   gravity=GetImageOption(image_info,"gravity");
   if (gravity != (char *) NULL)
-    draw_info->gravity=(GravityType)
-      ParseMagickOption(MagickGravityOptions,MagickFalse,gravity);
+    draw_info->gravity=(GravityType) ParseMagickOption(MagickGravityOptions,
+      MagickFalse,gravity);
+  length=strlen(caption)+1;
   for (p=caption; *p != '\0'; p++)
   {
     if (*p == '\r')
       *p=' ';
     if ((*p == '\\') && (*(p+1) == 'n'))
       {
-        (void) CopyMagickString(p,p+1,MaxTextExtent);
+        (void) CopyMagickString(p,p+1,length-(p-caption));
         *p='\n';
       }
   }
@@ -169,9 +173,15 @@ static Image *ReadCAPTIONImage(const ImageInfo *image_info,
     if (status == MagickFalse)
       ThrowReaderException(TypeError,"UnableToGetTypeMetrics");
     if (*p != '\n')
-      if ((metrics.width+metrics.max_advance/2) < (double) image->columns)
+      if ((metrics.width+metrics.max_advance/4) < (double) image->columns)
         continue;
-    if ((s != (char *) NULL) && (*s != '\0'))
+    if (s == (char *) NULL)
+      {
+        s=p;
+        while ((isspace((int) ((unsigned char) *s)) == 0) && (*s != '\0'))
+          s++;
+    	}
+    if (*s != '\0')
       {
         *s='\n';
         p=s+1;
@@ -189,7 +199,7 @@ static Image *ReadCAPTIONImage(const ImageInfo *image_info,
   /*
     Draw caption.
   */
-  (void) strcpy(draw_info->text,caption);
+  (void) CopyMagickString(draw_info->text,caption,length);
   (void) FormatMagickString(geometry,MaxTextExtent,"+%g+%g",
     metrics.max_advance/4,metrics.ascent);
   if (draw_info->gravity == UndefinedGravity)
