@@ -59,6 +59,7 @@
 #include "magick/memory_.h"
 #include "magick/monitor.h"
 #include "magick/quantum.h"
+#include "magick/quantum.h"
 #include "magick/static.h"
 #include "magick/string_.h"
 
@@ -238,6 +239,9 @@ static Image *ReadCINImage(const ImageInfo *image_info,
   MagickBooleanType
     status;
 
+  QuantumInfo
+    quantum_info;
+
   QuantumType
     quantum_type;
 
@@ -306,6 +310,7 @@ static Image *ReadCINImage(const ImageInfo *image_info,
   /*
     Convert CIN raster image to pixel packets.
   */
+  GetQuantumInfo(image_info,&quantum_info);
   quantum_type=RGBPadQuantum;
   length=GetBytesPerRow(image->columns,3,image->depth,MagickTrue);
   if (colortype == MonoColorType)
@@ -324,7 +329,7 @@ static Image *ReadCINImage(const ImageInfo *image_info,
     p=ReadBlobStream(image,length,pixels,&count);
     if ((size_t) count != length)
       break;
-    status=ExportQuantumPixels(image,quantum_type,0,p);
+    status=ExportQuantumPixels(image,&quantum_info,quantum_type,p);
     if (status == MagickFalse)
       break;
     if (SyncImagePixels(image) == MagickFalse)
@@ -435,6 +440,9 @@ ModuleExport void UnregisterCINImage(void)
 */
 static MagickBooleanType WriteCINImage(const ImageInfo *image_info,Image *image)
 {
+  char
+    filename[MaxTextExtent];
+
   long
     y;
 
@@ -445,6 +453,9 @@ static MagickBooleanType WriteCINImage(const ImageInfo *image_info,Image *image)
     max_color,
     min_color;
 
+  QuantumInfo
+    quantum_info;
+
   QuantumType
     quantum_type;
 
@@ -477,7 +488,8 @@ static MagickBooleanType WriteCINImage(const ImageInfo *image_info,Image *image)
   if (status == MagickFalse)
     return(status);
   image->depth=10;
-  (void) SetImageColorspace(image,LogColorspace);
+  if (image_info->colorspace == UndefinedColorspace)
+    (void) SetImageColorspace(image,LogColorspace);
   /*
     Compute range for each color component (10-bits).
   */
@@ -526,13 +538,14 @@ static MagickBooleanType WriteCINImage(const ImageInfo *image_info,Image *image)
   (void) WriteBlobLong(image,4*image->columns*image->rows+0x2000);  /* total image file size */
   (void) WriteBlobString(image,"V4.5");  /* version */
   (void) WriteBlobLong(image,0x0);
-  (void) WriteBlobString(image,image->filename);
-  for (i=0 ; i < (long) (100-strlen(image->filename)); i++ )
-    (void) WriteBlobByte(image,0);
+  (void) CopyMagickString(filename,image->filename,100);
+  (void) WriteBlobString(image,filename);
+  for (i=0; i < (long) (100-strlen(filename)); i++)
+    (void) WriteBlobByte(image,'\0');
   (void) WriteBlobString(image,"yyyy:mm:dd  ");  /* creation date. */
   (void) WriteBlobString(image,"hh:mm:ssxxx ");  /* creation time. */
   for (i=0 ; i < 36 ; i++)
-    (void) WriteBlobByte(image,0);
+    (void) WriteBlobByte(image,'\0');
   (void) WriteBlobByte(image,0);  /* 0 left to right top to bottom */
   (void) WriteBlobByte(image,3);  /* 3 channels */
   (void) WriteBlobByte(image,0x0);  /* alignment */
@@ -598,9 +611,9 @@ static MagickBooleanType WriteCINImage(const ImageInfo *image_info,Image *image)
     (void) WriteBlobByte(image,0x00);
   (void) WriteBlobLong(image,0x0);  /* x offset */
   (void) WriteBlobLong(image,0x0);  /* y offset */
-  (void) WriteBlobString(image,image->filename);
-  for (i=0 ; i < (long) (100-strlen(image->filename)); i++ )
-    (void) WriteBlobByte(image,0);
+  (void) WriteBlobString(image,filename);
+  for (i=0; i < (long) (100-strlen(filename)); i++)
+    (void) WriteBlobByte(image,'\0');
   /*
     Date.
   */
@@ -643,6 +656,7 @@ static MagickBooleanType WriteCINImage(const ImageInfo *image_info,Image *image)
   /*
     Convert pixel packets to CIN raster image.
   */
+  GetQuantumInfo(image_info,&quantum_info);
   quantum_type=RGBPadQuantum;
   length=GetBytesPerRow(image->columns,3,image->depth,MagickTrue);
   if (0)
@@ -658,7 +672,7 @@ static MagickBooleanType WriteCINImage(const ImageInfo *image_info,Image *image)
     p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
     if (p == (const PixelPacket *) NULL)
       break;
-    status=ImportQuantumPixels(image,quantum_type,0,pixels);
+    status=ImportQuantumPixels(image,&quantum_info,quantum_type,pixels);
     if (status == MagickFalse)
       break;
     count=WriteBlob(image,length,pixels);
