@@ -52,7 +52,7 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
-#include "magick/pixel.h"
+#include "magick/quantum.h"
 #include "magick/quantum.h"
 #include "magick/static.h"
 #include "magick/statistic.h"
@@ -108,6 +108,9 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
   MagickOffsetType
     offset;
 
+  QuantumInfo
+    quantum_info;
+
   register long
     i;
 
@@ -185,6 +188,7 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
     /*
       Convert raster image to pixel packets.
     */
+    GetQuantumInfo(image_info,&quantum_info);
     image->colorspace=CMYKColorspace;
     if ((image_info->ping != MagickFalse) && (image_info->number_scenes != 0))
       if (image->scene >= (image_info->scene+image_info->number_scenes-1))
@@ -216,9 +220,11 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
           if (q == (PixelPacket *) NULL)
             break;
           if (image->matte == MagickFalse)
-            (void) ExportQuantumPixels(image,CMYKQuantum,0,pixels+offset);
+            (void) ExportQuantumPixels(image,&quantum_info,CMYKQuantum,
+              pixels+offset);
           else
-            (void) ExportQuantumPixels(image,CMYKAQuantum,0,pixels+offset);
+            (void) ExportQuantumPixels(image,&quantum_info,CMYKAQuantum,
+              pixels+offset);
           if (SyncImagePixels(image) == MagickFalse)
             break;
           if (image->previous == (Image *) NULL)
@@ -264,26 +270,31 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
           q=SetImagePixels(image,0,y,image->columns,1);
           if (q == (PixelPacket *) NULL)
             break;
-          (void) ExportQuantumPixels(image,CyanQuantum,0,pixels+offset);
+          (void) ExportQuantumPixels(image,&quantum_info,CyanQuantum,
+            pixels+offset);
           count=ReadBlob(image,packet_size*image->extract_info.width,pixels);
           if (count != (ssize_t) (packet_size*image->extract_info.width))
             break;
-          (void) ExportQuantumPixels(image,MagentaQuantum,0,pixels+offset);
+          (void) ExportQuantumPixels(image,&quantum_info,MagentaQuantum,
+            pixels+offset);
           count=ReadBlob(image,packet_size*image->extract_info.width,pixels);
           if (count != (ssize_t) (packet_size*image->extract_info.width))
             break;
-          (void) ExportQuantumPixels(image,YellowQuantum,0,pixels+offset);
+          (void) ExportQuantumPixels(image,&quantum_info,YellowQuantum,
+            pixels+offset);
           count=ReadBlob(image,packet_size*image->extract_info.width,pixels);
           if (count != (ssize_t) (packet_size*image->extract_info.width))
             break;
-          (void) ExportQuantumPixels(image,BlackQuantum,0,pixels+offset);
+          (void) ExportQuantumPixels(image,&quantum_info,BlackQuantum,
+            pixels+offset);
           if (image->matte != MagickFalse)
             {
               count=ReadBlob(image,packet_size*image->extract_info.width,
                 pixels);
               if (count != (ssize_t) (packet_size*image->extract_info.width))
                 break;
-              (void) ExportQuantumPixels(image,AlphaQuantum,0,pixels+offset);
+              (void) ExportQuantumPixels(image,&quantum_info,AlphaQuantum,
+                pixels+offset);
             }
           if (SyncImagePixels(image) == MagickFalse)
             break;
@@ -346,7 +357,8 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
           q=SetImagePixels(image,0,y,image->columns,1);
           if (q == (PixelPacket *) NULL)
             break;
-          (void) ExportQuantumPixels(image,CyanQuantum,0,pixels+offset);
+          (void) ExportQuantumPixels(image,&quantum_info,CyanQuantum,
+            pixels+offset);
           if (SyncImagePixels(image) == MagickFalse)
             break;
           if (image->previous == (Image *) NULL)
@@ -392,7 +404,8 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
           q=GetImagePixels(image,0,y,image->columns,1);
           if (q == (PixelPacket *) NULL)
             break;
-          (void) ExportQuantumPixels(image,MagentaQuantum,0,pixels+offset);
+          (void) ExportQuantumPixels(image,&quantum_info,MagentaQuantum,
+            pixels+offset);
           if (SyncImagePixels(image) == MagickFalse)
             break;
           if (image->previous == (Image *) NULL)
@@ -438,7 +451,8 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
           q=GetImagePixels(image,0,y,image->columns,1);
           if (q == (PixelPacket *) NULL)
             break;
-          (void) ExportQuantumPixels(image,YellowQuantum,0,pixels+offset);
+          (void) ExportQuantumPixels(image,&quantum_info,YellowQuantum,
+            pixels+offset);
           if (SyncImagePixels(image) == MagickFalse)
             break;
           if (image->previous == (Image *) NULL)
@@ -484,7 +498,8 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
           q=GetImagePixels(image,0,y,image->columns,1);
           if (q == (PixelPacket *) NULL)
             break;
-          (void) ExportQuantumPixels(image,BlackQuantum,0,pixels+offset);
+          (void) ExportQuantumPixels(image,&quantum_info,BlackQuantum,
+            pixels+offset);
           if (SyncImagePixels(image) == MagickFalse)
             break;
           if (image->previous == (Image *) NULL)
@@ -537,7 +552,8 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
               q=GetImagePixels(image,0,y,image->columns,1);
               if (q == (PixelPacket *) NULL)
                 break;
-              (void) ExportQuantumPixels(image,AlphaQuantum,0,pixels+offset);
+              (void) ExportQuantumPixels(image,&quantum_info,AlphaQuantum,
+                pixels+offset);
               if (SyncImagePixels(image) == MagickFalse)
                 break;
               if (image->previous == (Image *) NULL)
@@ -715,6 +731,9 @@ static MagickBooleanType WriteCMYKImage(const ImageInfo *image_info,
   MagickOffsetType
     scene;
 
+  QuantumInfo
+    quantum_info;
+
   register const PixelPacket
     *p;
 
@@ -759,7 +778,9 @@ static MagickBooleanType WriteCMYKImage(const ImageInfo *image_info,
     /*
       Convert MIFF to CMYK raster pixels.
     */
-    (void) SetImageColorspace(image,CMYKColorspace);
+    GetQuantumInfo(image_info,&quantum_info);
+    if (image_info->colorspace == UndefinedColorspace)
+      (void) SetImageColorspace(image,CMYKColorspace);
     if (LocaleCompare(image_info->magick,"CMYKA") == 0)
       if (image->matte == MagickFalse)
         SetImageOpacity(image,OpaqueOpacity);
@@ -778,12 +799,14 @@ static MagickBooleanType WriteCMYKImage(const ImageInfo *image_info,
             break;
           if (LocaleCompare(image_info->magick,"CMYKA") != 0)
             {
-              (void) ImportQuantumPixels(image,CMYKQuantum,0,pixels);
+              (void) ImportQuantumPixels(image,&quantum_info,CMYKQuantum,
+                pixels);
               (void) WriteBlob(image,packet_size*image->columns,pixels);
             }
           else
             {
-              (void) ImportQuantumPixels(image,CMYKAQuantum,0,pixels);
+              (void) ImportQuantumPixels(image,&quantum_info,CMYKAQuantum,
+                pixels);
               (void) WriteBlob(image,packet_size*image->columns,pixels);
             }
           if (image->previous == (Image *) NULL)
@@ -808,17 +831,18 @@ static MagickBooleanType WriteCMYKImage(const ImageInfo *image_info,
           p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
           if (p == (const PixelPacket *) NULL)
             break;
-          (void) ImportQuantumPixels(image,CyanQuantum,0,pixels);
+          (void) ImportQuantumPixels(image,&quantum_info,CyanQuantum,pixels);
           (void) WriteBlob(image,(size_t) image->columns,pixels);
-          (void) ImportQuantumPixels(image,MagentaQuantum,0,pixels);
+          (void) ImportQuantumPixels(image,&quantum_info,MagentaQuantum,pixels);
           (void) WriteBlob(image,(size_t) image->columns,pixels);
-          (void) ImportQuantumPixels(image,YellowQuantum,0,pixels);
+          (void) ImportQuantumPixels(image,&quantum_info,YellowQuantum,pixels);
           (void) WriteBlob(image,(size_t) image->columns,pixels);
-          (void) ImportQuantumPixels(image,BlackQuantum,0,pixels);
+          (void) ImportQuantumPixels(image,&quantum_info,BlackQuantum,pixels);
           (void) WriteBlob(image,(size_t) image->columns,pixels);
           if (LocaleCompare(image_info->magick,"CMYKA") == 0)
             {
-              (void) ImportQuantumPixels(image,AlphaQuantum,0,pixels);
+              (void) ImportQuantumPixels(image,&quantum_info,AlphaQuantum,
+                pixels);
               (void) WriteBlob(image,(size_t) image->columns,pixels);
             }
           if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
@@ -851,7 +875,7 @@ static MagickBooleanType WriteCMYKImage(const ImageInfo *image_info,
           p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
           if (p == (const PixelPacket *) NULL)
             break;
-          (void) ImportQuantumPixels(image,CyanQuantum,0,pixels);
+          (void) ImportQuantumPixels(image,&quantum_info,CyanQuantum,pixels);
           (void) WriteBlob(image,(size_t) image->columns,pixels);
         }
         if (image->progress_monitor != (MagickProgressMonitor) NULL)
@@ -875,7 +899,7 @@ static MagickBooleanType WriteCMYKImage(const ImageInfo *image_info,
           p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
           if (p == (const PixelPacket *) NULL)
             break;
-          (void) ImportQuantumPixels(image,MagentaQuantum,0,pixels);
+          (void) ImportQuantumPixels(image,&quantum_info,MagentaQuantum,pixels);
           (void) WriteBlob(image,(size_t) image->columns,pixels);
         }
         if (image->progress_monitor != (MagickProgressMonitor) NULL)
@@ -899,7 +923,7 @@ static MagickBooleanType WriteCMYKImage(const ImageInfo *image_info,
           p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
           if (p == (const PixelPacket *) NULL)
             break;
-          (void) ImportQuantumPixels(image,YellowQuantum,0,pixels);
+          (void) ImportQuantumPixels(image,&quantum_info,YellowQuantum,pixels);
           (void) WriteBlob(image,(size_t) image->columns,pixels);
         }
         if (image->progress_monitor != (MagickProgressMonitor) NULL)
@@ -923,7 +947,7 @@ static MagickBooleanType WriteCMYKImage(const ImageInfo *image_info,
           p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
           if (p == (const PixelPacket *) NULL)
             break;
-          (void) ImportQuantumPixels(image,BlackQuantum,0,pixels);
+          (void) ImportQuantumPixels(image,&quantum_info,BlackQuantum,pixels);
           (void) WriteBlob(image,(size_t) image->columns,pixels);
         }
         if (LocaleCompare(image_info->magick,"CMYKA") == 0)
@@ -950,7 +974,8 @@ static MagickBooleanType WriteCMYKImage(const ImageInfo *image_info,
                 &image->exception);
               if (p == (const PixelPacket *) NULL)
                 break;
-              (void) ImportQuantumPixels(image,AlphaQuantum,0,pixels);
+              (void) ImportQuantumPixels(image,&quantum_info,AlphaQuantum,
+                pixels);
               (void) WriteBlob(image,(size_t) image->columns,pixels);
             }
           }
