@@ -399,10 +399,10 @@ static Image *ReadCUTImage(const ImageInfo *image_info,ExceptionInfo *exception)
         }
     }
 
-  (void) strcpy(clone_info->filename+i,".PAL");
+  (void) CopyMagickString(clone_info->filename+i,".PAL",MaxTextExtent-i);
   if((clone_info->file=fopen(clone_info->filename,"rb"))==NULL)
     {
-      (void) strcpy(clone_info->filename+i,".pal");
+      (void) CopyMagickString(clone_info->filename+i,".pal",MaxTextExtent-i);
       if((clone_info->file=fopen(clone_info->filename,"rb"))==NULL)
         {
           clone_info->filename[i]='\0';
