@@ -544,7 +544,8 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
     *p;
 
   register long
-    i;
+    i,
+    x;
 
   register PixelPacket
     *q;
@@ -557,7 +558,7 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
 
   unsigned char
     component_type,
-    single[16],
+    single[4],
     *pixels;
 
   unsigned long
@@ -601,7 +602,8 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
   dpx.file.generic_size=ReadBlobLong(image);
   dpx.file.industry_size=ReadBlobLong(image);
   dpx.file.user_size=ReadBlobLong(image);
-  (void) ReadBlob(image,100,(unsigned char *) dpx.file.filename);
+  (void) ReadBlob(image,sizeof(dpx.file.filename),(unsigned char *)
+    dpx.file.filename);
   (void) SetImageAttribute(image,"dpx:file.filename",dpx.file.filename);
   if (*dpx.file.filename != '\0')
     {
@@ -609,25 +611,29 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
         dpx.file.filename);
       (void) FormatImageAttribute(image,"document","%.100s",dpx.file.filename);
     }
-  (void) ReadBlob(image,24,(unsigned char *) dpx.file.timestamp);
+  (void) ReadBlob(image,sizeof(dpx.file.timestamp),(unsigned char *)
+    dpx.file.timestamp);
   if (*dpx.file.timestamp != '\0')
     (void) FormatImageAttribute(image,"dpx:file.tilestamp","%.24s",
       dpx.file.timestamp);
-  (void) ReadBlob(image,100,(unsigned char *) dpx.file.creator);
+  (void) ReadBlob(image,sizeof(dpx.file.creator),(unsigned char *)
+    dpx.file.creator);
   if (*dpx.file.creator != '\0')
     {
       (void) FormatImageAttribute(image,"dpx:file.creator","%.100s",
         dpx.file.creator);
       (void) FormatImageAttribute(image,"software","%.100s",dpx.file.creator);
     }
-  (void) ReadBlob(image,200,(unsigned char *) dpx.file.project);
+  (void) ReadBlob(image,sizeof(dpx.file.project),(unsigned char *)
+    dpx.file.project);
   if (*dpx.file.project != '\0')
     {
       (void) FormatImageAttribute(image,"dpx:file.project","%.200s",
         dpx.file.project);
       (void) FormatImageAttribute(image,"comment","%.100s",dpx.file.project);
     }
-  (void) ReadBlob(image,200,(unsigned char *) dpx.file.copyright);
+  (void) ReadBlob(image,sizeof(dpx.file.copyright),(unsigned char *)
+    dpx.file.copyright);
   if (*dpx.file.copyright != '\0')
     {
       (void) FormatImageAttribute(image,"dpx:file.copyright","%.200s",
@@ -639,7 +645,8 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
   if (dpx.file.encrypt_key != (unsigned long) (~0))
     (void) FormatImageAttribute(image,"dpx:file.encrypt_key","%lu",
       dpx.file.encrypt_key);
-  (void) ReadBlob(image,104,(unsigned char *) dpx.file.reserve);
+  (void) ReadBlob(image,sizeof(dpx.file.reserve),(unsigned char *)
+    dpx.file.reserve);
   /*
     Read DPX image header.
   */
@@ -668,10 +675,10 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
   {
     dpx.image.image_element[i].data_sign=ReadBlobLong(image);
     dpx.image.image_element[i].low_data=ReadBlobLong(image);
-    (void) ReadBlob(image,4,single);
+    (void) ReadBlob(image,sizeof(single),single);
     dpx.image.image_element[i].low_quantity=((float *) single)[0];
     dpx.image.image_element[i].high_data=ReadBlobLong(image);
-    (void) ReadBlob(image,4,single);
+    (void) ReadBlob(image,sizeof(single),single);
     dpx.image.image_element[i].high_quantity=((float *) single)[0];
     dpx.image.image_element[i].descriptor=(unsigned char) ReadBlobByte(image);
     dpx.image.image_element[i].transfer=(unsigned char) ReadBlobByte(image);
@@ -682,121 +689,152 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
     dpx.image.image_element[i].data_offset=ReadBlobLong(image);
     dpx.image.image_element[i].end_of_line_padding=ReadBlobLong(image);
     dpx.image.image_element[i].end_of_image_padding=ReadBlobLong(image);
-    (void) ReadBlob(image,32,(unsigned char *)
-      dpx.image.image_element[i].description);
+    (void) ReadBlob(image,sizeof(dpx.image.image_element[i].description),
+      (unsigned char *) dpx.image.image_element[i].description);
   }
   SetPrimaryChromaticity((DPXColorimetric)
     dpx.image.image_element[0].colorimetric,&image->chromaticity);
-  (void) ReadBlob(image,52,(unsigned char *) dpx.image.reserve);
+  (void) ReadBlob(image,sizeof(dpx.image.reserve),(unsigned char *)
+    dpx.image.reserve);
   component_type=dpx.image.image_element[0].descriptor;
   image->depth=dpx.image.image_element[0].bit_size;
-  /*
-    Read DPX orientation header.
-  */
-  dpx.orientation.x_offset=ReadBlobLong(image);
-  dpx.orientation.y_offset=ReadBlobLong(image);
-  (void) ReadBlob(image,4,single);
-  dpx.orientation.x_center=((float *) single)[0];
-  (void) ReadBlob(image,4,single);
-  dpx.orientation.y_center=((float *) single)[0];
-  dpx.orientation.x_size=ReadBlobLong(image);
-  dpx.orientation.y_size=ReadBlobLong(image);
-  (void) ReadBlob(image,100,(unsigned char *) dpx.orientation.filename);
-  if (*dpx.orientation.filename != '\0')
-    (void) FormatImageAttribute(image,"dpx:orientation.copyright","%.100s",
-      dpx.orientation.filename);
-  (void) ReadBlob(image,24,(unsigned char *) dpx.orientation.timestamp);
-  if (*dpx.orientation.timestamp != '\0')
-    (void) FormatImageAttribute(image,"dpx:orientation.timestamp","%.24s",
-      dpx.orientation.timestamp);
-  (void) ReadBlob(image,32,(unsigned char *) dpx.orientation.device);
-  if (*dpx.orientation.device != '\0')
-    (void) FormatImageAttribute(image,"dpx:orientation.device","%.32s",
-      dpx.orientation.device);
-  (void) ReadBlob(image,32,(unsigned char *) dpx.orientation.serial);
-  if (*dpx.orientation.serial != '\0')
-    (void) FormatImageAttribute(image,"dpx:orientation.serial","%.32s",
-      dpx.orientation.serial);
-  for (i=0; i < 4; i++)
-    dpx.orientation.border[i]=ReadBlobShort(image);
-  for (i=0; i < 2; i++)
-    dpx.orientation.aspect_ratio[i]=ReadBlobLong(image);
-  (void) ReadBlob(image,28,(unsigned char *) dpx.orientation.reserve);
-  /*
-    Read DPX film header.
-  */
-  (void) ReadBlob(image,2,(unsigned char *) dpx.film.id);
-  if (*dpx.film.type != '\0')
-    (void) FormatImageAttribute(image,"dpx:film.id","%.2s",dpx.film.id);
-  (void) ReadBlob(image,2,(unsigned char *) dpx.film.type);
-  if (*dpx.film.type != '\0')
-    (void) FormatImageAttribute(image,"dpx:film.type","%.2s",dpx.film.type);
-  (void) ReadBlob(image,2,(unsigned char *) dpx.film.offset);
-  if (*dpx.film.offset != '\0')
-    (void) FormatImageAttribute(image,"dpx:film.offset","%.2s",dpx.film.offset);
-  (void) ReadBlob(image,6,(unsigned char *) dpx.film.prefix);
-  if (*dpx.film.prefix != '\0')
-    (void) FormatImageAttribute(image,"dpx:film.prefix","%.6s",dpx.film.prefix);
-  (void) ReadBlob(image,4,(unsigned char *) dpx.film.count);
-  if (*dpx.film.count != '\0')
-    (void) FormatImageAttribute(image,"dpx:film.count","%.4s",dpx.film.count);
-  (void) ReadBlob(image,32,(unsigned char *) dpx.film.format);
-  if (*dpx.film.format != '\0')
-    (void) FormatImageAttribute(image,"dpx:film.format","%.4s",dpx.film.format);
-  dpx.film.frame_position=ReadBlobLong(image);
-  dpx.film.sequence_length=ReadBlobLong(image);
-  dpx.film.held_count=ReadBlobLong(image);
-  (void) ReadBlob(image,4,single);
-  dpx.film.frame_rate=((float *) single)[0];
-  (void) ReadBlob(image,4,single);
-  dpx.film.shutter_angle=((float *) single)[0];
-  (void) ReadBlob(image,32,(unsigned char *) dpx.film.frame_id);
-  if (*dpx.film.frame_id != '\0')
-    (void) FormatImageAttribute(image,"dpx:film.frame_id","%.32s",
-      dpx.film.frame_id);
-  (void) ReadBlob(image,100,(unsigned char *) dpx.film.slate);
-  if (*dpx.film.slate != '\0')
-    (void) FormatImageAttribute(image,"dpx:film.slate","%.100s",
-      dpx.film.slate);
-  (void) ReadBlob(image,56,(unsigned char *) dpx.film.reserve);
-  /*
-    Read DPX televison header.
-  */
-  dpx.television.time_code=ReadBlobLong(image);
-  TimeCodeToString(dpx.television.time_code,value);
-  (void) SetImageAttribute(image,"dpx:television.time.code",value);
-  dpx.television.user_bits=(unsigned char) ReadBlobLong(image);
-  dpx.television.interlace=(unsigned char) ReadBlobByte(image);
-  dpx.television.field_number=(unsigned char) ReadBlobByte(image);
-  dpx.television.video_signal=(unsigned char) ReadBlobByte(image);
-  dpx.television.padding=(unsigned char) ReadBlobByte(image);
-  (void) ReadBlob(image,4,single);
-  dpx.television.horizontal_sample_rate=((float *) single)[0];
-  (void) ReadBlob(image,4,single);
-  dpx.television.vertical_sample_rate=((float *) single)[0];
-  (void) ReadBlob(image,4,single);
-  dpx.television.frame_rate=((float *) single)[0];
-  (void) ReadBlob(image,4,single);
-  dpx.television.time_offset=((float *) single)[0];
-  (void) ReadBlob(image,4,single);
-  dpx.television.gamma=((float *) single)[0];
-  (void) ReadBlob(image,4,single);
-  dpx.television.black_level=((float *) single)[0];
-  (void) ReadBlob(image,4,single);
-  dpx.television.black_gain=((float *) single)[0];
-  (void) ReadBlob(image,4,single);
-  dpx.television.break_point=((float *) single)[0];
-  (void) ReadBlob(image,4,single);
-  dpx.television.white_level=((float *) single)[0];
-  (void) ReadBlob(image,4,single);
-  dpx.television.integration_times=((float *) single)[0];
-  (void) ReadBlob(image,76,(unsigned char *) dpx.television.reserve);
-  /*
-    Read DPX user header.
-  */
-  (void) ReadBlob(image,32,(unsigned char *) dpx.user.id);
-  if (*dpx.user.id != '\0')
-    (void) FormatImageAttribute(image,"dpx:user.id","%.32s",dpx.user.id);
+  if (dpx.file.image_offset >= 1664UL)
+    {
+      /*
+        Read DPX orientation header.
+      */
+      dpx.orientation.x_offset=ReadBlobLong(image);
+      dpx.orientation.y_offset=ReadBlobLong(image);
+      (void) ReadBlob(image,sizeof(single),single);
+      dpx.orientation.x_center=((float *) single)[0];
+      (void) ReadBlob(image,sizeof(single),single);
+      dpx.orientation.y_center=((float *) single)[0];
+      dpx.orientation.x_size=ReadBlobLong(image);
+      dpx.orientation.y_size=ReadBlobLong(image);
+      (void) ReadBlob(image,sizeof(dpx.orientation.filename),(unsigned char *)
+        dpx.orientation.filename);
+      if (*dpx.orientation.filename != '\0')
+        (void) FormatImageAttribute(image,"dpx:orientation.filename","%.100s",
+          dpx.orientation.filename);
+      (void) ReadBlob(image,sizeof(dpx.orientation.timestamp),(unsigned char *)
+        dpx.orientation.timestamp);
+      if (*dpx.orientation.timestamp != '\0')
+        (void) FormatImageAttribute(image,"dpx:orientation.timestamp","%.24s",
+          dpx.orientation.timestamp);
+      (void) ReadBlob(image,sizeof(dpx.orientation.device),(unsigned char *)
+        dpx.orientation.device);
+      if (*dpx.orientation.device != '\0')
+        (void) FormatImageAttribute(image,"dpx:orientation.device","%.32s",
+          dpx.orientation.device);
+      (void) ReadBlob(image,sizeof(dpx.orientation.serial),(unsigned char *)
+        dpx.orientation.serial);
+      if (*dpx.orientation.serial != '\0')
+        (void) FormatImageAttribute(image,"dpx:orientation.serial","%.32s",
+          dpx.orientation.serial);
+      for (i=0; i < 4; i++)
+        dpx.orientation.border[i]=ReadBlobShort(image);
+      for (i=0; i < 2; i++)
+        dpx.orientation.aspect_ratio[i]=ReadBlobLong(image);
+      (void) ReadBlob(image,sizeof(dpx.orientation.reserve),(unsigned char *)
+        dpx.orientation.reserve);
+    }
+  if (dpx.file.image_offset >= 1920UL)
+    {
+      /*
+        Read DPX film header.
+      */
+      (void) ReadBlob(image,sizeof(dpx.film.id),(unsigned char *) dpx.film.id);
+      if (*dpx.film.type != '\0')
+        (void) FormatImageAttribute(image,"dpx:film.id","%.2s",dpx.film.id);
+      (void) ReadBlob(image,sizeof(dpx.film.type),(unsigned char *)
+        dpx.film.type);
+      if (*dpx.film.type != '\0')
+        (void) FormatImageAttribute(image,"dpx:film.type","%.2s",dpx.film.type);
+      (void) ReadBlob(image,sizeof(dpx.film.offset),(unsigned char *)
+        dpx.film.offset);
+      if (*dpx.film.offset != '\0')
+        (void) FormatImageAttribute(image,"dpx:film.offset","%.2s",
+          dpx.film.offset);
+      (void) ReadBlob(image,sizeof(dpx.film.prefix),(unsigned char *)
+        dpx.film.prefix);
+      if (*dpx.film.prefix != '\0')
+        (void) FormatImageAttribute(image,"dpx:film.prefix","%.6s",
+          dpx.film.prefix);
+      (void) ReadBlob(image,sizeof(dpx.film.count),(unsigned char *)
+        dpx.film.count);
+      if (*dpx.film.count != '\0')
+        (void) FormatImageAttribute(image,"dpx:film.count","%.4s",
+          dpx.film.count);
+      (void) ReadBlob(image,sizeof(dpx.film.format),(unsigned char *)
+        dpx.film.format);
+      if (*dpx.film.format != '\0')
+        (void) FormatImageAttribute(image,"dpx:film.format","%.4s",
+          dpx.film.format);
+      dpx.film.frame_position=ReadBlobLong(image);
+      dpx.film.sequence_length=ReadBlobLong(image);
+      dpx.film.held_count=ReadBlobLong(image);
+      (void) ReadBlob(image,sizeof(single),single);
+      dpx.film.frame_rate=((float *) single)[0];
+      (void) ReadBlob(image,sizeof(single),single);
+      dpx.film.shutter_angle=((float *) single)[0];
+      (void) ReadBlob(image,sizeof(dpx.film.frame_id),(unsigned char *)
+        dpx.film.frame_id);
+      if (*dpx.film.frame_id != '\0')
+        (void) FormatImageAttribute(image,"dpx:film.frame_id","%.32s",
+          dpx.film.frame_id);
+      (void) ReadBlob(image,sizeof(dpx.film.slate),(unsigned char *)
+        dpx.film.slate);
+      if (*dpx.film.slate != '\0')
+        (void) FormatImageAttribute(image,"dpx:film.slate","%.100s",
+          dpx.film.slate);
+      (void) ReadBlob(image,sizeof(dpx.film.reserve),(unsigned char *)
+        dpx.film.reserve);
+    }
+  if (dpx.file.image_offset >= 2048UL)
+    {
+      /*
+        Read DPX television header.
+      */
+      dpx.television.time_code=ReadBlobLong(image);
+      TimeCodeToString(dpx.television.time_code,value);
+      (void) SetImageAttribute(image,"dpx:television.time.code",value);
+      dpx.television.user_bits=(unsigned char) ReadBlobLong(image);
+      dpx.television.interlace=(unsigned char) ReadBlobByte(image);
+      dpx.television.field_number=(unsigned char) ReadBlobByte(image);
+      dpx.television.video_signal=(unsigned char) ReadBlobByte(image);
+      dpx.television.padding=(unsigned char) ReadBlobByte(image);
+      (void) ReadBlob(image,sizeof(single),single);
+      dpx.television.horizontal_sample_rate=((float *) single)[0];
+      (void) ReadBlob(image,sizeof(single),single);
+      dpx.television.vertical_sample_rate=((float *) single)[0];
+      (void) ReadBlob(image,sizeof(single),single);
+      dpx.television.frame_rate=((float *) single)[0];
+      (void) ReadBlob(image,sizeof(single),single);
+      dpx.television.time_offset=((float *) single)[0];
+      (void) ReadBlob(image,sizeof(single),single);
+      dpx.television.gamma=((float *) single)[0];
+      (void) ReadBlob(image,sizeof(single),single);
+      dpx.television.black_level=((float *) single)[0];
+      (void) ReadBlob(image,sizeof(single),single);
+      dpx.television.black_gain=((float *) single)[0];
+      (void) ReadBlob(image,sizeof(single),single);
+      dpx.television.break_point=((float *) single)[0];
+      (void) ReadBlob(image,sizeof(single),single);
+      dpx.television.white_level=((float *) single)[0];
+      (void) ReadBlob(image,sizeof(single),single);
+      dpx.television.integration_times=((float *) single)[0];
+      (void) ReadBlob(image,sizeof(dpx.television.reserve),(unsigned char *)
+        dpx.television.reserve);
+    }
+  if (dpx.file.image_offset >= 2080UL)
+    {
+      /*
+        Read DPX user header.
+      */
+      (void) ReadBlob(image,sizeof(dpx.user.id),(unsigned char *) dpx.user.id);
+      if (*dpx.user.id != '\0')
+        (void) FormatImageAttribute(image,"dpx:user.id","%.32s",dpx.user.id);
+    }
   /*
     Read DPX image header.
   */
@@ -858,29 +896,90 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
   pixels=(unsigned char *) AcquireMagickMemory(length);
   if (pixels == (unsigned char *) NULL)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
-  for (y=0; y < (long) image->rows; y++)
-  {
-    q=SetImagePixels(image,0,y,image->columns,1);
-    if (q == (PixelPacket *) NULL)
-      break;
-    p=ReadBlobStream(image,length,pixels,&count);
-    if ((size_t) count != length)
-      break;
-    status=ExportQuantumPixels(image,&quantum_info,quantum_type,p);
-    if (status == MagickFalse)
-      break;
-    if (SyncImagePixels(image) == MagickFalse)
-      break;
-    if (image->previous == (Image *) NULL)
-      if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-          (QuantumTick(y,image->rows) != MagickFalse))
+  if ((quantum_type == GrayPadQuantum) && (image->depth == 10))
+    {
+      unsigned long
+        pixel;
+
+      /*
+        Cineon 10-bit pixel format.
+      */
+      pixel=0UL;
+      i=0;
+      for (y=0; y < (long) image->rows; y++)
+      {
+        q=SetImagePixels(image,0,y,image->columns,1);
+        if (q == (PixelPacket *) NULL)
+          break;
+        for (x=0; x < (long) image->columns; x++)
         {
-          status=image->progress_monitor(LoadImageTag,y,image->rows,
-            image->client_data);
-          if (status == MagickFalse)
-            break;
+          switch (i % 3)
+          {
+            case 0:
+            {
+              pixel=ReadBlobMSBLong(image);
+              q->red=(Quantum) ((MagickRealType) QuantumRange*((pixel >> 0) &
+                0x3ff)/1023+0.5);
+              break;
+            }
+            case 1:
+            {
+              q->red=(Quantum) ((MagickRealType) QuantumRange*((pixel >> 10) &
+                0x3ff)/1023+0.5);
+              break;
+            }
+            case 2:
+            {
+              q->red=(Quantum) ((MagickRealType) QuantumRange*((pixel >> 20) &
+                0x3ff)/1023+0.5);
+              break;
+            }
+          }
+          q->green=q->red;
+          q->blue=q->red;
+          q++;
+          i++;
         }
-  }
+        if (SyncImagePixels(image) == MagickFalse)
+          break;
+        if (image->previous == (Image *) NULL)
+          if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
+              (QuantumTick(y,image->rows) != MagickFalse))
+            {
+              status=image->progress_monitor(LoadImageTag,y,image->rows,
+                image->client_data);
+              if (status == MagickFalse)
+                break;
+            }
+      }
+    }
+  else
+    for (y=0; y < (long) image->rows; y++)
+    {
+      /*
+        DPX any-bit pixel format.
+      */
+      q=SetImagePixels(image,0,y,image->columns,1);
+      if (q == (PixelPacket *) NULL)
+        break;
+      p=ReadBlobStream(image,length,pixels,&count);
+      if ((size_t) count != length)
+        break;
+      status=ExportQuantumPixels(image,&quantum_info,quantum_type,p);
+      if (status == MagickFalse)
+        break;
+      if (SyncImagePixels(image) == MagickFalse)
+        break;
+      if (image->previous == (Image *) NULL)
+        if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
+            (QuantumTick(y,image->rows) != MagickFalse))
+          {
+            status=image->progress_monitor(LoadImageTag,y,image->rows,
+              image->client_data);
+            if (status == MagickFalse)
+              break;
+          }
+    }
   pixels=(unsigned char *) RelinquishMagickMemory(pixels);
   if (EOFBlob(image))
     ThrowFileException(exception,CorruptImageError,"UnexpectedEndOfFile",
@@ -997,6 +1096,9 @@ static MagickBooleanType WriteDPXImage(const ImageInfo *image_info,Image *image)
   MagickBooleanType
     status;
 
+  MagickOffsetType
+    offset;
+
   QuantumInfo
     quantum_info;
 
@@ -1033,7 +1135,7 @@ static MagickBooleanType WriteDPXImage(const ImageInfo *image_info,Image *image)
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
-  (void) ResetMagickMemory(&dpx.file,0,sizeof(dpx.file));
+  (void) ResetMagickMemory(&dpx,0,sizeof(dpx));
   if (image_info->colorspace == UndefinedColorspace)
     (void) SetImageColorspace(image,LogColorspace);
   /*
@@ -1056,24 +1158,33 @@ static MagickBooleanType WriteDPXImage(const ImageInfo *image_info,Image *image)
   dpx.file.user_size=0x00001800UL;
   (void) WriteBlobLong(image,dpx.file.user_size);
   (void) CopyMagickString(dpx.file.filename,"V2.0",sizeof(dpx.file.filename));
-  (void) WriteBlob(image,100,(unsigned char *) dpx.file.filename);
+  (void) WriteBlob(image,sizeof(dpx.file.filename),(unsigned char *)
+    dpx.file.filename);
   seconds=time((time_t *) NULL);
-  (void) FormatMagickTime(seconds,24,dpx.file.timestamp);
-  (void) WriteBlob(image,24,(unsigned char *) dpx.file.timestamp);
-  (void) CopyMagickString(dpx.file.creator,
-    GetMagickVersion((unsigned long *) NULL),100);
-  (void) WriteBlob(image,100,(unsigned char *) dpx.file.creator);
+  (void) FormatMagickTime(seconds,sizeof(dpx.file.timestamp),
+    dpx.file.timestamp);
+  (void) WriteBlob(image,sizeof(dpx.file.timestamp),(unsigned char *)
+    dpx.file.timestamp);
+  (void) CopyMagickString(dpx.file.creator,GetMagickVersion((unsigned long *)
+    NULL),sizeof(dpx.file.creator));
+  (void) WriteBlob(image,sizeof(dpx.file.creator),(unsigned char *)
+    dpx.file.creator);
   attribute=GetImageAttribute(image,"dpx:file.project");
   if (attribute != (const ImageAttribute *) NULL)
-    (void) CopyMagickString(dpx.file.project,attribute->value,200);
-  (void) WriteBlob(image,200,(unsigned char *) dpx.file.project);
+    (void) CopyMagickString(dpx.file.project,attribute->value,
+      sizeof(dpx.file.project));
+  (void) WriteBlob(image,sizeof(dpx.file.project),(unsigned char *)
+    dpx.file.project);
   attribute=GetImageAttribute(image,"dpx:file.copyright");
   if (attribute != (const ImageAttribute *) NULL)
-    (void) CopyMagickString(dpx.file.copyright,attribute->value,200);
-  (void) WriteBlob(image,200,(unsigned char *) dpx.file.copyright);
+    (void) CopyMagickString(dpx.file.copyright,attribute->value,
+      sizeof(dpx.file.copyright));
+  (void) WriteBlob(image,sizeof(dpx.file.copyright),(unsigned char *)
+    dpx.file.copyright);
   dpx.file.encrypt_key=(~0UL);
   (void) WriteBlobLong(image,dpx.file.encrypt_key);
-  (void) WriteBlob(image,104,(unsigned char *) dpx.file.reserve);
+  (void) WriteBlob(image,sizeof(dpx.file.reserve),(unsigned char *)
+    dpx.file.reserve);
   /*
     Write image header.
   */
@@ -1083,20 +1194,20 @@ static MagickBooleanType WriteDPXImage(const ImageInfo *image_info,Image *image)
   (void) WriteBlobShort(image,dpx.image.number_elements);
   (void) WriteBlobLong(image,image->columns);
   (void) WriteBlobLong(image,image->rows);
-  for (i=0; i < 15; i++)
+  for (i=0; i < 8; i++)
   {
     dpx.image.image_element[i].data_sign=0UL;
     (void) WriteBlobLong(image,dpx.image.image_element[i].data_sign);
     dpx.image.image_element[i].low_data=0UL;
     (void) WriteBlobLong(image,dpx.image.image_element[i].low_data);
     dpx.image.image_element[i].low_quantity=0.0f;
-    (void) WriteBlob(image,4,(unsigned char *) &
-      dpx.image.image_element[i].low_quantity);
+    (void) WriteBlob(image,4,(unsigned char *)
+      &dpx.image.image_element[i].low_quantity);
     dpx.image.image_element[i].high_data=0UL;
     (void) WriteBlobLong(image,dpx.image.image_element[i].high_data);
     dpx.image.image_element[i].high_quantity=0.0f;
-    (void) WriteBlob(image,4,(unsigned char *) &
-      dpx.image.image_element[i].high_quantity);
+    (void) WriteBlob(image,4,(unsigned char *)
+      &dpx.image.image_element[i].high_quantity);
     dpx.image.image_element[i].descriptor=0;
     if (i == 0)
       dpx.image.image_element[i].descriptor=RGBComponentType;
@@ -1119,10 +1230,12 @@ static MagickBooleanType WriteDPXImage(const ImageInfo *image_info,Image *image)
     (void) WriteBlobLong(image,dpx.image.image_element[i].data_offset);
     dpx.image.image_element[i].end_of_line_padding=0UL;
     (void) WriteBlobLong(image,dpx.image.image_element[i].end_of_line_padding);
-    (void) WriteBlob(image,32,(unsigned char *)
-      dpx.image.image_element[i].description);
+    (void) WriteBlobLong(image,dpx.image.image_element[i].end_of_image_padding);
+    (void) WriteBlob(image,sizeof(dpx.image.image_element[i].description),
+      (unsigned char *) dpx.image.image_element[i].description);
   }
-  (void) WriteBlob(image,52,(unsigned char *) dpx.image.reserve);
+  (void) WriteBlob(image,sizeof(dpx.image.reserve),(unsigned char *)
+    dpx.image.reserve);
   /*
     Write orientation header.
   */
@@ -1138,10 +1251,18 @@ static MagickBooleanType WriteDPXImage(const ImageInfo *image_info,Image *image)
   (void) WriteBlobLong(image,dpx.orientation.x_size);
   dpx.orientation.y_size=0UL;
   (void) WriteBlobLong(image,dpx.orientation.y_size);
-  (void) WriteBlob(image,100,(unsigned char *) dpx.orientation.filename);
-  (void) WriteBlob(image,24,(unsigned char *) dpx.orientation.timestamp);
-  (void) WriteBlob(image,32,(unsigned char *) dpx.orientation.device);
-  (void) WriteBlob(image,32,(unsigned char *) dpx.orientation.serial);
+  attribute=GetImageAttribute(image,"dpx:orientation.filename");
+  if (attribute != (const ImageAttribute *) NULL)
+    (void) CopyMagickString(dpx.orientation.filename,attribute->value,
+      sizeof(dpx.orientation.filename));
+  (void) WriteBlob(image,sizeof(dpx.orientation.filename),(unsigned char *)
+    dpx.orientation.filename);
+  (void) WriteBlob(image,sizeof(dpx.orientation.timestamp),(unsigned char *)
+    dpx.orientation.timestamp);
+  (void) WriteBlob(image,sizeof(dpx.orientation.device),(unsigned char *)
+    dpx.orientation.device);
+  (void) WriteBlob(image,sizeof(dpx.orientation.serial),(unsigned char *)
+    dpx.orientation.serial);
   for (i=0; i < 4; i++)
   {
     dpx.orientation.border[i]=0UL;
@@ -1152,8 +1273,61 @@ static MagickBooleanType WriteDPXImage(const ImageInfo *image_info,Image *image)
     dpx.orientation.aspect_ratio[i]=0UL;
     (void) WriteBlobLong(image,dpx.orientation.aspect_ratio[i]);
   }
-  (void) WriteBlob(image,28,(unsigned char *) dpx.orientation.reserve);
-  for (i=0; i < (0x2000-2108); i++)
+  (void) WriteBlob(image,sizeof(dpx.orientation.reserve),(unsigned char *)
+    dpx.orientation.reserve);
+  /*
+    Write film header.
+  */
+  (void) WriteBlob(image,sizeof(dpx.film.id),(unsigned char *) dpx.film.id);
+  (void) WriteBlob(image,sizeof(dpx.film.type),(unsigned char *) dpx.film.type);
+  (void) WriteBlob(image,sizeof(dpx.film.offset),(unsigned char *)
+    dpx.film.offset);
+  (void) WriteBlob(image,sizeof(dpx.film.prefix),(unsigned char *)
+    dpx.film.prefix);
+  (void) WriteBlob(image,sizeof(dpx.film.count),(unsigned char *)
+    dpx.film.count);
+  (void) WriteBlob(image,sizeof(dpx.film.format),(unsigned char *)
+    dpx.film.format);
+  (void) WriteBlobLong(image,dpx.film.frame_position);
+  (void) WriteBlobLong(image,dpx.film.sequence_length);
+  (void) WriteBlobLong(image,dpx.film.held_count);
+  (void) WriteBlob(image,4,(unsigned char *) &dpx.film.frame_rate);
+  (void) WriteBlob(image,4,(unsigned char *) &dpx.film.shutter_angle);
+  (void) WriteBlob(image,sizeof(dpx.film.frame_id),(unsigned char *)
+    dpx.film.frame_id);
+  (void) WriteBlob(image,sizeof(dpx.film.slate),(unsigned char *)
+    dpx.film.slate);
+  (void) WriteBlob(image,sizeof(dpx.film.reserve),(unsigned char *)
+    dpx.film.reserve);
+  /*
+    Write television header.
+  */
+  (void) WriteBlobLong(image,dpx.television.time_code);
+  (void) WriteBlobLong(image,dpx.television.user_bits);
+  (void) WriteBlobByte(image,dpx.television.interlace);
+  (void) WriteBlobByte(image,dpx.television.field_number);
+  (void) WriteBlobByte(image,dpx.television.video_signal);
+  (void) WriteBlobByte(image,dpx.television.padding);
+  (void) WriteBlob(image,4,(unsigned char *)
+    &dpx.television.horizontal_sample_rate);
+  (void) WriteBlob(image,4,(unsigned char *)
+    &dpx.television.vertical_sample_rate);
+  (void) WriteBlob(image,4,(unsigned char *) &dpx.television.frame_rate);
+  (void) WriteBlob(image,4,(unsigned char *) &dpx.television.time_offset);
+  (void) WriteBlob(image,4,(unsigned char *) &dpx.television.gamma);
+  (void) WriteBlob(image,4,(unsigned char *) &dpx.television.black_level);
+  (void) WriteBlob(image,4,(unsigned char *) &dpx.television.black_gain);
+  (void) WriteBlob(image,4,(unsigned char *) &dpx.television.break_point);
+  (void) WriteBlob(image,4,(unsigned char *) &dpx.television.white_level);
+  (void) WriteBlob(image,4,(unsigned char *) &dpx.television.integration_times);
+  (void) WriteBlob(image,sizeof(dpx.television.reserve),(unsigned char *)
+    dpx.television.reserve);
+  /*
+    Write user header.
+  */
+  (void) WriteBlob(image,sizeof(dpx.user.id),(unsigned char *) dpx.user.id);
+  offset=TellBlob(image);
+  for (i=0; i < (0x2000-offset); i++)
     (void) WriteBlobByte(image,0x00);
   /*
     Convert pixel packets to DPX raster image.
