@@ -370,9 +370,9 @@ static MagickBooleanType WriteEPTImage(const ImageInfo *image_info,Image *image)
   write_image=CloneImage(image,0,0,MagickTrue,&image->exception);
   if (write_image == (Image *) NULL)
     return(MagickFalse);
-  write_info=CloneImageInfo(image_info);
   DestroyBlob(write_image);
   write_image->blob=CloneBlobInfo((BlobInfo *) NULL);
+  write_info=CloneImageInfo(image_info);
   (void) CopyMagickString(write_info->magick,"EPS",MaxTextExtent);
   if (LocaleCompare(image_info->magick,"EPT2") == 0)
     (void) CopyMagickString(write_info->magick,"EPS2",MaxTextExtent);
@@ -382,14 +382,16 @@ static MagickBooleanType WriteEPTImage(const ImageInfo *image_info,Image *image)
   ept_info.magick=0xc6d3d0c5ul;
   ept_info.postscript=(unsigned char *) ImageToBlob(write_info,write_image,
     &ept_info.postscript_length,&image->exception);
+  write_image=DestroyImage(write_image);
+  write_info=DestroyImageInfo(write_info);
   if (ept_info.postscript == (void *) NULL)
-    {
-      write_image=DestroyImage(write_image);
-      write_info=DestroyImageInfo(write_info);
-      return(MagickFalse);
-    }
+    return(MagickFalse);
+  write_image=CloneImage(image,0,0,MagickTrue,&image->exception);
+  if (write_image == (Image *) NULL)
+    return(MagickFalse);
   DestroyBlob(write_image);
   write_image->blob=CloneBlobInfo((BlobInfo *) NULL);
+  write_info=CloneImageInfo(image_info);
   (void) CopyMagickString(write_info->magick,"TIFF",MaxTextExtent);
   FormatMagickString(write_info->filename,MaxTextExtent,"tiff:%.1024s",
     write_info->filename); 
@@ -415,8 +417,8 @@ static MagickBooleanType WriteEPTImage(const ImageInfo *image_info,Image *image)
   write_info=DestroyImageInfo(write_info);
   if (ept_info.tiff == (void *) NULL)
     {
-      ept_info.postscript=(unsigned char *)
-        RelinquishMagickMemory(ept_info.postscript);
+      ept_info.postscript=(unsigned char *) RelinquishMagickMemory(
+        ept_info.postscript);
       return(MagickFalse);
     }
   /*
@@ -435,8 +437,8 @@ static MagickBooleanType WriteEPTImage(const ImageInfo *image_info,Image *image)
   /*
     Relinquish resources.
   */
-  ept_info.postscript=(unsigned char *)
-    RelinquishMagickMemory(ept_info.postscript);
+  ept_info.postscript=(unsigned char *) RelinquishMagickMemory(
+    ept_info.postscript);
   ept_info.tiff=(unsigned char *) RelinquishMagickMemory(ept_info.tiff);
   CloseBlob(image);
   return(MagickTrue);
