@@ -59,6 +59,7 @@
 #include "magick/static.h"
 #include "magick/statistic.h"
 #include "magick/string_.h"
+#include "magick/version.h"
 
 /*
   Forward declarations.
@@ -162,7 +163,7 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
     exponential[2048],
     pixel,
     scale,
-    scaled_pixel;
+    scale_pixel;
 
   FITSInfo
     fits_info;
@@ -376,8 +377,8 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
     if ((packet_size*number_pixels) !=
         (MagickSizeType) ((size_t) (packet_size*number_pixels)))
       ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
-    fits_pixels=(unsigned char *)
-      AcquireMagickMemory(packet_size*image->columns*image->rows);
+    fits_pixels=(unsigned char *) AcquireMagickMemory(packet_size*
+      image->columns*image->rows*sizeof(*fits_pixels));
     if (fits_pixels == (unsigned char *) NULL)
       ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
     /*
@@ -386,9 +387,11 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
     count=ReadBlob(image,packet_size*image->columns*image->rows,fits_pixels);
     if (count != (ssize_t) (packet_size*image->columns*image->rows))
       ThrowReaderException(CorruptImageError,"InsufficientImageDataInFile");
-    if ((fits_info.bits_per_pixel > 0) &&
-        (fits_info.min_data == 0.0) && (fits_info.max_data == 0.0))
-      fits_info.max_data=(1UL << fits_info.bits_per_pixel)-1;
+    if ((fits_info.min_data != 0.0) || (fits_info.max_data != 0.0))
+      {
+        if ((fits_info.bits_per_pixel != 0) && (fits_info.max_data == 0.0))
+          fits_info.max_data=(1UL << fits_info.bits_per_pixel)-1;
+      }
     else
       {
         /*
@@ -403,36 +406,37 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
           quantum=(quantum << 8) | (*p++);
         }
         pixel=(double) quantum;
+        if (fits_info.bits_per_pixel == 16)
+          if (pixel > 32767)
+            pixel-=65536L;
         if (fits_info.bits_per_pixel == -32)
           {
             j=((long) long_quantum[1] << 16) | ((long) long_quantum[2] << 8) |
                (long) long_quantum[3];
             k=(int) *long_quantum;
-            exponent=((k & 127) << 1) | (j >> 23);
+            exponent=((k & 0x7f) << 1) | (j >> 23);
             *(float *) long_quantum=
               exponential[exponent]*(float) (j | 0x800000);
             if ((exponent | j) == 0)
               *(float *) long_quantum=0.0;
-            if (k & 128)
+            if (k & 0x7f)
               *(float *) long_quantum=(-(*(float *) long_quantum));
             pixel=(double) (*((float *) long_quantum));
           }
         if (fits_info.bits_per_pixel == -64)
           {
-            j=((long) long_quantum[1] << 24) |
-              ((long) long_quantum[2] << 16) |
-              ((long) long_quantum[3] << 8) |
-               (long) long_quantum[4];
+            j=((long) long_quantum[1] << 24) | ((long) long_quantum[2] << 16) |
+              ((long) long_quantum[3] << 8) | (long) long_quantum[4];
             k=(int) *long_quantum;
             l=((int) long_quantum[5] << 16) | ((int) long_quantum[6] << 8) |
                (int) long_quantum[7];
-            exponent=((k & 127) << 4) | (j >> 28);
+            exponent=((k & 0x7f) << 4) | (j >> 28);
             *(double *) long_quantum=exponential[exponent]*(16777216.0*
               (double) ((j & 0x0FFFFFFF) | 0x10000000)+(double) l);
             if ((exponent | j | l) == 0)
               *(double *) long_quantum=0.0;
-            if (k & 128)
-              *(double *)long_quantum=(-(*(double *) long_quantum));
+            if (k & 0x80)
+              *(double *) long_quantum=(-(*(double *) long_quantum));
             pixel=(double) (*((double *) long_quantum));
           }
         fits_info.min_data=pixel*fits_info.scale-fits_info.zero;
@@ -447,47 +451,46 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
             quantum=(quantum << 8) | (*p++);
           }
           pixel=(double) quantum;
+          if (fits_info.bits_per_pixel == 16)
+            if (pixel > 32767)
+              pixel-=65536L;
           if (fits_info.bits_per_pixel == -32)
             {
               j=((long) long_quantum[1] << 16) | ((long) long_quantum[2] << 8) |
                  (long) long_quantum[3];
               k=(int) *long_quantum;
-              exponent=((k & 127) << 1) | (j >> 23);
-              *(float *) long_quantum=
-                exponential[exponent]*(float) (j | 0x800000);
+              exponent=((k & 0x7f) << 1) | (j >> 23);
+              *(float *) long_quantum=exponential[exponent]*(float)
+                (j | 0x800000);
               if ((exponent | j) == 0)
                 *(float *) long_quantum=0.0;
-              if (k & 128)
+              if (k & 0x80)
                 *(float *) long_quantum=(-(*(float *) long_quantum));
               pixel=(double) (*((float *) long_quantum));
             }
           if (fits_info.bits_per_pixel == -64)
             {
               j=((long) long_quantum[1] << 24) |
-                ((long) long_quantum[2] << 16) |
-                ((long) long_quantum[3] << 8) |
+                ((long) long_quantum[2] << 16) | ((long) long_quantum[3] << 8) |
                  (long) long_quantum[4];
               k=(int) *long_quantum;
               l=((int) long_quantum[5] << 16) | ((int) long_quantum[6] << 8) |
                  (int) long_quantum[7];
-              exponent=((k & 127) << 4) | (j >> 28);
+              exponent=((k & 0x7f) << 4) | (j >> 28);
               *(double *) long_quantum=exponential[exponent]*(16777216.0*
                 (double) ((j & 0x0FFFFFFF) | 0x10000000)+(double) l);
               if ((exponent | j | l) == 0)
                 *(double *) long_quantum=0.0;
-              if (k & 128)
+              if (k & 0x80)
                 *(double *)long_quantum=(-(*(double *) long_quantum));
               pixel=(double) (*((double *) long_quantum));
             }
-          scaled_pixel=pixel*fits_info.scale-fits_info.zero;
-          if (scaled_pixel < fits_info.min_data)
-            fits_info.min_data=scaled_pixel;
-          if (scaled_pixel > fits_info.max_data)
-            fits_info.max_data=scaled_pixel;
+          scale_pixel=pixel*fits_info.scale-fits_info.zero;
+          if (scale_pixel < fits_info.min_data)
+            fits_info.min_data=scale_pixel;
+          if (scale_pixel > fits_info.max_data)
+            fits_info.max_data=scale_pixel;
         }
-        if (fits_info.bits_per_pixel == 16)
-          if (pixel > 32767)
-            pixel-=65536L;
       }
     /*
       Convert FITS pixels to pixel packets.
@@ -495,8 +498,8 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
     scale=1.0;
     if ((fits_info.bits_per_pixel < 0) || ((fits_info.max_data-
         fits_info.min_data) > (double) ((1UL << image->depth)-1)))
-      scale=(double) ((1UL << image->depth)-1)/
-        (fits_info.max_data-fits_info.min_data);
+      scale=(double) ((1UL << image->depth)-1)/(fits_info.max_data-
+        fits_info.min_data);
     p=fits_pixels;
     for (y=(long) image->rows-1; y >= 0; y--)
     {
@@ -514,47 +517,45 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
           quantum=(quantum << 8) | (*p++);
         }
         pixel=(double) quantum;
+        if (fits_info.bits_per_pixel == 16)
+          if (pixel > 32767)
+            pixel-=65536L;
         if (fits_info.bits_per_pixel == -32)
           {
             j=((long) long_quantum[1] << 16) | ((long) long_quantum[2] << 8) |
                (long) long_quantum[3];
             k=(int) *long_quantum;
-            exponent=((k & 127) << 1) | (j >> 23);
-            *(float *) long_quantum=
-              exponential[exponent]*(float) (j | 0x800000);
+            exponent=((k & 0x7f) << 1) | (j >> 23);
+            *(float *) long_quantum=exponential[exponent]*(float)
+              (j | 0x800000);
             if ((exponent | j) == 0)
               *(float *) long_quantum=0.0;
-            if (k & 128)
+            if (k & 0x80)
               *(float *) long_quantum=(-(*(float *) long_quantum));
             pixel=(double) (*((float *) long_quantum));
           }
         if (fits_info.bits_per_pixel == -64)
           {
-            j=((long) long_quantum[1] << 24) |
-              ((long) long_quantum[2] << 16) |
-              ((long) long_quantum[3] << 8) |
-               (long) long_quantum[4];
+            j=((long) long_quantum[1] << 24) | ((long) long_quantum[2] << 16) |
+              ((long) long_quantum[3] << 8) | (long) long_quantum[4];
             k=(long) *long_quantum;
             l=((long) long_quantum[5] << 16) | ((long) long_quantum[6] << 8) |
                (long) long_quantum[7];
-            exponent=(long) ((((unsigned long) k & 127) << 4) |
+            exponent=(long) ((((unsigned long) k & 0x7f) << 4) |
               ((unsigned long) j >> 28));
             *(double *) long_quantum=exponential[exponent]*(16777216.0*
               (double) ((j & 0x0FFFFFFF) | 0x10000000)+(double) l);
             if ((exponent | j | l) == 0)
               *(double *) long_quantum=0.0;
-            if ((k & 128) != 0)
-              *(double *)long_quantum=(-(*(double *) long_quantum));
+            if ((k & 0x80) != 0)
+              *(double *) long_quantum=(-(*(double *) long_quantum));
             pixel=(double) (*((double *) long_quantum));
           }
-        scaled_pixel=scale*
-          (pixel*fits_info.scale-fits_info.min_data-fits_info.zero);
-        if (fits_info.bits_per_pixel == 16)
-          if (scaled_pixel > 32767)
-            scaled_pixel-=65536L;
-        index=(IndexPacket) ((scaled_pixel < 0.0) ? 0 :
-          ((unsigned long) scaled_pixel > ((1UL << image->depth)-1)) ?
-          ((1UL << image->depth)-1) : (unsigned long) (scaled_pixel+0.5));
+        scale_pixel=scale*(pixel*fits_info.scale-fits_info.min_data-
+          fits_info.zero);
+        index=(IndexPacket) ((scale_pixel < 0.0) ? 0 : ((unsigned long)
+          scale_pixel > ((1UL << image->depth)-1)) ? ((1UL << image->depth)-1) :
+          (unsigned long) (scale_pixel+0.5));
         index=ConstrainColormapIndex(image,index);
         indexes[x]=index;
         *q++=image->colormap[index];
@@ -695,7 +696,6 @@ ModuleExport void UnregisterFITSImage(void)
 %
 %    o image:  The image.
 %
-%
 */
 static MagickBooleanType WriteFITSImage(const ImageInfo *image_info,
   Image *image)
@@ -780,8 +780,8 @@ static MagickBooleanType WriteFITSImage(const ImageInfo *image_info,
   (void) FormatMagickString(buffer,MaxTextExtent,"BZERO   =           %10u",
     image->depth > 8 ? 32768 : 0);
   (void) CopyMagickString(fits_info+560,buffer,2880);
-  (void) CopyMagickString(buffer,"HISTORY Created by ImageMagick.",
-    MaxTextExtent);
+  (void) FormatMagickString(buffer,MaxTextExtent,"HISTORY %s",
+    GetMagickVersion((unsigned long *) NULL));
   (void) CopyMagickString(fits_info+640,buffer,2880);
   (void) CopyMagickString(buffer,"END",MaxTextExtent);
   (void) CopyMagickString(fits_info+720,buffer,2880);
