@@ -806,6 +806,9 @@ static MagickBooleanType WriteFPXImage(const ImageInfo *image_info,Image *image)
   MagickBooleanType
     status;
 
+  QuantumInfo
+    quantum_info;
+
   register const PixelPacket
     *p;
 
@@ -837,7 +840,8 @@ static MagickBooleanType WriteFPXImage(const ImageInfo *image_info,Image *image)
     Initialize FPX toolkit.
   */
   image->depth=8;
-  (void) SetImageColorspace(image,RGBColorspace);
+  if (image_info->colorspace == UndefinedColorspace)
+    (void) SetImageColorspace(image,RGBColorspace);
   memory_limit=20000000;
   fpx_status=FPX_SetToolkitMemoryLimit(&memory_limit);
   if (fpx_status != FPX_OK)
@@ -928,12 +932,8 @@ static MagickBooleanType WriteFPXImage(const ImageInfo *image_info,Image *image)
         Note image comment.
       */
       summary_info.comments_valid=MagickTrue;
+      summary_info.comments.ptr=(unsigned char *) AcquireString(comment->value);
       summary_info.comments.length=strlen(comment->value);
-      summary_info.comments.ptr=(unsigned char *)
-        AcquireMagickMemory(strlen(comment->value)+MaxTextExtent);
-      if (summary_info.comments.ptr == (unsigned char *) NULL)
-        ThrowWriterException(DelegateError,"UnableToSetImageComment");
-      (void) strcpy((char *) summary_info.comments.ptr,comment->value);
     }
   fpx_status=FPX_SetSummaryInformation(flashpix,&summary_info);
   if (fpx_status != FPX_OK)
@@ -941,8 +941,8 @@ static MagickBooleanType WriteFPXImage(const ImageInfo *image_info,Image *image)
   /*
     Allocate pixels.
   */
-  pixels=(unsigned char *)
-    AcquireMagickMemory(colorspace.numberOfComponents*image->columns);
+  pixels=(unsigned char *) AcquireMagickMemory((colorspace.numberOfComponents*
+    image->columns)*sizeof(*pixels));
   if (pixels == (unsigned char *) NULL)
     {
       (void) FPX_CloseImage(flashpix);
@@ -971,18 +971,19 @@ static MagickBooleanType WriteFPXImage(const ImageInfo *image_info,Image *image)
   /*
     Write image scanlines.
   */
+  GetQuantumInfo(image_info,&quantum_info);
   for (y=0; y < (long) image->rows; y++)
   {
     p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
     if (p == (const PixelPacket *) NULL)
       break;
     if (fpx_info.numberOfComponents == 1)
-      (void) ImportQuantumPixels(image,GrayQuantum,0,pixels);
+      (void) ImportQuantumPixels(image,&quantum_info,GrayQuantum,pixels);
     else
       if (image->matte == MagickFalse)
-        (void) ImportQuantumPixels(image,RGBQuantum,0,pixels);
+        (void) ImportQuantumPixels(image,&quantum_info,RGBQuantum,pixels);
       else
-        (void) ImportQuantumPixels(image,RGBAQuantum,0,pixels);
+        (void) ImportQuantumPixels(image,&quantum_info,RGBAQuantum,pixels);
     fpx_status=FPX_WriteImageLine(flashpix,&fpx_info);
     if (fpx_status != FPX_OK)
       break;
