@@ -245,7 +245,8 @@ static MagickBooleanType WriteHTMLImage(const ImageInfo *image_info,
   if (status == MagickFalse)
     return(status);
   CloseBlob(image);
-  (void) SetImageColorspace(image,RGBColorspace);
+  if (image_info->colorspace == UndefinedColorspace)
+    (void) SetImageColorspace(image,RGBColorspace);
   *url='\0';
   if ((LocaleCompare(image_info->magick,"FTP") == 0) ||
       (LocaleCompare(image_info->magick,"HTTP") == 0))
@@ -376,7 +377,7 @@ static MagickBooleanType WriteHTMLImage(const ImageInfo *image_info,
       AppendImageFormat("gif",image->filename);
       next=GetNextImageInList(image);
       image->next=NewImageList();
-      (void) strcpy(image->magick,"GIF");
+      (void) CopyMagickString(image->magick,"GIF",MaxTextExtent);
       (void) WriteImage(write_info,image);
       image->next=next;
       /*
