@@ -40,6 +40,7 @@
   Include declarations.
 */
 #include "magick/studio.h"
+#include "magick/attribute.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
 #include "magick/colorspace.h"
@@ -192,7 +193,7 @@ static MagickBooleanType WriteINFOImage(const ImageInfo *image_info,
         char
           *text;
 
-        text=TranslateText(image_info,image,format);
+        text=InterpretImageAttributes(image_info,image,format);
         if (text != (char *) NULL)
           {
             (void) WriteBlobString(image,text);
