@@ -398,6 +398,9 @@ static MagickBooleanType WriteJBIGImage(const ImageInfo *image_info,
   double
     version;
 
+  IndexPacket
+    polarity;
+
   long
     y;
 
@@ -425,8 +428,7 @@ static MagickBooleanType WriteJBIGImage(const ImageInfo *image_info,
   unsigned char
     bit,
     byte,
-    *pixels,
-    polarity;
+    *pixels;
 
   unsigned long
     number_packets;
@@ -450,7 +452,8 @@ static MagickBooleanType WriteJBIGImage(const ImageInfo *image_info,
     /*
       Allocate pixel data.
     */
-    (void) SetImageColorspace(image,RGBColorspace);
+    if (image_info->colorspace == UndefinedColorspace)
+      (void) SetImageColorspace(image,RGBColorspace);
     number_packets=((image->columns+7) >> 3)*image->rows;
     pixels=(unsigned char *) AcquireMagickMemory(number_packets);
     if (pixels == (unsigned char *) NULL)
@@ -458,11 +461,13 @@ static MagickBooleanType WriteJBIGImage(const ImageInfo *image_info,
     /*
       Convert pixels to a bitmap.
     */
-    SetImageType(image,BilevelType);
-    polarity=PixelIntensityToQuantum(&image->colormap[0]) < (QuantumRange/2);
+    (void) SetImageType(image,PaletteType);
+    (void) SetImageType(image,BilevelType);
+    polarity=(IndexPacket) (PixelIntensityToQuantum(&image->colormap[0]) <
+      (QuantumRange/2) ? 1 : 0);
     if (image->colors == 2)
-      polarity=PixelIntensityToQuantum(&image->colormap[0]) >
-        PixelIntensityToQuantum(&image->colormap[1]);
+      polarity=(IndexPacket) (PixelIntensityToQuantum(&image->colormap[0]) >
+        PixelIntensityToQuantum(&image->colormap[1]) ? 1 : 0);
     q=pixels;
     for (y=0; y < (long) image->rows; y++)
     {
