@@ -424,9 +424,9 @@ static Image *ReadJP2Image(const ImageInfo *image_info,ExceptionInfo *exception)
   for (i=0; i < (long) number_components; i++)
   {
     if ((((jas_image_cmptwidth(jp2_image,components[i])*
-          jas_image_cmpthstep(jp2_image,components[i])) != image->columns)) ||
+          jas_image_cmpthstep(jp2_image,components[i])) != (long) image->columns)) ||
         (((jas_image_cmptheight(jp2_image,components[i])*
-          jas_image_cmptvstep(jp2_image,components[i])) != image->rows)) ||
+          jas_image_cmptvstep(jp2_image,components[i])) != (long) image->rows)) ||
         (jas_image_cmpttlx(jp2_image,components[i]) != 0) ||
         (jas_image_cmpttly(jp2_image,components[i]) != 0) ||
         (jas_image_cmptsgnd(jp2_image,components[i]) != MagickFalse))
@@ -452,7 +452,7 @@ static Image *ReadJP2Image(const ImageInfo *image_info,ExceptionInfo *exception)
   for (i=0; i < (long) number_components; i++)
   {
     maximum_component_depth=Max(jas_image_cmptprec(jp2_image,components[i]),
-      maximum_component_depth);
+      (long) maximum_component_depth);
     pixels[i]=jas_matrix_create(1,((unsigned int) image->columns)/x_step[i]);
     if (pixels[i] == (jas_matrix_t *) NULL)
       {
