@@ -366,7 +366,8 @@ static MagickBooleanType WriteMAPImage(const ImageInfo *image_info,Image *image)
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
-  (void) SetImageColorspace(image,RGBColorspace);
+  if (image_info->colorspace == UndefinedColorspace)
+    (void) SetImageColorspace(image,RGBColorspace);
   /*
     Allocate colormap.
   */
@@ -394,11 +395,11 @@ static MagickBooleanType WriteMAPImage(const ImageInfo *image_info,Image *image)
   else
     for (i=0; i < (long) image->colors; i++)
     {
-      *q++=(unsigned char) (image->colormap[i].red >> 8);
+      *q++=(unsigned char) ((unsigned long) image->colormap[i].red >> 8);
       *q++=(unsigned char) image->colormap[i].red;
-      *q++=(unsigned char) (image->colormap[i].green >> 8);
+      *q++=(unsigned char) ((unsigned long) image->colormap[i].green >> 8);
       *q++=(unsigned char) image->colormap[i].green;
-      *q++=(unsigned char) (image->colormap[i].blue >> 8);
+      *q++=(unsigned char) ((unsigned long) image->colormap[i].blue >> 8);
       *q++=(unsigned char) image->colormap[i].blue;
     }
   (void) WriteBlob(image,packet_size*image->colors,colormap);
@@ -416,7 +417,7 @@ static MagickBooleanType WriteMAPImage(const ImageInfo *image_info,Image *image)
     for (x=0; x < (long) image->columns; x++)
     {
       if (image->colors > 256)
-        *q++=(unsigned char) (indexes[x] >> 8);
+        *q++=(unsigned char) ((unsigned long) indexes[x] >> 8);
       *q++=(unsigned char) indexes[x];
     }
     (void) WriteBlob(image,(size_t) (q-pixels),pixels);
