@@ -229,7 +229,7 @@ static int convertHTMLcodes(char *s, int len)
         if (html_codes[i].len <= len)
           if (stringnicmp(s, html_codes[i].code, html_codes[i].len) == 0)
             {
-              (void) CopyMagickString(s+1,s+html_codes[i].len,strlen(s+html_codes[i].len));
+              (void) CopyMagickString(s+1,s+html_codes[i].len,strlen(s+html_codes[i].len)+1);
               *s = html_codes[i].val;
               return html_codes[i].len-1;
             }
@@ -2137,8 +2137,6 @@ static MagickBooleanType WriteMETAImage(const ImageInfo *image_info,
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
-  if (image->profiles == (void *) NULL)
-    return(MagickFalse);
   length=0;
   if (LocaleCompare(image_info->magick,"8BIM") == 0)
     {
