@@ -1069,10 +1069,11 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
     if (image->compression == RLECompression)
       packet_size++;
     length=packet_size*image->columns;
-    pixels=(unsigned char *) AcquireMagickMemory(packet_size*image->columns);
+    pixels=(unsigned char *) AcquireMagickMemory(length*sizeof(*pixels));
     length=(size_t) Max(BZipMaxExtent(packet_size*image->columns),
       ZipMaxExtent(packet_size*image->columns));
-    compress_pixels=(unsigned char *) AcquireMagickMemory(length);
+    compress_pixels=(unsigned char *) AcquireMagickMemory(length*
+      sizeof(*compress_pixels));
     if ((pixels == (unsigned char *) NULL) ||
         (compress_pixels == (unsigned char *) NULL))
       ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
@@ -1603,10 +1604,10 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
 #if defined(HasZLIB)
       case LZWCompression:
       case ZipCompression: compression=ZipCompression; break;
-#endif  
+#endif
 #if defined(HasBZLIB)
       case BZipCompression: compression=BZipCompression; break;
-#endif  
+#endif
       case RLECompression: compression=RLECompression; break;
       default:
         break;
@@ -1621,13 +1622,14 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
     if (compression == RLECompression)
       packet_size+=image->depth/8;
     length=packet_size*image->columns;
-    pixels=(unsigned char *) AcquireMagickMemory(length);
+    pixels=(unsigned char *) AcquireMagickMemory(length*sizeof(*pixels));
     length=(size_t) Max(BZipMaxExtent(packet_size*image->columns),
       ZipMaxExtent(packet_size*image->columns));
     if ((compression == BZipCompression) || (compression == ZipCompression))
       if (length != (size_t) ((unsigned int) length))
         compression=NoCompression;
-    compress_pixels=(unsigned char *) AcquireMagickMemory(length);
+    compress_pixels=(unsigned char *) AcquireMagickMemory(length*
+      sizeof(*compress_pixels));
     if ((pixels == (unsigned char *) NULL) ||
         (compress_pixels == (unsigned char *) NULL))
       ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
@@ -1792,7 +1794,7 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
         (void) WriteBlobString(image,buffer);
       }
     ResetImageAttributeIterator(image);
-	  attribute=GetNextImageAttribute(image);
+    attribute=GetNextImageAttribute(image);
     while (attribute != (const ImageAttribute *) NULL)
     {
       if (*attribute->key != '[')
@@ -1810,7 +1812,7 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
             (void) WriteBlobByte(image,'}');
           (void) WriteBlobByte(image,'\n');
         }
-  	  attribute=GetNextImageAttribute(image);
+      attribute=GetNextImageAttribute(image);
     }
     (void) WriteBlobString(image,"\f\n:\032");
     if (image->montage != (char *) NULL)
