@@ -315,16 +315,18 @@ static MagickBooleanType WriteMONOImage(const ImageInfo *image_info,
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
-  (void) SetImageColorspace(image,RGBColorspace);
+  if (image_info->colorspace == UndefinedColorspace)
+    (void) SetImageColorspace(image,RGBColorspace);
   /*
     Convert image to a bi-level image.
   */
+  (void) SetImageType(image,PaletteType);
   (void) SetImageType(image,BilevelType);
   polarity=(IndexPacket)
-    (PixelIntensityToQuantum(&image->colormap[0]) < (QuantumRange/2));
+    (PixelIntensityToQuantum(&image->colormap[0]) < (QuantumRange/2) ? 1 : 0);
   if (image->colors == 2)
     polarity=(IndexPacket) (PixelIntensityToQuantum(&image->colormap[0]) <
-      PixelIntensityToQuantum(&image->colormap[1]));
+      PixelIntensityToQuantum(&image->colormap[1]) ? 1 : 0);
   for (y=0; y < (long) image->rows; y++)
   {
     p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
