@@ -48,6 +48,7 @@
 #include "magick/geometry.h"
 #include "magick/image.h"
 #include "magick/image-private.h"
+#include "magick/layer.h"
 #include "magick/list.h"
 #include "magick/log.h"
 #include "magick/magick.h"
@@ -186,7 +187,7 @@ static Image *ReadMPEGImage(const ImageInfo *image_info,
     image=ReadImage(read_info,exception);
     if (image == (Image *) NULL)
       break;
-    (void) strcpy(image->magick,image_info->magick);
+    (void) CopyMagickString(image->magick,image_info->magick,MaxTextExtent);
     image->scene=(unsigned long) i;
     AppendImageToList(&images,image);
     if (read_info->number_scenes != 0)
