@@ -187,10 +187,10 @@ static Image *ReadMVGImage(const ImageInfo *image_info,ExceptionInfo *exception)
   if ((image->columns == 0) || (image->rows == 0))
     ThrowReaderException(OptionError,"MustSpecifyImageSize");
   draw_info=CloneDrawInfo(image_info,(DrawInfo *) NULL);
-  draw_info->affine.sx=
-    image->x_resolution == 0.0 ? 1.0 : image->x_resolution/DefaultResolution;
-  draw_info->affine.sy=
-    image->y_resolution == 0.0 ? 1.0 : image->y_resolution/DefaultResolution;
+  draw_info->affine.sx=image->x_resolution == 0.0 ? 1.0 : image->x_resolution/
+    DefaultResolution;
+  draw_info->affine.sy=image->y_resolution == 0.0 ? 1.0 : image->y_resolution/
+    DefaultResolution;
   image->columns=(unsigned long) (draw_info->affine.sx*image->columns);
   image->rows=(unsigned long) (draw_info->affine.sy*image->rows);
   SetImageBackgroundColor(image);
