@@ -296,6 +296,9 @@ static MagickBooleanType WriteOTBImage(const ImageInfo *image_info,Image *image)
 #define SetBit(a,i,set) \
   a=(unsigned char) ((set) ? (a) | (1L << (i)) : (a) & ~(1L << (i)))
 
+  IndexPacket
+    polarity;
+
   long
     y;
 
@@ -314,8 +317,7 @@ static MagickBooleanType WriteOTBImage(const ImageInfo *image_info,Image *image)
   unsigned char
     bit,
     byte,
-    info,
-    polarity;
+    info;
 
   /*
     Open output image file.
@@ -329,15 +331,18 @@ static MagickBooleanType WriteOTBImage(const ImageInfo *image_info,Image *image)
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
-  (void) SetImageColorspace(image,RGBColorspace);
+  if (image_info->colorspace == UndefinedColorspace)
+    (void) SetImageColorspace(image,RGBColorspace);
   /*
     Convert image to a bi-level image.
   */
-  SetImageType(image,BilevelType);
-  polarity=PixelIntensityToQuantum(&image->colormap[0]) < (QuantumRange/2);
+  (void) SetImageType(image,PaletteType);
+  (void) SetImageType(image,BilevelType);
+  polarity=(IndexPacket) (PixelIntensityToQuantum(&image->colormap[0]) <
+    (QuantumRange/2) ? 1 : 0);
   if (image->colors == 2)
-    polarity=PixelIntensityToQuantum(&image->colormap[0]) <
-      PixelIntensityToQuantum(&image->colormap[1]);
+    polarity=(IndexPacket) (PixelIntensityToQuantum(&image->colormap[0]) <
+      PixelIntensityToQuantum(&image->colormap[1]) ? 1 : 0);
   info=0;
   if ((image->columns >= 256) || (image->rows >= 256))
     SetBit(info,4,1);
