@@ -549,8 +549,8 @@ ModuleExport void RegisterPALMImage(void)
   entry->decoder=(DecoderHandler *) ReadPALMImage;
   entry->encoder=(EncoderHandler *) WritePALMImage;
   entry->seekable_stream=MagickTrue;
-  entry->description=AcquireString("Palm pixmap");
-  entry->module=AcquireString("PALM");
+  entry->description=ConstantString("Palm pixmap");
+  entry->module=ConstantString("PALM");
   (void) RegisterMagickInfo(entry);
 }
 
@@ -912,6 +912,6 @@ static MagickBooleanType WritePALMImage(const ImageInfo *image_info,Image *image
     image=SyncNextImageInList(image);
   } while (image_info->adjoin != MagickFalse);
   CloseBlob(image);
-  DestroyExceptionInfo(&exception);
+  (void) DestroyExceptionInfo(&exception);
   return(MagickTrue);
 }
