@@ -924,7 +924,8 @@ static Image *ReadPATTERNImage(const ImageInfo *image_info,
   for (i=0; PatternImageList[i].blob != (const void *) NULL; i++)
     if (LocaleCompare(blob_info->filename,PatternImageList[i].name) == 0)
       {
-        (void) strcpy(blob_info->magick,PatternImageList[i].magick);
+        (void) CopyMagickString(blob_info->magick,PatternImageList[i].magick,
+          MaxTextExtent);
         blob=PatternImageList[i].blob;
         extent=PatternImageList[i].extent;
         break;
