@@ -110,7 +110,7 @@ static MagickBooleanType
 static MagickBooleanType DecodeImage(Image *image,unsigned char *luma,
   unsigned char *chroma1,unsigned char *chroma2)
 {
-#define IsSync  ((sum & 0xffffff00) == 0xfffffe00)
+#define IsSync  ((sum & 0xffffff00UL) == 0xfffffe00UL)
 #define DecodeImageTag  "Decode/Image"
 #define PCDGetBits(n) \
 {  \
@@ -145,7 +145,6 @@ static MagickBooleanType DecodeImage(Image *image,unsigned char *luma,
   } PCDTable;
 
   long
-    count,
     quantum;
 
   MagickBooleanType
@@ -168,6 +167,9 @@ static MagickBooleanType DecodeImage(Image *image,unsigned char *luma,
   size_t
     length;
 
+  ssize_t
+    count;
+
   unsigned char
     *buffer;
 
@@ -210,14 +212,14 @@ static MagickBooleanType DecodeImage(Image *image,unsigned char *luma,
     for (j=0; j < (long) length; j++)
     {
       PCDGetBits(8);
-      r->length=(sum & 0xff)+1;
+      r->length=(unsigned int) (sum & 0xff)+1;
       if (r->length > 16)
         {
           buffer=(unsigned char *) RelinquishMagickMemory(buffer);
           return(MagickFalse);
         }
       PCDGetBits(16);
-      r->sequence=(sum & 0xffff) << 16;
+      r->sequence=(unsigned int) (sum & 0xffff) << 16;
       PCDGetBits(8);
       r->key=(unsigned char) (sum & 0xff);
       r->mask=(~((1U << (32-r->length))-1));
@@ -232,7 +234,7 @@ static MagickBooleanType DecodeImage(Image *image,unsigned char *luma,
     PCDGetBits(16);
   for (i=0; i < 1; i++)
     PCDGetBits(16);
-  while ((sum & 0x00fff000) != 0x00fff000)
+  while ((sum & 0x00fff000UL) != 0x00fff000UL)
     PCDGetBits(8);
   while (IsSync == 0)
     PCDGetBits(1);
@@ -263,20 +265,20 @@ static MagickBooleanType DecodeImage(Image *image,unsigned char *luma,
           case 0:
           {
             q=luma+row*image->columns;
-            count=(long) image->columns;
+            count=(ssize_t) image->columns;
             break;
           }
           case 2:
           {
             q=chroma1+(row >> 1)*image->columns;
-            count=(long) (image->columns >> 1);
+            count=(ssize_t) (image->columns >> 1);
             plane--;
             break;
           }
           case 3:
           {
             q=chroma2+(row >> 1)*image->columns;
-            count=(long) (image->columns >> 1);
+            count=(ssize_t) (image->columns >> 1);
             plane--;
             break;
           }
@@ -288,10 +290,10 @@ static MagickBooleanType DecodeImage(Image *image,unsigned char *luma,
         }
         length=pcd_length[plane];
         if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-            (QuantumTick(row,image->rows) != MagickFalse))
+            (QuantumTick((MagickOffsetType) row,image->rows) != MagickFalse))
           {
-            status=image->progress_monitor(DecodeImageTag,row,image->rows,
-              image->client_data);
+            status=image->progress_monitor(DecodeImageTag,(MagickOffsetType)
+              row,image->rows,image->client_data);
             if (status == MagickFalse)
               break;
           }
@@ -420,7 +422,7 @@ static Image *OverviewImage(const ImageInfo *image_info,Image *image,
   montage_info=CloneMontageInfo(image_info,(MontageInfo *) NULL);
   (void) CopyMagickString(montage_info->filename,image_info->filename,
     MaxTextExtent);
-  montage_image=MontageImages(image,montage_info,exception);
+  montage_image=MontageImageList(image_info,montage_info,image,exception);
   montage_info=DestroyMontageInfo(montage_info);
   if (montage_image == (Image *) NULL)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
@@ -512,7 +514,7 @@ static Image *ReadPCDImage(const ImageInfo *image_info,ExceptionInfo *exception)
     *c2,
     *yy;
 
-  size_t
+  ssize_t
     count;
 
   unsigned char
@@ -649,7 +651,7 @@ static Image *ReadPCDImage(const ImageInfo *image_info,ExceptionInfo *exception)
           "images/img%04ld.pcd",j);
         (void) FormatMagickString(image->magick_filename,MaxTextExtent,
           "images/img%04ld.pcd",j);
-        image->scene=j;
+        image->scene=(unsigned long) j;
         image->columns=width;
         image->rows=height;
         image->depth=8;
@@ -1020,7 +1022,8 @@ static MagickBooleanType WritePCDTile(const ImageInfo *image_info,Image *image,
       tile_image=bordered_image;
     }
   (void) TransformImage(&tile_image,(char *) NULL,tile_geometry);
-  (void) SetImageColorspace(tile_image,YCCColorspace);
+  if (image_info->colorspace == UndefinedColorspace)
+    (void) SetImageColorspace(tile_image,YCCColorspace);
   downsample_image=ResizeImage(tile_image,tile_image->columns/2,
     tile_image->rows/2,TriangleFilter,1.0,&image->exception);
   if (downsample_image == (Image *) NULL)
@@ -1110,7 +1113,8 @@ static MagickBooleanType WritePCDImage(const ImageInfo *image_info,Image *image)
   status=OpenBlob(image_info,pcd_image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
-  (void) SetImageColorspace(pcd_image,RGBColorspace);
+  if (image_info->colorspace == UndefinedColorspace)
+    (void) SetImageColorspace(pcd_image,RGBColorspace);
   /*
     Write PCD image header.
   */
