@@ -537,10 +537,11 @@ static MagickBooleanType WritePCLImage(const ImageInfo *image_info,Image *image)
       /*
         Write PCL monochrome image.
       */
-      polarity=PixelIntensityToQuantum(&image->colormap[0]) < (QuantumRange/2);
+      polarity=(IndexPacket) (PixelIntensityToQuantum(&image->colormap[0]) <
+        (QuantumRange/2) ? 1 : 0);
       if (image->colors == 2)
-        polarity=PixelIntensityToQuantum(&image->colormap[0]) <
-          PixelIntensityToQuantum(&image->colormap[1]);
+        polarity=(IndexPacket) (PixelIntensityToQuantum(&image->colormap[0]) <
+          PixelIntensityToQuantum(&image->colormap[1]) ? 1 : 0);
       (void) FormatMagickString(buffer,MaxTextExtent,"\033*t%ldR",density);
       (void) WriteBlobString(image,buffer);
       (void) WriteBlobString(image,"\033*r1A");  /* start graphics */
