@@ -836,7 +836,8 @@ static MagickBooleanType WritePCXImage(const ImageInfo *image_info,Image *image)
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
-  (void) SetImageColorspace(image,RGBColorspace);
+  if (image_info->colorspace == UndefinedColorspace)
+    (void) SetImageColorspace(image,RGBColorspace);
   page_table=(MagickOffsetType *) NULL;
   if ((LocaleCompare(image_info->magick,"DCX") == 0) ||
       ((GetNextImageInList(image) != (Image *) NULL) &&
@@ -1041,19 +1042,22 @@ static MagickBooleanType WritePCXImage(const ImageInfo *image_info,Image *image)
         }
       else
         {
+          IndexPacket
+            polarity;
+
           register unsigned char
             bit,
-            byte,
-            polarity;
+            byte;
 
           /*
             Convert PseudoClass image to a PCX monochrome image.
           */
-          polarity=PixelIntensityToQuantum(&image->colormap[0]) <
-            (QuantumRange/2);
+          polarity=(IndexPacket) (PixelIntensityToQuantum(&image->colormap[0]) <
+            (QuantumRange/2) ? 1 : 0);
           if (image->colors == 2)
-            polarity=PixelIntensityToQuantum(&image->colormap[0]) <
-              PixelIntensityToQuantum(&image->colormap[1]);
+            polarity=(IndexPacket) (
+              PixelIntensityToQuantum(&image->colormap[0]) <
+              PixelIntensityToQuantum(&image->colormap[1]) ? 1 : 0);
           for (y=0; y < (long) image->rows; y++)
           {
             p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
@@ -1124,9 +1128,15 @@ static MagickBooleanType WritePCXImage(const ImageInfo *image_info,Image *image)
         RelinquishMagickMemory(page_table);
     }
   if (status == MagickFalse)
-    (void) ThrowMagickException(&image->exception,GetMagickModule(),
-      FileOpenError,"UnableToWriteFile","`%s': %s",image->filename,
-      strerror(errno));
+    {
+      char
+        *message;
+
+      message=GetExceptionMessage(errno);
+      (void) ThrowMagickException(&image->exception,GetMagickModule(),
+        FileOpenError,"UnableToWriteFile","`%s': %s",image->filename,message);
+      message=(char *) RelinquishMagickMemory(message);
+    }
   CloseBlob(image);
   return(MagickTrue);
 }
