@@ -463,11 +463,12 @@ static unsigned char *DecodeImage(const ImageInfo *image_info,Image *blob,
   /*
     Allocate pixel and scanline buffer.
   */
-  pixels=(unsigned char *) AcquireMagickMemory(row_bytes*image->rows);
+  pixels=(unsigned char *) AcquireMagickMemory(row_bytes*image->rows*
+    sizeof(*pixels));
   if (pixels == (unsigned char *) NULL)
     return((unsigned char *) NULL);
   (void) ResetMagickMemory(pixels,0,row_bytes*image->rows);
-  scanline=(unsigned char *) AcquireMagickMemory(row_bytes);
+  scanline=(unsigned char *) AcquireMagickMemory(row_bytes*sizeof(scanline));
   if (scanline == (unsigned char *) NULL)
     return((unsigned char *) NULL);
   if (bytes_per_line < 8)
@@ -1035,12 +1036,13 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
               return((Image *) NULL);
             DestroyBlob(tile_image);
             tile_image->blob=CloneBlobInfo((BlobInfo *) NULL);
-            if ((code == 0x9a) || (code == 0x9b) || (bytes_per_line & 0x8000))
+            if ((code == 0x9a) || (code == 0x9b) ||
+                ((bytes_per_line & 0x8000) != 0))
               {
                 ReadPixmap(pixmap);
                 tile_image->depth=pixmap.component_size;
-                tile_image->matte=
-                  pixmap.component_count == 4 ? MagickTrue : MagickFalse;
+                tile_image->matte=pixmap.component_count == 4 ?
+                  MagickTrue : MagickFalse;
                 if (tile_image->matte != MagickFalse)
                   image->matte=tile_image->matte;
               }
@@ -1152,19 +1154,20 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
                       if (tile_image->matte == MagickFalse)
                         {
                           q->red=ScaleCharToQuantum(*p);
-                          q->green=
-                            ScaleCharToQuantum(*(p+tile_image->columns));
-                          q->blue=
-                            ScaleCharToQuantum(*(p+2*tile_image->columns));
+                          q->green=ScaleCharToQuantum(
+                            *(p+tile_image->columns));
+                          q->blue=ScaleCharToQuantum(
+                            *(p+2*tile_image->columns));
                         }
                       else
                         {
-                          q->opacity=(Quantum) (QuantumRange-ScaleCharToQuantum(*p));
+                          q->opacity=(Quantum) (QuantumRange-
+                            ScaleCharToQuantum(*p));
                           q->red=ScaleCharToQuantum(*(p+tile_image->columns));
-                          q->green=(Quantum)
-                            ScaleCharToQuantum(*(p+2*tile_image->columns));
-                          q->blue=
-                            ScaleCharToQuantum(*(p+3*tile_image->columns));
+                          q->green=(Quantum) ScaleCharToQuantum(
+                            *(p+2*tile_image->columns));
+                          q->blue=ScaleCharToQuantum(
+                            *(p+3*tile_image->columns));
                         }
                   }
                 p++;
@@ -1337,6 +1340,8 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
           Max(image->columns,tile_image->columns),
           Max(image->rows,tile_image->rows));
         (void) TransformImage(&image,(char *) NULL,geometry);
+        if (image_info->colorspace == UndefinedColorspace)
+          SetImageColorspace(image,tile_image->colorspace);
         (void) CompositeImage(image,CopyCompositeOp,tile_image,frame.left,
           frame.right);
         image->compression=tile_image->compression;
@@ -1482,6 +1487,9 @@ static MagickBooleanType WritePICTImage(const ImageInfo *image_info,
 #define PictPICTOp  0x98
 #define PictVersion  0x11
 
+  const StringInfo
+    *profile;
+
   double
     x_resolution,
     y_resolution;
@@ -1519,9 +1527,6 @@ static MagickBooleanType WritePICTImage(const ImageInfo *image_info,
   size_t
     count;
 
-  StringInfo
-    *profile;
-
   unsigned char
     *buffer,
     *packed_scanline,
@@ -1550,7 +1555,8 @@ static MagickBooleanType WritePICTImage(const ImageInfo *image_info,
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
-  (void) SetImageColorspace(image,RGBColorspace);
+  if (image_info->colorspace == UndefinedColorspace)
+    (void) SetImageColorspace(image,RGBColorspace);
   /*
     Initialize image info.
   */
@@ -1688,7 +1694,7 @@ static MagickBooleanType WritePICTImage(const ImageInfo *image_info,
       DestroyBlob(jpeg_image);
       jpeg_image->blob=CloneBlobInfo((BlobInfo *) NULL);
       jpeg_info=CloneImageInfo(image_info);
-      (void) strcpy(jpeg_info->magick,"JPEG");
+      (void) CopyMagickString(jpeg_info->magick,"JPEG",MaxTextExtent);
       length=0;
       blob=(unsigned char *) ImageToBlob(jpeg_info,jpeg_image,&length,
         &image->exception);
