@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -85,7 +85,7 @@
 %
 */
 
-static void inline PlasmaPixel(Image *image,double x,double y)
+static inline void PlasmaPixel(Image *image,double x,double y)
 {
   register PixelPacket
     *q;
@@ -230,14 +230,14 @@ ModuleExport void RegisterPLASMAImage(void)
   entry=SetMagickInfo("PLASMA");
   entry->decoder=(DecoderHandler *) ReadPlasmaImage;
   entry->adjoin=MagickFalse;
-  entry->description=AcquireString("Plasma fractal image");
-  entry->module=AcquireString("PLASMA");
+  entry->description=ConstantString("Plasma fractal image");
+  entry->module=ConstantString("PLASMA");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("FRACTAL");
   entry->decoder=(DecoderHandler *) ReadPlasmaImage;
   entry->adjoin=MagickFalse;
-  entry->description=AcquireString("Plasma fractal image");
-  entry->module=AcquireString("PLASMA");
+  entry->description=ConstantString("Plasma fractal image");
+  entry->module=ConstantString("PLASMA");
   (void) RegisterMagickInfo(entry);
 }
 
