@@ -356,7 +356,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
           while (isspace((int) ((unsigned char) c)) != 0)
             c=ReadBlobByte(image);
           p=value;
-          while (isalnum(c))
+          while (isalnum(c) || (c == '_'))
           {
             if ((size_t) (p-value) < (MaxTextExtent/2))
               *p++=c;
@@ -773,7 +773,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
                   if (image->matte != MagickFalse)
                     {
                       PushCharPixel(pixel,p);
-                      q->opacity=ScaleAnyToQuantum(pixel,
+                      q->opacity=QuantumRange-ScaleAnyToQuantum(pixel,
                         (1UL << image->depth)-1);
                     }
                   q++;
@@ -788,7 +788,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
                   if (image->matte != MagickFalse)
                     {
                       PushShortPixel(pixel,p);
-                      q->opacity=ScaleAnyToQuantum(pixel,
+                      q->opacity=QuantumRange-ScaleAnyToQuantum(pixel,
                         (1UL << image->depth)-1);
                     }
                   q++;
@@ -807,7 +807,8 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 if (image->matte != MagickFalse)
                   {
                     PushCharPixel(pixel,p);
-                    q->opacity=ScaleAnyToQuantum(pixel,(1UL << image->depth)-1);
+                    q->opacity=QuantumRange-ScaleAnyToQuantum(pixel,
+                      (1UL << image->depth)-1);
                   }
                 q++;
               }
@@ -823,7 +824,8 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 if (image->matte != MagickFalse)
                   {
                     PushShortPixel(pixel,p);
-                    q->opacity=ScaleAnyToQuantum(pixel,(1UL << image->depth)-1);
+                    q->opacity=QuantumRange-ScaleAnyToQuantum(pixel,
+                      (1UL << image->depth)-1);
                   }
                 q++;
               }
@@ -1093,7 +1095,8 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
     /*
       Write PNM file header.
     */
-    (void) SetImageColorspace(image,RGBColorspace);
+    if (image_info->colorspace == UndefinedColorspace)
+      (void) SetImageColorspace(image,RGBColorspace);
     grayscale=IsGrayImage(image,&image->exception);
     depth=image->depth;
     format=6;
@@ -1194,13 +1197,13 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
         /*
           Convert image to a PBM image.
         */
+        (void) SetImageType(image,PaletteType);
         (void) SetImageType(image,BilevelType);
-        polarity=(IndexPacket)
-          (PixelIntensityToQuantum(&image->colormap[0]) < (QuantumRange/2));
+        polarity=(IndexPacket) (PixelIntensityToQuantum(&image->colormap[0]) <
+          (QuantumRange/2) ? 1 : 0);
         if (image->colors == 2)
-          polarity=(IndexPacket)
-            (PixelIntensityToQuantum(&image->colormap[0]) <
-             PixelIntensityToQuantum(&image->colormap[1]));
+          polarity=(IndexPacket) (PixelIntensityToQuantum(&image->colormap[0]) <
+             PixelIntensityToQuantum(&image->colormap[1]) ? 1 : 0);
         i=0;
         for (y=0; y < (long) image->rows; y++)
         {
@@ -1341,13 +1344,14 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
         /*
           Convert image to a PBM image.
         */
+        (void) SetImageType(image,PaletteType);
         (void) SetImageType(image,BilevelType);
-        polarity=(IndexPacket)
-          (PixelIntensityToQuantum(&image->colormap[0]) < (QuantumRange/2));
+        polarity=(IndexPacket) (PixelIntensityToQuantum(&image->colormap[0]) <
+          (QuantumRange/2) ? 1 : 0);
         if (image->colors == 2)
           polarity=(IndexPacket)
             (PixelIntensityToQuantum(&image->colormap[0]) <
-             PixelIntensityToQuantum(&image->colormap[1]));
+             PixelIntensityToQuantum(&image->colormap[1]) ? 1 : 0);
         for (y=0; y < (long) image->rows; y++)
         {
           p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
@@ -1515,7 +1519,8 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
                   PopCharPixel(pixel,q);
                   if (image->matte != MagickFalse)
                     {
-                      pixel=ScaleQuantumToAny(p->opacity,(1UL << depth)-1);
+                      pixel=ScaleQuantumToAny(QuantumRange-p->opacity,
+                        (1UL << depth)-1);
                       PopCharPixel(pixel,q);
                     }
                   p++;
@@ -1528,7 +1533,8 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
                   PopShortPixel(pixel,q);
                   if (image->matte != MagickFalse)
                     {
-                      pixel=ScaleQuantumToAny(p->opacity,(1UL << depth)-1);
+                      pixel=ScaleQuantumToAny(QuantumRange-p->opacity,
+                        (1UL << depth)-1);
                       PopShortPixel(pixel,q);
                     }
                   p++;
@@ -1546,7 +1552,8 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
                 PopCharPixel(pixel,q);
                 if (image->matte != MagickFalse)
                   {
-                    pixel=ScaleQuantumToAny(p->opacity,(1UL << depth)-1);
+                    pixel=ScaleQuantumToAny(QuantumRange-p->opacity,
+                      (1UL << depth)-1);
                     PopCharPixel(pixel,q);
                   }
                 p++;
@@ -1562,7 +1569,8 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
                 PopShortPixel(pixel,q);
                 if (image->matte != MagickFalse)
                   {
-                    pixel=ScaleQuantumToAny(p->opacity,(1UL << depth)-1);
+                    pixel=ScaleQuantumToAny(QuantumRange-p->opacity,
+                      (1UL << depth)-1);
                     PopShortPixel(pixel,q);
                   }
                 p++;
