@@ -1216,6 +1216,7 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
         if ((image->gravity != UndefinedGravity) &&
             (LocaleCompare(image_info->magick,"PS") == 0))
           (void) CopyMagickString(page_geometry,PSPageGeometry,MaxTextExtent);
+    (void) ConcatenateMagickString(page_geometry,">",MaxTextExtent);
     (void) ParseMetaGeometry(page_geometry,&geometry.x,&geometry.y,
       &geometry.width,&geometry.height);
     scale.x=(double) (geometry.width*delta.x)/resolution.x;
@@ -1321,13 +1322,14 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
             /*
               Dump image as bitmap.
             */
+            (void) SetImageType(preview_image,PaletteType);
             (void) SetImageType(preview_image,BilevelType);
             polarity=(IndexPacket) (PixelIntensityToQuantum(
-              &preview_image->colormap[0]) < (QuantumRange/2));
+              &preview_image->colormap[0]) < (QuantumRange/2) ? 1 : 0);
             if (preview_image->colors == 2)
-              polarity=(IndexPacket)
-                (PixelIntensityToQuantum(&preview_image->colormap[0]) >
-                 PixelIntensityToQuantum(&preview_image->colormap[1]));
+              polarity=(IndexPacket) (
+                PixelIntensityToQuantum(&preview_image->colormap[0]) >
+                PixelIntensityToQuantum(&preview_image->colormap[1]) ? 1 : 0);
             (void) FormatMagickString(buffer,MaxTextExtent,
               "%%%%BeginPreview: %lu %lu %lu %lu\n%%  ",preview_image->columns,
               preview_image->rows,1L,(((preview_image->columns+7) >> 3)*
@@ -1508,13 +1510,14 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
             /*
               Dump image as bitmap.
             */
+            (void) SetImageType(image,PaletteType);
             (void) SetImageType(image,BilevelType);
             polarity=(IndexPacket) (PixelIntensityToQuantum(
-              &image->colormap[0]) < (QuantumRange/2));
+              &image->colormap[0]) < (QuantumRange/2) ? 1 : 0);
             if (image->colors == 2)
-              polarity=(IndexPacket)
-                (PixelIntensityToQuantum(&image->colormap[1]) <
-                 PixelIntensityToQuantum(&image->colormap[0]));
+              polarity=(IndexPacket) (
+                PixelIntensityToQuantum(&image->colormap[1]) <
+                PixelIntensityToQuantum(&image->colormap[0]) ? 1 : 0);
             count=0;
             for (y=0; y < (long) image->rows; y++)
             {
