@@ -472,7 +472,8 @@ static MagickBooleanType WritePS2Image(const ImageInfo *image_info,Image *image)
       else
         if ((image->gravity != UndefinedGravity) &&
             (LocaleCompare(image_info->magick,"PS") == 0))
-          (void) strcpy(page_geometry,PSPageGeometry);
+          (void) CopyMagickString(page_geometry,PSPageGeometry,MaxTextExtent);
+    (void) ConcatenateMagickString(page_geometry,">",MaxTextExtent);
     (void) ParseMetaGeometry(page_geometry,&geometry.x,&geometry.y,
       &geometry.width,&geometry.height);
     scale.x=(double) (geometry.width*delta.x)/resolution.x;
@@ -497,9 +498,10 @@ static MagickBooleanType WritePS2Image(const ImageInfo *image_info,Image *image)
           Output Postscript header.
         */
         if (LocaleCompare(image_info->magick,"PS2") == 0)
-          (void) strcpy(buffer,"%!PS-Adobe-3.0\n");
+          (void) CopyMagickString(buffer,"%!PS-Adobe-3.0\n",MaxTextExtent);
         else
-          (void) strcpy(buffer,"%!PS-Adobe-3.0 EPSF-3.0\n");
+          (void) CopyMagickString(buffer,"%!PS-Adobe-3.0 EPSF-3.0\n",
+            MaxTextExtent);
         (void) WriteBlobString(image,buffer);
         (void) WriteBlobString(image,"%%Creator: (ImageMagick)\n");
         (void) FormatMagickString(buffer,MaxTextExtent,"%%%%Title: (%s)\n",
@@ -518,7 +520,8 @@ static MagickBooleanType WritePS2Image(const ImageInfo *image_info,Image *image)
         bounds.y2=(double) geometry.y+geometry.height+text_size;
         if ((image_info->adjoin != MagickFalse) &&
             (GetNextImageInList(image) != (Image *) NULL))
-          (void) strcpy(buffer,"%%BoundingBox: (atend)\n");
+          (void) CopyMagickString(buffer,"%%BoundingBox: (atend)\n",
+            MaxTextExtent);
         else
           {
             (void) FormatMagickString(buffer,MaxTextExtent,
@@ -543,7 +546,7 @@ static MagickBooleanType WritePS2Image(const ImageInfo *image_info,Image *image)
             (void) WriteBlobString(image,"%%Orientation: Portrait\n");
             (void) WriteBlobString(image,"%%PageOrder: Ascend\n");
             if (image_info->adjoin == MagickFalse)
-              (void) strcpy(buffer,"%%Pages: 1\n");
+              (void) CopyMagickString(buffer,"%%Pages: 1\n",MaxTextExtent);
             else
               (void) FormatMagickString(buffer,MaxTextExtent,"%%%%Pages: %lu\n",
                 (unsigned long) GetImageListLength(image));
