@@ -497,6 +497,7 @@ static MagickBooleanType WritePS3MaskImage(const ImageInfo *image_info,
       mask_image=DestroyImage(mask_image);
       return(MagickFalse);
     }
+  (void) SetImageType(mask_image,PaletteType);
   (void) SetImageType(mask_image,BilevelType);
   mask_image->matte=MagickFalse;
   pixels=(unsigned char *) NULL;
@@ -921,6 +922,7 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
         if ((image->gravity != UndefinedGravity) &&
             (LocaleCompare(image_info->magick,"PS") == 0))
           (void) CopyMagickString(page_geometry,PSPageGeometry,MaxTextExtent);
+    (void) ConcatenateMagickString(page_geometry,">",MaxTextExtent);
     (void) ParseMetaGeometry(page_geometry,&geometry.x,&geometry.y,
       &geometry.width,&geometry.height);
     scale.x=(double) (geometry.width*delta.x)/resolution.x;
