@@ -809,6 +809,10 @@ static Image *ReadPSDImage(const ImageInfo *image_info,ExceptionInfo *exception)
         }
       else
         {
+          MagickOffsetType
+            layer_offset;
+
+          layer_offset=offset+length;
           number_layers=(short) ReadBlobMSBShort(image);
           if (image->debug != MagickFalse)
             (void) LogMagickEvent(CoderEvent,GetMagickModule(),
@@ -1277,6 +1281,8 @@ static Image *ReadPSDImage(const ImageInfo *image_info,ExceptionInfo *exception)
             layer_info=(LayerInfo *) RelinquishMagickMemory(layer_info);
 
             }
+          layer_offset-=TellBlob(image);
+          SeekBlob(image,layer_offset,SEEK_CUR);
         }
     }
   /*
