@@ -245,8 +245,15 @@ static Image *ReadPWPImage(const ImageInfo *image_info,ExceptionInfo *exception)
   CloseBlob(pwp_image);
   pwp_image=DestroyImage(pwp_image);
   if (EOFBlob(image) != MagickFalse)
-    (void) ThrowMagickException(exception,GetMagickModule(),CorruptImageError,
-      "UnexpectedEndOfFile","`%s': %s",image->filename,strerror(errno));
+    {
+      char
+        *message;
+
+      message=GetExceptionMessage(errno);
+      (void) ThrowMagickException(exception,GetMagickModule(),CorruptImageError,
+        "UnexpectedEndOfFile","`%s': %s",image->filename,message);
+      message=(char *) RelinquishMagickMemory(message);
+    }
   CloseBlob(image);
   return(GetFirstImageInList(image));
 }
