@@ -52,7 +52,7 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
-#include "magick/pixel.h"
+#include "magick/quantum.h"
 #include "magick/quantum.h"
 #include "magick/static.h"
 #include "magick/statistic.h"
@@ -103,6 +103,9 @@ static Image *ReadRAWImage(const ImageInfo *image_info,ExceptionInfo *exception)
   MagickBooleanType
     status;
 
+  QuantumInfo
+    quantum_info;
+
   register long
     i,
     x;
@@ -166,8 +169,8 @@ static Image *ReadRAWImage(const ImageInfo *image_info,ExceptionInfo *exception)
   */
   depth=GetImageQuantumDepth(image,MagickFalse);
   packet_size=(size_t) (depth/8);
-  pixels=(unsigned char *)
-    AcquireMagickMemory(packet_size*image->extract_info.width*sizeof(*pixels));
+  pixels=(unsigned char *) AcquireMagickMemory(packet_size*
+    image->extract_info.width*sizeof(*pixels));
   if (pixels == (unsigned char *) NULL)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   if (image_info->number_scenes != 0)
@@ -186,6 +189,7 @@ static Image *ReadRAWImage(const ImageInfo *image_info,ExceptionInfo *exception)
     /*
       Convert raster image to pixel packets.
     */
+    GetQuantumInfo(image_info,&quantum_info);
     if ((image_info->ping != MagickFalse) && (image_info->number_scenes != 0))
       if (image->scene >= (image_info->scene+image_info->number_scenes-1))
         break;
@@ -198,7 +202,7 @@ static Image *ReadRAWImage(const ImageInfo *image_info,ExceptionInfo *exception)
       q=SetImagePixels(image,0,y,image->columns,1);
       if (q == (PixelPacket *) NULL)
         break;
-      (void) ExportQuantumPixels(image,GrayQuantum,0,pixels+x);
+      (void) ExportQuantumPixels(image,&quantum_info,GrayQuantum,pixels+x);
       if (SyncImagePixels(image) == MagickFalse)
         break;
       if (image->previous == (Image *) NULL)
@@ -421,6 +425,9 @@ static MagickBooleanType WriteRAWImage(const ImageInfo *image_info,Image *image)
   MagickOffsetType
     scene;
 
+  QuantumInfo
+    quantum_info;
+
   QuantumType
     quantum_type;
 
@@ -533,10 +540,11 @@ static MagickBooleanType WriteRAWImage(const ImageInfo *image_info,Image *image)
     /*
       Allocate memory for pixels.
     */
+    GetQuantumInfo(image_info,&quantum_info);
     depth=GetImageQuantumDepth(image,MagickFalse);
     packet_size=(size_t) (depth/8);
-    pixels=(unsigned char *)
-      AcquireMagickMemory(packet_size*image->columns*sizeof(*pixels));
+    pixels=(unsigned char *) AcquireMagickMemory(packet_size*image->columns*
+      sizeof(*pixels));
     if (pixels == (unsigned char *) NULL)
       ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
     /*
@@ -547,7 +555,7 @@ static MagickBooleanType WriteRAWImage(const ImageInfo *image_info,Image *image)
       p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
       if (p == (const PixelPacket *) NULL)
         break;
-      (void) ImportQuantumPixels(image,quantum_type,0,pixels);
+      (void) ImportQuantumPixels(image,&quantum_info,quantum_type,pixels);
       (void) WriteBlob(image,packet_size*image->columns,pixels);
       if (image->previous == (Image *) NULL)
         if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
