@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -319,8 +319,8 @@ ModuleExport void RegisterSCTImage(void)
   entry->decoder=(DecoderHandler *) ReadSCTImage;
   entry->magick=(MagickHandler *) IsSCT;
   entry->adjoin=MagickFalse;
-  entry->description=AcquireString("Scitex HandShake");
-  entry->module=AcquireString("SCT");
+  entry->description=ConstantString("Scitex HandShake");
+  entry->module=ConstantString("SCT");
   (void) RegisterMagickInfo(entry);
 }
 
