@@ -77,10 +77,17 @@ typedef struct _SGIInfo
 
   unsigned long
     minimum_value,
-    maximum_value;
+    maximum_value,
+    sans;
 
   unsigned char
-    filler[492];
+    name[80];
+
+  unsigned long
+    pixel_format;
+
+  unsigned char
+    filler[404];
 } SGIInfo;
 
 /*
@@ -302,9 +309,18 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
     iris_info.columns=ReadBlobMSBShort(image);
     iris_info.rows=ReadBlobMSBShort(image);
     iris_info.depth=ReadBlobMSBShort(image);
+    iris_info.minimum_value=ReadBlobMSBLong(image);
+    iris_info.maximum_value=ReadBlobMSBLong(image);
+    iris_info.sans=ReadBlobMSBLong(image);
+    (void) ReadBlob(image,sizeof(iris_info.name),iris_info.name);
+    iris_info.name[sizeof(iris_info.name)-1]='\0';
+    iris_info.pixel_format=ReadBlobMSBLong(image);
+    count=ReadBlob(image,sizeof(iris_info.filler),iris_info.filler);
     image->columns=iris_info.columns;
     image->rows=iris_info.rows;
-    image->depth=(unsigned long) (iris_info.depth <= 8 ? 8 : QuantumDepth);
+    image->depth=Min(iris_info.depth,QuantumDepth);
+    if (iris_info.pixel_format == 0)
+      image->depth=Min(8*iris_info.bytes_per_pixel,QuantumDepth);
     if (iris_info.depth < 3)
       {
         image->storage_class=PseudoClass;
@@ -313,9 +329,6 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if ((image_info->ping != MagickFalse)  && (image_info->number_scenes != 0))
       if (image->scene >= (image_info->scene+image_info->number_scenes-1))
         break;
-    iris_info.minimum_value=ReadBlobMSBLong(image);
-    iris_info.maximum_value=ReadBlobMSBLong(image);
-    count=ReadBlob(image,sizeof(iris_info.filler),iris_info.filler);
     /*
       Allocate SGI pixels.
     */
@@ -324,8 +337,8 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if ((4*bytes_per_pixel*number_pixels) != ((MagickSizeType) (size_t)
         (4*bytes_per_pixel*number_pixels)))
       ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
-    iris_pixels=(unsigned char *)
-      AcquireMagickMemory(4*bytes_per_pixel*iris_info.columns*iris_info.rows);
+    iris_pixels=(unsigned char *) AcquireMagickMemory(4*bytes_per_pixel*
+      iris_info.columns*iris_info.rows);
     if (iris_pixels == (unsigned char *) NULL)
       ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
     if ((int) iris_info.storage != 0x01)
@@ -336,17 +349,16 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
         /*
           Read standard image format.
         */
-        scanline=(unsigned char *)
-          AcquireMagickMemory(bytes_per_pixel*iris_info.columns);
+        scanline=(unsigned char *) AcquireMagickMemory(bytes_per_pixel*
+          iris_info.columns);
         if (scanline == (unsigned char *) NULL)
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
-        for (z=0; z < (int) iris_info.depth; z++)
+        for (z=0; z < (long) iris_info.depth; z++)
         {
           p=iris_pixels+bytes_per_pixel*z;
           for (y=0; y < (long) iris_info.rows; y++)
           {
-            count=ReadBlob(image,bytes_per_pixel*iris_info.columns,
-              scanline);
+            count=ReadBlob(image,bytes_per_pixel*iris_info.columns,scanline);
             if (EOFBlob(image) != MagickFalse)
               break;
             if (bytes_per_pixel == 2)
@@ -386,35 +398,39 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
         */
         offsets=(ssize_t *) AcquireMagickMemory((size_t) iris_info.rows*
           iris_info.depth*sizeof(*offsets));
-        max_packets=(unsigned char *)
-          AcquireMagickMemory(4*(size_t) iris_info.columns+10);
+        max_packets=(unsigned char *) AcquireMagickMemory(4*(size_t)
+          iris_info.columns+10);
         runlength=(unsigned long *) AcquireMagickMemory(iris_info.rows*
           iris_info.depth*sizeof(*runlength));
         if ((offsets == (ssize_t *) NULL) ||
             (max_packets == (unsigned char *) NULL) ||
             (runlength == (unsigned long *) NULL))
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
-        for (i=0; i < (int) (iris_info.rows*iris_info.depth); i++)
+        for (i=0; i < (long) (iris_info.rows*iris_info.depth); i++)
           offsets[i]=(ssize_t) ReadBlobMSBLong(image);
-        for (i=0; i < (int) (iris_info.rows*iris_info.depth); i++)
+        for (i=0; i < (long) (iris_info.rows*iris_info.depth); i++)
+        {
           runlength[i]=ReadBlobMSBLong(image);
+          if (runlength[i] >= (4*(size_t) iris_info.columns+10))
+            ThrowReaderException(CorruptImageError,"ImproperImageHeader");
+        }
         /*
           Check data order.
         */
         offset=0;
-        data_order=MagickFalse;
-        for (y=0; ((y < (long) iris_info.rows) && (data_order == MagickFalse)); y++)
-          for (z=0; ((z < (int) iris_info.depth) && (data_order == MagickFalse)); z++)
+        data_order=0;
+        for (y=0; ((y < (long) iris_info.rows) && (data_order == 0)); y++)
+          for (z=0; ((z < (long) iris_info.depth) && (data_order == 0)); z++)
           {
             if (offsets[y+z*iris_info.rows] < offset)
-              data_order=MagickTrue;
+              data_order=1;
             offset=offsets[y+z*iris_info.rows];
           }
         offset=(ssize_t) (512+4*bytes_per_pixel*2*(iris_info.rows*
           iris_info.depth));
         if (data_order == 1)
           {
-            for (z=0; z < (int) iris_info.depth; z++)
+            for (z=0; z < (long) iris_info.depth; z++)
             {
               p=iris_pixels;
               for (y=0; y < (long) iris_info.rows; y++)
@@ -444,7 +460,7 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
             p=iris_pixels;
             for (y=0; y < (long) iris_info.rows; y++)
             {
-              for (z=0; z < (int) iris_info.depth; z++)
+              for (z=0; z < (long) iris_info.depth; z++)
               {
                 if (offset != offsets[y+z*iris_info.rows])
                   {
@@ -847,8 +863,9 @@ static MagickBooleanType WriteSGIImage(const ImageInfo *image_info,Image *image)
     /*
       Initialize SGI raster file header.
     */
-    if (image_info->colorspace != LogColorspace)
+    if (image_info->colorspace == UndefinedColorspace)
       (void) SetImageColorspace(image,RGBColorspace);
+    (void) ResetMagickMemory(&iris_info,0,sizeof(iris_info));
     iris_info.magic=0x01DA;
     if (image->compression == NoCompression)
       iris_info.storage=(unsigned char) 0x00;
@@ -873,8 +890,6 @@ static MagickBooleanType WriteSGIImage(const ImageInfo *image_info,Image *image)
       }
     iris_info.minimum_value=0;
     iris_info.maximum_value=(unsigned long) ScaleQuantumToChar(QuantumRange);
-    for (i=0; i < (int) sizeof(iris_info.filler); i++)
-      iris_info.filler[i]=(unsigned char) 0;
     /*
       Write SGI header.
     */
@@ -887,6 +902,9 @@ static MagickBooleanType WriteSGIImage(const ImageInfo *image_info,Image *image)
     (void) WriteBlobMSBShort(image,iris_info.depth);
     (void) WriteBlobMSBLong(image,iris_info.minimum_value);
     (void) WriteBlobMSBLong(image,iris_info.maximum_value);
+    (void) WriteBlobMSBLong(image,iris_info.sans);
+    (void) WriteBlob(image,sizeof(iris_info.name),iris_info.name);
+    (void) WriteBlobMSBLong(image,iris_info.pixel_format);
     (void) WriteBlob(image,sizeof(iris_info.filler),iris_info.filler);
     /*
       Allocate SGI pixels.
@@ -937,7 +955,7 @@ static MagickBooleanType WriteSGIImage(const ImageInfo *image_info,Image *image)
           AcquireMagickMemory((size_t) iris_info.columns);
         if (scanline == (unsigned char *) NULL)
           ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
-        for (z=0; z < (int) iris_info.depth; z++)
+        for (z=0; z < (long) iris_info.depth; z++)
         {
           q=iris_pixels+z;
           for (y=0; y < (long) iris_info.rows; y++)
