@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -184,7 +184,8 @@ static Image *ReadSTEGANOImage(const ImageInfo *image_info,
             break;
           }
         }
-        (void) SyncImage(image);
+        if (SyncImagePixels(image) == MagickFalse)
+          break;
         c++;
         if (c == 3)
           c=0;
@@ -239,8 +240,8 @@ ModuleExport void RegisterSTEGANOImage(void)
 
   entry=SetMagickInfo("STEGANO");
   entry->decoder=(DecoderHandler *) ReadSTEGANOImage;
-  entry->description=AcquireString("Steganographic image");
-  entry->module=AcquireString("STEGANO");
+  entry->description=ConstantString("Steganographic image");
+  entry->module=ConstantString("STEGANO");
   (void) RegisterMagickInfo(entry);
 }
 
