@@ -301,8 +301,8 @@ static Image *ReadSUNImage(const ImageInfo *image_info,ExceptionInfo *exception)
     sun_info.type=ReadBlobMSBLong(image);
     sun_info.maptype=ReadBlobMSBLong(image);
     sun_info.maplength=ReadBlobMSBLong(image);
-    image->columns= sun_info.width;
-    image->rows= sun_info.height;
+    image->columns=sun_info.width;
+    image->rows=sun_info.height;
     image->depth=sun_info.depth <= 8 ? 8UL : QuantumDepth;
     if (sun_info.depth < 24)
       {
@@ -708,7 +708,8 @@ static MagickBooleanType WriteSUNImage(const ImageInfo *image_info,Image *image)
     /*
       Initialize SUN raster file header.
     */
-    (void) SetImageColorspace(image,RGBColorspace);
+    if (image_info->colorspace == UndefinedColorspace)
+      (void) SetImageColorspace(image,RGBColorspace);
     sun_info.magic=0x59a66a95;
     sun_info.width=image->columns;
     sun_info.height=image->rows;
@@ -820,19 +821,24 @@ static MagickBooleanType WriteSUNImage(const ImageInfo *image_info,Image *image)
     else
       if (IsMonochromeImage(image,&image->exception))
         {
+          IndexPacket
+            polarity;
+
           register unsigned char
             bit,
-            byte,
-            polarity;
+            byte;
 
           /*
             Convert PseudoClass image to a SUN monochrome image.
           */
+          (void) SetImageType(image,PaletteType);
           (void) SetImageType(image,BilevelType);
-          polarity=PixelIntensityToQuantum(&image->colormap[0]) < (QuantumRange/2);
+          polarity=(IndexPacket) (PixelIntensityToQuantum(&image->colormap[0]) <
+            (QuantumRange/2) ? 1 : 0);
           if (image->colors == 2)
-            polarity=PixelIntensityToQuantum(&image->colormap[0]) <
-              PixelIntensityToQuantum(&image->colormap[1]);
+            polarity=(IndexPacket) (
+              PixelIntensityToQuantum(&image->colormap[0]) <
+              PixelIntensityToQuantum(&image->colormap[1]) ? 1 : 0);
           for (y=0; y < (long) image->rows; y++)
           {
             p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
