@@ -68,6 +68,41 @@ static MagickBooleanType
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   I s T G A                                                                 %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  IsTGA() returns MagickTrue if the image format type, identified by the
+%  magick string, is a Microsoft Windows Enhanced MetaFile (TGA) file.
+%
+%  The format of the ReadTGAImage method is:
+%
+%      MagickBooleanType IsTGA(const unsigned char *magick,const size_t length)
+%
+%  A description of each parameter follows:
+%
+%    o magick: This string is generally the first few bytes of an image file
+%      or blob.
+%
+%    o length: Specifies the length of the magick string.
+%
+*/
+static MagickBooleanType IsTGA(const unsigned char *magick,const size_t length)
+{
+  if (length < 4)
+    return(MagickFalse);
+  if (memcmp(magick,"\000\000\002\000",4) == 0)
+    return(MagickTrue);
+  return(MagickFalse);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   R e a d T G A I m a g e                                                   %
 %                                                                             %
 %                                                                             %
@@ -398,6 +433,9 @@ static Image *ReadTGAImage(const ImageInfo *image_info,ExceptionInfo *exception)
               pixel.green=ScaleAnyToQuantum(((int) (k & 0x03) << 3)+
                 ((int) (j & 0xe0) >> 5),31);
               pixel.blue=ScaleAnyToQuantum((int) (j & 0x1f),31);
+              if (image->matte != MagickFalse)
+                pixel.opacity=(k & 0x80) != 0? TransparentOpacity :
+                  OpaqueOpacity; 
               if (image->storage_class == PseudoClass)
                 index=ConstrainColormapIndex(image,((unsigned long) k << 8)+j);
               break;
@@ -423,7 +461,12 @@ static Image *ReadTGAImage(const ImageInfo *image_info,ExceptionInfo *exception)
           ThrowReaderException(CorruptImageError,"UnableToReadImageData");
         if (image->storage_class == PseudoClass)
           indexes[x]=index;
-        *q++=pixel;
+        q->red=pixel.red;
+        q->green=pixel.green;
+        q->blue=pixel.blue;
+        if (image->matte != MagickFalse)
+          q->opacity=pixel.opacity;
+        q++;
       }
       if (((unsigned char) (tga_info.attributes & 0xc0) >> 6) == 4)
         offset+=4;
@@ -526,24 +569,28 @@ ModuleExport void RegisterTGAImage(void)
   entry=SetMagickInfo("ICB");
   entry->decoder=(DecoderHandler *) ReadTGAImage;
   entry->encoder=(EncoderHandler *) WriteTGAImage;
+  entry->magick=(MagickHandler *) IsTGA;
   entry->description=ConstantString("Truevision Targa image");
   entry->module=ConstantString("TGA");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("TGA");
   entry->decoder=(DecoderHandler *) ReadTGAImage;
   entry->encoder=(EncoderHandler *) WriteTGAImage;
+  entry->magick=(MagickHandler *) IsTGA;
   entry->description=ConstantString("Truevision Targa image");
   entry->module=ConstantString("TGA");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("VDA");
   entry->decoder=(DecoderHandler *) ReadTGAImage;
   entry->encoder=(EncoderHandler *) WriteTGAImage;
+  entry->magick=(MagickHandler *) IsTGA;
   entry->description=ConstantString("Truevision Targa image");
   entry->module=ConstantString("TGA");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("VST");
   entry->decoder=(DecoderHandler *) ReadTGAImage;
   entry->encoder=(EncoderHandler *) WriteTGAImage;
+  entry->magick=(MagickHandler *) IsTGA;
   entry->description=ConstantString("Truevision Targa image");
   entry->module=ConstantString("TGA");
   (void) RegisterMagickInfo(entry);
@@ -690,7 +737,10 @@ static MagickBooleanType WriteTGAImage(const ImageInfo *image_info,Image *image)
     /*
       Initialize TGA raster file header.
     */
-    (void) SetImageColorspace(image,RGBColorspace);
+    if ((image->columns > 65535L) || (image->rows > 65535L))
+      ThrowWriterException(ImageError,"WidthOrHeightExceedsLimit");
+    if (image_info->colorspace == UndefinedColorspace)
+      (void) SetImageColorspace(image,RGBColorspace);
     targa_info.id_length=0;
     attribute=GetImageAttribute(image,"Comment");
     if (attribute != (const ImageAttribute *) NULL)
