@@ -312,6 +312,9 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
   char
     *text;
 
+  const char
+    *option;
+
   float
     *chromaticity,
     x_position,
@@ -539,7 +542,7 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
 #endif
 #if defined(TIFFTAG_PHOTOSHOP)
     if (TIFFGetField(tiff,TIFFTAG_PHOTOSHOP,&length,&profile) == 1)
-      (void) ReadProfile(image,"iptc",profile,(long) length);
+      (void) ReadProfile(image,"8bim",profile,(long) length);
 #endif
 #if defined(TIFFTAG_RICHTIFFIPTC)
     if (TIFFGetField(tiff,TIFFTAG_RICHTIFFIPTC,&length,&profile) == 1)
@@ -604,6 +607,10 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
             associated_alpha=MagickTrue;
           }
       }
+    option=GetImageOption(image_info,"tiff:alpha");
+    if (option != (const char *) NULL)
+      associated_alpha=LocaleCompare(option,"associate") ? MagickTrue :
+        MagickFalse;
     if ((samples_per_pixel <= 2) && (TIFFIsTiled(tiff) == MagickFalse) &&
         (image->compression != JPEGCompression) &&
         ((photometric == PHOTOMETRIC_MINISBLACK) ||
@@ -908,8 +915,7 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
             q->green=ScaleCharToQuantum((unsigned char) TIFFGetG(*p));
             q->blue=ScaleCharToQuantum((unsigned char) TIFFGetB(*p));
             if (image->matte != MagickFalse)
-              q->opacity=(Quantum)
-                ScaleCharToQuantum((unsigned char) TIFFGetA(*p));
+              q->opacity=ScaleCharToQuantum((unsigned char) TIFFGetA(*p));
             p++;
             q++;
           }
@@ -970,7 +976,7 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
             rows_remaining;
 
           rows_remaining=image->rows-y;
-          if ((y+rows) < (long) image->rows)
+          if ((y+rows) < image->rows)
             rows_remaining=rows;
           tile=SetImagePixels(image,0,y,image->columns,rows_remaining);
           if (tile == (PixelPacket *) NULL)
@@ -984,7 +990,7 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
             if (TIFFReadRGBATile(tiff,(uint32) x,(uint32) y,tile_pixels) == 0)
               break;
             columns_remaining=image->columns-x;
-            if ((x+columns) < (long) image->columns)
+            if ((x+columns) < image->columns)
               columns_remaining=columns;
             p=tile_pixels+(rows-rows_remaining)*columns;
             q=tile+(image->columns*(rows_remaining-1)+x);
@@ -1044,8 +1050,8 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
             TIFFClose(tiff);
             ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
           }
-        pixels=(uint32 *)
-          AcquireMagickMemory((size_t) number_pixels*sizeof(*pixels));
+        pixels=(uint32 *) AcquireMagickMemory((size_t) number_pixels*
+          sizeof(*pixels));
         if (pixels == (uint32 *) NULL)
           {
             TIFFClose(tiff);
@@ -1069,8 +1075,7 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
             q->green=ScaleCharToQuantum((unsigned char) TIFFGetG(*p));
             q->blue=ScaleCharToQuantum((unsigned char) TIFFGetB(*p));
             if (image->matte != MagickFalse)
-              q->opacity=(Quantum)
-                ScaleCharToQuantum((unsigned char) TIFFGetA(*p));
+              q->opacity=ScaleCharToQuantum((unsigned char) TIFFGetA(*p));
             p--;
             q--;
           }
@@ -1107,9 +1112,9 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
           {
             gamma=QuantumScale*((MagickRealType) QuantumRange-q->opacity);
             gamma=1.0/(fabs(gamma) <= MagickEpsilon ? 1.0 : gamma);
-            q->red=(Quantum) (gamma*q->red);
-            q->green=(Quantum) (gamma*q->green);
-            q->blue=(Quantum) (gamma*q->blue);
+            q->red=RoundToQuantum(gamma*q->red);
+            q->green=RoundToQuantum(gamma*q->green);
+            q->blue=RoundToQuantum(gamma*q->blue);
             q++;
           }
           if (SyncImagePixels(image) == MagickFalse)
@@ -1883,13 +1888,6 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
 #endif
           if (LocaleCompare(name,"iptc") == 0)
             {
-#if defined(TIFFTAG_PHOTOSHOP)
-              uint32
-                length;
-
-              length=(uint32) (profile->length+(profile->length & 0x01));
-              (void) TIFFSetField(tiff,TIFFTAG_PHOTOSHOP,length,profile->datum);
-#else
               size_t
                 length;
 
@@ -1904,6 +1902,15 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
               (void) TIFFSetField(tiff,TIFFTAG_RICHTIFFIPTC,
                 (uint32) iptc_profile->length/4,iptc_profile->datum);
               iptc_profile=DestroyStringInfo(iptc_profile);
+            }
+          if (LocaleCompare(name,"8bim") == 0)
+            {
+#if defined(TIFFTAG_PHOTOSHOP)
+              uint32
+                length;
+
+              length=(uint32) (profile->length+(profile->length & 0x01));
+              (void) TIFFSetField(tiff,TIFFTAG_PHOTOSHOP,length,profile->datum);
 #endif
             }
           if (LocaleCompare(name,"tiff:37724") == 0)
