@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -192,6 +192,8 @@ static Image *ReadTIMImage(const ImageInfo *image_info,ExceptionInfo *exception)
         (void)ReadBlobLSBShort(image);
         width=ReadBlobLSBShort(image);
         height=ReadBlobLSBShort(image);
+        image->columns=width;
+        image->rows=height;
         if (AllocateImageColormap(image,pixel_mode == 1 ? 256 : 16) == MagickFalse)
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
         tim_colormap=(unsigned char *) AcquireMagickMemory(image->colors*2);
@@ -443,8 +445,8 @@ ModuleExport void RegisterTIMImage(void)
 
   entry=SetMagickInfo("TIM");
   entry->decoder=(DecoderHandler *) ReadTIMImage;
-  entry->description=AcquireString("PSX TIM");
-  entry->module=AcquireString("TIM");
+  entry->description=ConstantString("PSX TIM");
+  entry->module=ConstantString("TIM");
   (void) RegisterMagickInfo(entry);
 }
 
