@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -54,8 +54,8 @@
 #include "magick/static.h"
 #include "magick/string_.h"
 #include "magick/type.h"
-#include "wand/magick-wand.h"
-#if defined(HasTTF)
+#include "wand/MagickWand.h"
+#if defined(HasFREETYPE)
 #if defined(HAVE_FT2BUILD_H)
 #  include <ft2build.h>
 #endif
@@ -140,7 +140,7 @@ static MagickBooleanType IsTTF(const unsigned char *magick,const size_t length)
   return(MagickFalse);
 }
 
-#if defined(HasTTF)
+#if defined(HasFREETYPE)
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
@@ -284,7 +284,7 @@ static Image *ReadTTFImage(const ImageInfo *image_info,ExceptionInfo *exception)
   CloseBlob(image);
   return(GetFirstImageInList(image));
 }
-#endif /* HasTTF */
+#endif /* HasFREETYPE */
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -323,59 +323,59 @@ ModuleExport void RegisterTTFImage(void)
     FREETYPE_MAJOR,FREETYPE_MINOR,FREETYPE_PATCH);
 #endif
   entry=SetMagickInfo("PFA");
-#if defined(HasTTF)
+#if defined(HasFREETYPE)
   entry->decoder=(DecoderHandler *) ReadTTFImage;
 #endif
   entry->magick=(MagickHandler *) IsPFA;
   entry->adjoin=MagickFalse;
-  entry->description=AcquireString("Postscript Type 1 font (ASCII)");
+  entry->description=ConstantString("Postscript Type 1 font (ASCII)");
   if (*version != '\0')
-    entry->version=AcquireString(version);
-  entry->module=AcquireString("TTF");
+    entry->version=ConstantString(version);
+  entry->module=ConstantString("TTF");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("PFB");
-#if defined(HasTTF)
+#if defined(HasFREETYPE)
   entry->decoder=(DecoderHandler *) ReadTTFImage;
 #endif
   entry->magick=(MagickHandler *) IsPFA;
   entry->adjoin=MagickFalse;
-  entry->description=AcquireString("Postscript Type 1 font (binary)");
+  entry->description=ConstantString("Postscript Type 1 font (binary)");
   if (*version != '\0')
-    entry->version=AcquireString(version);
-  entry->module=AcquireString("TTF");
+    entry->version=ConstantString(version);
+  entry->module=ConstantString("TTF");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("OTF");
-#if defined(HasTTF)
+#if defined(HasFREETYPE)
   entry->decoder=(DecoderHandler *) ReadTTFImage;
 #endif
   entry->magick=(MagickHandler *) IsTTF;
   entry->adjoin=MagickFalse;
-  entry->description=AcquireString("Open Type font");
+  entry->description=ConstantString("Open Type font");
   if (*version != '\0')
-    entry->version=AcquireString(version);
-  entry->module=AcquireString("TTF");
+    entry->version=ConstantString(version);
+  entry->module=ConstantString("TTF");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("TTC");
-#if defined(HasTTF)
+#if defined(HasFREETYPE)
   entry->decoder=(DecoderHandler *) ReadTTFImage;
 #endif
   entry->magick=(MagickHandler *) IsTTF;
   entry->adjoin=MagickFalse;
-  entry->description=AcquireString("TrueType font collection");
+  entry->description=ConstantString("TrueType font collection");
   if (*version != '\0')
-    entry->version=AcquireString(version);
-  entry->module=AcquireString("TTF");
+    entry->version=ConstantString(version);
+  entry->module=ConstantString("TTF");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("TTF");
-#if defined(HasTTF)
+#if defined(HasFREETYPE)
   entry->decoder=(DecoderHandler *) ReadTTFImage;
 #endif
   entry->magick=(MagickHandler *) IsTTF;
   entry->adjoin=MagickFalse;
-  entry->description=AcquireString("TrueType font");
+  entry->description=ConstantString("TrueType font");
   if (*version != '\0')
-    entry->version=AcquireString(version);
-  entry->module=AcquireString("TTF");
+    entry->version=ConstantString(version);
+  entry->module=ConstantString("TTF");
   (void) RegisterMagickInfo(entry);
 }
 
