@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -205,8 +205,8 @@ static Image *ReadVIDImage(const ImageInfo *image_info,ExceptionInfo *exception)
   montage_info=CloneMontageInfo(image_info,(MontageInfo *) NULL);
   if (image_info->debug != MagickFalse)
     (void) LogMagickEvent(CoderEvent,GetMagickModule(),"creating montage");
-  montage_image=MontageImages(GetFirstImageInList(images),montage_info,
-    exception);
+  montage_image=MontageImageList(image_info,montage_info,
+    GetFirstImageInList(images),exception);
   montage_info=DestroyMontageInfo(montage_info);
   images=DestroyImageList(images);
   return(montage_image);
@@ -243,8 +243,8 @@ ModuleExport void RegisterVIDImage(void)
   entry=SetMagickInfo("VID");
   entry->decoder=(DecoderHandler *) ReadVIDImage;
   entry->encoder=(EncoderHandler *) WriteVIDImage;
-  entry->description=AcquireString("Visual Image Directory");
-  entry->module=AcquireString("VID");
+  entry->description=ConstantString("Visual Image Directory");
+  entry->module=ConstantString("VID");
   (void) RegisterMagickInfo(entry);
 }
 
@@ -302,6 +302,9 @@ static MagickBooleanType WriteVIDImage(const ImageInfo *image_info,Image *image)
   Image
     *montage_image;
 
+  ImageInfo
+    *write_info;
+
   MagickBooleanType
     status;
 
@@ -317,12 +320,19 @@ static MagickBooleanType WriteVIDImage(const ImageInfo *image_info,Image *image)
   for (p=image; p != (Image *) NULL; p=GetNextImageInList(p))
     (void) SetImageAttribute(p,"Label",DefaultTileLabel);
   montage_info=CloneMontageInfo(image_info,(MontageInfo *) NULL);
-  montage_image=MontageImages(image,montage_info,&image->exception);
+  montage_image=MontageImageList(image_info,montage_info,image,
+    &image->exception);
   if (montage_image == (Image *) NULL)
     ThrowWriterException(CorruptImageError,image->exception.reason);
-  (void) FormatMagickString(montage_image->filename,MaxTextExtent,
-    "miff:%s",image->filename);
-  status=WriteImage(image_info,montage_image);
-  (void) DestroyImageList(montage_image);
+  (void) CopyMagickString(montage_image->filename,image_info->filename,
+    MaxTextExtent);
+  write_info=CloneImageInfo(image_info);
+  (void) SetImageInfo(write_info,MagickTrue,&image->exception);
+  if (LocaleCompare(write_info->magick,"VID") == 0)
+    (void) FormatMagickString(montage_image->filename,MaxTextExtent,
+      "miff:%s",image_info->filename);
+  status=WriteImage(write_info,montage_image);
+  montage_image=DestroyImage(montage_image);
+  write_info=DestroyImageInfo(write_info);
   return(status);
 }
