@@ -609,17 +609,19 @@ static Image *ReadVIFFImage(const ImageInfo *image_info,
     p=(unsigned char *) viff_pixels;
     if (viff_info.data_storage_type == VFF_TYP_BIT)
       {
-        unsigned int
+        IndexPacket
           polarity;
 
         /*
           Convert bitmap scanline.
         */
-        SetImageType(image,BilevelType);
-        polarity=PixelIntensityToQuantum(&image->colormap[0]) < (QuantumRange/2);
+        (void) SetImageType(image,PaletteType);
+        (void) SetImageType(image,BilevelType);
+        polarity=(IndexPacket) (PixelIntensityToQuantum(&image->colormap[0]) <
+          (QuantumRange/2) ? 1 : 0);
         if (image->colors >= 2)
-          polarity=PixelIntensityToQuantum(&image->colormap[0]) >
-            PixelIntensityToQuantum(&image->colormap[1]);
+          polarity=(IndexPacket) (PixelIntensityToQuantum(&image->colormap[0]) >
+            PixelIntensityToQuantum(&image->colormap[1]) ? 1 : 0);
         for (y=0; y < (long) image->rows; y++)
         {
           q=SetImagePixels(image,0,y,image->columns,1);
@@ -1158,23 +1160,28 @@ static MagickBooleanType WriteVIFFImage(const ImageInfo *image_info,
       else
         if (image->colors <= 2)
           {
+            IndexPacket
+              polarity;
+
             long
               x,
               y;
 
             register unsigned char
               bit,
-              byte,
-              polarity;
+              byte;
 
             /*
               Convert PseudoClass image to a VIFF monochrome image.
             */
-            SetImageType(image,BilevelType);
-            polarity=PixelIntensityToQuantum(&image->colormap[0]) < (QuantumRange/2);
+            (void) SetImageType(image,PaletteType);
+            (void) SetImageType(image,BilevelType);
+            polarity=(IndexPacket) (PixelIntensityToQuantum(
+              &image->colormap[0]) < (QuantumRange/2) ? 1 : 0);
             if (image->colors == 2)
-              polarity=PixelIntensityToQuantum(&image->colormap[0]) <
-                PixelIntensityToQuantum(&image->colormap[1]);
+              polarity=(IndexPacket) (
+                PixelIntensityToQuantum(&image->colormap[0]) <
+                PixelIntensityToQuantum(&image->colormap[1]) ? 1 : 0);
             for (y=0; y < (long) image->rows; y++)
             {
               p=AcquireImagePixels(image,0,y,image->columns,1,
