@@ -64,7 +64,7 @@
 #include "magick/string_.h"
 #include "magick/type.h"
 #include "magick/version.h"
-#include "wand/magick-wand.h"
+#include "wand/MagickWand.h"
 
 #if defined(HasWMF) || defined(HasWMFlite)
 
@@ -532,7 +532,7 @@ static void ipa_bmp_draw(wmfAPI *API, wmfBMP_Draw_t *bmp_draw)
   QueryColorDatabase( "white", &white, &exception );
 
   if ( ddata->image_info->texture ||
-       !(ColorMatch(&ddata->image_info->background_color,&white)) ||
+       !(IsColorEqual(&ddata->image_info->background_color,&white)) ||
        ddata->image_info->background_color.opacity != OpaqueOpacity )
   {
     MagickPixelPacket
@@ -583,8 +583,8 @@ static void ipa_bmp_read(wmfAPI * API, wmfBMP_Read_t * bmp_read) {
 
   GetExceptionInfo(&exception);
 
-  image_info = CloneImageInfo((ImageInfo *) 0);
-  strcpy(image_info->magick, "DIB");
+  image_info=CloneImageInfo((ImageInfo *) 0);
+  (void) CopyMagickString(image_info->magick,"DIB",MaxTextExtent);
   if (bmp_read->width || bmp_read->height)
     {
       char
@@ -724,8 +724,8 @@ static void ipa_device_begin(wmfAPI * API)
       GetExceptionInfo(&exception);
 
       image_info = CloneImageInfo((ImageInfo *) 0);
-      strcpy(image_info->filename, ddata->image_info->texture);
-
+      (void) CopyMagickString(image_info->filename,ddata->image_info->texture,
+        MaxTextExtent);
       if ( ddata->image_info->size )
         CloneString(&image_info->size,ddata->image_info->size);
 
@@ -739,7 +739,7 @@ static void ipa_device_begin(wmfAPI * API)
           MagickWand
             *magick_wand;
 
-          (void) strcpy(image->magick,"MIFF");
+          (void) CopyMagickString(image->magick,"MIFF",MaxTextExtent);
           DrawPushDefs(WmfDrawingWand);
           draw_pattern_push(API,ddata->pattern_id,image->columns,image->rows);
           magick_wand=NewMagickWandFromImage(image);
@@ -1369,7 +1369,7 @@ static void ipa_draw_text(wmfAPI * API, wmfDrawText_t * draw_text)
       ImageInfo
         *image_info;
 
-      image_info = CloneImageInfo((ImageInfo *) NULL);
+      image_info = AcquireImageInfo();
       CloneString(&image_info->font, WMF_FONT_PSNAME(font));
       image_info->pointsize = pointsize;
       GetDrawInfo(image_info, &draw_info);
@@ -1993,7 +1993,7 @@ static double util_pointsize( wmfAPI* API, wmfFont* font, char* str, double font
   double
     pointsize = 0;
 
-  image_info = CloneImageInfo((ImageInfo *) NULL);
+  image_info = AcquireImageInfo();
   CloneString(&image_info->font, WMF_FONT_PSNAME(font));
   image_info->pointsize = font_height;
   GetDrawInfo(image_info, &draw_info);
@@ -2114,7 +2114,7 @@ static float lite_font_stringwidth( wmfAPI* API, wmfFont* font, char* str)
   orig_y_resolution = image->y_resolution;
   orig_resolution_units = image->units;
 
-  image_info = CloneImageInfo((ImageInfo *) NULL);
+  image_info = AcquireImageInfo();
   CloneString(&image_info->font, WMF_FONT_PSNAME(font));
   image_info->pointsize = 12;
   GetDrawInfo(image_info, &draw_info);
@@ -2261,12 +2261,13 @@ static void lite_font_map( wmfAPI* API, wmfFont* font)
                                        strstr(wmf_font_name,"Oblique"))) )
         want_italic = MagickTrue;
 
-      strcpy(target,"Times");
+      (void) CopyMagickString(target,"Times",MaxTextExtent);
       for( i=0; SubFontMap[i].name != NULL; i++ )
         {
           if (LocaleCompare(wmf_font_name, SubFontMap[i].name) == 0)
             {
-              strcpy(target,SubFontMap[i].mapping);
+              (void) CopyMagickString(target,SubFontMap[i].mapping,
+                MaxTextExtent);
               break;
             }
         }
