@@ -507,7 +507,8 @@ static MagickBooleanType WriteXBMImage(const ImageInfo *image_info,Image *image)
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
-  (void) SetImageColorspace(image,RGBColorspace);
+  if (image_info->colorspace == UndefinedColorspace)
+    (void) SetImageColorspace(image,RGBColorspace);
   /*
     Write X bitmap header.
   */
@@ -521,23 +522,24 @@ static MagickBooleanType WriteXBMImage(const ImageInfo *image_info,Image *image)
   (void) FormatMagickString(buffer,MaxTextExtent,
     "static char %s_bits[] = {\n",basename);
   (void) WriteBlob(image,strlen(buffer),(unsigned char *) buffer);
-  (void) strcpy(buffer," ");
+  (void) CopyMagickString(buffer," ",MaxTextExtent);
   (void) WriteBlob(image,strlen(buffer),(unsigned char *) buffer);
   /*
     Convert MIFF to X bitmap pixels.
   */
+  (void) SetImageType(image,PaletteType);
   (void) SetImageType(image,BilevelType);
-  polarity=(IndexPacket)
-    (PixelIntensityToQuantum(&image->colormap[0]) < (QuantumRange/2));
+  polarity=(IndexPacket) (PixelIntensityToQuantum(&image->colormap[0]) <
+    (QuantumRange/2) ? 1 : 0);
   if (image->colors == 2)
     polarity=(IndexPacket) (PixelIntensityToQuantum(&image->colormap[0]) <
-      PixelIntensityToQuantum(&image->colormap[1]));
+      PixelIntensityToQuantum(&image->colormap[1]) ? 1 : 0);
   bit=0;
   byte=0;
   count=0;
   x=0;
   y=0;
-  (void) strcpy(buffer," ");
+  (void) CopyMagickString(buffer," ",MaxTextExtent);
   (void) WriteBlob(image,strlen(buffer),(unsigned char *) buffer);
   for (y=0; y < (long) image->rows; y++)
   {
@@ -562,7 +564,7 @@ static MagickBooleanType WriteXBMImage(const ImageInfo *image_info,Image *image)
           count++;
           if (count == 12)
             {
-              (void) strcpy(buffer,"\n  ");
+              (void) CopyMagickString(buffer,"\n  ",MaxTextExtent);
               (void) WriteBlob(image,strlen(buffer),(unsigned char *) buffer);
               count=0;
             };
@@ -583,7 +585,7 @@ static MagickBooleanType WriteXBMImage(const ImageInfo *image_info,Image *image)
         count++;
         if (count == 12)
           {
-            (void) strcpy(buffer,"\n  ");
+            (void) CopyMagickString(buffer,"\n  ",MaxTextExtent);
             (void) WriteBlob(image,strlen(buffer),(unsigned char *) buffer);
             count=0;
           };
@@ -600,7 +602,7 @@ static MagickBooleanType WriteXBMImage(const ImageInfo *image_info,Image *image)
             break;
         }
   }
-  (void) strcpy(buffer,"};\n");
+  (void) CopyMagickString(buffer,"};\n",MaxTextExtent);
   (void) WriteBlob(image,strlen(buffer),(unsigned char *) buffer);
   CloseBlob(image);
   return(MagickTrue);
