@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -200,8 +200,8 @@ ModuleExport void RegisterXCImage(void)
   entry->adjoin=MagickFalse;
   entry->raw=MagickTrue;
   entry->endian_support=MagickTrue;
-  entry->description=AcquireString("Constant image uniform color");
-  entry->module=AcquireString("XC");
+  entry->description=ConstantString("Constant image uniform color");
+  entry->module=ConstantString("XC");
   (void) RegisterMagickInfo(entry);
 }
 
