@@ -702,6 +702,7 @@ static MagickBooleanType ReadOneLayer(Image* image,XCFDocInfo* inDocInfo,
   if (outLayer->image == (Image *) NULL)
     return MagickFalse;
 
+
   /* read the layer properties! */
   foundPropEnd = 0;
   while ( foundPropEnd  == MagickFalse ) {
@@ -1258,9 +1259,14 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
         /* now reverse the order of the layers as they are put
            into subimages
         */
-        image->next=layer_info[number_layers-2].image;
-        layer_info[number_layers-2].image->previous=image;
-        for (j=number_layers-2; j>=0; j--)
+        j=number_layers-2;
+        image->next=layer_info[j].image;
+        layer_info[j].image->previous=image;
+        layer_info[j].image->page.x = layer_info[j].offset_x;
+        layer_info[j].image->page.y = layer_info[j].offset_y;
+        layer_info[j].image->page.width = layer_info[j].width;
+        layer_info[j].image->page.height = layer_info[j].height;
+        for (j=number_layers-3; j>=0; j--)
         {
           if (j > 0)
             layer_info[j].image->next=layer_info[j-1].image;
