@@ -275,7 +275,7 @@ static Image *ReadXPMImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if (count == 4)
       break;
   }
-  if ((count != 4) || (width > 2) || (image->columns == 0) ||
+  if ((count != 4) || (width > 10) || (image->columns == 0) ||
       (image->rows == 0) || (image->colors == 0))
     ThrowReaderException(CorruptImageError,"ImproperImageHeader");
   image->depth=16;
@@ -335,7 +335,7 @@ static Image *ReadXPMImage(const ImageInfo *image_info,ExceptionInfo *exception)
     /*
       Parse color.
     */
-    (void) strcpy(target,"gray");
+    (void) CopyMagickString(target,"gray",MaxTextExtent);
     q=ParseColor(p+width);
     if (q != (char *) NULL)
       {
@@ -352,7 +352,7 @@ static Image *ReadXPMImage(const ImageInfo *image_info,ExceptionInfo *exception)
         image->storage_class=DirectClass;
         image->matte=MagickTrue;
         none=j;
-        (void) strcpy(target,"black");
+        (void) CopyMagickString(target,"black",MaxTextExtent);
       }
     if (QueryColorDatabase(target,&image->colormap[j],exception) == MagickFalse)
       break;
@@ -615,7 +615,8 @@ static MagickBooleanType WritePICONImage(const ImageInfo *image_info,
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
-  (void) SetImageColorspace(image,RGBColorspace);
+  if (image_info->colorspace == UndefinedColorspace)
+    (void) SetImageColorspace(image,RGBColorspace);
   SetGeometry(image,&geometry);
   (void) ParseMetaGeometry(PiconGeometry,&geometry.x,&geometry.y,
     &geometry.width,&geometry.height);
@@ -723,7 +724,7 @@ static MagickBooleanType WritePICONImage(const ImageInfo *image_info,
     if (transparent != MagickFalse)
       {
         if (i == (long) (colors-1))
-          (void) strcpy(name,"grey75");
+          (void) CopyMagickString(name,"grey75",MaxTextExtent);
       }
     /*
       Write XPM color.
@@ -860,7 +861,8 @@ static MagickBooleanType WriteXPMImage(const ImageInfo *image_info,Image *image)
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
-  (void) SetImageColorspace(image,RGBColorspace);
+    if (image_info->colorspace == UndefinedColorspace)
+    (void) SetImageColorspace(image,RGBColorspace);
   transparent=MagickFalse;
   if (image->storage_class == PseudoClass)
     {
@@ -932,6 +934,14 @@ static MagickBooleanType WriteXPMImage(const ImageInfo *image_info,Image *image)
   */
   (void) WriteBlobString(image,"/* XPM */\n");
   GetPathComponent(image->filename,BasePath,basename);
+  if (isalnum((int) ((unsigned char) *basename)) == 0)
+    {
+      (void) FormatMagickString(buffer,MaxTextExtent,"xpm_%s",basename);
+      (void) CopyMagickString(basename,buffer,MaxTextExtent);
+    }
+  for (i=0; basename[i] != '\0'; i++)
+    if (isalpha((int) ((unsigned char) basename[i])) == 0)
+      basename[i]='_';
   (void) FormatMagickString(buffer,MaxTextExtent,
     "static char *%s[] = {\n",basename);
   (void) WriteBlobString(image,buffer);
@@ -950,7 +960,7 @@ static MagickBooleanType WriteXPMImage(const ImageInfo *image_info,Image *image)
     if (transparent != MagickFalse)
       {
         if (i == (long) (colors-1))
-          (void) strcpy(name,"None");
+          (void) CopyMagickString(name,"None",MaxTextExtent);
       }
     /*
       Write XPM color.
