@@ -57,14 +57,21 @@
 %
 %  The format of the AnalyzeImage method is:
 %
-%      MagickBooleanType AnalyzeImage(Image *image)
+%      MagickBooleanType AnalyzeImage(Image *images,const int argc,
+%        char **argv)
 %
 %  A description of each parameter follows:
 %
 %    o image: The address of a structure of type Image.
 %
+%    o argc: Specifies a pointer to an integer describing the number of
+%      elements in the argument vector.
+%
+%    o argv: Specifies a pointer to a text array containing the command line
+%      arguments.
+%
 */
-ModuleExport MagickBooleanType AnalyzeImage(Image **image,const int argc,
+ModuleExport MagickBooleanType AnalyzeImage(Image **images,const int argc,
   char **argv)
 {
 #define PRECISION "%.0f"
@@ -73,21 +80,24 @@ ModuleExport MagickBooleanType AnalyzeImage(Image **image,const int argc,
     text[MaxTextExtent];
 
   double
-    bsumX = 0.0,
-    bsumX2 = 0.0,
-    brightness_mean = 0.0,
-    brightness_stdev = 0.0,
-    ssumX = 0.0,
-    ssumX2 = 0.0,
-    saturation_mean = 0.0,
-    saturation_stdev = 0.0,
-    total_pixels = 0.0;
+    bsumX,
+    bsumX2,
+    brightness_mean,
+    brightness_stdev,
+    ssumX,
+    ssumX2,
+    saturation_mean,
+    saturation_stdev,
+    total_pixels;
 
   double
     brightness,
     hue,
     saturation;
 
+  Image
+    *image;
+
   long
     y;
 
@@ -97,41 +107,57 @@ ModuleExport MagickBooleanType AnalyzeImage(Image **image,const int argc,
   register long
     x;
 
-  assert(image != (Image **) NULL);
-  assert(*image != (Image *) NULL);
-  for (y=0; y < (int) (*image)->rows; y++)
+  assert(images != (Image **) NULL);
+  assert(*images != (Image *) NULL);
+  assert((*images)->signature == MagickSignature);
+  image=(*images);
+  for ( ; image != (Image *) NULL; image=GetNextImageInList(image))
   {
-    p=AcquireImagePixels((*image),0,y,(*image)->columns,1,&(*image)->exception);
-    if (p == (const PixelPacket *) NULL)
-      break;
-    for (x=0; x < (long) (*image)->columns; x++)
+    bsumX = 0.0,
+    bsumX2 = 0.0,
+    brightness_mean = 0.0,
+    brightness_stdev = 0.0,
+    ssumX = 0.0,
+    ssumX2 = 0.0,
+    saturation_mean = 0.0,
+    saturation_stdev = 0.0,
+    total_pixels = 0.0;
+    for (y=0; y < (long) image->rows; y++)
     {
-      TransformHSB(p->red,p->green,p->blue,&hue,&saturation,&brightness);
-      brightness*=QuantumRange;
-      bsumX+=brightness;
-      bsumX2+=brightness*brightness;
-      saturation*=QuantumRange;
-      ssumX+=saturation;
-      ssumX2+=saturation*saturation;
-      total_pixels++;
-      p++;
+      p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
+      if (p == (const PixelPacket *) NULL)
+        break;
+      for (x=0; x < (long) image->columns; x++)
+      {
+        TransformHSB(p->red,p->green,p->blue,&hue,&saturation,&brightness);
+        brightness*=QuantumRange;
+        bsumX+=brightness;
+        bsumX2+=brightness*brightness;
+        saturation*=QuantumRange;
+        ssumX+=saturation;
+        ssumX2+=saturation*saturation;
+        total_pixels++;
+        p++;
+      }
     }
+    if (total_pixels <= 0.0)
+      return(MagickFalse);
+    brightness_mean=bsumX/total_pixels;
+    (void) FormatMagickString(text,MaxTextExtent,PRECISION,brightness_mean);
+    (void) SetImageAttribute(image,"BrightnessMean",text);
+    brightness_stdev=sqrt(bsumX2/total_pixels-(bsumX/total_pixels*bsumX/
+      total_pixels));
+    (void) FormatMagickString(text,MaxTextExtent,PRECISION,brightness_stdev);
+    (void) SetImageAttribute(image,"BrightnessStddev",text);
+    saturation_mean=ssumX/total_pixels;
+    (void) FormatMagickString(text,MaxTextExtent,PRECISION,saturation_mean);
+    (void) SetImageAttribute(image,"SaturationMean",text);
+    saturation_stdev=sqrt(ssumX2/total_pixels-(ssumX/total_pixels*ssumX/
+      total_pixels));
+    (void) FormatMagickString(text,MaxTextExtent,PRECISION,saturation_stdev);
+    (void) SetImageAttribute(image,"SaturationStddev",text);
+    (void) FormatMagickString(text,MaxTextExtent,PRECISION,saturation_stdev);
+    (void) SetImageAttribute(image,"ByteMe",text);
   }
-  if (total_pixels <= 0.0)
-    return(MagickFalse);
-  brightness_mean=bsumX/total_pixels;
-  (void) FormatMagickString(text,MaxTextExtent,PRECISION,brightness_mean);
-  (void) SetImageAttribute((*image),"BrightnessMean",text);
-  brightness_stdev=sqrt(bsumX2/total_pixels-(bsumX/total_pixels*bsumX/
-    total_pixels));
-  (void) FormatMagickString(text,MaxTextExtent,PRECISION,brightness_stdev);
-  (void) SetImageAttribute((*image),"BrightnessStddev",text);
-  saturation_mean=ssumX/total_pixels;
-  (void) FormatMagickString(text,MaxTextExtent,PRECISION,saturation_mean);
-  (void) SetImageAttribute((*image),"SaturationMean",text);
-  saturation_stdev=sqrt(ssumX2/total_pixels-(ssumX/total_pixels*ssumX/
-    total_pixels));
-  (void) FormatMagickString(text,MaxTextExtent,PRECISION,saturation_stdev);
-  (void) SetImageAttribute((*image),"SaturationStddev",text);
   return(MagickTrue);
 }
