@@ -45,6 +45,7 @@
 #include "magick/studio.h"
 #include "magick/annotate.h"
 #include "magick/attribute.h"
+#include "magick/cache-view.h"
 #include "magick/client.h"
 #include "magick/color.h"
 #include "magick/color-private.h"
@@ -67,7 +68,7 @@
 #include "magick/type.h"
 #include "magick/utility.h"
 #include "magick/xwindow-private.h"
-#if defined(HasTTF)
+#if defined(HasFREETYPE)
 #if defined(__MINGW32__)
 #  undef interface
 #endif
@@ -435,7 +436,7 @@ MagickExport MagickBooleanType AnnotateImage(Image *image,
   return(status);
 }
 
-#if defined(HasTTF)
+#if defined(HasFREETYPE)
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
@@ -539,7 +540,7 @@ static unsigned short *EncodeSJIS(const Image *image,const char *text,
 }
 #endif
 
-#if defined(HasTTF)
+#if defined(HasFREETYPE)
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
@@ -596,7 +597,7 @@ static unsigned short *EncodeText(const Image *image,const char *text,
 }
 #endif
 
-#if defined(HasTTF)
+#if defined(HasFREETYPE)
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
@@ -614,19 +615,18 @@ static unsigned short *EncodeText(const Image *image,const char *text,
 %
 %  The format of the EncodeUnicode function is:
 %
-%      unicode=EncodeUnicode(const Image *image,const unsigned char *text,
-%        size_t count)
+%      unsigned short *EncodeUnicode(const Image *image,
+%        const unsigned char *text,size_t count)
 %
 %  A description of each parameter follows:
 %
 %    o unicode:  EncodeUnicode() returns a pointer to an unsigned short array
-%      array representing the encoded version of the ASCII string.
+%      representing the encoded version of the ASCII string.
 %
 %    o text: The text.
 %
 %    o count: return the number of characters generated by the encoding.
 %
-%
 */
 
 static long GetUnicodeCharacter(const unsigned char *text,size_t *length)
@@ -815,12 +815,12 @@ MagickExport MagickBooleanType GetMultilineTypeMetrics(Image *image,
   /*
     Find the widest of the text lines.
   */
-  annotate_info->text = textlist[0];
+  annotate_info->text=textlist[0];
   status=RenderType(image,annotate_info,&offset,metrics);
-  max_width = metrics->width;
+  max_width=metrics->width;
   for (i=1; textlist[i] != (char *) NULL; i++)
   {
-    annotate_info->text = textlist[i];
+    annotate_info->text=textlist[i];
     status=RenderType(image,annotate_info,&offset,metrics);
     if (metrics->width > max_width)
       max_width=metrics->width;
@@ -1030,7 +1030,7 @@ static MagickBooleanType RenderType(Image *image,const DrawInfo *draw_info,
 %
 */
 
-#if defined(HasTTF)
+#if defined(HasFREETYPE)
 static int TraceCubicBezier(FT_Vector *p,FT_Vector *q,FT_Vector *to,
   DrawInfo *draw_info)
 {
@@ -1238,8 +1238,10 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
         encoding_type=ft_encoding_gb2312;
       if (LocaleCompare(encoding,"Johab") == 0)
         encoding_type=ft_encoding_johab;
+#if defined(ft_encoding_latin_1)
       if (LocaleCompare(encoding,"Latin-1") == 0)
         encoding_type=ft_encoding_latin_1;
+#endif
       if (LocaleCompare(encoding,"Latin-2") == 0)
         encoding_type=ft_encoding_latin_2;
       if (LocaleCompare(encoding,"None") == 0)
@@ -1284,7 +1286,9 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
   metrics->descent=(double) face->size->metrics.descender/64.0;
   metrics->width=0;
   metrics->height=(double) face->size->metrics.height/64.0;
-  metrics->max_advance=(double) face->size->metrics.max_advance/64.0;
+  metrics->max_advance=0.0;
+  if (face->size->metrics.max_advance > MagickEpsilon)
+    metrics->max_advance=(double) face->size->metrics.max_advance/64.0;
   metrics->bounds.x1=0.0;
   metrics->bounds.y1=metrics->descent;
   metrics->bounds.x2=metrics->ascent+metrics->descent;
@@ -1427,6 +1431,9 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
           x_offset,
           y_offset;
 
+        ViewInfo
+          *image_view;
+
         /*
           Rasterize the glyph.
         */
@@ -1440,6 +1447,7 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
         point.x=offset->x+bitmap->left;
         point.y=offset->y-bitmap->top;
         p=bitmap->bitmap.buffer;
+        image_view=OpenCacheView(image);
         for (y=0; y < (long) bitmap->bitmap.rows; y++)
         {
           x_offset=(long) (point.x+0.5);
@@ -1449,7 +1457,7 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
               p+=bitmap->bitmap.width;
               continue;
             }
-          q=GetImagePixels(image,x_offset,y_offset,bitmap->bitmap.width,1);
+          q=GetCacheView(image_view,x_offset,y_offset,bitmap->bitmap.width,1);
           active=q != (PixelPacket *) NULL ? MagickTrue : MagickFalse;
           for (x=0; x < (long) bitmap->bitmap.width; x++)
           {
@@ -1461,12 +1469,11 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
                 q++;
                 continue;
               }
-            if (draw_info->text_antialias != MagickFalse)
-              fill_opacity=(MagickRealType) (*p)/255.0;
-            else
-              fill_opacity=(*p) > 127 ? 1.0 : 0.0;
+            fill_opacity=(MagickRealType) (*p)/255.0;
+            if (draw_info->text_antialias == MagickFalse)
+              fill_opacity=fill_opacity > 0.5 ? 1.0 : 0.0;
             if (active == MagickFalse)
-              q=GetImagePixels(image,x_offset,y_offset,1,1);
+              q=GetCacheView(image_view,x_offset,y_offset,1,1);
             if (q == (PixelPacket *) NULL)
               {
                 p++;
@@ -1474,17 +1481,18 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
                 continue;
               }
             fill_color=GetFillColor(draw_info,x_offset,y_offset);
-            fill_opacity=QuantumRange-fill_opacity*
-              (QuantumRange-fill_color.opacity);
+            fill_opacity=QuantumRange-fill_opacity*(QuantumRange-
+              fill_color.opacity);
             MagickCompositeOver(&fill_color,fill_opacity,q,q->opacity,q);
             if (active == MagickFalse)
-              (void) SyncImagePixels(image);
+              (void) SyncCacheView(image_view);
             p++;
             q++;
           }
-          if (SyncImagePixels(image) == MagickFalse)
+          if (SyncCacheView(image_view) == MagickFalse)
             break;
         }
+        image_view=CloseCacheView(image_view);
       }
     origin.x+=face->glyph->advance.x;
     if (origin.x > metrics->width)
@@ -1706,7 +1714,7 @@ static MagickBooleanType RenderPostscript(Image *image,
   (void) fclose(file);
   (void) FormatMagickString(geometry,MaxTextExtent,"%ldx%ld+0+0!",
     (long) (extent.x+0.5),(long) (extent.y+0.5));
-  annotate_info=CloneImageInfo((ImageInfo *) NULL);
+  annotate_info=AcquireImageInfo();
   (void) FormatMagickString(annotate_info->filename,MaxTextExtent,
     "ps:%s",filename);
   (void) CloneString(&annotate_info->page,geometry);
@@ -1775,6 +1783,9 @@ static MagickBooleanType RenderPostscript(Image *image,
       PixelPacket
         fill_color;
 
+      ViewInfo
+        *annotate_view;
+
       /*
         Render fill color.
       */
@@ -1784,9 +1795,10 @@ static MagickBooleanType RenderPostscript(Image *image,
         SetImageOpacity(annotate_image,OpaqueOpacity);
       fill_color=draw_info->fill;
       pattern=draw_info->fill_pattern;
+      annotate_view=OpenCacheView(annotate_image);
       for (y=0; y < (long) annotate_image->rows; y++)
       {
-        q=GetImagePixels(annotate_image,0,y,annotate_image->columns,1);
+        q=GetCacheView(annotate_view,0,y,annotate_image->columns,1);
         if (q == (PixelPacket *) NULL)
           break;
         for (x=0; x < (long) annotate_image->columns; x++)
@@ -1804,9 +1816,10 @@ static MagickBooleanType RenderPostscript(Image *image,
           q->blue=fill_color.blue;
           q++;
         }
-        if (SyncImagePixels(annotate_image) == MagickFalse)
+        if (SyncCacheView(annotate_view) == MagickFalse)
           break;
       }
+      annotate_view=CloseCacheView(annotate_view);
       (void) CompositeImage(image,OverCompositeOp,annotate_image,
         (long) (offset->x+0.5),(long) (offset->y-(metrics->ascent+
         metrics->descent)+0.5));
