@@ -38,6 +38,9 @@ typedef struct _ImageAttribute
     *next;  /* deprecated */
 } ImageAttribute;
 
+extern MagickExport char
+  *InterpretImageAttributes(const ImageInfo *,Image *,const char *);
+
 extern MagickExport const ImageAttribute
   *GetImageAttribute(const Image *,const char *),
   *GetImageClippingPathAttribute(Image *),
