@@ -196,10 +196,10 @@ extern MagickExport unsigned long
   GetNexus(Cache);
 
 extern MagickExport void
-  ClonePixelCacheMethods(Cache,const Cache),
+  CloneCacheMethods(Cache,const Cache),
   DestroyCacheNexus(Cache,const unsigned long),
   GetCacheMethods(CacheMethods *),
-  SetPixelCacheMethods(Cache,CacheMethods *);
+  SetCacheMethods(Cache,CacheMethods *);
 
 #if defined(__cplusplus) || defined(c_plusplus)
 }
