@@ -124,6 +124,47 @@ MagickExport const PixelPacket *AcquireCacheView(const ViewInfo *view_info,
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   A c q u i r e O n e C a c h e V i e w P i x e l                           %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  AcquireCacheView() returns a single pixel at the specified (x,y) location.
+%  The image background color is returned if an error occurs.  If you plan to
+%  modify the pixel, use GetOneCacheViewPixel() instead.
+%
+%  The format of the AcquireOneCacheViewPixel method is:
+%
+%      PixelPacket AcquireOneCacheViewPixel(const ViewInfo *view_info,
+%        const long x,const long y,ExceptionInfo *exception)
+%
+%  A description of each parameter follows:
+%
+%    o view_info: The address of a structure of type ViewInfo.
+%
+%    o x,y:  These values define the offset of the pixel.
+%
+%    o exception: Return any errors or warnings in this structure.
+%
+*/
+MagickExport PixelPacket AcquireOneCacheViewPixel(const ViewInfo *view_info,
+  const long x,const long y,ExceptionInfo *exception)
+{
+  assert(view_info != (ViewInfo *) NULL);
+  assert(view_info->signature == MagickSignature);
+  assert(view_info->image != (Image *) NULL);
+  if (view_info->image->debug != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      view_info->image->filename);
+  return(AcquireOnePixel(view_info->image,x,y,exception));
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   C l o s e C a c h e V i e w                                               %
 %                                                                             %
 %                                                                             %
@@ -135,14 +176,14 @@ MagickExport const PixelPacket *AcquireCacheView(const ViewInfo *view_info,
 %
 %  The format of the CloseCacheView method is:
 %
-%      void CloseCacheView(ViewInfo *view_info)
+%      ViewInfo *CloseCacheView(ViewInfo *view_info)
 %
 %  A description of each parameter follows:
 %
 %    o view_info: The address of a structure of type ViewInfo.
 %
 */
-MagickExport void CloseCacheView(ViewInfo *view_info)
+MagickExport ViewInfo *CloseCacheView(ViewInfo *view_info)
 {
   assert(view_info != (ViewInfo *) NULL);
   assert(view_info->signature == MagickSignature);
@@ -155,6 +196,7 @@ MagickExport void CloseCacheView(ViewInfo *view_info)
   view_info->image=DestroyImage(view_info->image);
   view_info->signature=(~MagickSignature);
   view_info=(ViewInfo *) RelinquishMagickMemory(view_info);
+  return(view_info);
 }
 
 /*
@@ -374,6 +416,44 @@ MagickExport ClassType GetCacheViewStorageClass(const ViewInfo *view_info)
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   G e t O n e C a c h e V i e w P i x e l                                   %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  GetOneCacheViewPixel() returns a single pixel at the specified (x,y)
+%  location.  The image background color is returned if an error occurs.
+%
+%  The format of the GetOneCacheViewPixel method is:
+%
+%      PixelPacket GetOneCacheViewPixel(const ViewInfo *view_info,
+%        const long x,const long y)
+%
+%  A description of each parameter follows:
+%
+%    o view_info: The address of a structure of type ViewInfo.
+%
+%    o x,y:  These values define the offset of the pixel.
+%
+*/
+MagickExport PixelPacket GetOneCacheViewPixel(const ViewInfo *view_info,
+  const long x,const long y)
+{
+  assert(view_info != (ViewInfo *) NULL);
+  assert(view_info->signature == MagickSignature);
+  assert(view_info->image != (Image *) NULL);
+  if (view_info->image->debug != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      view_info->image->filename);
+  return(GetOnePixel(view_info->image,x,y));
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   O p e n C a c h e V i e w                                                 %
 %                                                                             %
 %                                                                             %
@@ -384,14 +464,14 @@ MagickExport ClassType GetCacheViewStorageClass(const ViewInfo *view_info)
 %
 %  The format of the OpenCacheView method is:
 %
-%      ViewInfo *OpenCacheView(Image *image)
+%      ViewInfo *OpenCacheView(const Image *image)
 %
 %  A description of each parameter follows:
 %
 %    o image: The image.
 %
 */
-MagickExport ViewInfo *OpenCacheView(Image *image)
+MagickExport ViewInfo *OpenCacheView(const Image *image)
 {
   ViewInfo
     *view_info;
@@ -405,7 +485,7 @@ MagickExport ViewInfo *OpenCacheView(Image *image)
     ThrowMagickFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
       image->filename);
   (void) ResetMagickMemory(view_info,0,sizeof(*view_info));
-  view_info->image=ReferenceImage(image);
+  view_info->image=ReferenceImage((Image *) image);
   view_info->id=GetNexus(view_info->image->cache);
   view_info->signature=MagickSignature;
   return(view_info);
