@@ -244,9 +244,6 @@ MagickExport void DestroyCoderList(void)
 MagickExport const CoderInfo *GetCoderInfo(const char *name,
   ExceptionInfo *exception)
 {
-  register const CoderInfo
-    *p;
-
   assert(exception != (ExceptionInfo *) NULL);
   if ((coder_list == (SplayTreeInfo *) NULL) ||
       (instantiate_coder == MagickFalse))
@@ -260,20 +257,7 @@ MagickExport const CoderInfo *GetCoderInfo(const char *name,
       ResetSplayTreeIterator(coder_list);
       return((const CoderInfo *) GetNextValueInSplayTree(coder_list));
     }
-  /*
-    Search for requested coder.
-  */
-  AcquireSemaphoreInfo(&coder_semaphore);
-  ResetSplayTreeIterator(coder_list);
-  p=(const CoderInfo *) GetNextValueInSplayTree(coder_list);
-  while (p != (const CoderInfo *) NULL)
-  {
-    if (LocaleCompare(name,p->magick) == 0)
-      break;
-    p=(const CoderInfo *) GetNextValueInSplayTree(coder_list);
-  }
-  RelinquishSemaphoreInfo(coder_semaphore);
-  return(p);
+  return((const CoderInfo *) GetValueFromSplayTree(coder_list,name));
 }
 
 /*
@@ -287,9 +271,7 @@ MagickExport const CoderInfo *GetCoderInfo(const char *name,
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  GetCoderInfoList() returns any coders that match the specified pattern.
-%
-%  The format of the GetCoderInfoList function is:
+%  GetCoderInfoList() returns any coders that match the specified pattern.  % %  The format of the GetCoderInfoList function is:
 %
 %      const CoderInfo **GetCoderInfoList(const char *pattern,
 %        unsigned long *number_coders,ExceptionInfo *exception)
