@@ -138,8 +138,7 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
     }
   }
   image->colorspace=colorspace;
-  if (SyncImageCache(image) == MagickFalse)
-    return(MagickFalse);
+  (void) SetImagePixels(image,0,0,image->columns,1);
   switch (colorspace)
   {
     case CMYKColorspace:
@@ -845,8 +844,11 @@ MagickExport MagickBooleanType SetImageColorspace(Image *image,
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
-  assert(image->colorspace != UndefinedColorspace);
-  assert(colorspace != UndefinedColorspace);
+  if (colorspace == UndefinedColorspace)
+    {
+      image->colorspace=UndefinedColorspace;
+      return(MagickTrue);
+    }
   if (image->colorspace == colorspace)
     return(MagickTrue);
   if ((colorspace == RGBColorspace) || (colorspace == TransparentColorspace))
@@ -989,7 +991,6 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
-  assert(image->colorspace != UndefinedColorspace);
   switch (colorspace)
   {
     case GRAYColorspace:
@@ -997,6 +998,7 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
     case Rec709LumaColorspace:
     case RGBColorspace:
     case TransparentColorspace:
+    case UndefinedColorspace:
       return(MagickTrue);
     default:
       break;
@@ -1041,8 +1043,7 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
           break;
       }
       image->colorspace=RGBColorspace;
-      if (SyncImageCache(image) == MagickFalse)
-        return(MagickFalse);
+      (void) SetImagePixels(image,0,0,image->columns,1);
       return(y == (long) image->rows ? MagickTrue : MagickFalse);
     }
     case HSBColorspace:
