@@ -41,6 +41,7 @@
   Include declarations.
 */
 #include "magick/studio.h"
+#include "magick/cache-view.h"
 #include "magick/client.h"
 #include "magick/color.h"
 #include "magick/color-private.h"
@@ -144,6 +145,11 @@ MagickExport Image *CompareImageChannels(Image *image,
   register PixelPacket
     *r;
 
+  ViewInfo
+    *difference_view,
+    *image_view,
+    *reconstruct_view;
+
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
@@ -166,7 +172,11 @@ MagickExport Image *CompareImageChannels(Image *image,
   if (difference_image == (Image *) NULL)
     return((Image *) NULL);
   if (SetImageStorageClass(difference_image,DirectClass) == MagickFalse)
-    return((Image *) NULL);
+    {
+      InheritException(exception,&difference_image->exception);
+      difference_image=DestroyImage(difference_image);
+      return((Image *) NULL);
+    }
   (void) QueryMagickColor("#f1001e00",&red,exception);
   (void) QueryMagickColor("#ffffff00",&white,exception);
   if (difference_image->colorspace == CMYKColorspace)
@@ -179,18 +189,21 @@ MagickExport Image *CompareImageChannels(Image *image,
   */
   GetMagickPixelPacket(reconstruct_image,&source);
   GetMagickPixelPacket(difference_image,&composite);
+  image_view=OpenCacheView(image);
+  reconstruct_view=OpenCacheView(reconstruct_image);
+  difference_view=OpenCacheView(difference_image);
   for (y=0; y < (long) image->rows; y++)
   {
-    p=AcquireImagePixels(image,0,y,image->columns,1,exception);
-    q=AcquireImagePixels(reconstruct_image,0,y,reconstruct_image->columns,1,
+    p=AcquireCacheView(image_view,0,y,image->columns,1,exception);
+    q=AcquireCacheView(reconstruct_view,0,y,reconstruct_image->columns,1,
       exception);
-    r=SetImagePixels(difference_image,0,y,difference_image->columns,1);
+    r=SetCacheView(difference_view,0,y,difference_image->columns,1);
     if ((p == (const PixelPacket *) NULL) ||
         (q == (const PixelPacket *) NULL) || (r == (PixelPacket *) NULL))
       break;
-    indexes=GetIndexes(image);
-    reconstruct_indexes=GetIndexes(reconstruct_image);
-    difference_indexes=GetIndexes(difference_image);
+    indexes=GetCacheViewIndexes(image_view);
+    reconstruct_indexes=GetCacheViewIndexes(reconstruct_view);
+    difference_indexes=GetCacheViewIndexes(difference_view);
     for (x=0; x < (long) image->columns; x++)
     {
       difference=MagickFalse;
@@ -222,9 +235,12 @@ MagickExport Image *CompareImageChannels(Image *image,
       q++;
       r++;
     }
-    if (SyncImagePixels(difference_image) == MagickFalse)
+    if (SyncCacheView(difference_view) == MagickFalse)
       break;
   }
+  difference_view=CloseCacheView(difference_view);
+  reconstruct_view=CloseCacheView(reconstruct_view);
+  image_view=CloseCacheView(image_view);
   (void) GetImageChannelDistortion(image,reconstruct_image,channel,metric,
     distortion,exception);
   return(difference_image);
@@ -264,7 +280,6 @@ MagickExport Image *CompareImageChannels(Image *image,
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 
 MagickExport MagickBooleanType GetImageDistortion(Image *image,
@@ -279,6 +294,66 @@ MagickExport MagickBooleanType GetImageDistortion(Image *image,
   return(status);
 }
 
+static MagickRealType GetAbsoluteError(const Image *image,
+  const Image *reconstruct_image,ExceptionInfo *exception)
+{
+  IndexPacket
+    *indexes,
+    *reconstruct_indexes;
+
+  long
+    y;
+
+  MagickPixelPacket
+    image_pixel,
+    reconstruct_pixel;
+
+  MagickRealType
+    distortion;
+
+  register const PixelPacket
+    *p,
+    *q;
+
+  register long
+    x;
+
+  ViewInfo
+    *image_view,
+    *reconstruct_view;
+
+  /*
+    Compute the absolute difference in pixels between two images.
+  */
+  GetMagickPixelPacket(image,&image_pixel);
+  GetMagickPixelPacket(reconstruct_image,&reconstruct_pixel);
+  distortion=0.0;
+  image_view=OpenCacheView(image);
+  reconstruct_view=OpenCacheView(reconstruct_image);
+  for (y=0; y < (long) image->rows; y++)
+  {
+    p=AcquireCacheView(image_view,0,y,image->columns,1,exception);
+    q=AcquireCacheView(reconstruct_view,0,y,reconstruct_image->columns,1,
+      exception);
+    if ((p == (const PixelPacket *) NULL) || (q == (const PixelPacket *) NULL))
+      break;
+    indexes=GetCacheViewIndexes(image_view);
+    reconstruct_indexes=GetCacheViewIndexes(reconstruct_view);
+    for (x=0; x < (long) image->columns; x++)
+    {
+      SetMagickPixelPacket(p,indexes+x,&image_pixel);
+      SetMagickPixelPacket(q,reconstruct_indexes+x,&reconstruct_pixel);
+      if (IsMagickColorSimilar(&image_pixel,&reconstruct_pixel) == MagickFalse)
+        distortion++;
+      p++;
+      q++;
+    }
+  }
+  reconstruct_view=CloseCacheView(reconstruct_view);
+  image_view=CloseCacheView(image_view);
+  return(distortion);
+}
+
 static MagickRealType GetMeanAbsoluteError(const Image *image,
   const Image *reconstruct_image,const ChannelType channel,
   ExceptionInfo *exception)
@@ -301,17 +376,23 @@ static MagickRealType GetMeanAbsoluteError(const Image *image,
   register long
     x;
 
+  ViewInfo
+    *image_view,
+    *reconstruct_view;
+
   area=0.0;
   distortion=0.0;
+  image_view=OpenCacheView(image);
+  reconstruct_view=OpenCacheView(reconstruct_image);
   for (y=0; y < (long) image->rows; y++)
   {
-    p=AcquireImagePixels(image,0,y,image->columns,1,exception);
-    q=AcquireImagePixels(reconstruct_image,0,y,reconstruct_image->columns,1,
+    p=AcquireCacheView(image_view,0,y,image->columns,1,exception);
+    q=AcquireCacheView(reconstruct_view,0,y,reconstruct_image->columns,1,
       exception);
     if ((p == (const PixelPacket *) NULL) || (q == (const PixelPacket *) NULL))
       break;
-    indexes=GetIndexes(image);
-    reconstruct_indexes=GetIndexes(reconstruct_image);
+    indexes=GetCacheViewIndexes(image_view);
+    reconstruct_indexes=GetCacheViewIndexes(reconstruct_view);
     for (x=0; x < (long) image->columns; x++)
     {
       if ((channel & RedChannel) != 0)
@@ -344,6 +425,8 @@ static MagickRealType GetMeanAbsoluteError(const Image *image,
       q++;
     }
   }
+  reconstruct_view=CloseCacheView(reconstruct_view);
+  image_view=CloseCacheView(image_view);
   return(distortion/area);
 }
 
@@ -370,17 +453,23 @@ static MagickRealType GetMeanSquaredError(const Image *image,
   register long
     x;
 
+  ViewInfo
+    *image_view,
+    *reconstruct_view;
+
   area=0.0;
   distortion=0.0;
+  image_view=OpenCacheView(image);
+  reconstruct_view=OpenCacheView(reconstruct_image);
   for (y=0; y < (long) image->rows; y++)
   {
-    p=AcquireImagePixels(image,0,y,image->columns,1,exception);
-    q=AcquireImagePixels(reconstruct_image,0,y,reconstruct_image->columns,1,
+    p=AcquireCacheView(image_view,0,y,image->columns,1,exception);
+    q=AcquireCacheView(reconstruct_view,0,y,reconstruct_image->columns,1,
       exception);
     if ((p == (const PixelPacket *) NULL) || (q == (const PixelPacket *) NULL))
       break;
-    indexes=GetIndexes(image);
-    reconstruct_indexes=GetIndexes(reconstruct_image);
+    indexes=GetCacheViewIndexes(image_view);
+    reconstruct_indexes=GetCacheViewIndexes(reconstruct_view);
     for (x=0; x < (long) image->columns; x++)
     {
       if ((channel & RedChannel) != 0)
@@ -418,6 +507,8 @@ static MagickRealType GetMeanSquaredError(const Image *image,
       q++;
     }
   }
+  reconstruct_view=CloseCacheView(reconstruct_view);
+  image_view=CloseCacheView(image_view);
   return(distortion/area);
 }
 
@@ -443,16 +534,22 @@ static MagickRealType GetPeakAbsoluteError(const Image *image,
   register long
     x;
 
+  ViewInfo
+    *image_view,
+    *reconstruct_view;
+
   distortion=0.0;
+  image_view=OpenCacheView(image);
+  reconstruct_view=OpenCacheView(reconstruct_image);
   for (y=0; y < (long) image->rows; y++)
   {
-    p=AcquireImagePixels(image,0,y,image->columns,1,exception);
-    q=AcquireImagePixels(reconstruct_image,0,y,reconstruct_image->columns,1,
+    p=AcquireCacheView(image_view,0,y,image->columns,1,exception);
+    q=AcquireCacheView(reconstruct_view,0,y,reconstruct_image->columns,1,
       exception);
     if ((p == (const PixelPacket *) NULL) || (q == (const PixelPacket *) NULL))
       break;
-    indexes=GetIndexes(image);
-    reconstruct_indexes=GetIndexes(reconstruct_image);
+    indexes=GetCacheViewIndexes(image_view);
+    reconstruct_indexes=GetCacheViewIndexes(reconstruct_view);
     for (x=0; x < (long) image->columns; x++)
     {
       if ((channel & RedChannel) != 0)
@@ -490,6 +587,8 @@ static MagickRealType GetPeakAbsoluteError(const Image *image,
       q++;
     }
   }
+  reconstruct_view=CloseCacheView(reconstruct_view);
+  image_view=CloseCacheView(image_view);
   return(distortion);
 }
 
@@ -541,6 +640,11 @@ MagickExport MagickBooleanType GetImageChannelDistortion(Image *image,
   */
   switch (metric)
   {
+    case AbsoluteErrorMetric:
+    {
+      *distortion=(double) GetAbsoluteError(image,reconstruct_image,exception);
+      break;
+    }
     case MeanAbsoluteErrorMetric:
     {
       *distortion=(double) GetMeanAbsoluteError(image,reconstruct_image,channel,
@@ -650,6 +754,10 @@ MagickExport MagickBooleanType IsImagesEqual(Image *image,
   register long
     x;
 
+  ViewInfo
+    *image_view,
+    *reconstruct_view;
+
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   assert(reconstruct_image != (const Image *) NULL);
@@ -665,15 +773,17 @@ MagickExport MagickBooleanType IsImagesEqual(Image *image,
   maximum_error=0.0;
   mean_error_per_pixel=0.0;
   mean_error=0.0;
+  image_view=OpenCacheView(image);
+  reconstruct_view=OpenCacheView(reconstruct_image);
   for (y=0; y < (long) image->rows; y++)
   {
-    p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
-    q=AcquireImagePixels(reconstruct_image,0,y,reconstruct_image->columns,1,
+    p=AcquireCacheView(image_view,0,y,image->columns,1,&image->exception);
+    q=AcquireCacheView(reconstruct_view,0,y,reconstruct_image->columns,1,
       &image->exception);
     if ((p == (const PixelPacket *) NULL) || (q == (const PixelPacket *) NULL))
       break;
-    indexes=GetIndexes(image);
-    reconstruct_indexes=GetIndexes(reconstruct_image);
+    indexes=GetCacheViewIndexes(image_view);
+    reconstruct_indexes=GetCacheViewIndexes(reconstruct_view);
     for (x=0; x < (long) image->columns; x++)
     {
       distance=fabs(p->red-(double) q->red);
@@ -716,10 +826,12 @@ MagickExport MagickBooleanType IsImagesEqual(Image *image,
       q++;
     }
   }
+  reconstruct_view=CloseCacheView(reconstruct_view);
+  image_view=CloseCacheView(image_view);
   image->error.mean_error_per_pixel=(double) (mean_error_per_pixel/area);
   image->error.normalized_mean_error=(double)
-    (mean_error/area/QuantumRange/QuantumRange);
-  image->error.normalized_maximum_error=(double) (maximum_error/QuantumRange);
+    (QuantumScale*QuantumScale*mean_error/area);
+  image->error.normalized_maximum_error=(double) (QuantumScale*maximum_error);
   status=image->error.mean_error_per_pixel == 0.0 ? MagickTrue : MagickFalse;
   return(status);
 }
