@@ -1182,10 +1182,13 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
           x_displace=(horizontal_scale*(PixelIntensityToQuantum(p)-
             (((MagickRealType) QuantumRange+1.0)/2)))/
             (((MagickRealType) QuantumRange+1.0)/2.0);
-          y_displace=x_displace;
           if (composite_image->matte != MagickFalse)
-            y_displace=(vertical_scale*(p->opacity-(((MagickRealType)
+            y_displace=(-vertical_scale*(p->opacity-(((MagickRealType)
               QuantumRange+1.0)/2.0)))/(((MagickRealType) QuantumRange+1.0)/2);
+          else
+            y_displace=(vertical_scale*(PixelIntensityToQuantum(p)-
+              (((MagickRealType) QuantumRange+1.0)/2)))/
+              (((MagickRealType) QuantumRange+1.0)/2.0);
           pixel=InterpolateColor(image,image_view,(double) (x_offset+x+
             x_displace),(double) (y_offset+y+y_displace),&image->exception);
           SetPixelPacket(&pixel,r,displace_indexes+x);
