@@ -1080,7 +1080,7 @@ MagickExport MagickBooleanType JPEGEncodeImage(const ImageInfo *image_info,
   jpeg_image->blob=CloneBlobInfo((BlobInfo *) NULL);
   jpeg_info=CloneImageInfo(image_info);
   *jpeg_info->filename='\0';
-  (void) strcpy(jpeg_info->magick,"JPEG");
+  (void) CopyMagickString(jpeg_info->magick,"JPEG",MaxTextExtent);
   length=0;
   blob=ImageToBlob(jpeg_info,jpeg_image,&length,&image->exception);
   jpeg_info=DestroyImageInfo(jpeg_info);
@@ -1155,7 +1155,7 @@ MagickExport MagickBooleanType JP2EncodeImage(const ImageInfo *image_info,
   jp2_image->blob=CloneBlobInfo((BlobInfo *) NULL);
   jp2_info=CloneImageInfo(image_info);
   *jp2_info->filename='\0';
-  (void) strcpy(jp2_info->magick,"JP2");
+  (void) CopyMagickString(jp2_info->magick,"JP2",MaxTextExtent);
   length=0;
   blob=ImageToBlob(jp2_info,jp2_image,&length,&image->exception);
   jp2_info=DestroyImageInfo(jp2_info);
@@ -1560,7 +1560,7 @@ MagickExport MagickBooleanType ZLIBEncodeImage(Image *image,const size_t length,
     for (i=0; i < (long) compressed_packets; i++)
       (void) WriteBlobByte(image,compressed_pixels[i]);
   compressed_pixels=(unsigned char *) RelinquishMagickMemory(compressed_pixels);
-  return((MagickBooleanType) (status == Z_OK));
+  return(status == Z_OK ? MagickTrue : MagickFalse);
 }
 #else
 MagickExport MagickBooleanType ZLIBEncodeImage(Image *image,
