@@ -556,32 +556,33 @@ MagickExport LinkedListInfo *GetConfigurePaths(const char *filename,
   (void) CopyMagickString(path,filename,MaxTextExtent);
   paths=NewLinkedList(0);
   {
-    const char
+    char
       *configure_path;
 
-    register char
-      *q;
-
-    register const char
-      *p;
-
     /*
       Search $MAGICK_CONFIGURE_PATH.
     */
-    configure_path=getenv("MAGICK_CONFIGURE_PATH");
-    if (configure_path != (const char *) NULL)
-      for (p=configure_path-1; p != (char *) NULL; )
+    configure_path=GetEnvironmentValue("MAGICK_CONFIGURE_PATH");
+    if (configure_path != (char *) NULL)
       {
-        (void) CopyMagickString(path,p+1,MaxTextExtent);
-        q=strchr(path,DirectoryListSeparator);
-        if (q != (char *) NULL)
-          *q='\0';
-        q=path+strlen(path)-1;
-        if ((q >= path) && (*q != *DirectorySeparator))
-          (void) ConcatenateMagickString(path,DirectorySeparator,
-            MaxTextExtent);
-        (void) AppendValueToLinkedList(paths,ConstantString(path));
-        p=strchr(p+1,DirectoryListSeparator);
+        register char
+          *p,
+          *q;
+
+        for (p=configure_path-1; p != (char *) NULL; )
+        {
+          (void) CopyMagickString(path,p+1,MaxTextExtent);
+          q=strchr(path,DirectoryListSeparator);
+          if (q != (char *) NULL)
+            *q='\0';
+          q=path+strlen(path)-1;
+          if ((q >= path) && (*q != *DirectorySeparator))
+            (void) ConcatenateMagickString(path,DirectorySeparator,
+              MaxTextExtent);
+          (void) AppendValueToLinkedList(paths,ConstantString(path));
+          p=strchr(p+1,DirectoryListSeparator);
+        }
+        configure_path=(char *) RelinquishMagickMemory(configure_path);
       }
   }
 #if defined(UseInstalledMagick)
@@ -618,14 +619,14 @@ MagickExport LinkedListInfo *GetConfigurePaths(const char *filename,
 #endif
 #else
   {
-    const char
+    char
       *home;
 
     /*
       Search under MAGICK_HOME.
     */
-    home=getenv("MAGICK_HOME");
-    if (home != (const char *) NULL)
+    home=GetEnvironmentValue("MAGICK_HOME");
+    if (home != (char *) NULL)
       {
 #if !defined(POSIX)
         (void) FormatMagickString(path,MaxTextExtent,"%s%s",home,
@@ -639,6 +640,7 @@ MagickExport LinkedListInfo *GetConfigurePaths(const char *filename,
           MagickShareConfigSubDir);
         (void) AppendValueToLinkedList(paths,ConstantString(path));
 #endif
+        home=(char *) RelinquishMagickMemory(home);
       }
     }
   if (*GetClientPath() != '\0')
@@ -666,13 +668,13 @@ MagickExport LinkedListInfo *GetConfigurePaths(const char *filename,
     }
 #endif
   {
-    const char
+    char
       *home;
 
-    home=getenv("HOME");
-    if (home == (const char *) NULL)
-      home=getenv("USERPROFILE");
-    if (home != (const char *) NULL)
+    home=GetEnvironmentValue("HOME");
+    if (home == (char *) NULL)
+      home=GetEnvironmentValue("USERPROFILE");
+    if (home != (char *) NULL)
       {
         /*
           Search $HOME/.magick.
@@ -680,6 +682,7 @@ MagickExport LinkedListInfo *GetConfigurePaths(const char *filename,
         (void) FormatMagickString(path,MaxTextExtent,"%s%s%s",home,
           *home == '/' ? "/.magick" : "",DirectorySeparator);
         (void) AppendValueToLinkedList(paths,ConstantString(path));
+        home=(char *) RelinquishMagickMemory(home);
       }
   }
 #if defined(__WINDOWS__)
