@@ -416,8 +416,12 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
       (void) CopyMagickString(image->filename,read_info->filename,
         MaxTextExtent);
       *read_info->filename='\0';
+      if (GetDelegateThreadSupport(delegate_info) == MagickFalse)
+        AcquireSemaphoreInfo(&constitute_semaphore);
       (void) InvokeDelegate(read_info,image,read_info->magick,(char *) NULL,
         exception);
+      if (GetDelegateThreadSupport(delegate_info) == MagickFalse)
+        RelinquishSemaphoreInfo(constitute_semaphore);
       image=DestroyImageList(image);
       read_info->temporary=MagickTrue;
       (void) SetImageInfo(read_info,MagickFalse,exception);
@@ -963,8 +967,12 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
             Process the image with delegate.
           */
           *write_info->filename='\0';
+          if (GetDelegateThreadSupport(delegate_info) == MagickFalse)
+            AcquireSemaphoreInfo(&constitute_semaphore);
           status=InvokeDelegate(write_info,image,(char *) NULL,
             write_info->magick,&image->exception);
+          if (GetDelegateThreadSupport(delegate_info) == MagickFalse)
+            RelinquishSemaphoreInfo(constitute_semaphore);
           (void) CopyMagickString(image->filename,filename,MaxTextExtent);
         }
       else
