@@ -215,7 +215,11 @@ MagickExport Image *FrameImage(const Image *image,const FrameInfo *frame_info,
   if (frame_image == (Image *) NULL)
     return((Image *) NULL);
   if (SetImageStorageClass(frame_image,DirectClass) == MagickFalse)
-    return((Image *) NULL);
+    {
+      InheritException(exception,&frame_image->exception);
+		  frame_image=DestroyImage(frame_image);
+      return((Image *) NULL);
+    }
   if (frame_image->matte_color.opacity != OpaqueOpacity)
     frame_image->matte=MagickTrue;
   frame_image->page=image->page;
