@@ -78,13 +78,13 @@ static const char
     "  <delegate decode=\"autotrace\" stealth=\"True\" command='\"autotrace\" -output-format svg -output-file \"%o\" \"%i\"' />"
     "  <delegate decode=\"browse\" stealth=\"True\" spawn=\"True\" command='\"htmlview\" http://www.imagemagick.org/'  />"
     "  <delegate decode=\"cgm\" command='\"ralcgm\" -d ps -oC < \"%i\" > \"%o\" 2>/dev/null' />"
-    "  <delegate decode=\"crw\" command='\"dcraw\" -3 -w -c \"%i\" > \"%o\"' />"
-    "  <delegate decode=\"dcr\" command='\"dcraw\" -3 -w -c \"%i\" > \"%o\"' />"
-    "  <delegate decode=\"mrw\" command='\"dcraw\" -3 -w -c \"%i\" > \"%o\"' />"
-    "  <delegate decode=\"nef\" command='\"dcraw\" -3 -w -c \"%i\" > \"%o\"' />"
-    "  <delegate decode=\"orf\" command='\"dcraw\" -3 -w -c \"%i\" > \"%o\"' />"
-    "  <delegate decode=\"raf\" command='\"dcraw\" -3 -w -c \"%i\" > \"%o\"' />"
-    "  <delegate decode=\"x3f\" command='\"dcraw\" -3 -w -c \"%i\" > \"%o\"' />"
+    "  <delegate decode=\"crw\" thread-support=\"False\" command='\"dcraw\" -3 -w -c \"%i\" > \"%o\"' />"
+    "  <delegate decode=\"dcr\" thread-support=\"False\" command='\"dcraw\" -3 -w -c \"%i\" > \"%o\"' />"
+    "  <delegate decode=\"mrw\" thread-support=\"False\" command='\"dcraw\" -3 -w -c \"%i\" > \"%o\"' />"
+    "  <delegate decode=\"nef\" thread-support=\"False\" command='\"dcraw\" -3 -w -c \"%i\" > \"%o\"' />"
+    "  <delegate decode=\"orf\" thread-support=\"False\" command='\"dcraw\" -3 -w -c \"%i\" > \"%o\"' />"
+    "  <delegate decode=\"raf\" thread-support=\"False\" command='\"dcraw\" -3 -w -c \"%i\" > \"%o\"' />"
+    "  <delegate decode=\"x3f\" thread-support=\"False\" command='\"dcraw\" -3 -w -c \"%i\" > \"%o\"' />"
     "  <delegate decode=\"dvi\" command='\"dvips\" -q -o \"%o\" \"%i\"' />"
     "  <delegate decode=\"edit\" stealth=\"True\" command='\"xterm\" -title \"Edit Image Comment\" -e vi \"%o\"' />"
     "  <delegate decode=\"emf\" command='\"wmf2eps\" -o \"%o\" \"%i\"' />"
@@ -635,6 +635,39 @@ MagickExport long GetDelegateMode(const DelegateInfo *delegate_info)
 %                                                                             %
 %                                                                             %
 %                                                                             %
++   G e t D e l e g a t e T h r e a d S u p p o r t                           %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  GetDelegateThreadSupport() returns MagickTrue if the delegate supports
+%  threads.
+%
+%  The format of the GetDelegateThreadSupport method is:
+%
+%      MagickBooleanType GetDelegateThreadSupport(
+%        const DelegateInfo *delegate_info)
+%
+%  A description of each parameter follows:
+%
+%    o delegate_info:  The delegate info.
+%
+*/
+MagickExport MagickBooleanType GetDelegateThreadSupport(
+  const DelegateInfo *delegate_info)
+{
+  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
+  assert(delegate_info != (DelegateInfo *) NULL);
+  assert(delegate_info->signature == MagickSignature);
+  return(delegate_info->thread_support);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 +   I n i t i a l i z e D e l e g a t e L i s t                               %
 %                                                                             %
 %                                                                             %
@@ -1214,6 +1247,7 @@ static MagickBooleanType LoadDelegateList(const char *xml,const char *filename,
             "MemoryAllocationFailed",filename);
         (void) ResetMagickMemory(delegate_info,0,sizeof(*delegate_info));
         delegate_info->path=ConstantString(filename);
+        delegate_info->thread_support=MagickFalse;
         delegate_info->signature=MagickSignature;
         continue;
       }
@@ -1313,6 +1347,17 @@ static MagickBooleanType LoadDelegateList(const char *xml,const char *filename,
           }
         break;
       }
+      case 'T':
+      case 't':
+      {
+        if (LocaleCompare((char *) keyword,"thread-support") == 0)
+          {
+            delegate_info->thread_support=LocaleCompare(token,"True") == 0 ?
+              MagickTrue : MagickFalse;
+            break;
+          }
+        break;
+      }
       default:
         break;
     }
