@@ -25,7 +25,7 @@ extern "C" {
 #include <stdarg.h>
 #include "magick/blob.h"
 #include "magick/constitute.h"
-#include "magick/pixel.h"
+#include "magick/quantum.h"
 #include "magick/semaphore.h"
 
 #if !defined(magick_attribute)
@@ -81,7 +81,8 @@ typedef MagickBooleanType
 
 extern MagickExport char
   *AllocateString(const char *),
-  *PostscriptGeometry(const char *);
+  *PostscriptGeometry(const char *),
+  *TranslateText(const ImageInfo *,Image *,const char *);
 
 extern MagickExport Image
   *GetImageList(const Image *,const long,ExceptionInfo *),
