@@ -32,8 +32,15 @@ extern "C" {
   return(MagickFalse); \
 }
 #define ThrowFileException(exception,severity,tag,context) \
+{ \
+  char \
+    *message; \
+ \
+  message=GetExceptionMessage(errno); \
   (void) ThrowMagickException(exception,GetMagickModule(),severity,tag, \
-    "`%s': %s",context,strerror(errno));
+    "`%s': %s",context,message); \
+  message=(char *) RelinquishMagickMemory(message); \
+}
 #define ThrowImageException(severity,tag) \
 { \
   (void) ThrowMagickException(exception,GetMagickModule(),severity,tag, \
