@@ -105,8 +105,15 @@ MagickExport ExceptionInfo *AcquireExceptionInfo(void)
 
   exception=(ExceptionInfo *) AcquireMagickMemory(sizeof(*exception));
   if (exception == (ExceptionInfo *) NULL)
-    ThrowMagickFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
-		  strerror(errno));
+    {
+      char
+        *message;
+
+      message=GetExceptionMessage(errno);
+      ThrowMagickFatalException(ResourceLimitFatalError,
+        "MemoryAllocationFailed",message);
+      message=(char *) RelinquishMagickMemory(message);
+    }
   (void) ResetMagickMemory(exception,0,sizeof(*exception));
   GetExceptionInfo(exception);
   exception->relinquish=MagickTrue;
@@ -172,6 +179,7 @@ MagickExport void ClearMagickException(ExceptionInfo *exception)
   exception->reason=(char *) NULL;
   exception->description=(char *) NULL;
   RelinquishSemaphoreInfo(exception->semaphore);
+  errno=0;
 }
 
 /*
@@ -426,6 +434,34 @@ MagickExport void GetExceptionInfo(ExceptionInfo *exception)
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   G e t E x c e p t i o n M e s s a g e                                     %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  GetExceptionMessage() returns the error message defined by the specified
+%  error code.
+%
+%  The format of the GetExceptionMessage method is:
+%
+%      char *GetExceptionMessage(const int error_code)
+%
+%  A description of each parameter follows:
+%
+%    o error_code: the error code.
+%
+*/
+MagickExport char *GetExceptionMessage(const int error_code)
+{
+  return(ConstantString(strerror(error_code)));
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   G e t L o c a l e E x c e p t i o n M e s s a g e                         %
 %                                                                             %
 %                                                                             %
@@ -446,8 +482,6 @@ MagickExport void GetExceptionInfo(ExceptionInfo *exception)
 %
 %    o tag: the message tag.
 %
-%
-%
 */
 
 static const char *ExceptionSeverityToTag(const ExceptionType severity)
@@ -842,8 +876,15 @@ MagickExport MagickBooleanType ThrowException(ExceptionInfo *exception,
     return(MagickTrue);
   p=(ExceptionInfo *) AcquireMagickMemory(sizeof(*p));
   if (p == (ExceptionInfo *) NULL)
-    ThrowMagickFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
-      strerror(errno));
+    {
+      char
+        *message;
+
+      message=GetExceptionMessage(errno);
+      ThrowMagickFatalException(ResourceLimitFatalError,
+        "MemoryAllocationFailed",message);
+      message=(char *) RelinquishMagickMemory(message);
+    }
   (void) ResetMagickMemory(p,0,sizeof(*p));
   p->severity=severity;
   if (reason != (const char *) NULL)
