@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -13,10 +13,10 @@
   See the License for the specific language governing permissions and
   limitations under the License.
 
-  ImageMagick image f/x methods.
+  MagickCore image f/x methods.
 */
-#ifndef _MAGICK_FX_H
-#define _MAGICK_FX_H
+#ifndef _MAGICKCORE_FX_H
+#define _MAGICKCORE_FX_H
 
 #if defined(__cplusplus) || defined(c_plusplus)
 extern "C" {
@@ -54,10 +54,14 @@ extern MagickExport Image
   *SepiaToneImage(const Image *,const double,ExceptionInfo *),
   *ShadowImage(const Image *,const double,const double,const long,const long,
     ExceptionInfo *),
+  *SketchImage(const Image *,const double,const double,const double,
+    ExceptionInfo *),
   *SteganoImage(const Image *,const Image *,ExceptionInfo *),
   *StereoImage(const Image *,const Image *,ExceptionInfo *),
   *SwirlImage(const Image *,double,ExceptionInfo *),
   *TintImage(const Image *,const char *,const PixelPacket,ExceptionInfo *),
+  *VignetteImage(const Image *,const double,const double,const long,
+    const long,ExceptionInfo *),
   *WaveImage(const Image *,const double,const double,ExceptionInfo *);
 
 extern MagickExport MagickBooleanType
