@@ -188,7 +188,7 @@ MagickExport unsigned long GetOptimalKernelWidth1D(const double radius,
   (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(sigma != 0.0);
   if (radius > 0.0)
-    return(Max(2*((unsigned long) radius)+1,3));
+    return(Max(2*((unsigned long) (radius+0.5))+1,3));
   for (width=5; ;)
   {
     normalize=0.0;
@@ -214,6 +214,7 @@ MagickExport unsigned long GetOptimalKernelWidth2D(const double radius,
     alpha,
     normalize,
     value;
+
   register long
     u,
     v;
@@ -221,7 +222,7 @@ MagickExport unsigned long GetOptimalKernelWidth2D(const double radius,
   assert(sigma != 0.0);
   (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   if (radius > 0.0)
-    return(Max(2*((unsigned long) radius)+1,3));
+    return(Max(2*((unsigned long) (radius+0.5))+1,3));
   for (width=5; ;)
   {
     normalize=0.0;
@@ -643,173 +644,6 @@ MagickExport void Hull(const long x_offset,const long y_offset,
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%   I n t e r p o l a t e C o l o r                                           %
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%
-%  InterpolateColor() applies bi-linear interpolation between a pixel and its
-%  neighbors.
-%
-%  The format of the InterpolateColor method is:
-%
-%      MagickPixelPacket InterpolateColor(const Image *image,
-%        const double x_offset,const double y_offset,ExceptionInfo *exception)
-%
-%  A description of each parameter follows:
-%
-%    o image: The image.
-%
-%    o x_offset,y_offset: A double representing the current (x,y) position of
-%      the pixel.
-%
-%
-*/
-
-MagickExport MagickPixelPacket InterpolateColor(const Image *image,
-  const double x_offset,const double y_offset,ExceptionInfo *exception)
-{
-  MagickPixelPacket
-    pixel,
-    pixels[4];
-
-  MagickRealType
-    alpha[4],
-    gamma;
-
-  PointInfo
-    delta;
-
-  register const PixelPacket
-    *p;
-
-  register IndexPacket
-    *indexes;
-
-  register long
-    i;
-
-  assert(image != (Image *) NULL);
-  assert(image->signature == MagickSignature);
-  GetMagickPixelPacket(image,&pixel);
-  p=AcquireImagePixels(image,(long) x_offset,(long) y_offset,2,2,exception);
-  if (p == (const PixelPacket *) NULL)
-    return(pixel);
-  for (i=0; i < 4L; i++)
-  {
-    indexes=GetIndexes(image);
-    alpha[i]=1.0;
-    if (image->matte != MagickFalse)
-      alpha[i]=((MagickRealType) QuantumRange-p->opacity)/QuantumRange;
-    GetMagickPixelPacket(image,pixels+i);
-    SetMagickPixelPacket(p,indexes,pixels+i);
-    pixels[i].red*=alpha[i];
-    pixels[i].green*=alpha[i];
-    pixels[i].blue*=alpha[i];
-    if (image->colorspace == CMYKColorspace)
-      pixels[i].index*=alpha[i];
-    p++;
-  }
-  delta.x=x_offset-floor(x_offset);
-  delta.y=y_offset-floor(y_offset);
-  gamma=(((1.0-delta.y)*((1.0-delta.x)*alpha[0]+delta.x*alpha[1])+
-    delta.y*((1.0-delta.x)*alpha[2]+delta.x*alpha[3])));
-  gamma=1.0/(fabs((double) gamma) <= MagickEpsilon ? 1.0 : gamma);
-  pixel.red=(gamma*((1.0-delta.y)*((1.0-delta.x)*pixels[0].red+delta.x*
-    pixels[1].red)+delta.y*((1.0-delta.x)*pixels[2].red+delta.x*
-    pixels[3].red)));
-  pixel.green=(gamma*((1.0-delta.y)*((1.0-delta.x)*pixels[0].green+delta.x*
-    pixels[1].green)+delta.y*((1.0-delta.x)*pixels[2].green+delta.x*
-    pixels[3].green)));
-  pixel.blue=(gamma*((1.0-delta.y)*((1.0-delta.x)*pixels[0].blue+delta.x*
-    pixels[1].blue)+delta.y*((1.0-delta.x)*pixels[2].blue+delta.x*
-    pixels[3].blue)));
-  if (image->matte != MagickFalse)
-    pixel.opacity=((1.0-delta.y)*((1.0-delta.x)*pixels[0].opacity+delta.x*
-      pixels[1].opacity)+delta.y*((1.0-delta.x)*pixels[2].opacity+delta.x*
-      pixels[3].opacity));
-  if (image->colorspace == CMYKColorspace)
-    pixel.index=(gamma*((1.0-delta.y)*((1.0-delta.x)*pixels[0].index+delta.x*
-      pixels[1].index)+delta.y*((1.0-delta.x)*pixels[2].index+delta.x*
-      pixels[3].index)));
-  return(pixel);
-}
-
-MagickExport MagickPixelPacket IInterpolateColor(const Image *image,
-  const double x_offset,const double y_offset,ExceptionInfo *exception)
-{
-  MagickPixelPacket
-    pixel,
-    pixels[4];
-
-  MagickRealType
-    alpha[4],
-    gamma;
-
-  PointInfo
-    delta;
-
-  register const PixelPacket
-    *p;
-
-  register IndexPacket
-    *indexes;
-
-  register long
-    i;
-
-  assert(image != (Image *) NULL);
-  assert(image->signature == MagickSignature);
-  GetMagickPixelPacket(image,&pixel);
-  p=AcquireImagePixels(image,(long) x_offset,(long) y_offset,2,2,exception);
-  if (p == (const PixelPacket *) NULL)
-    return(pixel);
-  indexes=GetIndexes(image);
-  for (i=0; i < 4L; i++)
-  {
-    alpha[i]=1.0;
-    if (image->matte != MagickFalse)
-      alpha[i]=((MagickRealType) QuantumRange-p->opacity)/QuantumRange;
-    GetMagickPixelPacket(image,pixels+i);
-    SetMagickPixelPacket(p,indexes+i,pixels+i);
-    pixels[i].red*=alpha[i];
-    pixels[i].green*=alpha[i];
-    pixels[i].blue*=alpha[i];
-    if (image->colorspace == CMYKColorspace)
-      pixels[i].index*=alpha[i];
-    p++;
-  }
-  delta.x=x_offset-(long) x_offset;
-  delta.y=y_offset-(long) y_offset;
-  gamma=(alpha[0]+(alpha[2]-alpha[0])*delta.y+(alpha[1]-alpha[0])*delta.x+
-    (alpha[0]+alpha[3]-alpha[2]-alpha[1])*delta.x*delta.y);
-  gamma=1.0/(fabs((double) gamma) <= MagickEpsilon ? 1.0 : gamma);
-  pixel.red=gamma*(pixels[0].red+(pixels[2].red-pixels[0].red)*delta.y+
-    (pixels[1].red-pixels[0].red)*delta.x+(pixels[0].red+pixels[3].red-
-    pixels[2].red-pixels[1].red)*delta.x*delta.y);
-  pixel.green=gamma*(pixels[0].green+(pixels[2].green-pixels[0].green)*
-    delta.y+(pixels[1].green-pixels[0].green)*delta.x+(pixels[0].green+
-    pixels[3].green-pixels[2].green-pixels[1].green)*delta.x*delta.y);
-  pixel.blue=gamma*(pixels[0].blue+(pixels[2].blue-pixels[0].blue)*delta.y+
-    (pixels[1].blue-pixels[0].blue)*delta.x+(pixels[0].blue+pixels[3].blue-
-    pixels[2].blue-pixels[1].blue)*delta.x*delta.y);
-  if (image->matte != MagickFalse)
-    pixel.opacity=(pixels[0].opacity+(pixels[2].opacity-pixels[0].opacity)*
-      delta.y+(pixels[1].opacity-pixels[0].opacity)*delta.x+(pixels[0].opacity+
-      pixels[3].opacity-pixels[2].opacity-pixels[1].opacity)*delta.x*delta.y);
-  if (image->colorspace == CMYKColorspace)
-    pixel.index=gamma*(pixels[0].index+(pixels[2].index-pixels[0].index)*
-      delta.y+(pixels[1].index-pixels[0].index)*delta.x+(pixels[0].index+
-      pixels[3].index-pixels[2].index-pixels[1].index)*delta.x*delta.y);
-  return(pixel);
-}
-
-/*
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%                                                                             %
-%                                                                             %
-%                                                                             %
 %   M o d u l a t e H S B                                                     %
 %                                                                             %
 %                                                                             %
@@ -1083,9 +917,9 @@ MagickExport void TransformHSL(const Quantum red,const Quantum green,
   assert(hue != (double *) NULL);
   assert(saturation != (double *) NULL);
   assert(luminosity != (double *) NULL);
-  r=(MagickRealType) red/QuantumRange;
-  g=(MagickRealType) green/QuantumRange;
-  b=(MagickRealType) blue/QuantumRange;
+  r=QuantumScale*red;
+  g=QuantumScale*green;
+  b=QuantumScale*blue;
   max=Max(r,Max(g,b));
   min=Min(r,Min(g,b));
   *hue=0.0;
