@@ -257,7 +257,6 @@ MagickExport MagickStatusType GetGeometry(const char *geometry,long *x,long *y,
 %      The string is either a Postscript page name (e.g. A4) or a postscript
 %      page geometry (e.g. 612x792+36+36).
 %
-%
 */
 MagickExport char *GetPageGeometry(const char *page_geometry)
 {
@@ -494,6 +493,69 @@ MagickExport MagickStatusType ParseAbsoluteGeometry(const char *geometry,
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   P a r s e A f f i n e G e o m e t r y                                     %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  ParseAffineGeometry() returns an affine matrix as defined by the geometry
+%  string.
+%
+%  The format of the ParseAffineGeometry method is:
+%
+%      MagickStatusType ParseAffineGeometry(const char *geometry,
+%        AffineMatrix *affine_matrix)
+%
+%  A description of each parameter follows:
+%
+%    o geometry:  The geometry (e.g. 1.0,0.0,0.0,1.0,3.2,1.2).
+%
+%    o affine_matrix: The affine matrix as defined by the geometry string.
+%
+*/
+MagickExport MagickStatusType ParseAffineGeometry(const char *geometry,
+  AffineMatrix *affine_matrix)
+{
+  char
+    *p;
+
+  double
+    value;
+
+  int
+    flags;
+
+  register long
+    i;
+
+  GetAffineMatrix(affine_matrix);
+  flags=NoValue;
+  p=(char *) geometry;
+  for (i=0; i < 6; i++)
+  {
+    value=strtod(p,&p);
+    switch (i)
+    {
+      case 0: affine_matrix->sx=value; break;
+      case 1: affine_matrix->rx=value; break;
+      case 2: affine_matrix->ry=value; break;
+      case 3: affine_matrix->sy=value; break;
+      case 4: affine_matrix->tx=value; flags|=XValue; break;
+      case 5: affine_matrix->ty=value; flags|=YValue; break;
+    }
+    if (*p !=',')
+      break;
+    p++;
+  }
+  return(flags);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   P a r s e G e o m e t r y                                                 %
 %                                                                             %
 %                                                                             %
@@ -604,6 +666,7 @@ MagickExport MagickStatusType ParseGeometry(const char *geometry,
       case 'X':
       case ',':
       case '/':
+      case ':':
       {
         p++;
         break;
@@ -729,7 +792,7 @@ MagickExport MagickStatusType ParseGeometry(const char *geometry,
       /*
         Normalize sampling factor (e.g. 4:2:2 => 2x1).
       */
-      geometry_info->rho*=geometry_info->sigma;
+      geometry_info->rho/=geometry_info->sigma;
       geometry_info->sigma=1.0;
       if (geometry_info->xi == 0.0)
         geometry_info->sigma=2.0;
@@ -775,6 +838,10 @@ MagickExport MagickStatusType ParseGravityGeometry(Image *image,
     width;
 
   SetGeometry(image,region_info);
+  if (image->page.width != 0)
+    region_info->width=image->page.width;
+  if (image->page.height != 0)
+    region_info->height=image->page.height;
   flags=ParseAbsoluteGeometry(geometry,region_info);
   if (flags == NoValue)
     {
@@ -1066,6 +1133,10 @@ MagickExport MagickStatusType ParsePageGeometry(Image *image,
     flags;
 
   SetGeometry(image,region_info);
+  if (image->page.width != 0)
+    region_info->width=image->page.width;
+  if (image->page.height != 0)
+    region_info->height=image->page.height;
   flags=ParseAbsoluteGeometry(geometry,region_info);
   if (flags == NoValue)
     {
@@ -1103,7 +1174,6 @@ MagickExport MagickStatusType ParsePageGeometry(Image *image,
 %
 %    o region_info: The region as defined by the geometry string.
 %
-%
 */
 MagickExport MagickStatusType ParseSizeGeometry(Image *image,
   const char *geometry,RectangleInfo *region_info)
