@@ -421,8 +421,7 @@ MagickExport LinkedListInfo *DestroyLinkedList(LinkedListInfo *list_info,
   if (list_info->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   AcquireSemaphoreInfo(&list_info->semaphore);
-  next=list_info->head;
-  while (next != (ElementInfo *) NULL)
+  for (next=list_info->head; next != (ElementInfo *) NULL; )
   {
     if (relinquish_value != (void *(*)(void *)) NULL)
       next->value=relinquish_value(next->value);
@@ -1391,7 +1390,7 @@ MagickExport HashmapInfo *NewHashmap(const unsigned long capacity,
 %  NewLinkedList() returns a pointer to a LinkedListInfo structure
 %  initialized to default values.
 %
-%  The format of the Acquirestruct LinkedListInfomethod is:
+%  The format of the NewLinkedList method is:
 %
 %      LinkedListInfo *NewLinkedList(const unsigned long capacity)
 %
@@ -1898,7 +1897,7 @@ MagickExport void *RemoveLastElementFromLinkedList(LinkedListInfo *list_info)
     {
       value=list_info->head->value;
       list_info->head=(ElementInfo *) NULL;
-      list_info->tail=(ElementInfo *) NULL;
+      list_info->tail=(ElementInfo *) RelinquishMagickMemory(list_info->tail);
     }
   else
     {
