@@ -171,7 +171,7 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
   elapsed_time=GetElapsedTime(&image->timer);
   user_time=GetUserTime(&image->timer);
   GetTimerInfo(&image->timer);
-  if (verbose == MagickFalse)
+  if ((verbose == MagickFalse) || (image->cache == (void *) NULL))
     {
       /*
         Display summary info about the image.
@@ -200,7 +200,7 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
           (void) fprintf(file,"DirectClass ");
           if (image->total_colors != 0)
             {
-              FormatSize(image->total_colors,format);
+              FormatMagickSize(image->total_colors,format);
               (void) fprintf(file,"%s ",format);
             }
         }
@@ -212,6 +212,7 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
             (void) fprintf(file,"PseudoClass %lu=>%luc ",image->total_colors,
               image->colors);
           }
+      (void) fprintf(file,"%lu-bit ",image->depth);
       if (image->error.mean_error_per_pixel != 0.0)
         (void) fprintf(file,"%ld/%f/%fdb ",
           (long) (image->error.mean_error_per_pixel+0.5),
@@ -219,7 +220,7 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
           image->error.normalized_maximum_error);
       if (GetBlobSize(image) != 0)
         {
-          FormatSize(GetBlobSize(image),format);
+          FormatMagickSize(GetBlobSize(image),format);
           (void) fprintf(file,"%s ",format);
         }
       if (elapsed_time > 0.02)
@@ -234,7 +235,16 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
   */
   (void) SignatureImage(image);
   image->total_colors=GetNumberColors(image,(FILE *) NULL,&image->exception);
-  (void) fprintf(file,"Image: %s\n",image->filename);
+    (void) fprintf(file,"Image: %s\n",image->filename);
+  if (*image->magick_filename != '\0')
+    if (LocaleCompare(image->magick_filename,image->filename) != 0)
+      {
+        char
+          filename[MaxTextExtent];
+
+        GetPathComponent(image->magick_filename,TailPath,filename);
+        (void) fprintf(file,"  Base filename: %s\n",filename);
+      }
   magick_info=GetMagickInfo(image->magick,&image->exception);
   if ((magick_info == (const MagickInfo *) NULL) ||
       (*GetMagickDescription(magick_info) == '\0'))
@@ -242,9 +252,9 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
   else
     (void) fprintf(file,"  Format: %s (%s)\n",image->magick,
       GetMagickDescription(magick_info));
-  (void) fprintf(file,"  Geometry: %lux%lu\n",image->columns,image->rows);
   (void) fprintf(file,"  Class: %s\n",
     MagickOptionToMnemonic(MagickClassOptions,(long) image->storage_class));
+  (void) fprintf(file,"  Geometry: %lux%lu\n",image->columns,image->rows);
   if ((image->magick_columns != 0) || (image->magick_rows != 0))
     if ((image->magick_columns != image->columns) ||
         (image->magick_rows != image->rows))
@@ -269,38 +279,38 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
     case RGBColorspace:
     default:
     {
-      (void) fprintf(file,"    Red: %lu-bits\n",
+      (void) fprintf(file,"    Red: %lu-bit\n",
         channel_statistics[RedChannel].depth);
-      (void) fprintf(file,"    Green: %lu-bits\n",
+      (void) fprintf(file,"    Green: %lu-bit\n",
         channel_statistics[GreenChannel].depth);
-      (void) fprintf(file,"    Blue: %lu-bits\n",
+      (void) fprintf(file,"    Blue: %lu-bit\n",
         channel_statistics[BlueChannel].depth);
       if (image->matte != MagickFalse)
-        (void) fprintf(file,"    Alpha: %lu-bits\n",
+        (void) fprintf(file,"    Alpha: %lu-bit\n",
           channel_statistics[OpacityChannel].depth);
       break;
     }
     case CMYKColorspace:
     {
-      (void) fprintf(file,"    Cyan: %lu-bits\n",
+      (void) fprintf(file,"    Cyan: %lu-bit\n",
         channel_statistics[CyanChannel].depth);
-      (void) fprintf(file,"    Magenta: %lu-bits\n",
+      (void) fprintf(file,"    Magenta: %lu-bit\n",
         channel_statistics[MagentaChannel].depth);
-      (void) fprintf(file,"    Yellow: %lu-bits\n",
+      (void) fprintf(file,"    Yellow: %lu-bit\n",
         channel_statistics[YellowChannel].depth);
-      (void) fprintf(file,"    Black: %lu-bits\n",
+      (void) fprintf(file,"    Black: %lu-bit\n",
         channel_statistics[BlackChannel].depth);
       if (image->matte != MagickFalse)
-        (void) fprintf(file,"    Alpha: %lu-bits\n",
+        (void) fprintf(file,"    Alpha: %lu-bit\n",
           channel_statistics[OpacityChannel].depth);
       break;
     }
     case GRAYColorspace:
     {
-      (void) fprintf(file,"    Gray: %lu-bits\n",
+      (void) fprintf(file,"    Gray: %lu-bit\n",
         channel_statistics[GrayChannel].depth);
       if (image->matte != MagickFalse)
-        (void) fprintf(file,"    Alpha: %lu-bits\n",
+        (void) fprintf(file,"    Alpha: %lu-bit\n",
           channel_statistics[OpacityChannel].depth);
       break;
     }
@@ -419,13 +429,11 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
   channel_statistics=(ChannelStatistics *)
     RelinquishMagickMemory(channel_statistics);
   if (colorspace == CMYKColorspace)
-    (void) fprintf(file,"  Total Ink Density: %.0f%%\n",100.0*
+    (void) fprintf(file,"  Total ink density: %.0f%%\n",100.0*
       GetImageTotalInkDensity(image)/(double) QuantumRange);
   x=0;
   p=NewImageList();
-  if (((image->matte != MagickFalse) &&
-      (LocaleCompare(image->magick,"GIF") != 0)) ||
-      (image->taint != MagickFalse))
+  if (image->matte != MagickFalse)
     {
       register const PixelPacket
         *p;
@@ -521,7 +529,7 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
   if (image->error.normalized_maximum_error != 0.0)
     (void) fprintf(file,"  Normalized maximum error: %gn",
       image->error.normalized_maximum_error);
-  (void) fprintf(file,"  Rendering-intent: %s\n",
+  (void) fprintf(file,"  Rendering intent: %s\n",
     MagickOptionToMnemonic(MagickIntentOptions,(long) image->rendering_intent));
   if (image->gamma != 0.0)
     (void) fprintf(file,"  Gamma: %g\n",image->gamma);
@@ -553,19 +561,19 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
       image->y_resolution);
   (void) fprintf(file,"  Units: %s\n",
     MagickOptionToMnemonic(MagickResolutionOptions,(long) image->units));
-  FormatSize(GetBlobSize(image),format);
+  FormatMagickSize(GetBlobSize(image),format);
   (void) fprintf(file,"  Filesize: %s\n",format);
   (void) fprintf(file,"  Interlace: %s\n",
     MagickOptionToMnemonic(MagickInterlaceOptions,(long) image->interlace));
   (void) QueryColorname(image,&image->background_color,SVGCompliance,color,
     &image->exception);
-  (void) fprintf(file,"  Background Color: %s\n",color);
+  (void) fprintf(file,"  Background color: %s\n",color);
   (void) QueryColorname(image,&image->border_color,SVGCompliance,color,
     &image->exception);
-  (void) fprintf(file,"  Border Color: %s\n",color);
+  (void) fprintf(file,"  Border color: %s\n",color);
   (void) QueryColorname(image,&image->matte_color,SVGCompliance,color,
     &image->exception);
-  (void) fprintf(file,"  Matte Color: %s\n",color);
+  (void) fprintf(file,"  Matte color: %s\n",color);
   if ((image->page.width != 0) || (image->page.height != 0) ||
       (image->page.x != 0) || (image->page.y != 0))
     (void) fprintf(file,"  Page geometry: %lux%lu%+ld%+ld\n",image->page.width,
@@ -613,7 +621,7 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
       /*
         Display visual image directory.
       */
-      image_info=CloneImageInfo((ImageInfo *) NULL);
+      image_info=AcquireImageInfo();
       (void) CloneString(&image_info->size,"64x64");
       (void) fprintf(file,"  Directory:\n");
       for (p=image->directory; *p != '\0'; p++)
@@ -738,27 +746,35 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
         if (LocaleCompare(name,"iptc") == 0)
           {
             char
-              *text;
+              *attribute,
+              **attribute_list;
 
             const char
               *tag;
 
+            long
+              dataset,
+              record,
+              sentinel;
+
+            register long
+              j;
+
             size_t
               length;
 
             /*
               Identify IPTC data.
             */
-            for (i=0; i < (long) profile->length; )
+            for (i=0; i < (long) profile->length; i+=(long) length)
             {
-              if ((int) profile->datum[i] != 0x1c)
-                {
-                  i++;
-                  continue;
-                }
-              i++;  /* skip file separator */
-              i++;  /* skip record number */
-              switch (profile->datum[i])
+              length=1;
+              sentinel= profile->datum[i++];
+              if (sentinel != 0x1c)
+                continue;
+              dataset=profile->datum[i++];
+              record=profile->datum[i++];
+              switch (record)
               {
                 case 5: tag="Image Name"; break;
                 case 7: tag="Edit Status"; break;
@@ -814,36 +830,30 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
                 case 219: tag="Custom Field 20"; break;
                 default: tag="unknown"; break;
               }
-              (void) fprintf(file,"    %s[%d,%d]: ",tag,profile->datum[i-1],
-                profile->datum[i]);
-              i++;
+              (void) fprintf(file,"    %s[%ld,%ld]: ",tag,dataset,record);
               length=(size_t) (profile->datum[i++] << 8);
               length|=profile->datum[i++];
-              text=(char *) AcquireMagickMemory(length+MaxTextExtent);
-              if (text != (char *) NULL)
+              attribute=(char *) AcquireMagickMemory((length+MaxTextExtent)*
+                sizeof(*attribute));
+              if (attribute != (char *) NULL)
                 {
-                  char
-                    **textlist;
-
-                  register long
-                    j;
-
-                  (void) CopyMagickString(text,(char *) profile->datum+i,
+                  (void) CopyMagickString(attribute,(char *) profile->datum+i,
                     length+1);
-                  textlist=StringToList(text);
-                  if (textlist != (char **) NULL)
+                  attribute_list=StringToList(attribute);
+                  if (attribute_list != (char **) NULL)
                     {
-                      for (j=0; textlist[j] != (char *) NULL; j++)
+                      for (j=0; attribute_list[j] != (char *) NULL; j++)
                       {
-                        (void) fprintf(file,"%s\n",textlist[j]);
-                        textlist[j]=(char *)
-                          RelinquishMagickMemory(textlist[j]);
+                        (void) fputs(attribute_list[j],file);
+                        (void) fputs("\n",file);
+                        attribute_list[j]=(char *)
+                          RelinquishMagickMemory(attribute_list[j]);
                       }
-                      textlist=(char **) RelinquishMagickMemory(textlist);
+                      attribute_list=(char **) RelinquishMagickMemory(
+                        attribute_list);
                     }
-                  text=(char *) RelinquishMagickMemory(text);
+                  attribute=(char *) RelinquishMagickMemory(attribute);
                 }
-              i+=(long) length;
             }
           }
         name=GetNextImageProfile(image);
@@ -855,10 +865,10 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
     (void) fprintf(file,"  Tainted: False\n");
   if (elapsed_time > 0.02)
     {
-      (void) fprintf(file,"  User Time: %0.3fu\n",user_time);
-      (void) fprintf(file,"  Elapsed Time: %ld:%02ld\n",
+      (void) fprintf(file,"  User time: %0.3fu\n",user_time);
+      (void) fprintf(file,"  Elapsed time: %ld:%02ld\n",
       (long) (elapsed_time/60.0+0.5),(long) ceil(fmod(elapsed_time,60.0)));
-      FormatSize((MagickSizeType) ((double) image->columns*image->rows/
+      FormatMagickSize((MagickSizeType) ((double) image->columns*image->rows/
         elapsed_time),format);
       (void) fprintf(file,"  Pixels per second: %s\n",format);
     }
