@@ -17,7 +17,7 @@
 %                               December 2002                                 %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -164,6 +164,105 @@ MagickExport Image *CloneImageList(const Image *images,ExceptionInfo *exception)
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   C l o n e I m a g e s                                                     %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  CloneImages() clones one or more images from an image sequence.
+%
+%  The format of the CloneImages method is:
+%
+%      Image *CloneImages(const Image *images,const char *scenes,
+%        ExceptionInfo *exception)
+%
+%  A description of each parameter follows:
+%
+%    o images: The image sequence.
+%
+%    o scenes: This character string specifies which scenes to clone
+%      (e.g. 1,3-5,7-6,2).
+%
+%    o exception: Return any errors or warnings in this structure.
+%
+*/
+MagickExport Image *CloneImages(const Image *images,const char *scenes,
+  ExceptionInfo *exception)
+{
+  char
+    *q;
+
+  const Image
+    *next;
+
+  Image
+    *clone_images,
+    *image;
+
+  long
+    first,
+    last,
+    quantum;
+
+  register const char
+    *p;
+
+  register long
+    i;
+
+  assert(images != (const Image *) NULL);
+  assert(images->signature == MagickSignature);
+  assert(scenes != (char *) NULL);
+  if (images->debug != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",images->filename);
+  assert(exception != (ExceptionInfo *) NULL);
+  assert(exception->signature == MagickSignature);
+  clone_images=NewImageList();
+  p=scenes;
+  for (q=(char *) scenes; *q != '\0'; p++)
+  {
+    while ((isspace((int) ((unsigned char) *p)) != 0) || (*p == ','))
+      p++;
+    first=strtol(p,&q,10);
+    if (first < 0)
+      first+=GetImageListLength(images);
+    last=first;
+    while (isspace((int) ((unsigned char) *q)) != 0)
+      q++;
+    if (*q == '-')
+      {
+        last=strtol(q+1,&q,10);
+        if (last < 0)
+          last+=GetImageListLength(images);
+      }
+    quantum=first > last ? -1 : 1;
+    for (p=q; first != (last+quantum); first+=quantum)
+    {
+      i=0;
+      for (next=images; next != (Image *) NULL; next=GetNextImageInList(next))
+      {
+        if (i == (long) first)
+          {
+            image=CloneImage(next,0,0,MagickTrue,exception);
+            if (image == (Image *) NULL)
+              break;
+            AppendImageToList(&clone_images,image);
+          }
+        i++;
+      }
+    }
+  }
+  if (clone_images == (Image *) NULL)
+    return((Image *) NULL);
+  return(GetFirstImageInList(clone_images));
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   D e l e t e I m a g e F r o m L i s t                                     %
 %                                                                             %
 %                                                                             %
@@ -218,6 +317,116 @@ MagickExport void DeleteImageFromList(Image **images)
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   D e l e t e I m a g e s                                                   %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  DeleteImages() deletes one or more images from an image sequence.
+%
+%  The format of the DeleteImages method is:
+%
+%      DeleteImages(Image **images,const char *scenes,ExceptionInfo *exception)
+%
+%  A description of each parameter follows:
+%
+%    o images: The image sequence.
+%
+%    o scenes: This character string specifies which scenes to delete
+%      (e.g. 1,3-5,7-6,2).
+%
+%    o exception: Return any errors or warnings in this structure.
+%
+*/
+MagickExport void DeleteImages(Image **images,const char *scenes,
+  ExceptionInfo *exception)
+{
+  char
+    *q;
+
+  Image
+    **delete_images,
+    *image;
+
+  long
+    first,
+    j,
+    last,
+    quantum;
+
+  register const char
+    *p;
+
+  register long
+    i;
+
+  assert(images != (Image **) NULL);
+  assert((*images)->signature == MagickSignature);
+  assert(scenes != (char *) NULL);
+  if ((*images)->debug != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      (*images)->filename);
+  assert(exception != (ExceptionInfo *) NULL);
+  assert(exception->signature == MagickSignature);
+  delete_images=ImageListToArray(*images,exception);
+  if (delete_images == (Image **) NULL)
+    return;
+  j=0;
+  p=scenes;
+  for (q=(char *) scenes; *q != '\0'; p++)
+  {
+    while ((isspace((int) ((unsigned char) *p)) != 0) || (*p == ','))
+      p++;
+    first=strtol(p,&q,10);
+    if (first < 0)
+      first+=GetImageListLength(*images);
+    last=first;
+    while (isspace((int) ((unsigned char) *q)) != 0)
+      q++;
+    if (*q == '-')
+      {
+        last=strtol(q+1,&q,10);
+        if (last < 0)
+          last+=GetImageListLength(*images);
+      }
+    quantum=first > last ? -1 : 1;
+    for (p=q; first != (last+quantum); first+=quantum)
+    {
+      i=0;
+      image=(*images);
+      for ( ; image != (Image *) NULL; image=GetNextImageInList(image))
+      {
+        if (i == (long) first)
+          {
+            delete_images[j]=image;
+            j++;
+          }
+        i++;
+      }
+    }
+  }
+  /*
+    Delete images from image list.
+  */
+  for (i=0; i < j; i++)
+  {
+    for ( ; *images != (Image *) NULL; *images=GetNextImageInList(*images))
+      if (*images == delete_images[i])
+        {
+          DeleteImageFromList(images);
+          break;
+        }
+    *images=GetFirstImageInList(*images);
+  }
+  delete_images=(Image **) RelinquishMagickMemory(delete_images);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   D e s t r o y I m a g e L i s t                                           %
 %                                                                             %
 %                                                                             %
@@ -610,16 +819,6 @@ MagickExport void InsertImageInList(Image **images,Image *image)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   if ((*images) == (Image *) NULL)
     return;
-  if ((*images)->next == (Image *) NULL)
-    {
-      AppendImageToList(images,image);
-      return;
-    }
-  if ((*images)->previous == (Image *) NULL)
-    {
-      PrependImageToList(images,image);
-      return;
-    }
   assert((*images)->signature == MagickSignature);
   split=SplitImageList(*images);
   if (split == (Image *) NULL)
