@@ -187,9 +187,6 @@ MagickExport LinkedListInfo *DestroyLocaleOptions(LinkedListInfo *messages)
 MagickExport const LocaleInfo *GetLocaleInfo_(const char *tag,
   ExceptionInfo *exception)
 {
-  register const LocaleInfo
-    *p;
-
   assert(exception != (ExceptionInfo *) NULL);
   if ((locale_list == (SplayTreeInfo *) NULL) ||
       (instantiate_locale == MagickFalse))
@@ -203,20 +200,7 @@ MagickExport const LocaleInfo *GetLocaleInfo_(const char *tag,
       ResetSplayTreeIterator(locale_list);
       return((const LocaleInfo *) GetNextValueInSplayTree(locale_list));
     }
-  /*
-    Search for named tag.
-  */
-  AcquireSemaphoreInfo(&locale_semaphore);
-  ResetSplayTreeIterator(locale_list);
-  p=(const LocaleInfo *) GetNextValueInSplayTree(locale_list);
-  while (p != (const LocaleInfo *) NULL)
-  {
-    if (LocaleCompare(tag,p->tag) == 0)
-      break;
-    p=(const LocaleInfo *) GetNextValueInSplayTree(locale_list);
-  }
-  RelinquishSemaphoreInfo(locale_semaphore);
-  return(p);
+  return((const LocaleInfo *) GetValueFromSplayTree(locale_list,tag));
 }
 
 /*
@@ -605,23 +589,30 @@ static MagickBooleanType InitializeLocaleList(ExceptionInfo *exception)
           char
             *locale;
 
-          locale=setlocale(LC_CTYPE,0);
-          if ((locale == (char *) NULL) || (*locale == '\0'))
-            locale=getenv("LC_ALL");
-          if ((locale == (char *) NULL) || (*locale == '\0'))
-            locale=getenv("LC_MESSAGES");
-          if ((locale == (char *) NULL) || (*locale == '\0'))
-            locale=getenv("LC_CTYPE");
-          if ((locale == (char *) NULL) || (*locale == '\0'))
-            locale=getenv("LANG");
-          if ((locale == (char *) NULL) || (*locale == '\0'))
-            locale="C";
+          register const char
+            *p;
+
+          locale=(char *) NULL;
+          p=setlocale(LC_CTYPE,0);
+          if (p != (const char *) NULL)
+            locale=ConstantString(p);
+          if (locale == (char *) NULL)
+            locale=GetEnvironmentValue("LC_ALL");
+          if (locale == (char *) NULL)
+            locale=GetEnvironmentValue("LC_MESSAGES");
+          if (locale == (char *) NULL)
+            locale=GetEnvironmentValue("LC_CTYPE");
+          if (locale == (char *) NULL)
+            locale=GetEnvironmentValue("LANG");
+          if (locale == (char *) NULL)
+            locale=ConstantString("C");
           (void) LoadLocaleLists(LocaleFilename,locale,exception);
+          locale=(char *) RelinquishMagickMemory(locale);
           instantiate_locale=MagickTrue;
         }
       RelinquishSemaphoreInfo(locale_semaphore);
     }
-  return((MagickBooleanType) (locale_list != (SplayTreeInfo *) NULL));
+  return(locale_list != (SplayTreeInfo *) NULL ? MagickTrue : MagickFalse);
 }
 
 /*
