@@ -55,6 +55,7 @@
 #include "magick/token.h"
 #include "magick/utility.h"
 #include "magick/version.h"
+#include "magick/xml-tree.h"
 #if defined(HAVE_PTHREAD)
 #include <pthread.h>
 #endif
@@ -70,6 +71,18 @@
 /*
   Typedef declarations.
 */
+typedef enum
+{
+  UndefinedHandler = 0x0000,
+  NoHandler = 0x0000,
+  ConsoleHandler = 0x0001,
+  StdoutHandler = 0x0002,
+  StderrHandler = 0x0004,
+  FileHandler = 0x0008,
+  DebugHandler = 0x0010,
+  EventHandler = 0x0020
+} LogHandlerType;
+
 typedef struct _EventInfo
 {
   char
@@ -109,23 +122,16 @@ struct _LogInfo
   FILE
     *file;
 
-  MagickBooleanType
-    append;
-
   unsigned long
-    generation,
-    count;
+    generation;
 
   MagickBooleanType
+    append,
     stealth;
 
   TimerInfo
     timer;
 
-  struct _LogInfo
-    *previous,
-    *next;  /* deprecated, use GetLogInfoList() */
-
   unsigned long
     signature;
 };
@@ -153,8 +159,6 @@ static const char
     "  <log events=\"None\" />"
     "  <log output=\"console\" />"
     "  <log filename=\"Magick-%d.log\" />"
-    "  <log generations=\"3\" />"
-    "  <log limit=\"2000\" />"
     "  <log format=\"%t %r %u %v %d %c[%p]: %m/%f/%l/%d\n  %e\" />"
     "</logmap>";
 
@@ -188,6 +192,48 @@ static MagickBooleanType
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   C l o s e M a g i c k L o g                                               %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  CloseMagickLog() closes the Magick log.
+%
+%  The format of the CloseMagickLog method is:
+%
+%      CloseMagickLog(void)
+%
+*/
+MagickExport void CloseMagickLog(void)
+{
+  ExceptionInfo
+    *exception;
+
+  LogInfo
+    *log_info;
+
+  if (IsEventLogging() == MagickFalse)
+    return;
+  exception=AcquireExceptionInfo();
+  log_info=(LogInfo *) GetLogInfo("*",exception);
+  exception=DestroyExceptionInfo(exception);
+  AcquireSemaphoreInfo(&log_semaphore);
+  if (log_info->file != (FILE *) NULL)
+    {
+      if (log_info->append == MagickFalse)
+        (void) fprintf(log_info->file,"</log>\n");
+      (void) fclose(log_info->file);
+      log_info->file=(FILE *) NULL;
+    }
+  RelinquishSemaphoreInfo(log_semaphore);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 +   D e s t r o y L o g L i s t                                               %
 %                                                                             %
 %                                                                             %
@@ -214,6 +260,7 @@ static void *DestroyLogElement(void *log_info)
       if (p->append == MagickFalse)
         (void) fprintf(p->file,"</log>\n");
       (void) fclose(p->file);
+      p->file=(FILE *) NULL;
     }
   if (p->filename != (char *) NULL)
     p->filename=(char *) RelinquishMagickMemory(p->filename);
@@ -577,7 +624,7 @@ MagickExport MagickBooleanType IsEventLogging(void)
   GetExceptionInfo(&exception);
   log_info=GetLogInfo("*",&exception);
   (void) DestroyExceptionInfo(&exception);
-  return((MagickBooleanType) (log_info->event_mask != NoEvents));
+  return(log_info->event_mask != NoEvents ? MagickTrue : MagickFalse);
 }
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -606,6 +653,11 @@ MagickExport MagickBooleanType IsEventLogging(void)
 */
 MagickExport MagickBooleanType ListLogInfo(FILE *file,ExceptionInfo *exception)
 {
+#define MegabytesToBytes(value) ((MagickSizeType) (value)*1024*1024)
+
+  char
+    limit[MaxTextExtent];
+
   const char
     *path;
 
@@ -637,7 +689,7 @@ MagickExport MagickBooleanType ListLogInfo(FILE *file,ExceptionInfo *exception)
       {
         if (log_info[i]->path != (char *) NULL)
           (void) fprintf(file,"\nPath: %s\n\n",log_info[i]->path);
-        (void) fprintf(file,"Filename         Generations  Limit  Format\n");
+        (void) fprintf(file,"Filename       Generations     Limit  Format\n");
         (void) fprintf(file,"-------------------------------------------------"
           "------------------------------\n");
       }
@@ -648,8 +700,9 @@ MagickExport MagickBooleanType ListLogInfo(FILE *file,ExceptionInfo *exception)
         for (j=(long) strlen(log_info[i]->filename); j <= 16; j++)
           (void) fprintf(file," ");
       }
-    (void) fprintf(file,"%11lu",log_info[i]->generations);
-    (void) fprintf(file,"%7lu  ",log_info[i]->limit);
+    (void) fprintf(file,"%9lu  ",log_info[i]->generations);
+    FormatMagickSize(MegabytesToBytes(log_info[i]->limit),limit);
+    (void) fprintf(file,"%8s  ",limit);
     if (log_info[i]->format != (char *) NULL)
       (void) fprintf(file,"%s",log_info[i]->format);
     (void) fprintf(file,"\n");
@@ -705,9 +758,9 @@ static unsigned long GetLogThreadId(void)
   return(0);
 }
 
-static char *TranslateEvent(const LogEventType type,const char *module,
-  const char *function,const unsigned long line,const char *domain,
-  const char *event)
+static char *TranslateEvent(const LogEventType magick_unused(type),
+  const char *module,const char *function,const unsigned long line,
+  const char *domain,const char *event)
 {
   char
     *text;
@@ -797,8 +850,7 @@ static char *TranslateEvent(const LogEventType type,const char *module,
         %d   domain
         %e   event
         %f   function
-				%g   generation
-        %i   thread id
+        %g   generation
         %l   line
         %m   module
         %n   log name
@@ -857,24 +909,18 @@ static char *TranslateEvent(const LogEventType type,const char *module,
       }
       case 'g':
       {
-        (void) FormatMagickString(q,MaxTextExtent,"%lu",
-          log_info->generation % log_info->generations);
-        while (*q != '\0')
-          q++;
-        break;
-      }
-      case 'i':
-      {
-        (void) FormatMagickString(q,MaxTextExtent,"%lu",GetLogThreadId());
+        if (log_info->generations == 0)
+          (void) CopyMagickString(q,"0",MaxTextExtent);
+        else
+          (void) FormatMagickString(q,MaxTextExtent,"%lu",
+            log_info->generation % log_info->generations);
         while (*q != '\0')
           q++;
         break;
       }
       case 'l':
       {
-        (void) FormatMagickString(q,MaxTextExtent,"%lu",line);
-        while (*q != '\0')
-          q++;
+        q+=FormatMagickString(q,MaxTextExtent,"%lu",line);
         break;
       }
       case 'm':
@@ -900,32 +946,24 @@ static char *TranslateEvent(const LogEventType type,const char *module,
       }
       case 'p':
       {
-        (void) FormatMagickString(q,MaxTextExtent,"%ld",(long) getpid());
-        while (*q != '\0')
-          q++;
+        q+=FormatMagickString(q,MaxTextExtent,"%ld",(long) getpid());
         break;
       }
       case 'r':
       {
-        (void) FormatMagickString(q,MaxTextExtent,"%ld:%02ld",
+        q+=FormatMagickString(q,MaxTextExtent,"%ld:%02ld",
           (long) (elapsed_time/60.0),(long) ceil(fmod(elapsed_time,60.0)));
-        while (*q != '\0')
-          q++;
         break;
       }
       case 't':
       {
-        (void) FormatMagickString(q,MaxTextExtent,"%02d:%02d:%02d",
+        q+=FormatMagickString(q,MaxTextExtent,"%02d:%02d:%02d",
           time_meridian->tm_hour,time_meridian->tm_min,time_meridian->tm_sec);
-        while (*q != '\0')
-          q++;
         break;
       }
       case 'u':
       {
-        (void) FormatMagickString(q,MaxTextExtent,"%0.3fu",user_time);
-        while (*q != '\0')
-          q++;
+        q+=FormatMagickString(q,MaxTextExtent,"%0.3fu",user_time);
         break;
       }
       case 'v':
@@ -934,8 +972,14 @@ static char *TranslateEvent(const LogEventType type,const char *module,
         q+=strlen(MagickLibVersionText);
         break;
       }
+      case '%':
+      {
+        *q++=(*p);
+        break;
+      }
       default:
       {
+        *q++='%';
         *q++=(*p);
         break;
       }
@@ -985,7 +1029,6 @@ static char *TranslateFilename(const LogInfo *log_info)
 
         %c   client name
         %n   log name
-        %i   thread id
         %p   process id
         %v   version
         %%   percent sign
@@ -1006,15 +1049,11 @@ static char *TranslateFilename(const LogInfo *log_info)
       }
       case 'g':
       {
-        (void) FormatMagickString(q,MaxTextExtent,"%lu",
-          log_info->generation % log_info->generations);
-        while (*q != '\0')
-          q++;
-        break;
-      }
-      case 'i':
-      {
-        (void) FormatMagickString(q,MaxTextExtent,"%lu",GetLogThreadId());
+        if (log_info->generations == 0)
+          (void) CopyMagickString(q,"0",MaxTextExtent);
+        else
+          (void) FormatMagickString(q,MaxTextExtent,"%lu",
+            log_info->generation % log_info->generations);
         while (*q != '\0')
           q++;
         break;
@@ -1027,9 +1066,7 @@ static char *TranslateFilename(const LogInfo *log_info)
       }
       case 'p':
       {
-        (void) FormatMagickString(q,MaxTextExtent,"%ld",(long) getpid());
-        while (*q != '\0')
-          q++;
+        q+=FormatMagickString(q,MaxTextExtent,"%ld",(long) getpid());
         break;
       }
       case 'v':
@@ -1038,8 +1075,14 @@ static char *TranslateFilename(const LogInfo *log_info)
         q+=strlen(MagickLibVersionText);
         break;
       }
+      case '%':
+      {
+        *q++=(*p);
+        break;
+      }
       default:
       {
+        *q++='%';
         *q++=(*p);
         break;
       }
@@ -1114,13 +1157,17 @@ MagickBooleanType LogMagickEventList(const LogEventType type,const char *module,
     }
   if ((log_info->handler_mask & FileHandler) != 0)
     {
-      log_info->count++;
-      if (log_info->count == log_info->limit)
+      struct stat
+        file_info;
+
+      file_info.st_size=0;
+      if (log_info->file != (FILE *) NULL)
+        (void) fstat(fileno(log_info->file),&file_info);
+      if (file_info.st_size > (off_t) (1024*1024*log_info->limit))
         {
           (void) fprintf(log_info->file,"</log>\n");
           (void) fclose(log_info->file);
           log_info->file=(FILE *) NULL;
-          log_info->count=0;
         }
       if (log_info->file == (FILE *) NULL)
         {
@@ -1378,6 +1425,11 @@ static MagickBooleanType LoadLogList(const char *xml,const char *filename,
       {
         if (LocaleCompare((char *) keyword,"generations") == 0)
           {
+            if (LocaleCompare(token,"unlimited") == 0)
+              {
+                log_info->generations=(~0UL);
+                break;
+              }
             log_info->generations=(unsigned long) atol(token);
             break;
           }
@@ -1388,6 +1440,11 @@ static MagickBooleanType LoadLogList(const char *xml,const char *filename,
       {
         if (LocaleCompare((char *) keyword,"limit") == 0)
           {
+            if (LocaleCompare(token,"unlimited") == 0)
+              {
+                log_info->limit=(~0UL);
+                break;
+              }
             log_info->limit=(unsigned long) atol(token);
             break;
           }
