@@ -16,7 +16,7 @@
 %                                 July 2000                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -465,7 +465,7 @@ MagickExport char **GetMagicList(const char *pattern,
   {
     if ((p->stealth == MagickFalse) &&
         (GlobExpression(p->name,pattern) != MagickFalse))
-      aliases[i++]=ConstantString(AcquireString(p->name));
+      aliases[i++]=ConstantString(p->name);
     p=(const MagicInfo *) GetNextValueInLinkedList(magic_list);
   }
   RelinquishSemaphoreInfo(magic_semaphore);
@@ -650,7 +650,6 @@ MagickExport MagickBooleanType ListMagicInfo(FILE *file,
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 static MagickBooleanType LoadMagicList(const char *xml,const char *filename,
   const unsigned long depth,ExceptionInfo *exception)
@@ -674,15 +673,7 @@ static MagickBooleanType LoadMagicList(const char *xml,const char *filename,
   if (xml == (char *) NULL)
     return(MagickFalse);
   if (magic_list == (LinkedListInfo *) NULL)
-    {
-      magic_list=NewLinkedList(0);
-      if (magic_list == (LinkedListInfo *) NULL)
-        {
-          ThrowFileException(exception,ResourceLimitError,
-            "MemoryAllocationFailed",filename);
-          return(MagickFalse);
-        }
-    }
+    magic_list=NewLinkedList(0);
   status=MagickTrue;
   token=AcquireString(xml);
   for (q=(char *) xml; *q != '\0'; )
@@ -750,7 +741,7 @@ static MagickBooleanType LoadMagicList(const char *xml,const char *filename,
       }
     if (LocaleCompare(keyword,"<magic") == 0)
       {
-       /*
+        /*
           Allocate memory for the magic list.
         */
         magic_info=(MagicInfo *) AcquireMagickMemory(sizeof(*magic_info));
@@ -758,7 +749,7 @@ static MagickBooleanType LoadMagicList(const char *xml,const char *filename,
           ThrowMagickFatalException(ResourceLimitFatalError,
             "MemoryAllocationFailed",filename);
         (void) ResetMagickMemory(magic_info,0,sizeof(*magic_info));
-        magic_info->path=ConstantString(AcquireString(filename));
+        magic_info->path=ConstantString(filename);
         magic_info->signature=MagickSignature;
         continue;
       }
@@ -785,7 +776,7 @@ static MagickBooleanType LoadMagicList(const char *xml,const char *filename,
       {
         if (LocaleCompare((char *) keyword,"name") == 0)
           {
-            magic_info->name=ConstantString(AcquireString(token));
+            magic_info->name=ConstantString(token);
             break;
           }
         break;
@@ -822,8 +813,8 @@ static MagickBooleanType LoadMagicList(const char *xml,const char *filename,
             register unsigned char
               *q;
 
-            magic_info->target=AcquireString(token);
-            magic_info->magic=(unsigned char *) AcquireString(token);
+            magic_info->target=ConstantString(token);
+            magic_info->magic=(unsigned char *) ConstantString(token);
             q=magic_info->magic;
             for (p=magic_info->target; *p != '\0'; )
             {
