@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -13,10 +13,10 @@
   See the License for the specific language governing permissions and
   limitations under the License.
 
-  ImageMagick structure members.
+  MagickCore types.
 */
-#ifndef _MAGICK_MAGICK_TYPE_H
-#define _MAGICK_MAGICK_TYPE_H
+#ifndef _MAGICKCORE_MAGICK_TYPE_H
+#define _MAGICKCORE_MAGICK_TYPE_H
 
 #if defined(__cplusplus) || defined(c_plusplus)
 extern "C" {
@@ -130,7 +130,8 @@ typedef enum
   MatteChannel = 0x0008,  /* deprecated */
   BlackChannel = 0x0020,
   IndexChannel = 0x0020,
-  AllChannels = 0xff
+  AllChannels = 0xff,
+  DefaultChannels = (AllChannels &~ OpacityChannel)
 } ChannelType;
 
 typedef enum
@@ -598,6 +599,15 @@ typedef struct _ExceptionInfo
     *reason,
     *description;
 
+  void
+    *exceptions;
+
+  MagickBooleanType
+    relinquish;
+
+  SemaphoreInfo
+    *semaphore;
+
   unsigned long
     signature;
 } ExceptionInfo;
@@ -856,7 +866,7 @@ typedef struct _ImageInfo
     channel;
 
   Image
-    *attributes;
+    *attributes;  /* no longer used */
 
   void
     *options;
