@@ -784,11 +784,6 @@ MagickExport MagickBooleanType GetMagickThreadSupport(
 %
 */
 
-static void MagickExitHandler(void)
-{
-  DestroyMagick();
-}
-
 static SignalHandler *SetMagickSignalHandler(int signal_number,
   SignalHandler *handler)
 {
@@ -876,12 +871,10 @@ static SignalHandler *RegisterMagickSignalHandler(int signal_number)
 MagickExport void InitializeMagick(const char *path)
 {
   char
+    *events,
     execution_path[MaxTextExtent],
     filename[MaxTextExtent];
 
-  const char
-    *p;
-
   ExceptionInfo
     exception;
 
@@ -896,9 +889,12 @@ MagickExport void InitializeMagick(const char *path)
   seconds=time((time_t *) NULL);
   srand((unsigned int) (seconds+getpid()));
   InitializeSemaphore();
-  p=getenv("MAGICK_DEBUG");
-  if (p != (const char *) NULL)
-    (void) SetLogEventMask(p);
+  events=GetEnvironmentValue("MAGICK_DEBUG");
+  if (events != (char *) NULL)
+    {
+      (void) SetLogEventMask(events);
+      events=(char *) RelinquishMagickMemory(events);
+    }
 #if defined(__WINDOWS__)
   (void) NTControlHandler();
 #if defined(_DEBUG) && !defined(__BORLANDC__)
@@ -967,7 +963,6 @@ MagickExport void InitializeMagick(const char *path)
   if (signal_handlers[SIGXFSZ] == (SignalHandler *) NULL)
     signal_handlers[SIGXFSZ]=RegisterMagickSignalHandler(SIGXFSZ);
 #endif
-  (void) atexit(MagickExitHandler);
   /*
     Initialize magick resources.
   */
@@ -1038,22 +1033,43 @@ static MagickBooleanType InitializeMagickList(ExceptionInfo *exception)
           magick_list=NewSplayTree(CompareSplayTreeString,
             RelinquishMagickMemory,DestroyMagickNode);
           if (magick_list == (SplayTreeInfo *) NULL)
-            ThrowMagickFatalException(ResourceLimitFatalError,
-              "MemoryAllocationFailed",strerror(errno));
+            {
+              char
+                *message;
+
+              message=GetExceptionMessage(errno);
+              ThrowMagickFatalException(ResourceLimitFatalError,
+                "MemoryAllocationFailed",message);
+              message=(char *) RelinquishMagickMemory(message);
+            }
           magick_info=SetMagickInfo("tmp");
           magick_info->stealth=MagickTrue;
           status=AddValueToSplayTree(magick_list,ConstantString(
             magick_info->name),magick_info);
           if (status == MagickFalse)
-            ThrowMagickFatalException(ResourceLimitFatalError,
-              "UnableToAllocateMagickInfo",magick_info->name);
+            {
+              char
+                *message;
+
+              message=GetExceptionMessage(errno);
+              ThrowMagickFatalException(ResourceLimitFatalError,
+                "MemoryAllocationFailed",message);
+              message=(char *) RelinquishMagickMemory(message);
+            }
           magick_info=SetMagickInfo("clipmask");
           magick_info->stealth=MagickTrue;
           status=AddValueToSplayTree(magick_list,ConstantString(
             magick_info->name),magick_info);
           if (status == MagickFalse)
-            ThrowMagickFatalException(ResourceLimitFatalError,
-              "UnableToAllocateMagickInfo",magick_info->name);
+            {
+              char
+                *message;
+
+              message=GetExceptionMessage(errno);
+              ThrowMagickFatalException(ResourceLimitFatalError,
+                "MemoryAllocationFailed",message);
+              message=(char *) RelinquishMagickMemory(message);
+            }
 #if defined(SupportMagickModules)
           (void) GetModuleInfo((char *) NULL,exception);
 #endif
@@ -1168,6 +1184,7 @@ MagickExport MagickBooleanType ListMagickInfo(FILE *file,
   magick_info=GetMagickInfoList("*",&number_formats,exception);
   if (magick_info == (const MagickInfo **) NULL)
     return(MagickFalse);
+  ClearMagickException(exception);
 #if !defined(SupportMagickModules)
   (void) fprintf(file,"   Format  Mode  Description\n");
 #else
@@ -1189,7 +1206,7 @@ MagickExport MagickBooleanType ListMagickInfo(FILE *file,
 
       *module='\0';
       if (magick_info[i]->module != (char *) NULL)
-        (void) strcpy(module,magick_info[i]->module);
+        (void) CopyMagickString(module,magick_info[i]->module,MaxTextExtent);
       (void) ConcatenateMagickString(module,"          ",MaxTextExtent);
       module[9]='\0';
       (void) fprintf(file,"%9s ",module);
