@@ -1,11 +1,11 @@
 /*
-  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
   obtain a copy of the License at
   
-    http://www.imagemagick.org/www/Copyright.html
+    http://www.imagemagick.org/script/license.php
   
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
@@ -13,23 +13,23 @@
   See the License for the specific language governing permissions and
   limitations under the License.
 
-  ImageMagick application programming interface declarations.
+  MagickCore magick methods.
 */
-#ifndef _MAGICK_MAGICK_H
-#define _MAGICK_MAGICK_H
+#ifndef _MAGICKCORE_MAGICK_H
+#define _MAGICKCORE_MAGICK_H
 
 #if defined(__cplusplus) || defined(c_plusplus)
 extern "C" {
 #endif
 
 typedef Image
-  *(DecoderHandler)(const ImageInfo *,ExceptionInfo *);
+  *DecoderHandler(const ImageInfo *,ExceptionInfo *);
 
 typedef MagickBooleanType
-  (EncoderHandler)(const ImageInfo *,Image *);
+  EncoderHandler(const ImageInfo *,Image *);
 
 typedef MagickBooleanType
-  (MagickHandler)(const unsigned char *,const size_t);
+  MagickHandler(const unsigned char *,const size_t);
 
 typedef struct _MagickInfo
 {
