@@ -687,7 +687,7 @@ MagickExport void *ResizeMagickMemory(void *memory,const size_t size)
           RelinquishSemaphoreInfo(memory_semaphore);
           memory=RelinquishMagickMemory(memory);
           ThrowMagickFatalException(ResourceLimitFatalError,
-            "MemoryAllocationFailed",strerror(errno));
+            "MemoryAllocationFailed",GetExceptionMessage(errno));
         }
       block=ResizeBlock(memory,size == 0 ? 1UL : size);
       assert(block != (void *) NULL);
