@@ -44,16 +44,23 @@ extern "C" {
 #define AcquireMagickMemory  PrependMagickMethod(AcquireMagickMemory)
 #define AcquireMagickResource  PrependMagickMethod(AcquireMagickResource)
 #define AcquireMemory  PrependMagickMethod(AcquireMemory)
+#define AcquireOneCacheViewPixel  PrependMagickMethod(AcquireOneCacheViewPixel)
 #define AcquireOnePixel  PrependMagickMethod(AcquireOnePixel)
+#define AcquireQuantumInfo  PrependMagickMethod(AcquireQuantumInfo)
 #define AcquireSemaphoreInfo  PrependMagickMethod(AcquireSemaphoreInfo)
+#define AcquireStreamInfo  PrependMagickMethod(AcquireStreamInfo)
 #define AcquireStringInfo  PrependMagickMethod(AcquireStringInfo)
 #define AcquireString  PrependMagickMethod(AcquireString)
 #define AcquireUniqueFilename  PrependMagickMethod(AcquireUniqueFilename)
 #define AcquireUniqueFileResource  PrependMagickMethod(AcquireUniqueFileResource)
+#define AcquireUniqueSymbolicLink  PrependMagickMethod(AcquireUniqueSymbolicLink)
+#define AdaptiveSharpenImageChannel  PrependMagickMethod(AdaptiveSharpenImageChannel)
+#define AdaptiveSharpenImage  PrependMagickMethod(AdaptiveSharpenImage)
 #define AdaptiveThresholdImage  PrependMagickMethod(AdaptiveThresholdImage)
 #define AddChildToXMLTree  PrependMagickMethod(AddChildToXMLTree)
 #define AddNoiseImageChannel  PrependMagickMethod(AddNoiseImageChannel)
 #define AddNoiseImage  PrependMagickMethod(AddNoiseImage)
+#define AddPathToXMLTree  PrependMagickMethod(AddPathToXMLTree)
 #define AddValueToSplayTree  PrependMagickMethod(AddValueToSplayTree)
 #define AffineTransformImage  PrependMagickMethod(AffineTransformImage)
 #define AllocateImageColormap  PrependMagickMethod(AllocateImageColormap)
@@ -84,6 +91,7 @@ extern "C" {
 #define BlurImageChannel  PrependMagickMethod(BlurImageChannel)
 #define BlurImage  PrependMagickMethod(BlurImage)
 #define BorderImage  PrependMagickMethod(BorderImage)
+#define CanonicalXMLContent  PrependMagickMethod(CanonicalXMLContent)
 #define CatchException  PrependMagickMethod(CatchException)
 #define CatchImageException  PrependMagickMethod(CatchImageException)
 #define ChannelImage  PrependMagickMethod(ChannelImage)
@@ -96,6 +104,7 @@ extern "C" {
 #define ClipImage  PrependMagickMethod(ClipImage)
 #define ClipPathImage  PrependMagickMethod(ClipPathImage)
 #define CloneBlobInfo  PrependMagickMethod(CloneBlobInfo)
+#define CloneCacheMethods  PrependMagickMethod(CloneCacheMethods)
 #define CloneDrawInfo  PrependMagickMethod(CloneDrawInfo)
 #define CloneImageAttributes  PrependMagickMethod(CloneImageAttributes)
 #define CloneImageInfo  PrependMagickMethod(CloneImageInfo)
@@ -106,7 +115,6 @@ extern "C" {
 #define CloneImages  PrependMagickMethod(CloneImages)
 #define CloneMemory  PrependMagickMethod(CloneMemory)
 #define CloneMontageInfo  PrependMagickMethod(CloneMontageInfo)
-#define ClonePixelCacheMethods  PrependMagickMethod(ClonePixelCacheMethods)
 #define CloneQuantizeInfo  PrependMagickMethod(CloneQuantizeInfo)
 #define CloneStringInfo  PrependMagickMethod(CloneStringInfo)
 #define CloneString  PrependMagickMethod(CloneString)
@@ -119,10 +127,12 @@ extern "C" {
 #define CompareHashmapStringInfo  PrependMagickMethod(CompareHashmapStringInfo)
 #define CompareHashmapString  PrependMagickMethod(CompareHashmapString)
 #define CompareImageChannels  PrependMagickMethod(CompareImageChannels)
+#define CompareImageLayers  PrependMagickMethod(CompareImageLayers)
 #define CompareImages  PrependMagickMethod(CompareImages)
 #define CompareSplayTreeStringInfo  PrependMagickMethod(CompareSplayTreeStringInfo)
 #define CompareSplayTreeString  PrependMagickMethod(CompareSplayTreeString)
 #define CompareStringInfo  PrependMagickMethod(CompareStringInfo)
+#define CompositeImageChannel  PrependMagickMethod(CompositeImageChannel)
 #define CompositeImage  PrependMagickMethod(CompositeImage)
 #define CompressImageColormap  PrependMagickMethod(CompressImageColormap)
 #define ConcatenateMagickString  PrependMagickMethod(ConcatenateMagickString)
@@ -135,6 +145,8 @@ extern "C" {
 #define ContinueTimer  PrependMagickMethod(ContinueTimer)
 #define ContrastImage  PrependMagickMethod(ContrastImage)
 #define Contrast  PrependMagickMethod(Contrast)
+#define ContrastStretchImageChannel  PrependMagickMethod(ContrastStretchImageChannel)
+#define ContrastStretchImage  PrependMagickMethod(ContrastStretchImage)
 #define ConvolveImageChannel  PrependMagickMethod(ConvolveImageChannel)
 #define ConvolveImage  PrependMagickMethod(ConvolveImage)
 #define CopyMagickMemory  PrependMagickMethod(CopyMagickMemory)
@@ -184,10 +196,12 @@ extern "C" {
 #define DestroyMagicList  PrependMagickMethod(DestroyMagicList)
 #define DestroyMontageInfo  PrependMagickMethod(DestroyMontageInfo)
 #define DestroyQuantizeInfo  PrependMagickMethod(DestroyQuantizeInfo)
+#define DestroyQuantumInfo  PrependMagickMethod(DestroyQuantumInfo)
 #define DestroyRandomReservoir  PrependMagickMethod(DestroyRandomReservoir)
 #define DestroySemaphoreInfo  PrependMagickMethod(DestroySemaphoreInfo)
 #define DestroySemaphore  PrependMagickMethod(DestroySemaphore)
 #define DestroySplayTree  PrependMagickMethod(DestroySplayTree)
+#define DestroyStreamInfo  PrependMagickMethod(DestroyStreamInfo)
 #define DestroyStringInfo  PrependMagickMethod(DestroyStringInfo)
 #define DestroyStringList  PrependMagickMethod(DestroyStringList)
 #define DestroyString  PrependMagickMethod(DestroyString)
@@ -198,6 +212,7 @@ extern "C" {
 #define DetachBlob  PrependMagickMethod(DetachBlob)
 #define DispatchImage  PrependMagickMethod(DispatchImage)
 #define DisplayImages  PrependMagickMethod(DisplayImages)
+#define DisposeImages  PrependMagickMethod(DisposeImages)
 #define DistillRandomEvent  PrependMagickMethod(DistillRandomEvent)
 #define DrawAffineImage  PrependMagickMethod(DrawAffineImage)
 #define DrawClipPath  PrependMagickMethod(DrawClipPath)
@@ -227,10 +242,10 @@ extern "C" {
 #define FlopImage  PrependMagickMethod(FlopImage)
 #define FormatImageAttributeList  PrependMagickMethod(FormatImageAttributeList)
 #define FormatImageAttribute  PrependMagickMethod(FormatImageAttribute)
+#define FormatMagickSize  PrependMagickMethod(FormatMagickSize)
 #define FormatMagickStringList  PrependMagickMethod(FormatMagickStringList)
 #define FormatMagickString  PrependMagickMethod(FormatMagickString)
 #define FormatMagickTime  PrependMagickMethod(FormatMagickTime)
-#define FormatSize  PrependMagickMethod(FormatSize)
 #define FormatStringList  PrependMagickMethod(FormatStringList)
 #define FormatString  PrependMagickMethod(FormatString)
 #define FrameImage  PrependMagickMethod(FrameImage)
@@ -250,10 +265,10 @@ extern "C" {
 #define GetBlobSize  PrependMagickMethod(GetBlobSize)
 #define GetBlobStreamData  PrependMagickMethod(GetBlobStreamData)
 #define GetBlobStreamHandler  PrependMagickMethod(GetBlobStreamHandler)
+#define GetCacheMethods  PrependMagickMethod(GetCacheMethods)
 #define GetCacheClass  PrependMagickMethod(GetCacheClass)
 #define GetCacheColorspace  PrependMagickMethod(GetCacheColorspace)
 #define GetCacheInfo  PrependMagickMethod(GetCacheInfo)
-#define GetCacheMethods  PrependMagickMethod(GetCacheMethods)
 #define GetCacheNexus  PrependMagickMethod(GetCacheNexus)
 #define GetCacheViewColorspace  PrependMagickMethod(GetCacheViewColorspace)
 #define GetCacheViewException  PrependMagickMethod(GetCacheViewException)
@@ -285,7 +300,9 @@ extern "C" {
 #define GetDelegateMode  PrependMagickMethod(GetDelegateMode)
 #define GetDrawInfo  PrependMagickMethod(GetDrawInfo)
 #define GetElapsedTime  PrependMagickMethod(GetElapsedTime)
+#define GetEnvironmentValue  PrependMagickMethod(GetEnvironmentValue)
 #define GetExceptionInfo  PrependMagickMethod(GetExceptionInfo)
+#define GetExceptionMessage  PrependMagickMethod(GetExceptionMessage)
 #define GetExecutionPath  PrependMagickMethod(GetExecutionPath)
 #define GetFirstImageInList  PrependMagickMethod(GetFirstImageInList)
 #define GetGeometry  PrependMagickMethod(GetGeometry)
@@ -390,17 +407,20 @@ extern "C" {
 #define GetNumberOfEntriesInHashmap  PrependMagickMethod(GetNumberOfEntriesInHashmap)
 #define GetNumberOfNodesInSplayTree  PrependMagickMethod(GetNumberOfNodesInSplayTree)
 #define GetNumberScenes  PrependMagickMethod(GetNumberScenes)
+#define GetOneCacheViewPixel  PrependMagickMethod(GetOneCacheViewPixel)
 #define GetOnePixel  PrependMagickMethod(GetOnePixel)
 #define GetOptimalKernelWidth1D  PrependMagickMethod(GetOptimalKernelWidth1D)
 #define GetOptimalKernelWidth2D  PrependMagickMethod(GetOptimalKernelWidth2D)
 #define GetOptimalKernelWidth  PrependMagickMethod(GetOptimalKernelWidth)
 #define GetPageGeometry  PrependMagickMethod(GetPageGeometry)
 #define GetPathComponent  PrependMagickMethod(GetPathComponent)
+#define GetPathComponents  PrependMagickMethod(GetPathComponents)
 #define GetPixelCacheArea  PrependMagickMethod(GetPixelCacheArea)
 #define GetPixels  PrependMagickMethod(GetPixels)
 #define GetPreviousImageInList  PrependMagickMethod(GetPreviousImageInList)
 #define GetPreviousImage  PrependMagickMethod(GetPreviousImage)
 #define GetQuantizeInfo  PrependMagickMethod(GetQuantizeInfo)
+#define GetQuantumInfo  PrependMagickMethod(GetQuantumInfo)
 #define GetRandomKey  PrependMagickMethod(GetRandomKey)
 #define GetRandomValue  PrependMagickMethod(GetRandomValue)
 #define GetSignatureInfo  PrependMagickMethod(GetSignatureInfo)
@@ -417,6 +437,8 @@ extern "C" {
 #define GetXMLTreeAttribute  PrependMagickMethod(GetXMLTreeAttribute)
 #define GetXMLTreeChild  PrependMagickMethod(GetXMLTreeChild)
 #define GetXMLTreeContent  PrependMagickMethod(GetXMLTreeContent)
+#define GetXMLTreeOrdered  PrependMagickMethod(GetXMLTreeOrdered)
+#define GetXMLTreePath  PrependMagickMethod(GetXMLTreePath)
 #define GetXMLTreeProcessingInstructions  PrependMagickMethod(GetXMLTreeProcessingInstructions)
 #define GetXMLTreeSibling  PrependMagickMethod(GetXMLTreeSibling)
 #define GetXMLTreeTag  PrependMagickMethod(GetXMLTreeTag)
@@ -434,7 +456,6 @@ extern "C" {
 #define HWBTransform  PrependMagickMethod(HWBTransform)
 #define IdentifyImage  PrependMagickMethod(IdentifyImage)
 #define IdentityAffine  PrependMagickMethod(IdentityAffine)
-#define IInterpolateColor  PrependMagickMethod(IInterpolateColor)
 #define ImageListToArray  PrependMagickMethod(ImageListToArray)
 #define ImagesToBlob  PrependMagickMethod(ImagesToBlob)
 #define ImageToBlob  PrependMagickMethod(ImageToBlob)
@@ -447,11 +468,12 @@ extern "C" {
 #define InitializeMagickResources  PrependMagickMethod(InitializeMagickResources)
 #define InitializeSemaphore  PrependMagickMethod(InitializeSemaphore)
 #define InsertImageInList  PrependMagickMethod(InsertImageInList)
+#define InsertTagIntoXMLTree  PrependMagickMethod(InsertTagIntoXMLTree)
 #define InsertValueInLinkedList  PrependMagickMethod(InsertValueInLinkedList)
 #define InsertValueInSortedLinkedList  PrependMagickMethod(InsertValueInSortedLinkedList)
-#define InterpolateColor  PrependMagickMethod(InterpolateColor)
+#define InterpretImageAttributes  PrependMagickMethod(InterpretImageAttributes)
+#define InterpretImageFilename  PrependMagickMethod(InterpretImageFilename)
 #define InvokeDelegate  PrependMagickMethod(InvokeDelegate)
-#define InvokePostscriptDelegate  PrependMagickMethod(InvokePostscriptDelegate)
 #define IsAccessible  PrependMagickMethod(IsAccessible)
 #define IsBlobExempt  PrependMagickMethod(IsBlobExempt)
 #define IsBlobSeekable  PrependMagickMethod(IsBlobSeekable)
@@ -468,6 +490,7 @@ extern "C" {
 #define IsMagickConflict  PrependMagickMethod(IsMagickConflict)
 #define IsMagickInstantiated  PrependMagickMethod(IsMagickInstantiated)
 #define IsMagickOption  PrependMagickMethod(IsMagickOption)
+#define IsMagickTrue  PrependMagickMethod(IsMagickTrue)
 #define IsMonochromeImage  PrependMagickMethod(IsMonochromeImage)
 #define IsOpacitySimilar  PrependMagickMethod(IsOpacitySimilar)
 #define IsOpaqueImage  PrependMagickMethod(IsOpaqueImage)
@@ -475,7 +498,6 @@ extern "C" {
 #define IsSceneGeometry  PrependMagickMethod(IsSceneGeometry)
 #define IsSubimage  PrependMagickMethod(IsSubimage)
 #define IsTaintImage  PrependMagickMethod(IsTaintImage)
-#define IsTrue  PrependMagickMethod(IsTrue)
 #define JP2EncodeImage  PrependMagickMethod(JP2EncodeImage)
 #define JPEGEncodeImage  PrependMagickMethod(JPEGEncodeImage)
 #define LevelImageChannel  PrependMagickMethod(LevelImageChannel)
@@ -493,7 +515,9 @@ extern "C" {
 #define ListMagicInfo  PrependMagickMethod(ListMagicInfo)
 #define ListMagickInfo  PrependMagickMethod(ListMagickInfo)
 #define ListMagickResourceInfo  PrependMagickMethod(ListMagickResourceInfo)
+#define ListModuleInfo  PrependMagickMethod(ListModuleInfo)
 #define ListTypeInfo  PrependMagickMethod(ListTypeInfo)
+#define LoadFontConfigFonts  PrependMagickMethod(LoadFontConfigFonts)
 #define LoadWPG2Flags  PrependMagickMethod(LoadWPG2Flags)
 #define LocaleCompare  PrependMagickMethod(LocaleCompare)
 #define LocaleLower  PrependMagickMethod(LocaleLower)
@@ -522,6 +546,7 @@ extern "C" {
 #define ModulateHSL  PrependMagickMethod(ModulateHSL)
 #define ModulateHWB  PrependMagickMethod(ModulateHWB)
 #define ModulateImage  PrependMagickMethod(ModulateImage)
+#define MontageImageList  PrependMagickMethod(MontageImageList)
 #define MontageImages  PrependMagickMethod(MontageImages)
 #define MorphImages  PrependMagickMethod(MorphImages)
 #define MosaicImages  PrependMagickMethod(MosaicImages)
@@ -544,8 +569,12 @@ extern "C" {
 #define OpaqueImage  PrependMagickMethod(OpaqueImage)
 #define OpenBlob  PrependMagickMethod(OpenBlob)
 #define OpenCacheView  PrependMagickMethod(OpenCacheView)
+#define OpenStream  PrependMagickMethod(OpenStream)
+#define OptimizeImageLayers  PrependMagickMethod(OptimizeImageLayers)
+#define OptimizePlusImageLayers  PrependMagickMethod(OptimizePlusImageLayers)
 #define OrderedDitherImage  PrependMagickMethod(OrderedDitherImage)
 #define PackbitsEncodeImage  PrependMagickMethod(PackbitsEncodeImage)
+#define PaintOpaqueImageChannel  PrependMagickMethod(PaintOpaqueImageChannel)
 #define PaintOpaqueImage  PrependMagickMethod(PaintOpaqueImage)
 #define PaintTransparentImage  PrependMagickMethod(PaintTransparentImage)
 #define ParseAbsoluteGeometry  PrependMagickMethod(ParseAbsoluteGeometry)
@@ -570,6 +599,7 @@ extern "C" {
 #define PreviewImage  PrependMagickMethod(PreviewImage)
 #define PrintStringInfo  PrependMagickMethod(PrintStringInfo)
 #define ProfileImage  PrependMagickMethod(ProfileImage)
+#define PruneTagFromXMLTree  PrependMagickMethod(PruneTagFromXMLTree)
 #define PushImageList  PrependMagickMethod(PushImageList)
 #define PushImagePixels  PrependMagickMethod(PushImagePixels)
 #define PutEntryInHashmap  PrependMagickMethod(PutEntryInHashmap)
@@ -715,7 +745,6 @@ extern "C" {
 #define RemoveLastImageFromList  PrependMagickMethod(RemoveLastImageFromList)
 #define RemoveNodeByValueFromSplayTree  PrependMagickMethod(RemoveNodeByValueFromSplayTree)
 #define RemoveNodeFromSplayTree  PrependMagickMethod(RemoveNodeFromSplayTree)
-#define RemoveTagFromXMLTree  PrependMagickMethod(RemoveTagFromXMLTree)
 #define ReplaceImageInList  PrependMagickMethod(ReplaceImageInList)
 #define ResetHashmapIterator  PrependMagickMethod(ResetHashmapIterator)
 #define ResetImageAttributeIterator  PrependMagickMethod(ResetImageAttributeIterator)
@@ -739,6 +768,7 @@ extern "C" {
 #define SeparateImageChannel  PrependMagickMethod(SeparateImageChannel)
 #define SepiaToneImage  PrependMagickMethod(SepiaToneImage)
 #define SetBlobExempt  PrependMagickMethod(SetBlobExempt)
+#define SetCacheMethods  PrependMagickMethod(SetCacheMethods)
 #define SetCacheNexus  PrependMagickMethod(SetCacheNexus)
 #define SetCacheThreshold  PrependMagickMethod(SetCacheThreshold)
 #define SetCacheView  PrependMagickMethod(SetCacheView)
@@ -778,7 +808,8 @@ extern "C" {
 #define SetMagickRegistry  PrependMagickMethod(SetMagickRegistry)
 #define SetMagickResourceLimit  PrependMagickMethod(SetMagickResourceLimit)
 #define SetMonitorHandler  PrependMagickMethod(SetMonitorHandler)
-#define SetPixelCacheMethods  PrependMagickMethod(SetPixelCacheMethods)
+#define SetStreamInfoMap  PrependMagickMethod(SetStreamInfoMap)
+#define SetStreamInfoStorageType  PrependMagickMethod(SetStreamInfoStorageType)
 #define SetStringInfoDatum  PrependMagickMethod(SetStringInfoDatum)
 #define SetStringInfoLength  PrependMagickMethod(SetStringInfoLength)
 #define SetStringInfo  PrependMagickMethod(SetStringInfo)
@@ -807,6 +838,7 @@ extern "C" {
 #define StartTimer  PrependMagickMethod(StartTimer)
 #define SteganoImage  PrependMagickMethod(SteganoImage)
 #define StereoImage  PrependMagickMethod(StereoImage)
+#define StreamImage  PrependMagickMethod(StreamImage)
 #define StringInfoToString  PrependMagickMethod(StringInfoToString)
 #define StringToArgv  PrependMagickMethod(StringToArgv)
 #define StringToDouble  PrependMagickMethod(StringToDouble)
@@ -820,7 +852,6 @@ extern "C" {
 #define SyncBlob  PrependMagickMethod(SyncBlob)
 #define SyncCacheNexus  PrependMagickMethod(SyncCacheNexus)
 #define SyncCacheView  PrependMagickMethod(SyncCacheView)
-#define SyncImageCache  PrependMagickMethod(SyncImageCache)
 #define SyncImageList  PrependMagickMethod(SyncImageList)
 #define SyncImageOptions  PrependMagickMethod(SyncImageOptions)
 #define SyncImagePixels  PrependMagickMethod(SyncImagePixels)
@@ -847,6 +878,8 @@ extern "C" {
 #define TransformRGBImage  PrependMagickMethod(TransformRGBImage)
 #define TranslateText  PrependMagickMethod(TranslateText)
 #define TransparentImage  PrependMagickMethod(TransparentImage)
+#define TransposeImage  PrependMagickMethod(TransposeImage)
+#define TransverseImage  PrependMagickMethod(TransverseImage)
 #define TrimImage  PrependMagickMethod(TrimImage)
 #define UnlockSemaphoreInfo  PrependMagickMethod(UnlockSemaphoreInfo)
 #define UnmapBlob  PrependMagickMethod(UnmapBlob)
@@ -951,6 +984,7 @@ extern "C" {
 #define UnshiftImageList  PrependMagickMethod(UnshiftImageList)
 #define UpdateSignature  PrependMagickMethod(UpdateSignature)
 #define ValidateColormapIndex  PrependMagickMethod(ValidateColormapIndex)
+#define VignetteImage  PrependMagickMethod(VignetteImage)
 #define WaveImage  PrependMagickMethod(WaveImage)
 #define WhiteThresholdImage  PrependMagickMethod(WhiteThresholdImage)
 #define WriteBlobByte  PrependMagickMethod(WriteBlobByte)
@@ -1037,7 +1071,6 @@ extern "C" {
 #define XWindowByProperty  PrependMagickMethod(XWindowByProperty)
 #define ZLIBEncodeImage  PrependMagickMethod(ZLIBEncodeImage)
 #define ZoomImage  PrependMagickMethod(ZoomImage)
-
 #endif
 
 #if defined(__cplusplus) || defined(c_plusplus)
