@@ -202,7 +202,6 @@ MagickExport MagickBooleanType ExecuteModuleProcess(const char *tag,
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",(*image)->filename);
 #if !defined(BuildMagickModules)
   status=ExecuteStaticModuleProcess(tag,image,argc,argv);
-printf("%d\n",status);
   if (status != MagickFalse)
     return(status);
 #endif
@@ -610,7 +609,10 @@ static MagickBooleanType GetMagickModulePath(const char *filename,
           (void) ConcatenateMagickString(path,DirectorySeparator,MaxTextExtent);
         (void) ConcatenateMagickString(path,filename,MaxTextExtent);
         if (IsAccessible(path) != MagickFalse)
-          return(MagickTrue);
+          {
+            module_path=(char *) RelinquishMagickMemory(module_path);
+            return(MagickTrue);
+          }
         p=strchr(p+1,DirectoryListSeparator);
       }
       module_path=(char *) RelinquishMagickMemory(module_path);
@@ -798,9 +800,9 @@ static MagickBooleanType GetMagickModulePath(const char *filename,
         */
         (void) FormatMagickString(path,MaxTextExtent,"%s%s%s%s",home,
           *home == '/' ? "/.magick" : "",DirectorySeparator,filename);
+        home=(char *) RelinquishMagickMemory(home);
         if (IsAccessible(path) != MagickFalse)
           return(MagickTrue);
-        home=(char *) RelinquishMagickMemory(home);
       }
   }
   /*
