@@ -1,13 +1,29 @@
 /*
-  ImageMagick Modules Methods.
+  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization
+  dedicated to making software imaging solutions freely available.
+  
+  You may not use this file except in compliance with the License.
+  obtain a copy of the License at
+  
+    http://www.imagemagick.org/script/license.php
+  
+  Unless required by applicable law or agreed to in writing, software
+  distributed under the License is distributed on an "AS IS" BASIS,
+  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+  See the License for the specific language governing permissions and
+  limitations under the License.
+
+  MagickCore module methods.
 */
-#ifndef _MAGICK_MODULE_H
-#define _MAGICK_MODULE_H
+#ifndef _MAGICKCORE_MODULE_H
+#define _MAGICKCORE_MODULE_H
 
 #if defined(__cplusplus) || defined(c_plusplus)
 extern "C" {
 #endif
 
+#include <time.h>
+
 typedef enum
 {
   MagickCoderModule,
@@ -40,14 +56,11 @@ typedef struct _ModuleInfo
 } ModuleInfo;
 
 extern MagickExport char
-  **GetModuleList(const char *,unsigned long *);
-
-extern MagickExport char
-  *TagToModule(const char *);
+  **GetModuleList(const char *,unsigned long *,ExceptionInfo *);
 
 extern MagickExport const ModuleInfo
   *GetModuleInfo(const char *,ExceptionInfo *),
-  **GetModuleInfoList(const char *,unsigned long *);
+  **GetModuleInfoList(const char *,unsigned long *,ExceptionInfo *);
 
 extern MagickExport MagickBooleanType
   ExecuteModuleProcess(const char *,Image **,const int,char **),
@@ -58,7 +71,6 @@ extern MagickExport MagickBooleanType
 
 extern MagickExport void
   DestroyModuleList(void),
-  *GetModuleBlob(const char *,char *,size_t *,ExceptionInfo *),
   RegisterStaticModules(void),
   UnregisterStaticModules(void);
 
