@@ -242,28 +242,30 @@ MagickExport void GetMontageInfo(const ImageInfo *image_info,
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%   M o n t a g e I m a g e s                                                 %
+%   M o n t a g e I m a g e L i s t                                           %
 %                                                                             %
 %                                                                             %
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  Montageimages() is a layout manager that lets you tile one or more
+%  MontageImageList() is a layout manager that lets you tile one or more
 %  thumbnails across an image canvas.
 %
-%  The format of the MontageImages method is:
+%  The format of the MontageImageList method is:
 %
-%      Image *MontageImages(const Image *images,const MontageInfo *montage_info,
+%      Image *MontageImageList(const ImageInfo *image_info,
+%        const MontageInfo *montage_info,Image *images,
 %        ExceptionInfo *exception)
 %
 %  A description of each parameter follows:
 %
-%    o images: Specifies a pointer to an array of Image structures.
+%    o image_info: The image info.
 %
 %    o montage_info: Specifies a pointer to a MontageInfo structure.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o images: Specifies a pointer to an array of Image structures.
 %
+%    o exception: Return any errors or warnings in this structure.
 %
 */
 
@@ -305,6 +307,21 @@ static int SceneCompare(const void *x,const void *y)
 
 MagickExport Image *MontageImages(const Image *images,
   const MontageInfo *montage_info,ExceptionInfo *exception)
+{
+  Image
+    *montage_image;
+
+  ImageInfo
+    *image_info;
+
+  image_info=AcquireImageInfo();
+  montage_image=MontageImageList(image_info,montage_info,images,exception);
+  image_info=DestroyImageInfo(image_info);
+  return(montage_image);
+}
+
+MagickExport Image *MontageImageList(const ImageInfo *image_info,
+  const MontageInfo *montage_info,const Image *images,ExceptionInfo *exception)
 {
 #define MontageImageTag  "Montage/Image"
 #define TileImageTag  "Tile/Image"
@@ -332,7 +349,7 @@ MagickExport Image *MontageImages(const Image *images,
     *thumbnail;
 
   ImageInfo
-    *image_info;
+    *clone_info;
 
   long
     x,
@@ -513,10 +530,10 @@ MagickExport Image *MontageImages(const Image *images,
   /*
     Initialize draw attributes.
   */
-  image_info=CloneImageInfo((ImageInfo *) NULL);
-  image_info->background_color=montage_info->background_color;
-  image_info->border_color=montage_info->border_color;
-  draw_info=CloneDrawInfo(image_info,(DrawInfo *) NULL);
+  clone_info=CloneImageInfo(image_info);
+  clone_info->background_color=montage_info->background_color;
+  clone_info->border_color=montage_info->border_color;
+  draw_info=CloneDrawInfo(clone_info,(DrawInfo *) NULL);
   if (montage_info->font != (char *) NULL)
     (void) CloneString(&draw_info->font,montage_info->font);
   draw_info->pointsize=montage_info->pointsize;
@@ -528,14 +545,14 @@ MagickExport Image *MontageImages(const Image *images,
   texture=NewImageList();
   if (montage_info->texture != (char *) NULL)
     {
-      (void) CopyMagickString(image_info->filename,montage_info->texture,
+      (void) CopyMagickString(clone_info->filename,montage_info->texture,
         MaxTextExtent);
-      texture=ReadImage(image_info,exception);
+      texture=ReadImage(clone_info,exception);
     }
   /*
     Determine the number of lines in an next label.
   */
-  title=TranslateText(image_info,image_list[0],montage_info->title);
+  title=InterpretImageAttributes(clone_info,image_list[0],montage_info->title);
   title_offset=0;
   if (montage_info->title != (char *) NULL)
     title_offset=(unsigned long) (2*(metrics.ascent-metrics.descent)*
@@ -553,7 +570,7 @@ MagickExport Image *MontageImages(const Image *images,
     Allocate next structure.
   */
   tile_image=AllocateImage(NULL);
-  montage=AllocateImage(image_info);
+  montage=AllocateImage(clone_info);
   montage->scene=0;
   images_per_page=(number_images-1)/(tiles_per_row*tiles_per_column)+1;
   tiles=0;
@@ -852,7 +869,7 @@ MagickExport Image *MontageImages(const Image *images,
         /*
           Allocate next image structure.
         */
-        AllocateNextImage(image_info,montage);
+        AllocateNextImage(clone_info,montage);
         if (GetNextImageInList(montage) == (Image *) NULL)
           {
             montage=DestroyImageList(montage);
@@ -868,7 +885,7 @@ MagickExport Image *MontageImages(const Image *images,
     texture=DestroyImage(texture);
   master_list=(Image **) RelinquishMagickMemory(master_list);
   draw_info=DestroyDrawInfo(draw_info);
-  image_info=DestroyImageInfo(image_info);
+  clone_info=DestroyImageInfo(clone_info);
   while (GetPreviousImageInList(montage) != (Image *) NULL)
     montage=GetPreviousImageInList(montage);
   return(montage);
