@@ -471,53 +471,6 @@ MagickExport int NTExitLibrary(void)
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%   N T F i l e T r u n c a t e                                               %
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%
-%  NTFileTruncate() truncates a file to a specified length.
-%
-%  The format of the NTFileTruncate method is:
-%
-%      int NTFileTruncate(int file,const MagickSizeType length)
-%
-%  A description of each parameter follows:
-%
-%    o file: The file.
-%
-%    o length: The file length.
-%
-*/
-MagickExport int NTFileTruncate(int file,const MagickSizeType length)
-{
-  DWORD
-    file_pointer;
-
-  long
-    file_handle,
-    high,
-    low;
-
-  file_handle=_get_osfhandle(file);
-  if (file_handle == -1L)
-    return(-1);
-  low=(long) (length & 0xffffffffUL);
-  high=(long) ((((MagickOffsetType) length) >> 32) & 0xffffffffUL);
-  file_pointer=SetFilePointer((HANDLE) file_handle,low,&high,FILE_BEGIN);
-  if ((file_pointer == 0xFFFFFFFF) && (GetLastError() != NO_ERROR))
-    return(-1);
-  if (SetEndOfFile((HANDLE) file_handle) == 0)
-    return(-1);
-  return(0);
-}
-
-/*
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%                                                                             %
-%                                                                             %
-%                                                                             %
 %   N T G e t E x e c u t i o n P a t h                                       %
 %                                                                             %
 %                                                                             %
@@ -2032,6 +1985,53 @@ MagickExport long NTTellDirectory(DIR *entry)
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   N T T r u n c a t e F i l e                                               %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  NTTruncateFile() truncates a file to a specified length.
+%
+%  The format of the NTTruncateFile method is:
+%
+%      int NTTruncateFile(int file,const MagickSizeType length)
+%
+%  A description of each parameter follows:
+%
+%    o file: The file.
+%
+%    o length: The file length.
+%
+*/
+MagickExport int NTTruncateFile(int file,const MagickSizeType length)
+{
+  DWORD
+    file_pointer;
+
+  long
+    file_handle,
+    high,
+    low;
+
+  file_handle=_get_osfhandle(file);
+  if (file_handle == -1L)
+    return(-1);
+  low=(long) (length & 0xffffffffUL);
+  high=(long) ((((MagickOffsetType) length) >> 32) & 0xffffffffUL);
+  file_pointer=SetFilePointer((HANDLE) file_handle,low,&high,FILE_BEGIN);
+  if ((file_pointer == 0xFFFFFFFF) && (GetLastError() != NO_ERROR))
+    return(-1);
+  if (SetEndOfFile((HANDLE) file_handle) == 0)
+    return(-1);
+  return(0);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 +  N T U n m a p M e m o r y                                                  %
 %                                                                             %
 %                                                                             %
