@@ -52,10 +52,12 @@
 #include "magick/exception-private.h"
 #include "magick/fx.h"
 #include "magick/geometry.h"
+#include "magick/layer.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
 #include "magick/montage.h"
 #include "magick/option.h"
+#include "magick/quantum.h"
 #include "magick/resource_.h"
 #include "magick/splay-tree.h"
 #include "magick/string_.h"
@@ -96,11 +98,14 @@ static const OptionInfo
     { "Default", (long) DefaultChannels },
     { "Gray", (long) GrayChannel },
     { "Green", (long) GreenChannel },
+    { "Hue", (long) RedChannel },
     { "Index", (long) IndexChannel },
+    { "Luminosity", (long) BlueChannel },
     { "Magenta", (long) MagentaChannel },
     { "Matte", (long) OpacityChannel },
     { "Opacity", (long) OpacityChannel },
     { "Red", (long) RedChannel },
+    { "Saturation", (long) GreenChannel },
     { "Yellow", (long) YellowChannel },
     { (char *) NULL, (long) UndefinedChannel }
   },
@@ -121,194 +126,451 @@ static const OptionInfo
   },
   CommandOptions[] =
   {
-    { "-{0}", 0L },
-    { "-{1}", 1L },
-    { "-{2}", 2L },
+    { "+adjoin", 0L },
     { "-adjoin", 0L },
+    { "-adaptive-sharpen", 1L },
+    { "+adaptive-sharpen", 1L },
+    { "-adaptive-threshold", 1L },
+    { "+adaptive-threshold", 1L },
+    { "+affine", 0L },
     { "-affine", 1L },
+    { "+annotate", 0L },
     { "-annotate", 2L },
+    { "+antialias", 0L },
     { "-antialias", 0L },
+    { "+append", 0L },
     { "-append", 0L },
+    { "+authenticate", 0L },
     { "-authenticate", 1L },
+    { "+auto-orient", 0L },
+    { "-auto-orient", 0L },
+    { "+average", 0L },
     { "-average", 0L },
+    { "+backdrop", 0L },
+    { "-backdrop", 1L },
+    { "+background", 0L },
     { "-background", 1L },
+    { "+bias", 0L },
     { "-bias", 1L },
+    { "+black-threshold", 0L },
     { "-black-threshold", 1L },
+    { "+blend", 0L },
     { "-blend", 1L },
+    { "+blue-primary", 0L },
     { "-blue-primary", 1L },
+    { "+blur", 0L },
     { "-blur", 1L },
+    { "+border", 0L },
     { "-border", 1L },
+    { "+bordercolor", 0L },
     { "-bordercolor", 1L },
+    { "+borderwidth", 0L },
+    { "-borderwidth", 1L },
+    { "+box", 0L },
     { "-box", 1L },
+    { "+cache", 0L },
     { "-cache", 1L },
+    { "+channel", 0L },
     { "-channel", 1L },
-    { "-charcoal", 1L },
+    { "+charcoal", 0L },
+    { "-charcoal", 0L },
+    { "+chop", 0L },
     { "-chop", 1L },
+    { "+clip", 0L },
+    { "-clip", 1L },
+    { "+clip-path", 0L },
     { "-clip-path", 1L },
+    { "+clone", 0L },
     { "-clone", 1L },
+    { "+coalesce", 0L },
     { "-coalesce", 0L },
+    { "+colorize", 0L },
     { "-colorize", 1L },
+    { "+colormap", 0L },
+    { "-colormap", 1L },
+    { "+colors", 0L },
     { "-colors", 1L },
+    { "+colorspace", 0L },
     { "-colorspace", 1L },
+    { "+combine", 0L },
     { "-combine", 0L },
+    { "+comment", 0L },
     { "-comment", 1L },
+    { "+compose", 0L },
     { "-compose", 1L },
+    { "+composite", 0L },
     { "-composite", 0L },
+    { "+compress", 0L },
     { "-compress", 1L },
+    { "+contrast", 0L },
     { "-contrast", 0L },
+    { "+contrast-stretch", 0L },
     { "-contrast-stretch", 1L },
+    { "+convolve", 0L },
     { "-convolve", 1L },
+    { "+crop", 0L },
     { "-crop", 1L },
+    { "+cycle", 0L },
     { "-cycle", 1L },
-    { "-deconstruct", 0L },
+    { "+debug", 0L },
     { "-debug", 1L },
-    { "-define", 1L },
+    { "+deconstruct", 0L },
+    { "-deconstruct", 0L },
     { "+define", 1L },
+    { "-define", 1L },
+    { "+delay", 0L },
     { "-delay", 1L },
+    { "+delete", 0L },
     { "-delete", 1L },
+    { "+density", 0L },
     { "-density", 1L },
+    { "+depth", 0L },
     { "-depth", 1L },
+    { "+descend", 0L },
+    { "-descend", 1L },
+    { "+despeckle", 0L },
     { "-despeckle", 0L },
+    { "+displace", 0L },
+    { "-displace", 1L },
+    { "+display", 0L },
     { "-display", 1L },
+    { "+dispose", 0L },
     { "-dispose", 1L },
+    { "+dissolve", 0L },
+    { "-dissolve", 1L },
+    { "+dither", 0L },
     { "-dither", 0L },
+    { "+draw", 0L },
     { "-draw", 1L },
+    { "+edge", 0L },
     { "-edge", 1L },
+    { "+emboss", 0L },
     { "-emboss", 1L },
+    { "+encoding", 0L },
     { "-encoding", 1L },
+    { "+endian", 0L },
     { "-endian", 1L },
+    { "+enhance", 0L },
     { "-enhance", 0L },
+    { "+equalize", 0L },
     { "-equalize", 0L },
+    { "+evaluate", 0L },
     { "-evaluate", 2L },
+    { "+extent", 0L },
     { "-extent", 1L },
+    { "+extract", 0L },
     { "-extract", 1L },
+    { "+family", 0L },
     { "-family", 1L },
+    { "+fill", 0L },
     { "-fill", 1L },
+    { "+filter", 0L },
     { "-filter", 1L },
+    { "+flatten", 0L },
     { "-flatten", 0L },
+    { "+flip", 0L },
     { "-flip", 0L },
-    { "-flop", 0L },
+    { "+floodfill", 0L },
     { "-floodfill", 2L },
-    { "-family", 1L },
+    { "+flop", 0L },
+    { "-flop", 0L },
+    { "+font", 0L },
     { "-font", 1L },
+    { "+foreground", 0L },
+    { "-foreground", 1L },
+    { "+format", 0L },
     { "-format", 1L },
+    { "+frame", 0L },
     { "-frame", 1L },
+    { "+fuzz", 0L },
     { "-fuzz", 1L },
+    { "+fx", 0L },
     { "-fx", 1L },
+    { "+gamma", 0L },
     { "-gamma", 1L },
+    { "+gaussian", 0L },
     { "-gaussian", 1L },
+    { "+geometry", 0L },
     { "-geometry", 1L },
-    { "-green-primary", 1L },
+    { "+gravity", 0L },
     { "-gravity", 1L },
+    { "+green-primary", 0L },
+    { "-green-primary", 1L },
+    { "+help", 0L },
     { "-help", 0L },
+    { "+iconGeometry", 0L },
+    { "-iconGeometry", 1L },
+    { "+iconic", 0L },
+    { "-iconic", 1L },
+    { "+identify", 0L },
     { "-identify", 0L },
+    { "+immutable", 0L },
+    { "-immutable", 1L },
+    { "+implode", 0L },
     { "-implode", 1L },
+    { "+insert", 0L },
     { "-insert", 1L },
+    { "+intent", 0L },
     { "-intent", 1L },
+    { "+interlace", 0L },
     { "-interlace", 1L },
+    { "+label", 0L },
     { "-label", 1L },
+    { "+lat", 0L },
     { "-lat", 1L },
+    { "+layers", 0L },
+    { "-layers", 1L },
+    { "+level", 0L },
     { "-level", 1L },
+    { "+limit", 0L },
     { "-limit", 2L },
+    { "+linewidth", 0L },
     { "-linewidth", 1L },
+    { "+list", 0L },
     { "-list", 1L },
+    { "+log", 0L },
     { "-log", 1L },
+    { "+loop", 0L },
     { "-loop", 1L },
+    { "+magnify", 0L },
+    { "-magnify", 1L },
+    { "+map", 0L },
     { "-map", 1L },
+    { "+mask", 0L },
     { "-mask", 1L },
+    { "+matte", 0L },
     { "-matte", 0L },
+    { "+mattecolor", 0L },
     { "-mattecolor", 1L },
+    { "+median", 0L },
     { "-median", 1L },
+    { "+metric", 0L },
+    { "-metric", 1L },
+    { "+mode", 0L },
     { "-mode", 1L },
+    { "+modulate", 0L },
     { "-modulate", 1L },
+    { "+monitor", 0L },
+    { "-monitor", 1L },
+    { "+monochrome", 0L },
     { "-monochrome", 0L },
+    { "+morph", 0L },
     { "-morph", 1L },
+    { "+mosaic", 0L },
     { "-mosaic", 0L },
+    { "+motion-blur", 0L },
     { "-motion-blur", 1L },
+    { "+name", 0L },
+    { "-name", 1L },
+    { "+negate", 0L },
     { "-negate", 0L },
-    { "-normalize", 0L },
-    { "-noise", 1L },
     { "+noise", 1L },
+    { "-noise", 1L },
+    { "+noop", 0L },
+    { "-noop", 0L },
+    { "+normalize", 0L },
+    { "-normalize", 0L },
+    { "+opaque", 0L },
     { "-opaque", 1L },
+    { "+ordered-dither", 0L },
     { "-ordered-dither", 1L },
+    { "+orient", 0L },
     { "-orient", 1L },
+    { "+page", 0L },
     { "-page", 1L },
+    { "+paint", 0L },
     { "-paint", 1L },
+    { "+pause", 0L },
+    { "-pause", 1L },
+    { "+pen", 0L },
     { "-pen", 1L },
+    { "+ping", 0L },
     { "-ping", 0L },
+    { "+pointsize", 0L },
     { "-pointsize", 1L },
+    { "+posterize", 0L },
     { "-posterize", 1L },
+    { "+preview", 0L },
     { "-preview", 1L },
-    { "-profile", 1L },
-    { "+profile", 1L },
+    { "+process", 0L },
     { "-process", 1L },
-    { "-quiet", 0L },
+    { "+profile", 1L },
+    { "-profile", 1L },
+    { "+quality", 0L },
     { "-quality", 1L },
+    { "+quiet", 0L },
+    { "-quiet", 0L },
+    { "+radial-blur", 0L },
     { "-radial-blur", 1L },
+    { "+raise", 0L },
     { "-raise", 1L },
+    { "+random-threshold", 0L },
     { "-random-threshold", 1L },
-    { "-region", 1L },
-    { "-raise", 1L },
+    { "+red-primary", 0L },
     { "-red-primary", 1L },
+    { "+regard-warnings", 0L },
+    { "-regard-warnings", 0L },
+    { "+region", 0L },
+    { "-region", 1L },
+    { "+remote", 0L },
+    { "-remote", 1L },
+    { "+render", 0L },
     { "-render", 0L },
+    { "+repage", 0L },
     { "-repage", 1L },
+    { "+resample", 0L },
     { "-resample", 1L },
+    { "+resize", 0L },
     { "-resize", 1L },
+    { "+roll", 0L },
     { "-roll", 1L },
+    { "+rotate", 0L },
     { "-rotate", 1L },
+    { "+sample", 0L },
     { "-sample", 1L },
+    { "+sampling-factor", 0L },
     { "-sampling-factor", 1L },
+    { "+sans", 0L },
+    { "-sans", 1L },
+    { "+sans0", 0L },
+    { "-sans0", 0L },
+    { "+sans2", 2L },
+    { "-sans2", 2L },
+    { "+scale", 0L },
     { "-scale", 1L },
+    { "+scene", 0L },
     { "-scene", 1L },
+    { "+scenes", 0L },
+    { "-scenes", 1L },
+    { "+screen", 0L },
+    { "-screen", 1L },
+    { "+seed", 0L },
     { "-seed", 1L },
+    { "+segment", 0L },
     { "-segment", 1L },
+    { "+separate", 0L },
     { "-separate", 0L },
+    { "+sepia-tone", 0L },
+    { "-sepia-tone", 1L },
     { "+set", 1L },
     { "-set", 2L },
+    { "+shade", 0L },
     { "-shade", 1L },
+    { "+shadow", 0L },
     { "-shadow", 1L },
+    { "+shared-memory", 0L },
+    { "-shared-memory", 1L },
+    { "+sharpen", 0L },
     { "-sharpen", 1L },
+    { "+shave", 0L },
     { "-shave", 1L },
+    { "+shear", 0L },
     { "-shear", 1L },
+    { "+sigmoidal-contrast", 0L },
+    { "-sigmoidal-contrast", 1L },
+    { "+silent", 0L },
+    { "-silent", 1L },
+    { "+size", 0L },
     { "-size", 1L },
+    { "+sketch", 0L },
+    { "-sketch", 1L },
+    { "+snaps", 0L },
     { "-snaps", 1L },
+    { "+solarize", 0L },
     { "-solarize", 1L },
+    { "+splice", 0L },
     { "-splice", 1L },
+    { "+spread", 0L },
     { "-spread", 1L },
+    { "+stegano", 0L },
     { "-stegano", 1L },
-    { "-stroke", 1L },
-    { "-strokewidth", 1L },
+    { "+stereo", 0L },
+    { "-stereo", 1L },
+    { "+stretch", 0L },
     { "-stretch", 1L },
+    { "+strip", 0L },
     { "-strip", 0L },
+    { "+stroke", 0L },
+    { "-stroke", 1L },
+    { "+strokewidth", 0L },
+    { "-strokewidth", 1L },
+    { "+style", 0L },
     { "-style", 1L },
+    { "+support", 0L },
     { "-support", 1L },
+    { "+swap", 0L },
     { "-swap", 1L },
+    { "+swirl", 0L },
     { "-swirl", 1L },
+    { "+text-font", 0L },
+    { "-text-font", 1L },
+    { "+texture", 0L },
     { "-texture", 1L },
+    { "+threshold", 0L },
     { "-threshold", 1L },
+    { "+thumbnail", 0L },
     { "-thumbnail", 1L },
+    { "+thumnail", 0L },
+    { "-thumnail", 1L },
+    { "+tile", 0L },
     { "-tile", 1L },
+    { "+tint", 0L },
     { "-tint", 1L },
+    { "+title", 0L },
+    { "-title", 1L },
+    { "+transform", 0L },
+    { "-transform", 0L },
+    { "+transparent", 0L },
     { "-transparent", 1L },
+    { "+transpose", 0L },
+    { "-transpose", 0L },
+    { "+transverse", 0L },
+    { "-transverse", 0L },
+    { "+treedepth", 0L },
     { "-treedepth", 1L },
+    { "+trim", 0L },
     { "-trim", 0L },
+    { "+type", 0L },
     { "-type", 1L },
+    { "+undercolor", 0L },
     { "-undercolor", 1L },
+    { "+unique-colors", 0L },
+    { "-unique-colors", 0L },
+    { "+units", 0L },
     { "-units", 1L },
+    { "+unsharp", 0L },
     { "-unsharp", 1L },
+    { "+update", 0L },
     { "-update", 1L },
+    { "+use-pixmap", 0L },
+    { "-use-pixmap", 1L },
+    { "+verbose", 0L },
     { "-verbose", 0L },
-    { "-version", 0L },
+    { "+version", 0L },
+    { "-version", 1L },
+    { "+view", 0L },
     { "-view", 1L },
+    { "+vignette", 0L },
     { "-vignette", 1L },
+    { "+virtual-pixel", 0L },
     { "-virtual-pixel", 1L },
+    { "+visual", 0L },
+    { "-visual", 1L },
+    { "+watermark", 0L },
     { "-watermark", 1L },
+    { "+wave", 0L },
     { "-wave", 1L },
+    { "+weight", 0L },
     { "-weight", 1L },
-    { "-window", 1L },
-    { "-window_group", 1L },
+    { "+white-point", 0L },
     { "-white-point", 1L },
+    { "+white-threshold", 0L },
     { "-white-threshold", 1L },
+    { "+window", 0L },
+    { "-window", 1L },
+    { "+window-group", 0L },
+    { "-window-group", 1L },
+    { "+write", 0L },
     { "-write", 1L },
     { (char *) NULL, (long) 0L }
   },
@@ -316,7 +578,7 @@ static const OptionInfo
   {
     { "Undefined", (long) UndefinedCompositeOp },
     { "Add", (long) AddCompositeOp },
-    { "Atop", (long) SrcAtopCompositeOp },
+    { "Atop", (long) AtopCompositeOp },
     { "Blend", (long) BlendCompositeOp },
     { "Bumpmap", (long) BumpmapCompositeOp },
     { "Clear", (long) ClearCompositeOp },
@@ -352,7 +614,7 @@ static const OptionInfo
     { "Modulate", (long) ModulateCompositeOp },
     { "Multiply", (long) MultiplyCompositeOp },
     { "None", (long) NoCompositeOp },
-    { "Out", (long) SrcOutCompositeOp },
+    { "Out", (long) OutCompositeOp },
     { "Overlay", (long) OverlayCompositeOp },
     { "Over", (long) OverCompositeOp },
     { "Plus", (long) PlusCompositeOp },
@@ -536,6 +798,18 @@ static const OptionInfo
     { "Partition", (long) PartitionInterlace },
     { (char *) NULL, (long) UndefinedInterlace }
   },
+  LayersOptions[] =
+  {
+    { "Undefined", (long) UndefinedLayer },
+    { "Coalesce", (long) CoalesceLayer },
+    { "CompareAny", (long) CompareAnyLayer },
+    { "CompareClear", (long) CompareClearLayer },
+    { "CompareOverlay", (long) CompareOverlayLayer },
+    { "Dispose", (long) DisposeLayer },
+    { "Optimize", (long) OptimizeLayer },
+    { "OptimizePlus", (long) OptimizePlusLayer },
+    { (char *) NULL, (long) UndefinedLayer }
+  },
   LineCapOptions[] =
   {
     { "Undefined", (long) UndefinedCap },
@@ -593,6 +867,7 @@ static const OptionInfo
   MetricOptions[] =
   {
     { "Undefined", (long) UndefinedMetric },
+    { "AE", (long) AbsoluteErrorMetric },
     { "MAE", (long) MeanAbsoluteErrorMetric },
     { "MSE", (long) MeanSquaredErrorMetric },
     { "PAE", (long) PeakAbsoluteErrorMetric },
@@ -634,6 +909,7 @@ static const OptionInfo
     { "map", MagickTrue },
     { "morph", MagickTrue },
     { "mosaic", MagickTrue },
+    { "optimize", MagickTrue },
     { "process", MagickTrue },
     { "scene", MagickTrue },
     { "swap", MagickTrue },
@@ -717,6 +993,14 @@ static const OptionInfo
     { "Text", (long) TextPrimitive },
     { (char *) NULL, (long) UndefinedPrimitive }
   },
+  QuantumFormatOptions[] =
+  {
+    { "Undefined", (long) UndefinedClass },
+    { "FloatingPoint", (long) FloatingPointQuantumFormat },
+    { "Signed", (long) SignedQuantumFormat },
+    { "Unsigned", (long) UnsignedQuantumFormat },
+    { (char *) NULL, (long) FloatingPointQuantumFormat }
+  },
   ResolutionOptions[] =
   {
     { "Undefined", (long) UndefinedResolution },
@@ -775,8 +1059,10 @@ static const OptionInfo
     { "Undefined", (long) UndefinedVirtualPixelMethod },
     { "Background", (long) BackgroundVirtualPixelMethod },
     { "Constant", (long) BackgroundVirtualPixelMethod },
+    { "Dither", (long) DitherVirtualPixelMethod },
     { "Edge", (long) EdgeVirtualPixelMethod },
     { "Mirror", (long) MirrorVirtualPixelMethod },
+    { "Random", (long) RandomVirtualPixelMethod },
     { "Tile", (long) TileVirtualPixelMethod },
     { "Transparent", (long) TransparentVirtualPixelMethod },
     { (char *) NULL, (long) UndefinedVirtualPixelMethod }
@@ -1046,6 +1332,7 @@ static const OptionInfo *GetOptionInfo(const MagickOption value)
     case MagickImageOptions: return(ImageOptions);
     case MagickIntentOptions: return(IntentOptions);
     case MagickInterlaceOptions: return(InterlaceOptions);
+    case MagickLayersOptions: return(LayersOptions);
     case MagickLineCapOptions: return(LineCapOptions);
     case MagickLineJoinOptions: return(LineJoinOptions);
     case MagickListOptions: return(ListOptions);
@@ -1058,6 +1345,7 @@ static const OptionInfo *GetOptionInfo(const MagickOption value)
     case MagickOrientationOptions: return(OrientationOptions);
     case MagickPreviewOptions: return(PreviewOptions);
     case MagickPrimitiveOptions: return(PrimitiveOptions);
+    case MagickQuantumFormatOptions: return(QuantumFormatOptions);
     case MagickResolutionOptions: return(ResolutionOptions);
     case MagickResourceOptions: return(ResourceOptions);
     case MagickStorageOptions: return(StorageOptions);
@@ -1138,7 +1426,8 @@ MagickExport char *GetNextImageOption(const ImageInfo *image_info)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  IsMagickOption() returns MagickTrue if the option begins with a - or +.
+%  IsMagickOption() returns MagickTrue if the option begins with a - or + and
+%  the first character that follows is alphanumeric.
 %
 %  The format of the IsMagickOption method is:
 %
@@ -1150,7 +1439,6 @@ MagickExport char *GetNextImageOption(const ImageInfo *image_info)
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 MagickExport MagickBooleanType IsMagickOption(const char *option)
 {
@@ -1159,7 +1447,8 @@ MagickExport MagickBooleanType IsMagickOption(const char *option)
     return(MagickFalse);
   if (strlen(option) == 1)
     return(MagickFalse);
-  if (isalpha((int) (unsigned char) *(option+1)) == 0)
+  option++;
+  if (isalpha((int) ((unsigned char) *option)) == 0)
     return(MagickFalse);
   return(MagickTrue);
 }
@@ -1378,12 +1667,6 @@ MagickExport long ParseMagickOption(const MagickOption option,
     negate=(*token == '!') ? MagickTrue : MagickFalse;
     if (negate != MagickFalse)
       GetMagickToken(q,&q,token);
-    p=strchr(token+1,'-');
-    if (p != (char *) NULL)
-      (void) CopyMagickString(p,p+1,MaxTextExtent);
-    p=strchr(token+1,'_');
-    if (p != (char *) NULL)
-      (void) CopyMagickString(p,p+1,MaxTextExtent);
     for (i=0; option_info[i].mnemonic != (char *) NULL; i++)
       if (LocaleCompare(token,option_info[i].mnemonic) == 0)
         {
@@ -1393,6 +1676,24 @@ MagickExport long ParseMagickOption(const MagickOption option,
             option_types=option_types | option_info[i].type;
           break;
         }
+    if (option_info[i].mnemonic == (char *) NULL)
+      {
+        p=strchr(token+1,'-');
+        if (p != (char *) NULL)
+          (void) CopyMagickString(p,p+1,MaxTextExtent);
+        p=strchr(token+1,'_');
+        if (p != (char *) NULL)
+          (void) CopyMagickString(p,p+1,MaxTextExtent);
+        for (i=0; option_info[i].mnemonic != (char *) NULL; i++)
+          if (LocaleCompare(token,option_info[i].mnemonic) == 0)
+            {
+              if (*token == '!')
+                option_types=option_types &~ option_info[i].type;
+              else
+                option_types=option_types | option_info[i].type;
+              break;
+            }
+      }
     if (option_info[i].mnemonic == (char *) NULL)
       return(-1);
     if (list == MagickFalse)
