@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -13,10 +13,10 @@
   See the License for the specific language governing permissions and
   limitations under the License.
 
-  ImageMagick option methods.
+  MagickCore option methods.
 */
-#ifndef _MAGICK_OPTION_H
-#define _MAGICK_OPTION_H
+#ifndef _MAGICKCORE_OPTION_H
+#define _MAGICKCORE_OPTION_H
 
 #if defined(__cplusplus) || defined(c_plusplus)
 extern "C" {
@@ -43,6 +43,7 @@ typedef enum
   MagickImageOptions,
   MagickIntentOptions,
   MagickInterlaceOptions,
+  MagickLayersOptions,
   MagickLineCapOptions,
   MagickLineJoinOptions,
   MagickListOptions,
@@ -55,6 +56,7 @@ typedef enum
   MagickOrientationOptions,
   MagickPreviewOptions,
   MagickPrimitiveOptions,
+  MagickQuantumFormatOptions,
   MagickResolutionOptions,
   MagickResourceOptions,
   MagickStorageOptions,
