@@ -327,7 +327,7 @@ MagickExport MagickBooleanType ColorFloodfillImage(Image *image,
   }
   segment_stack=(SegmentInfo *) RelinquishMagickMemory(segment_stack);
   floodplane_image=DestroyImage(floodplane_image);
-  return((MagickBooleanType) (y == (long) image->rows));
+  return(y == (long) image->rows ? MagickTrue : MagickFalse);
 }
 
 /*
@@ -576,7 +576,7 @@ MagickExport MagickBooleanType MatteFloodfillImage(Image *image,
   }
   segment_stack=(SegmentInfo *) RelinquishMagickMemory(segment_stack);
   floodplane_image=DestroyImage(floodplane_image);
-  return((MagickBooleanType) (y == (long) image->rows));
+  return(y == (long) image->rows ? MagickTrue : MagickFalse);
 }
 
 /*
@@ -601,19 +601,31 @@ MagickExport MagickBooleanType MatteFloodfillImage(Image *image,
 %
 %      MagickBooleanType PaintOpaqueImage(Image *image,
 %        const PixelPacket *target,const PixelPacket *fill)
+%      MagickBooleanType PaintOpaqueImageChannel(Image *image,
+%        const ChannelType channel,const PixelPacket *target,
+%        const PixelPacket *fill)
 %
 %  A description of each parameter follows:
 %
 %    o image: The image.
 %
+%    o channel: The channel.
+%
 %    o target: The RGB value of the target color.
 %
 %    o fill: The replacement color.
 %
-%
 */
+
 MagickExport MagickBooleanType PaintOpaqueImage(Image *image,
   const MagickPixelPacket *target,const MagickPixelPacket *fill)
+{
+  return(PaintOpaqueImageChannel(image,DefaultChannels,target,fill));
+}
+
+MagickExport MagickBooleanType PaintOpaqueImageChannel(Image *image,
+  const ChannelType channel,const MagickPixelPacket *target,
+  const MagickPixelPacket *fill)
 {
 #define PaintOpaqueImageTag  "Opaque/Image"
 
@@ -657,7 +669,20 @@ MagickExport MagickBooleanType PaintOpaqueImage(Image *image,
     {
       SetMagickPixelPacket(q,indexes+x,&pixel);
       if (IsMagickColorSimilar(&pixel,target) != MagickFalse)
-        SetPixelPacket(fill,q,indexes+x);
+        {
+          if ((channel & RedChannel) != 0)
+            q->red=RoundToQuantum(fill->red);
+          if ((channel & GreenChannel) != 0)
+            q->green=RoundToQuantum(fill->green);
+          if ((channel & BlueChannel) != 0)
+            q->blue=RoundToQuantum(fill->blue);
+          if (((channel & OpacityChannel) != 0) &&
+              (image->matte != MagickFalse))
+            q->opacity=RoundToQuantum(fill->opacity);
+          if (((channel & IndexChannel) != 0) &&
+              (image->colorspace == CMYKColorspace))
+            indexes[x]=RoundToQuantum(fill->index);
+        }
       q++;
     }
     if (SyncImagePixels(image) == MagickFalse)
@@ -678,6 +703,7 @@ MagickExport MagickBooleanType PaintOpaqueImage(Image *image,
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
 %                                                                             %
+%                                                                             %
 %     P a i n t T r a n s p a r e n t I m a g e                               %
 %                                                                             %
 %                                                                             %
@@ -706,7 +732,6 @@ MagickExport MagickBooleanType PaintOpaqueImage(Image *image,
 %
 %    o opacity: The replacement opacity value.
 %
-%
 */
 MagickExport MagickBooleanType PaintTransparentImage(Image *image,
   const MagickPixelPacket *target,const Quantum opacity)
@@ -739,6 +764,8 @@ MagickExport MagickBooleanType PaintTransparentImage(Image *image,
   assert(target != (MagickPixelPacket *) NULL);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
+  if (SetImageStorageClass(image,DirectClass) == MagickFalse)
+    return(MagickFalse);
   if (image->matte == MagickFalse)
     SetImageOpacity(image,OpaqueOpacity);
   GetMagickPixelPacket(image,&pixel);
