@@ -40,6 +40,7 @@
   Include declarations.
 */
 #include "magick/studio.h"
+#include "magick/attribute.h"
 #include "magick/color.h"
 #include "magick/exception.h"
 #include "magick/exception-private.h"
@@ -157,7 +158,7 @@ MagickExport void DestroyImageProfiles(Image *image)
 %
 %  The format of the GetImageProfile method is:
 %
-%      StringInfo *GetImageProfile(const Image *image,const char *name)
+%      const StringInfo *GetImageProfile(const Image *image,const char *name)
 %
 %  A description of each parameter follows:
 %
@@ -166,12 +167,13 @@ MagickExport void DestroyImageProfiles(Image *image)
 %    o name: The profile name.
 %
 */
-MagickExport StringInfo *GetImageProfile(const Image *image,const char *name)
+MagickExport const StringInfo *GetImageProfile(const Image *image,
+  const char *name)
 {
   char
     key[MaxTextExtent];
 
-  StringInfo
+  const StringInfo
     *profile;
 
   assert(image != (Image *) NULL);
@@ -182,8 +184,8 @@ MagickExport StringInfo *GetImageProfile(const Image *image,const char *name)
     return((StringInfo *) NULL);
   (void) CopyMagickString(key,name,MaxTextExtent);
   LocaleLower(key);
-  profile=(StringInfo *)
-    GetValueFromSplayTree((SplayTreeInfo *) image->profiles,key);
+  profile=(const StringInfo *) GetValueFromSplayTree((SplayTreeInfo *)
+    image->profiles,key);
   return(profile);
 }
 
@@ -239,8 +241,7 @@ MagickExport char *GetNextImageProfile(const Image *image)
 %  The format of the ProfileImage method is:
 %
 %      MagickBooleanType ProfileImage(Image *image,const char *name,
-%        const void *datum,const unsigned long length,
-%        const MagickBooleanType clone)
+%        const void *datum,const size_t length,const MagickBooleanType clone)
 %
 %  A description of each parameter follows:
 %
@@ -269,7 +270,8 @@ static int LCMSErrorHandler(int severity,const char *context)
 #endif
 
 MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
-  const void *datum,const unsigned long length,const MagickBooleanType clone)
+  const void *datum,const size_t length,
+  const MagickBooleanType magick_unused(clone))
 {
 #define ThrowProfileException(severity,tag,context) \
 { \
@@ -305,11 +307,11 @@ MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
   SetStringInfoDatum(profile,(unsigned char *) datum);
   if ((LocaleCompare("icc",name) == 0) || (LocaleCompare("icm",name) == 0))
     {
-      StringInfo
+      const StringInfo
         *icc_profile;
 
       icc_profile=GetImageProfile(image,"icc");
-      if ((icc_profile != (StringInfo *) NULL) &&
+      if ((icc_profile != (const StringInfo *) NULL) &&
           (CompareStringInfo(icc_profile,profile) == 0))
         {
           profile=DestroyStringInfo(profile);
@@ -333,7 +335,11 @@ MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
           cmsHTRANSFORM
             transform;
 
+          const ImageAttribute
+            *attribute;
+
           DWORD
+            flags,
             source_type,
             target_type;
 
@@ -503,8 +509,16 @@ MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
             case SaturationIntent: intent=INTENT_SATURATION; break;
             default: intent=INTENT_PERCEPTUAL; break;
           }
+          flags=cmsFLAGS_HIGHRESPRECALC;
+          attribute=GetImageAttribute(image,"PROFILE:black-point-compensation");
+#if defined(cmsFLAGS_BLACKPOINTCOMPENSATION)
+          if ((attribute != (const ImageAttribute *) NULL) &&
+              (attribute->value != (char *) NULL))
+            if (LocaleCompare(attribute->value,"true") == 0)
+              flags|=cmsFLAGS_BLACKPOINTCOMPENSATION;
+#endif
           transform=cmsCreateTransform(source_profile,source_type,
-            target_profile,target_type,intent,cmsFLAGS_HIGHRESPRECALC);
+            target_profile,target_type,intent,flags);
           (void) cmsCloseProfile(source_profile);
           (void) cmsCloseProfile(target_profile);
           if (transform == (cmsHTRANSFORM) NULL)
