@@ -27,16 +27,16 @@ extern "C" {
 extern MagickExport char
   *GetNextImageProfile(const Image *);
 
+extern MagickExport const StringInfo
+  *GetImageProfile(const Image *,const char *);
+
 extern MagickExport MagickBooleanType
   CloneImageProfiles(Image *,const Image *),
-  ProfileImage(Image *,const char *,const void *,const unsigned long,
+  ProfileImage(Image *,const char *,const void *,const size_t,
     const MagickBooleanType),
   RemoveImageProfile(Image *,const char *),
   SetImageProfile(Image *,const char *,const StringInfo *);
 
-extern MagickExport StringInfo
-  *GetImageProfile(const Image *,const char *);
-
 extern MagickExport void
   DestroyImageProfiles(Image *),
   ResetImageProfileIterator(const Image *);
