@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
 
   You may not use this file except in compliance with the License.
@@ -13,15 +13,79 @@
   See the License for the specific language governing permissions and
   limitations under the License.
 
-  ImageMagick quantum inline methods.
+  MagickCore quantum inline methods.
 */
-#ifndef _MAGICK_QUANTUM_H
-#define _MAGICK_QUANTUM_H
+#ifndef _MAGICKCORE_QUANTUM_H
+#define _MAGICKCORE_QUANTUM_H
 
 #if defined(__cplusplus) || defined(c_plusplus)
 extern "C" {
 #endif
 
+#include "magick/semaphore.h"
+
+typedef enum
+{
+  UndefinedQuantum,
+  AlphaQuantum,
+  BlackQuantum,
+  BlueQuantum,
+  CMYKAQuantum,
+  CMYKQuantum,
+  CyanQuantum,
+  GrayAlphaQuantum,
+  GrayQuantum,
+  GreenQuantum,
+  IndexAlphaQuantum,
+  IndexQuantum,
+  MagentaQuantum,
+  OpacityQuantum,
+  RedQuantum,
+  RGBAQuantum,
+  RGBOQuantum,
+  RGBQuantum,
+  YellowQuantum,
+  GrayPadQuantum,
+  RGBPadQuantum
+} QuantumType;
+
+typedef enum
+{
+  UndefinedQuantumFormat,
+  FloatingPointQuantumFormat,
+  SignedQuantumFormat,
+  UnsignedQuantumFormat
+} QuantumFormatType;
+
+typedef struct _QuantumInfo
+{
+  QuantumFormatType
+    format;
+
+  double
+    minimum,
+    maximum,
+    scale;
+
+  size_t
+    pad;
+
+  SemaphoreInfo
+    *semaphore;
+
+  unsigned long
+    signature;
+} QuantumInfo;
+
+static inline MagickRealType ClipToQuantum(const MagickRealType value)
+{
+  if (value < 0.0)
+    return(0);
+  if (value >= (MagickRealType) QuantumRange)
+    return((MagickRealType) QuantumRange);
+  return(value);
+}
+
 static inline unsigned short RoundToMap(const MagickRealType value)
 {
   if (value < 0.0)
@@ -254,6 +318,19 @@ static inline unsigned long long ScaleToQuantum(const unsigned long value)
 }
 #endif
 
+extern MagickExport MagickBooleanType
+  ExportQuantumPixels(Image *,const QuantumInfo *,const QuantumType,
+    const unsigned char *),
+  ImportQuantumPixels(Image *,const QuantumInfo *,const QuantumType,
+    unsigned char *);
+
+extern MagickExport QuantumInfo
+  *AcquireQuantumInfo(const ImageInfo *),
+  *DestroyQuantumInfo(QuantumInfo *);
+
+extern MagickExport void
+  GetQuantumInfo(const ImageInfo *,QuantumInfo *);
+
 #if defined(__cplusplus) || defined(c_plusplus)
 }
 #endif
