@@ -123,16 +123,7 @@ MagickExport MagickBooleanType DeleteMagickRegistry(const long id)
     return(MagickFalse);
   if (GetNumberOfNodesInSplayTree(registry_list) == 0)
     return(MagickFalse);
-  AcquireSemaphoreInfo(&registry_semaphore);
-  ResetSplayTreeIterator(registry_list);
-  p=(const RegistryInfo *) GetNextValueInSplayTree(registry_list);
-  while (p != (const RegistryInfo *) NULL)
-  {
-    if (p->id == id)
-      break;
-    p=(const RegistryInfo *) GetNextValueInSplayTree(registry_list);
-  }
-  RelinquishSemaphoreInfo(registry_semaphore);
+  p=(const RegistryInfo *) GetValueFromSplayTree(registry_list,&id);
   return(RemoveNodeByValueFromSplayTree(registry_list,p));
 }
 
@@ -325,9 +316,13 @@ MagickExport void *GetMagickRegistry(const long id,RegistryType *type,
           blob=(void *) AcquireMagickMemory(p->length);
           if (blob == (void *) NULL)
             {
+              char
+                *message;
+
+              message=GetExceptionMessage(errno);
               (void) ThrowMagickException(exception,GetMagickModule(),
-                ResourceLimitError,"MemoryAllocationFailed","`%s'",
-                strerror(errno));
+                ResourceLimitError,"MemoryAllocationFailed","`%s'",message);
+              message=(char *) RelinquishMagickMemory(message);
               break;
             }
           (void) CopyMagickMemory(blob,p->blob,p->length);
@@ -432,14 +427,24 @@ MagickExport long SetMagickRegistry(const RegistryType type,const void *blob,
       image=(Image *) blob;
       if (length != sizeof(Image))
         {
+          char
+            *message;
+
+          message=GetExceptionMessage(errno);
           (void) ThrowMagickException(exception,GetMagickModule(),RegistryError,
-            "UnableToSetRegistry","`%s'",strerror(errno));
+            "UnableToSetRegistry","`%s'",message);
+          message=(char *) RelinquishMagickMemory(message);
           return(-1);
         }
       if (image->signature != MagickSignature)
         {
+          char
+            *message;
+
+          message=GetExceptionMessage(errno);
           (void) ThrowMagickException(exception,GetMagickModule(),RegistryError,
-            "UnableToSetRegistry","`%s'",strerror(errno));
+            "UnableToSetRegistry","`%s'",message);
+          message=(char *) RelinquishMagickMemory(message);
           return(-1);
         }
       clone_blob=(void *) CloneImageList(image,exception);
@@ -455,14 +460,24 @@ MagickExport long SetMagickRegistry(const RegistryType type,const void *blob,
       image_info=(ImageInfo *) blob;
       if (length != sizeof(ImageInfo))
         {
+          char
+            *message;
+
+          message=GetExceptionMessage(errno);
           (void) ThrowMagickException(exception,GetMagickModule(),RegistryError,
-            "UnableToSetRegistry","`%s'",strerror(errno));
+            "UnableToSetRegistry","`%s'",message);
+          message=(char *) RelinquishMagickMemory(message);
           return(-1);
         }
       if (image_info->signature != MagickSignature)
         {
+          char
+            *message;
+
+          message=GetExceptionMessage(errno);
           (void) ThrowMagickException(exception,GetMagickModule(),RegistryError,
-            "UnableToSetRegistry","`%s'",strerror(errno));
+            "UnableToSetRegistry","`%s'",message);
+          message=(char *) RelinquishMagickMemory(message);
           return(-1);
         }
       clone_blob=(void *) CloneImageInfo(image_info);
@@ -480,8 +495,15 @@ MagickExport long SetMagickRegistry(const RegistryType type,const void *blob,
   }
   registry_info=(RegistryInfo *) AcquireMagickMemory(sizeof(*registry_info));
   if (registry_info == (RegistryInfo *) NULL)
-    ThrowMagickFatalException(ResourceLimitFatalError,
-      "UnableToAllocateRegistryInfo",strerror(errno));
+    {
+      char
+        *message;
+
+      message=GetExceptionMessage(errno);
+      ThrowMagickFatalException(ResourceLimitFatalError,
+        "MemoryAllocationFailed",message);
+      message=(char *) RelinquishMagickMemory(message);
+    }
   (void) ResetMagickMemory(registry_info,0,sizeof(*registry_info));
   registry_info->type=type;
   registry_info->blob=clone_blob;
@@ -494,13 +516,27 @@ MagickExport long SetMagickRegistry(const RegistryType type,const void *blob,
       registry_list=NewSplayTree((int (*)(const void *,const void *)) NULL,
         (void *(*)(void *)) NULL,DestroyRegistryNode);
       if (registry_list == (SplayTreeInfo *) NULL)
-        ThrowMagickFatalException(ResourceLimitFatalError,
-          "UnableToAllocateRegistryInfo",strerror(errno));
+        {
+          char
+            *message;
+
+          message=GetExceptionMessage(errno);
+          ThrowMagickFatalException(ResourceLimitFatalError,
+            "MemoryAllocationFailed",message);
+          message=(char *) RelinquishMagickMemory(message);
+        }
     }
   status=AddValueToSplayTree(registry_list,(const void *) id,registry_info);
   if (status == MagickFalse)
-    (void) ThrowMagickException(exception,GetMagickModule(),ResourceLimitError,
-      "MemoryAllocationFailed","`%s'",strerror(errno));
+    {
+      char
+        *message;
+
+      message=GetExceptionMessage(errno);
+      (void) ThrowMagickException(exception,GetMagickModule(),
+        ResourceLimitError,"MemoryAllocationFailed","`%s'",message);
+      message=(char *) RelinquishMagickMemory(message);
+    }
   RelinquishSemaphoreInfo(registry_semaphore);
   return(registry_info->id);
 }
