@@ -40,17 +40,21 @@
 */
 #include "magick/studio.h"
 #include "magick/attribute.h"
+#include "magick/blob.h"
 #include "magick/color.h"
 #include "magick/draw.h"
 #include "magick/exception.h"
 #include "magick/exception-private.h"
 #include "magick/image.h"
 #include "magick/image-private.h"
+#include "magick/list.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
 #include "magick/quantum.h"
 #include "magick/resize.h"
 #include "magick/string_.h"
+#include "magick/utility.h"
+#include "magick/version.h"
 
 /*
   Typedef declarations.
@@ -614,7 +618,10 @@ static MagickBooleanType HorizontalFilter(const Image *source,
   if (support > 0.5)
     {
       if (SetImageStorageClass(destination,DirectClass) == MagickFalse)
-        return(MagickFalse);
+        {
+          InheritException(exception,&destination->exception);
+          return(MagickFalse);
+        }
     }
   else
     {
@@ -680,8 +687,8 @@ static MagickBooleanType HorizontalFilter(const Image *source,
           {
             j=y*(contribution[n-1].pixel-contribution[0].pixel+1)+
               (contribution[i].pixel-contribution[0].pixel);
-            alpha=contribution[i].weight*((MagickRealType) QuantumRange-
-              (p+j)->opacity)/QuantumRange;
+            alpha=contribution[i].weight*QuantumScale*((MagickRealType)
+              QuantumRange-(p+j)->opacity);
             pixel.red+=alpha*(p+j)->red;
             pixel.green+=alpha*(p+j)->green;
             pixel.blue+=alpha*(p+j)->blue;
@@ -723,8 +730,8 @@ static MagickBooleanType HorizontalFilter(const Image *source,
               {
                 j=y*(contribution[n-1].pixel-contribution[0].pixel+1)+
                   (contribution[i].pixel-contribution[0].pixel);
-                alpha=contribution[i].weight*((MagickRealType) QuantumRange-
-                  (p+j)->opacity)/QuantumRange;
+                alpha=contribution[i].weight*QuantumScale*((MagickRealType)
+                  QuantumRange-(p+j)->opacity);
                 pixel.index+=alpha*source_indexes[j];
                 gamma+=alpha;
               }
@@ -754,7 +761,7 @@ static MagickBooleanType HorizontalFilter(const Image *source,
       }
     (*quantum)++;
   }
-  return((MagickBooleanType) (x == (long) destination->columns));
+  return(x == (long) destination->columns ? MagickTrue : MagickFalse);
 }
 
 static MagickBooleanType VerticalFilter(const Image *source,Image *destination,
@@ -807,7 +814,10 @@ static MagickBooleanType VerticalFilter(const Image *source,Image *destination,
   if (support > 0.5)
     {
       if (SetImageStorageClass(destination,DirectClass) == MagickFalse)
-        return(MagickFalse);
+        {
+          InheritException(exception,&destination->exception);
+          return(MagickFalse);
+        }
     }
   else
     {
@@ -874,8 +884,8 @@ static MagickBooleanType VerticalFilter(const Image *source,Image *destination,
           {
             j=(long) ((contribution[i].pixel-contribution[0].pixel)*
               source->columns+x);
-            alpha=contribution[i].weight*((MagickRealType) QuantumRange-
-              (p+j)->opacity)/QuantumRange;
+            alpha=contribution[i].weight*QuantumScale*((MagickRealType)
+              QuantumRange-(p+j)->opacity);
             pixel.red+=alpha*(p+j)->red;
             pixel.green+=alpha*(p+j)->green;
             pixel.blue+=alpha*(p+j)->blue;
@@ -917,8 +927,8 @@ static MagickBooleanType VerticalFilter(const Image *source,Image *destination,
               {
                 j=(long) ((contribution[i].pixel-contribution[0].pixel)*
                   source->columns+x);
-                alpha=contribution[i].weight*((MagickRealType) QuantumRange-
-                  (p+j)->opacity)/QuantumRange;
+                alpha=contribution[i].weight*QuantumScale*((MagickRealType)
+                  QuantumRange-(p+j)->opacity);
                 pixel.index+=alpha*source_indexes[j];
                 gamma+=alpha;
               }
@@ -948,7 +958,7 @@ static MagickBooleanType VerticalFilter(const Image *source,Image *destination,
       }
     (*quantum)++;
   }
-  return((MagickBooleanType) (y == (long) destination->rows));
+  return(y == (long) destination->rows ? MagickTrue : MagickFalse);
 }
 
 MagickExport Image *ResizeImage(const Image *image,const unsigned long columns,
@@ -1023,8 +1033,8 @@ MagickExport Image *ResizeImage(const Image *image,const unsigned long columns,
   /*
     Allocate filter contribution info.
   */
-  x_factor=(MagickRealType)
-    resize_image->columns/(MagickRealType) image->columns;
+  x_factor=(MagickRealType) resize_image->columns/(MagickRealType)
+    image->columns;
   y_factor=(MagickRealType) resize_image->rows/(MagickRealType) image->rows;
   i=(long) LanczosFilter;
   if (filter != UndefinedFilter)
@@ -1058,8 +1068,8 @@ MagickExport Image *ResizeImage(const Image *image,const unsigned long columns,
       source_image=CloneImage(image,columns,image->rows,MagickTrue,exception);
       if (source_image == (Image *) NULL)
         {
-          contribution=(ContributionInfo *)
-            RelinquishMagickMemory(contribution);
+          contribution=(ContributionInfo *) RelinquishMagickMemory(
+            contribution);
           resize_image=DestroyImage(resize_image);
           return((Image *) NULL);
         }
@@ -1074,8 +1084,8 @@ MagickExport Image *ResizeImage(const Image *image,const unsigned long columns,
       source_image=CloneImage(image,image->columns,rows,MagickTrue,exception);
       if (source_image == (Image *) NULL)
         {
-          contribution=(ContributionInfo *)
-            RelinquishMagickMemory(contribution);
+          contribution=(ContributionInfo *) RelinquishMagickMemory(
+             contribution);
           resize_image=DestroyImage(resize_image);
           return((Image *) NULL);
         }
@@ -1347,7 +1357,11 @@ MagickExport Image *ScaleImage(const Image *image,const unsigned long columns,
   if (scale_image == (Image *) NULL)
     return((Image *) NULL);
   if (SetImageStorageClass(scale_image,DirectClass) == MagickFalse)
-    return((Image *) NULL);
+    {
+      InheritException(exception,&scale_image->exception);
+      scale_image=DestroyImage(scale_image);
+      return((Image *) NULL);
+    }
   /*
     Allocate memory.
   */
@@ -1674,6 +1688,12 @@ MagickExport Image *ScaleImage(const Image *image,const unsigned long columns,
 MagickExport Image *ThumbnailImage(const Image *image,
   const unsigned long columns,const unsigned long rows,ExceptionInfo *exception)
 {
+  char
+    value[MaxTextExtent];
+
+  const ImageAttribute
+    *attribute;
+
   Image
     *sample_image,
     *thumbnail_image;
@@ -1682,6 +1702,12 @@ MagickExport Image *ThumbnailImage(const Image *image,
     x_factor,
     y_factor;
 
+  struct stat
+    attributes;
+
+  unsigned long
+    version;
+
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
@@ -1702,7 +1728,43 @@ MagickExport Image *ThumbnailImage(const Image *image,
     return((Image *) NULL);
   thumbnail_image=ZoomImage(sample_image,columns,rows,exception);
   sample_image=DestroyImage(sample_image);
+  if (thumbnail_image == (Image *) NULL)
+    return(thumbnail_image);
+  if (thumbnail_image->matte == MagickFalse)
+    SetImageOpacity(thumbnail_image,OpaqueOpacity);
+  thumbnail_image->depth=8;
+  thumbnail_image->interlace=NoInterlace;
   (void) StripImage(thumbnail_image);
+  (void) CopyMagickString(value,image->magick_filename,MaxTextExtent);
+  if (strstr(image->magick_filename,"///") == (char *) NULL)
+    (void) FormatMagickString(value,MaxTextExtent,"file:///%s",
+      image->magick_filename);
+  (void) SetImageAttribute(thumbnail_image,"Thumb::URI",value);
+  (void) CopyMagickString(value,image->magick_filename,MaxTextExtent);
+  if (stat(image->filename,&attributes) == 0)
+    {
+      (void) FormatMagickString(value,MaxTextExtent,"%ld",attributes.st_mtime);
+      (void) SetImageAttribute(thumbnail_image,"Thumb::MTime",value);
+    }
+  (void) FormatMagickString(value,MaxTextExtent,"%ld",attributes.st_mtime);
+  FormatMagickSize(GetBlobSize(image),value);
+  (void) SetImageAttribute(thumbnail_image,"Thumb::Size",value);
+  (void) FormatMagickString(value,MaxTextExtent,"image/%s",image->magick);
+  LocaleLower(value);
+  (void) SetImageAttribute(thumbnail_image,"Thumb::Mimetype",value);
+  attribute=GetImageAttribute(image,"comment");
+  if ((attribute != (const ImageAttribute *) NULL) &&
+      (attribute->value != (char *) NULL))
+    (void) SetImageAttribute(thumbnail_image,"Description",attribute->value);
+  (void) SetImageAttribute(thumbnail_image,"Software",
+    GetMagickVersion(&version));
+  (void) FormatMagickString(value,MaxTextExtent,"%lu",image->magick_columns);
+  (void) SetImageAttribute(thumbnail_image,"Thumb::Image::Width",value);
+  (void) FormatMagickString(value,MaxTextExtent,"%lu",image->magick_rows);
+  (void) SetImageAttribute(thumbnail_image,"Thumb::Image::height",value);
+  (void) FormatMagickString(value,MaxTextExtent,"%lu",
+    GetImageListLength(image));
+  (void) SetImageAttribute(thumbnail_image,"Thumb::Document::Pages",value);
   return(thumbnail_image);
 }
 
