@@ -90,7 +90,7 @@ typedef struct _ResourceInfo
 */
 static ResourceInfo
   resource_info =
-    { 0, 0, 0, 0, 0, 384, 768, 1536, ResourceInfinity, 768 };
+    { 0, 0, 0, 0, 0, 2048, 1536, 8192, ResourceInfinity, 768 };
 
 static SemaphoreInfo
   *resource_semaphore = (SemaphoreInfo *) NULL;
@@ -141,7 +141,7 @@ MagickExport MagickBooleanType AcquireMagickResource(const ResourceType type,
     limit;
 
   status=MagickFalse;
-  FormatSize(size,resource_request);
+  (void) FormatMagickSize(size,resource_request);
   AcquireSemaphoreInfo(&resource_semaphore);
   switch (type)
   {
@@ -151,8 +151,10 @@ MagickExport MagickBooleanType AcquireMagickResource(const ResourceType type,
       limit=MegabytesToBytes(resource_info.area_limit);
       status=(resource_info.area_limit == ResourceInfinity) || (size < limit) ?
         MagickTrue : MagickFalse;
-      FormatSize((MagickSizeType) resource_info.area,resource_current);
-      FormatSize(MegabytesToBytes(resource_info.area_limit),resource_limit);
+      (void) FormatMagickSize((MagickSizeType) resource_info.area,
+        resource_current);
+      (void) FormatMagickSize(MegabytesToBytes(resource_info.area_limit),
+        resource_limit);
       break;
     }
     case MemoryResource:
@@ -162,8 +164,10 @@ MagickExport MagickBooleanType AcquireMagickResource(const ResourceType type,
       status=(resource_info.memory_limit == ResourceInfinity) ||
         ((MagickSizeType) resource_info.memory < limit) ?
         MagickTrue : MagickFalse;
-      FormatSize((MagickSizeType) resource_info.memory,resource_current);
-      FormatSize(MegabytesToBytes(resource_info.memory_limit),resource_limit);
+      (void) FormatMagickSize((MagickSizeType) resource_info.memory,
+        resource_current);
+      (void) FormatMagickSize(MegabytesToBytes(resource_info.memory_limit),
+        resource_limit);
       break;
     }
     case MapResource:
@@ -173,8 +177,10 @@ MagickExport MagickBooleanType AcquireMagickResource(const ResourceType type,
       status=(resource_info.map_limit == ResourceInfinity) ||
         ((MagickSizeType) resource_info.map < limit) ?
         MagickTrue : MagickFalse;
-      FormatSize((MagickSizeType) resource_info.map,resource_current);
-      FormatSize(MegabytesToBytes(resource_info.map_limit),resource_limit);
+      (void) FormatMagickSize((MagickSizeType) resource_info.map,
+        resource_current);
+      (void) FormatMagickSize(MegabytesToBytes(resource_info.map_limit),
+        resource_limit);
       break;
     }
     case DiskResource:
@@ -184,8 +190,10 @@ MagickExport MagickBooleanType AcquireMagickResource(const ResourceType type,
       status=(resource_info.disk_limit == ResourceInfinity) ||
         ((MagickSizeType) resource_info.disk < limit) ?
         MagickTrue : MagickFalse;
-      FormatSize((MagickSizeType) resource_info.disk,resource_current);
-      FormatSize(GigabytesToBytes(resource_info.disk_limit),resource_limit);
+      (void) FormatMagickSize((MagickSizeType) resource_info.disk,
+        resource_current);
+      (void) FormatMagickSize(GigabytesToBytes(resource_info.disk_limit),
+        resource_limit);
       break;
     }
     case FileResource:
@@ -195,8 +203,10 @@ MagickExport MagickBooleanType AcquireMagickResource(const ResourceType type,
       status=(resource_info.file_limit == ResourceInfinity) ||
         ((MagickSizeType) resource_info.file < limit) ?
         MagickTrue : MagickFalse;
-      FormatSize((MagickSizeType) resource_info.file,resource_current);
-      FormatSize((MagickSizeType) resource_info.file_limit,resource_limit);
+      (void) FormatMagickSize((MagickSizeType) resource_info.file,
+        resource_current);
+      (void) FormatMagickSize((MagickSizeType) resource_info.file_limit,
+        resource_limit);
       break;
     }
     default:
@@ -277,13 +287,13 @@ MagickExport void AsynchronousDestroyMagickResources(void)
 
 static void *DestroyTemporaryResources(void *temporary_resource)
 {
-  remove((char *) temporary_resource);
+  (void) remove((char *) temporary_resource);
   return((void *) NULL);
 }
 
 static MagickBooleanType GetPathTemplate(char *path)
 {
-  const char
+  char
     *directory;
 
   int
@@ -292,35 +302,43 @@ static MagickBooleanType GetPathTemplate(char *path)
   struct stat
     file_info;
 
-  (void) strcpy(path,"magick-XXXXXXXX");
-  directory=getenv("MAGICK_TMPDIR");
-  if (directory == (const char *) NULL)
-    directory=getenv("TMPDIR");
+  (void) CopyMagickString(path,"magick-XXXXXXXX",MaxTextExtent);
+  directory=GetEnvironmentValue("MAGICK_TMPDIR");
+  if (directory == (char *) NULL)
+    directory=GetEnvironmentValue("TMPDIR");
 #if defined(__WINDOWS__)
-  if (directory == (const char *) NULL)
-    directory=getenv("TMP");
-  if (directory == (const char *) NULL)
-    directory=getenv("TEMP");
+  if (directory == (char *) NULL)
+    directory=GetEnvironmentValue("TMP");
+  if (directory == (char *) NULL)
+    directory=GetEnvironmentValue("TEMP");
 #endif
 #if defined(__VMS)
-  directory=getenv("MTMPDIR");
+  if (directory == (char *) NULL)
+    directory=GetEnvironmentValue("MTMPDIR");
 #endif
 #if defined(P_tmpdir)
-  if (directory == (const char *) NULL)
-    directory=P_tmpdir;
+  if (directory == (char *) NULL)
+    directory=ConstantString(P_tmpdir);
 #endif
-  if (directory == (const char *) NULL)
+  if (directory == (char *) NULL)
     return(MagickTrue);
   if (strlen(directory) > (MaxTextExtent-15))
-    return(MagickTrue);
+    {
+      directory=(char *) RelinquishMagickMemory(directory);
+      return(MagickTrue);
+    }
   status=stat(directory,&file_info);
   if ((status != 0) || !S_ISDIR(file_info.st_mode))
-    return(MagickTrue);
+    {
+      directory=(char *) RelinquishMagickMemory(directory);
+      return(MagickTrue);
+    }
   if (directory[strlen(directory)-1] == *DirectorySeparator)
     (void) FormatMagickString(path,MaxTextExtent,"%smagick-XXXXXXXX",directory);
   else
     (void) FormatMagickString(path,MaxTextExtent,"%s%smagick-XXXXXXXX",
       directory,DirectorySeparator);
+  directory=(char *) RelinquishMagickMemory(directory);
   return(MagickTrue);
 }
 
@@ -563,8 +581,8 @@ MagickExport unsigned long GetMagickResourceLimit(const ResourceType type)
 */
 MagickExport void InitializeMagickResources(void)
 {
-  const char
-    *p;
+  char
+    *limit;
 
   long
     files,
@@ -595,31 +613,46 @@ MagickExport void InitializeMagickResources(void)
 #if defined(PixelCacheThreshold)
   memory=PixelCacheThreshold;
 #endif
-  (void) SetMagickResourceLimit(AreaResource,memory);
-  (void) SetMagickResourceLimit(MemoryResource,2*memory);
-  (void) SetMagickResourceLimit(MapResource,4*memory);
-  p=getenv("MAGICK_AREA_LIMIT");
-  if (p != (const char *) NULL)
-    (void) SetMagickResourceLimit(AreaResource,(unsigned long) atol(p));
-  p=getenv("MAGICK_MEMORY_LIMIT");
-  if (p != (const char *) NULL)
-    (void) SetMagickResourceLimit(MemoryResource,(unsigned long) atol(p));
-  p=getenv("MAGICK_MAP_LIMIT");
-  if (p != (const char *) NULL)
-    (void) SetMagickResourceLimit(MapResource,(unsigned long) atol(p));
-  p=getenv("MAGICK_DISK_LIMIT");
-  if (p != (const char *) NULL)
-    (void) SetMagickResourceLimit(DiskResource,(unsigned long) atol(p));
+  (void) SetMagickResourceLimit(AreaResource,2*memory);
+  (void) SetMagickResourceLimit(MemoryResource,3*memory/2);
+  (void) SetMagickResourceLimit(MapResource,8*memory);
+  limit=GetEnvironmentValue("MAGICK_AREA_LIMIT");
+  if (limit != (char *) NULL)
+    {
+      (void) SetMagickResourceLimit(AreaResource,(unsigned long) atol(limit));
+      limit=(char *) RelinquishMagickMemory(limit);
+    }
+  limit=GetEnvironmentValue("MAGICK_MEMORY_LIMIT");
+  if (limit != (char *) NULL)
+    {
+      (void) SetMagickResourceLimit(MemoryResource,(unsigned long) atol(limit));
+      limit=(char *) RelinquishMagickMemory(limit);
+    }
+  limit=GetEnvironmentValue("MAGICK_MAP_LIMIT");
+  if (limit != (char *) NULL)
+    {
+      (void) SetMagickResourceLimit(MapResource,(unsigned long) atol(limit));
+      limit=(char *) RelinquishMagickMemory(limit);
+    }
+  limit=GetEnvironmentValue("MAGICK_DISK_LIMIT");
+  if (limit != (char *) NULL)
+    {
+      (void) SetMagickResourceLimit(DiskResource,(unsigned long) atol(limit));
+      limit=(char *) RelinquishMagickMemory(limit);
+    }
   files=(-1);
 #if defined(HAVE_SYSCONF) && defined(_SC_OPEN_MAX)
   files=sysconf(_SC_OPEN_MAX);
 #elif defined(HAVE_GETDTABLESIZE) && defined(POSIX)
   files=getdtablesize();
 #endif
-  (void) SetMagickResourceLimit(FileResource,(unsigned long) Max(files-64,64));
-  p=getenv("MAGICK_FILES_LIMIT");
-  if (p != (const char *) NULL)
-    (void) SetMagickResourceLimit(FileResource,(unsigned long) atol(p));
+  (void) SetMagickResourceLimit(FileResource,(unsigned long) Max(3*files/4,64));
+  limit=GetEnvironmentValue("MAGICK_FILE_LIMIT");
+  if (limit != (char *) NULL)
+    {
+      (void) SetMagickResourceLimit(FileResource,(unsigned long) atol(limit));
+      limit=(char *) RelinquishMagickMemory(limit);
+    }
 }
 
 /*
@@ -649,7 +682,7 @@ MagickExport void InitializeMagickResources(void)
 %
 */
 MagickExport MagickBooleanType ListMagickResourceInfo(FILE *file,
-  ExceptionInfo *exception)
+  ExceptionInfo *magick_unused(exception))
 {
   char
     area_limit[MaxTextExtent],
@@ -661,14 +694,17 @@ MagickExport MagickBooleanType ListMagickResourceInfo(FILE *file,
   if (file == (const FILE *) NULL)
     file=stdout;
   AcquireSemaphoreInfo(&resource_semaphore);
-  FormatSize(MegabytesToBytes(resource_info.area_limit),area_limit);
-  FormatSize(GigabytesToBytes(resource_info.disk_limit),disk_limit);
-  FormatSize((MagickSizeType) resource_info.file_limit,file_limit);
-  FormatSize(MegabytesToBytes(resource_info.map_limit),map_limit);
-  FormatSize(MegabytesToBytes(resource_info.memory_limit),memory_limit);
+  (void) FormatMagickSize(MegabytesToBytes(resource_info.area_limit),
+    area_limit);
+  (void) FormatMagickSize(GigabytesToBytes(resource_info.disk_limit),
+    disk_limit);
+  (void) FormatMagickSize((MagickSizeType) resource_info.file_limit,file_limit);
+  (void) FormatMagickSize(MegabytesToBytes(resource_info.map_limit),map_limit);
+  (void) FormatMagickSize(MegabytesToBytes(resource_info.memory_limit),
+    memory_limit);
   (void) fprintf(file,"File       Area     Memory        Map       Disk\n");
   (void) fprintf(file,"------------------------------------------------\n");
-  (void) fprintf(file,"%4s %10s %10s %10s %10s\n",file_limit,area_limit,
+  (void) fprintf(file,"%4s  %9s  %9s  %9s  %9s\n",file_limit,area_limit,
     memory_limit,map_limit,disk_limit);
   (void) fflush(file);
   RelinquishSemaphoreInfo(resource_semaphore);
@@ -709,43 +745,53 @@ MagickExport void RelinquishMagickResource(const ResourceType type,
     resource_limit[MaxTextExtent],
     resource_request[MaxTextExtent];
 
-  FormatSize(size,resource_request);
+  (void) FormatMagickSize(size,resource_request);
   AcquireSemaphoreInfo(&resource_semaphore);
   switch (type)
   {
     case AreaResource:
     {
       resource_info.area=(MagickOffsetType) size;
-      FormatSize((MagickSizeType) resource_info.area,resource_current);
-      FormatSize(MegabytesToBytes(resource_info.area_limit),resource_limit);
+      (void) FormatMagickSize((MagickSizeType) resource_info.area,
+        resource_current);
+      (void) FormatMagickSize(MegabytesToBytes(resource_info.area_limit),
+        resource_limit);
       break;
     }
     case MemoryResource:
     {
       resource_info.memory-=size;
-      FormatSize((MagickSizeType) resource_info.memory,resource_current);
-      FormatSize(MegabytesToBytes(resource_info.memory_limit),resource_limit);
+      (void) FormatMagickSize((MagickSizeType) resource_info.memory,
+        resource_current);
+      (void) FormatMagickSize(MegabytesToBytes(resource_info.memory_limit),
+        resource_limit);
       break;
     }
     case MapResource:
     {
       resource_info.map-=size;
-      FormatSize((MagickSizeType) resource_info.map,resource_current);
-      FormatSize(MegabytesToBytes(resource_info.map_limit),resource_limit);
+      (void) FormatMagickSize((MagickSizeType) resource_info.map,
+        resource_current);
+      (void) FormatMagickSize(MegabytesToBytes(resource_info.map_limit),
+        resource_limit);
       break;
     }
     case DiskResource:
     {
       resource_info.disk-=size;
-      FormatSize((MagickSizeType) resource_info.disk,resource_current);
-      FormatSize(GigabytesToBytes(resource_info.disk_limit),resource_limit);
+      (void) FormatMagickSize((MagickSizeType) resource_info.disk,
+        resource_current);
+      (void) FormatMagickSize(GigabytesToBytes(resource_info.disk_limit),
+        resource_limit);
       break;
     }
     case FileResource:
     {
       resource_info.file-=size;
-      FormatSize((MagickSizeType) resource_info.file,resource_current);
-      FormatSize((MagickSizeType) resource_info.file_limit,resource_limit);
+      (void) FormatMagickSize((MagickSizeType) resource_info.file,
+        resource_current);
+      (void) FormatMagickSize((MagickSizeType) resource_info.file_limit,
+        resource_limit);
       break;
     }
     default:
