@@ -172,8 +172,15 @@ MagickExport SemaphoreInfo *AllocateSemaphoreInfo(void)
   */
   semaphore_info=(SemaphoreInfo *) malloc(sizeof(SemaphoreInfo));
   if (semaphore_info == (SemaphoreInfo *) NULL)
-    ThrowMagickFatalException(ResourceLimitFatalError,
-      "UnableToAllocateSemaphoreInfo",strerror(errno));
+    {
+      char
+        *message;
+
+      message=GetExceptionMessage(errno);
+      ThrowMagickFatalException(ResourceLimitFatalError,
+        "MemoryAllocationFailed",message);
+      message=(char *) RelinquishMagickMemory(message);
+    }
   (void) ResetMagickMemory(semaphore_info,0,sizeof(SemaphoreInfo));
   /*
     Initialize the semaphore.
@@ -361,8 +368,14 @@ MagickExport MagickBooleanType LockSemaphoreInfo(SemaphoreInfo *semaphore_info)
   }
 #endif
 #if defined(__WINDOWS__)
-  EnterCriticalSection(&semaphore_info->mutex);
-  semaphore_info->id=GetCurrentThreadId();
+  {
+    DWORD
+      id;
+
+    id=GetCurrentThreadId();
+    EnterCriticalSection(&semaphore_info->mutex);
+    semaphore_info->id=id;
+  }
 #endif
   semaphore_info->reference_count++;
   return(MagickTrue);
@@ -426,6 +439,7 @@ MagickExport MagickBooleanType UnlockSemaphoreInfo(
   assert(semaphore_info->signature == MagickSignature);
   if (semaphore_info->reference_count == 0)
     return(MagickFalse);
+  semaphore_info->reference_count--;
 #if defined(HAVE_PTHREAD)
   {
     int
@@ -441,6 +455,5 @@ MagickExport MagickBooleanType UnlockSemaphoreInfo(
   assert(semaphore_info->id == GetCurrentThreadId());
   LeaveCriticalSection(&semaphore_info->mutex);
 #endif
-  semaphore_info->reference_count--;
   return(MagickTrue);
 }
