@@ -79,21 +79,21 @@
 %
 %  The format of the AffineTransformImage method is:
 %
-%      Image *AffineTransformImage(const Image *image,AffineMatrix *affine,
-%        ExceptionInfo *exception)
+%      Image *AffineTransformImage(const Image *image,
+%        AffineMatrix *affine_matrix,ExceptionInfo *exception)
 %
 %  A description of each parameter follows:
 %
 %    o image: The image.
 %
-%    o affine: The affine transform.
+%    o affine_matrix: The affine matrix.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
 %
 */
 MagickExport Image *AffineTransformImage(const Image *image,
-  const AffineMatrix *affine,ExceptionInfo *exception)
+  const AffineMatrix *affine_matrix,ExceptionInfo *exception)
 {
   AffineMatrix
     transform;
@@ -101,6 +101,9 @@ MagickExport Image *AffineTransformImage(const Image *image,
   Image
     *affine_image;
 
+  MagickBooleanType
+    identity;
+
   PointInfo
     extent[4],
     min,
@@ -117,7 +120,7 @@ MagickExport Image *AffineTransformImage(const Image *image,
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
-  assert(affine != (AffineMatrix *) NULL);
+  assert(affine_matrix != (AffineMatrix *) NULL);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
   extent[0].x=0.0;
@@ -131,8 +134,10 @@ MagickExport Image *AffineTransformImage(const Image *image,
   for (i=0; i < 4; i++)
   {
     point=extent[i];
-    extent[i].x=(double) (point.x*affine->sx+point.y*affine->ry+affine->tx);
-    extent[i].y=(double) (point.x*affine->rx+point.y*affine->sy+affine->ty);
+    extent[i].x=(double) (point.x*affine_matrix->sx+point.y*affine_matrix->ry+
+      affine_matrix->tx);
+    extent[i].y=(double) (point.x*affine_matrix->rx+point.y*affine_matrix->sy+
+       affine_matrix->ty);
   }
   min=extent[0];
   max=extent[0];
@@ -156,9 +161,17 @@ MagickExport Image *AffineTransformImage(const Image *image,
     return((Image *) NULL);
   affine_image->background_color.opacity=TransparentOpacity;
   SetImageBackgroundColor(affine_image);
-  transform=(*affine);
-  transform.tx=(-min.x);
-  transform.ty=(-min.y);
+  transform=(*affine_matrix);
+  transform.tx=0;
+  transform.ty=0;
+  identity=(affine_matrix->sx == affine_matrix->sy) &&
+    (affine_matrix->rx == 0.0) && (affine_matrix->ry == 0.0) ? MagickTrue :
+    MagickFalse;
+  if (identity == MagickFalse)
+    {
+      transform.tx=(-min.x);
+      transform.ty=(-min.y);
+    }
   (void) DrawAffineImage(affine_image,image,&transform);
   affine_image->page.x=(long) floor(min.x+0.5);
   affine_image->page.y=(long) floor(min.y+0.5);
@@ -946,7 +959,11 @@ MagickExport Image *RotateImage(const Image *image,const double degrees,
   if ((shear.x == 0.0) && (shear.y == 0.0))
     return(integral_image);
   if (SetImageStorageClass(integral_image,DirectClass) == MagickFalse)
-    return(integral_image);
+    {
+      InheritException(exception,&integral_image->exception);
+      integral_image=DestroyImage(integral_image);
+      return(integral_image);
+    }
   if (integral_image->matte == MagickFalse)
     SetImageOpacity(integral_image,OpaqueOpacity);
   /*
@@ -959,9 +976,9 @@ MagickExport Image *RotateImage(const Image *image,const double degrees,
       width=image->rows;
       height=image->columns;
     }
-  x_offset=(long) (fabs(2.25*(double) height*shear.y)+0.5);
-  y_width=(unsigned long) (fabs((double) height*shear.x)+width+0.5);
-  y_offset=(long) (fabs((double) y_width*shear.y)+0.5);
+  y_width=width+(long) (fabs(shear.x)*height+0.5);
+  x_offset=(long) (width+((fabs(shear.y)*height+0.5)-width)/2.0+0.5);
+  y_offset=(long) (height+((fabs(shear.y)*y_width+0.5)-height)/2.0+0.5);
   /*
     Surround image with a border.
   */
@@ -1070,16 +1087,21 @@ MagickExport Image *ShearImage(const Image *image,const double x_shear,
   if ((shear.x == 0.0) && (shear.y == 0.0))
     return(integral_image);
   if (SetImageStorageClass(integral_image,DirectClass) == MagickFalse)
-    return(integral_image);
+    {
+      InheritException(exception,&integral_image->exception);
+      integral_image=DestroyImage(integral_image);
+      return(integral_image);
+    }
   if (integral_image->matte == MagickFalse)
     SetImageOpacity(integral_image,OpaqueOpacity);
   /*
     Compute image size.
   */
-  x_offset=(long) (fabs((double) image->rows*shear.x)+0.5);
-  y_width=(unsigned long)
-    (fabs((double) image->rows*shear.x)+image->columns+0.5);
-  y_offset=(long) (fabs((double) y_width*shear.y)+0.5);
+  y_width=image->columns+(long) (fabs(shear.x)*image->rows+0.5);
+  x_offset=(long) (image->columns+((fabs(shear.x)*image->rows)-
+    image->columns)/2.0+0.5);
+  y_offset=(long) (image->rows+((fabs(shear.y)*y_width+0.5)-image->rows)/2.0+
+    0.5);
   /*
     Surround image with border.
   */
