@@ -17,7 +17,7 @@
 %                                 March 2000                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -168,6 +168,7 @@ MagickExport void RegisterStaticModules(void)
   RegisterHISTOGRAMImage();
   RegisterHTMLImage();
   RegisterICONImage();
+  RegisterINFOImage();
 #if defined(HasJBIG)
   RegisterJBIGImage();
 #endif
@@ -316,6 +317,7 @@ MagickExport void UnregisterStaticModules(void)
   UnregisterHISTOGRAMImage();
   UnregisterHTMLImage();
   UnregisterICONImage();
+  UnregisterINFOImage();
 #if defined(HasJBIG)
   UnregisterJBIGImage();
 #endif
