@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -373,7 +373,7 @@ MagickExport MagickBooleanType GetImageChannelExtrema(const Image *image,
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   *maxima=0;
-  *minima=QuantumRange;
+  *minima=(unsigned long) QuantumRange;
   y=(long) image->rows;
   if ((image->storage_class == PseudoClass) && (image->matte == MagickFalse))
     {
@@ -659,199 +659,133 @@ MagickExport ChannelStatistics *GetImageChannelStatistics(const Image *image,
   for (i=0; i <= AllChannels; i++)
   {
     channel_statistics[i].depth=1;
-    channel_statistics[i].scale=QuantumRange/(QuantumRange >> (QuantumDepth-1));
+    channel_statistics[i].scale=(unsigned long)
+      QuantumRange/(QuantumRange >> (QuantumDepth-1));
     channel_statistics[i].maxima=0;
     channel_statistics[i].minima=QuantumRange;
     channel_statistics[i].mean=0.0;
     channel_statistics[i].standard_deviation=0.0;
   }
   y=(long) image->rows;
-  if ((image->storage_class == PseudoClass) && (image->matte == MagickFalse))
+  for (y=0; y < (long) image->rows; y++)
+  {
+    p=AcquireImagePixels(image,0,y,image->columns,1,exception);
+    if (p == (const PixelPacket *) NULL)
+      break;
+    indexes=GetIndexes(image);
+    for (x=0; x < (long) image->columns; )
     {
-      p=image->colormap;
-      for (x=0; x < (long) image->colors; )
-      {
-        if (channel_statistics[RedChannel].depth != QuantumDepth)
-          {
-            scale=channel_statistics[RedChannel].scale;
-            if ((unsigned long) p->red != (scale*(p->red/scale)))
-              {
-                channel_statistics[RedChannel].depth++;
-                channel_statistics[RedChannel].scale=QuantumRange/
-                  (QuantumRange >> (QuantumDepth-
-                  channel_statistics[RedChannel].depth));
-                continue;
-              }
-          }
-        if (channel_statistics[GreenChannel].depth != QuantumDepth)
-          {
-            scale=channel_statistics[GreenChannel].scale;
-            if ((unsigned long) p->green != (scale*(p->green/scale)))
-              {
-                channel_statistics[GreenChannel].depth++;
-                channel_statistics[GreenChannel].scale=QuantumRange/
-                  (QuantumRange >> (QuantumDepth-
-                  channel_statistics[GreenChannel].depth));
-                continue;
-              }
-          }
-        if (channel_statistics[BlueChannel].depth != QuantumDepth)
-          {
-            scale=channel_statistics[BlueChannel].scale;
-            if ((unsigned long) p->blue != (scale*(p->blue/scale)))
-              {
-                channel_statistics[BlueChannel].depth++;
-                channel_statistics[BlueChannel].scale=QuantumRange/
-                  (QuantumRange >> (QuantumDepth-
-                  channel_statistics[BlueChannel].depth));
-                continue;
-              }
-          }
-        if (p->red < channel_statistics[RedChannel].minima)
-          channel_statistics[RedChannel].minima=p->red;
-        if (p->red > channel_statistics[RedChannel].maxima)
-          channel_statistics[RedChannel].maxima=p->red;
-        channel_statistics[RedChannel].mean+=p->red;
-        channel_statistics[RedChannel].standard_deviation+=
-          (double) p->red*p->red;
-        if (p->green < channel_statistics[GreenChannel].minima)
-          channel_statistics[GreenChannel].minima=p->green;
-        if (p->green > channel_statistics[GreenChannel].maxima)
-          channel_statistics[GreenChannel].maxima=p->green;
-        channel_statistics[GreenChannel].mean+=p->green;
-        channel_statistics[GreenChannel].standard_deviation+=
-          (double) p->green*p->green;
-        if (p->blue < channel_statistics[BlueChannel].minima)
-          channel_statistics[BlueChannel].minima=p->blue;
-        if (p->blue > channel_statistics[BlueChannel].maxima)
-          channel_statistics[BlueChannel].maxima=p->blue;
-        channel_statistics[BlueChannel].mean+=p->blue;
-        channel_statistics[BlueChannel].standard_deviation+=
-          (double) p->blue*p->blue;
-        x++;
-        p++;
-      }
-    }
-  else
-    for (y=0; y < (long) image->rows; y++)
-    {
-      p=AcquireImagePixels(image,0,y,image->columns,1,exception);
-      if (p == (const PixelPacket *) NULL)
-        break;
-      indexes=GetIndexes(image);
-      for (x=0; x < (long) image->columns; )
-      {
-        if (channel_statistics[RedChannel].depth < QuantumDepth)
-          {
-            scale=channel_statistics[RedChannel].scale;
-            if ((unsigned long) p->red != (scale*(p->red/scale)))
-              {
-                channel_statistics[RedChannel].depth++;
-                channel_statistics[RedChannel].scale=QuantumRange/
-                  (QuantumRange >> (QuantumDepth-
-                  channel_statistics[RedChannel].depth));
-                continue;
-              }
-          }
-        if (channel_statistics[GreenChannel].depth != QuantumDepth)
-          {
-            scale=channel_statistics[GreenChannel].scale;
-            if ((unsigned long) p->green != (scale*(p->green/scale)))
-              {
-                channel_statistics[GreenChannel].depth++;
-                channel_statistics[GreenChannel].scale=QuantumRange/
-                  (QuantumRange >> (QuantumDepth-
-                  channel_statistics[GreenChannel].depth));
-                continue;
-              }
-          }
-        if (channel_statistics[BlueChannel].depth != QuantumDepth)
-          {
-            scale=channel_statistics[BlueChannel].scale;
-            if ((unsigned long) p->blue != (scale*(p->blue/scale)))
-              {
-                channel_statistics[BlueChannel].depth++;
-                channel_statistics[BlueChannel].scale=QuantumRange/
-                  (QuantumRange >> (QuantumDepth-
-                  channel_statistics[BlueChannel].depth));
-                continue;
-              }
-          }
-        if (image->matte != MagickFalse)
-          {
-            if (channel_statistics[OpacityChannel].depth != QuantumDepth)
-              {
-                scale=channel_statistics[OpacityChannel].scale;
-                if ((unsigned long) p->opacity != (scale*(p->opacity/scale)))
-                  {
-                    channel_statistics[OpacityChannel].depth++;
-                    channel_statistics[OpacityChannel].scale=QuantumRange/
-                      (QuantumRange >> (QuantumDepth-
-                      channel_statistics[OpacityChannel].depth));
-                    continue;
-                  }
-              }
-          }
-        if (image->colorspace == CMYKColorspace)
-          {
-            if (channel_statistics[BlackChannel].depth != QuantumDepth)
-              {
-                scale=channel_statistics[BlackChannel].scale;
-                if ((unsigned long) indexes[x] != (scale*(indexes[x]/scale)))
-                  {
-                    channel_statistics[BlackChannel].depth++;
-                    channel_statistics[BlackChannel].scale=QuantumRange/
-                      (QuantumRange >> (QuantumDepth-
-                      channel_statistics[BlackChannel].depth));
-                    continue;
-                  }
-              }
-          }
-        if (p->red < channel_statistics[RedChannel].minima)
-          channel_statistics[RedChannel].minima=p->red;
-        if (p->red > channel_statistics[RedChannel].maxima)
-          channel_statistics[RedChannel].maxima=p->red;
-        channel_statistics[RedChannel].mean+=p->red;
-        channel_statistics[RedChannel].standard_deviation+=
-          (double) p->red*p->red;
-        if (p->green < channel_statistics[GreenChannel].minima)
-          channel_statistics[GreenChannel].minima=p->green;
-        if (p->green > channel_statistics[GreenChannel].maxima)
-          channel_statistics[GreenChannel].maxima=p->green;
-        channel_statistics[GreenChannel].mean+=p->green;
-        channel_statistics[GreenChannel].standard_deviation+=
-          (double) p->green*p->green;
-        if (p->blue < channel_statistics[BlueChannel].minima)
-          channel_statistics[BlueChannel].minima=p->blue;
-        if (p->blue > channel_statistics[BlueChannel].maxima)
-          channel_statistics[BlueChannel].maxima=p->blue;
-        channel_statistics[BlueChannel].mean+=p->blue;
-        channel_statistics[BlueChannel].standard_deviation+=
-          (double) p->blue*p->blue;
-        if (image->matte != MagickFalse)
-          {
-            if (p->opacity < channel_statistics[OpacityChannel].minima)
-              channel_statistics[OpacityChannel].minima=p->opacity;
-            if (p->opacity > channel_statistics[OpacityChannel].maxima)
-              channel_statistics[OpacityChannel].maxima=p->opacity;
-            channel_statistics[OpacityChannel].mean+=p->opacity;
-            channel_statistics[OpacityChannel].standard_deviation+=
-              (double) p->opacity*p->opacity;
-          }
-        if (image->colorspace == CMYKColorspace)
-          {
-            if (indexes[x] < channel_statistics[BlackChannel].minima)
-              channel_statistics[BlackChannel].minima=indexes[x];
-            if (indexes[x] > channel_statistics[BlackChannel].maxima)
-              channel_statistics[BlackChannel].maxima=indexes[x];
-            channel_statistics[BlackChannel].mean+=indexes[x];
-            channel_statistics[BlackChannel].standard_deviation+=
-              (double) indexes[x]*indexes[x];
-          }
-        x++;
-        p++;
-      }
+      if (channel_statistics[RedChannel].depth != QuantumDepth)
+        {
+          scale=channel_statistics[RedChannel].scale;
+          if ((unsigned long) p->red != (scale*(p->red/scale)))
+            {
+              channel_statistics[RedChannel].depth++;
+              channel_statistics[RedChannel].scale=QuantumRange/
+                (QuantumRange >> (QuantumDepth-
+                channel_statistics[RedChannel].depth));
+              continue;
+            }
+        }
+      if (channel_statistics[GreenChannel].depth != QuantumDepth)
+        {
+          scale=channel_statistics[GreenChannel].scale;
+          if ((unsigned long) p->green != (scale*(p->green/scale)))
+            {
+              channel_statistics[GreenChannel].depth++;
+              channel_statistics[GreenChannel].scale=QuantumRange/
+                (QuantumRange >> (QuantumDepth-
+                channel_statistics[GreenChannel].depth));
+              continue;
+            }
+        }
+      if (channel_statistics[BlueChannel].depth != QuantumDepth)
+        {
+          scale=channel_statistics[BlueChannel].scale;
+          if ((unsigned long) p->blue != (scale*(p->blue/scale)))
+            {
+              channel_statistics[BlueChannel].depth++;
+              channel_statistics[BlueChannel].scale=QuantumRange/
+                (QuantumRange >> (QuantumDepth-
+                channel_statistics[BlueChannel].depth));
+              continue;
+            }
+        }
+      if (image->matte != MagickFalse)
+        {
+          if (channel_statistics[OpacityChannel].depth != QuantumDepth)
+            {
+              scale=channel_statistics[OpacityChannel].scale;
+              if ((unsigned long) p->opacity != (scale*(p->opacity/scale)))
+                {
+                  channel_statistics[OpacityChannel].depth++;
+                  channel_statistics[OpacityChannel].scale=QuantumRange/
+                    (QuantumRange >> (QuantumDepth-
+                    channel_statistics[OpacityChannel].depth));
+                  continue;
+                }
+            }
+        }
+      if (image->colorspace == CMYKColorspace)
+        {
+          if (channel_statistics[BlackChannel].depth != QuantumDepth)
+            {
+              scale=channel_statistics[BlackChannel].scale;
+              if ((unsigned long) indexes[x] != (scale*(indexes[x]/scale)))
+                {
+                  channel_statistics[BlackChannel].depth++;
+                  channel_statistics[BlackChannel].scale=QuantumRange/
+                    (QuantumRange >> (QuantumDepth-
+                    channel_statistics[BlackChannel].depth));
+                  continue;
+                }
+            }
+        }
+      if (p->red < channel_statistics[RedChannel].minima)
+        channel_statistics[RedChannel].minima=p->red;
+      if (p->red > channel_statistics[RedChannel].maxima)
+        channel_statistics[RedChannel].maxima=p->red;
+      channel_statistics[RedChannel].mean+=p->red;
+      channel_statistics[RedChannel].standard_deviation+=
+        (double) p->red*p->red;
+      if (p->green < channel_statistics[GreenChannel].minima)
+        channel_statistics[GreenChannel].minima=p->green;
+      if (p->green > channel_statistics[GreenChannel].maxima)
+        channel_statistics[GreenChannel].maxima=p->green;
+      channel_statistics[GreenChannel].mean+=p->green;
+      channel_statistics[GreenChannel].standard_deviation+=
+        (double) p->green*p->green;
+      if (p->blue < channel_statistics[BlueChannel].minima)
+        channel_statistics[BlueChannel].minima=p->blue;
+      if (p->blue > channel_statistics[BlueChannel].maxima)
+        channel_statistics[BlueChannel].maxima=p->blue;
+      channel_statistics[BlueChannel].mean+=p->blue;
+      channel_statistics[BlueChannel].standard_deviation+=
+        (double) p->blue*p->blue;
+      if (image->matte != MagickFalse)
+        {
+          if (p->opacity < channel_statistics[OpacityChannel].minima)
+            channel_statistics[OpacityChannel].minima=p->opacity;
+          if (p->opacity > channel_statistics[OpacityChannel].maxima)
+            channel_statistics[OpacityChannel].maxima=p->opacity;
+          channel_statistics[OpacityChannel].mean+=p->opacity;
+          channel_statistics[OpacityChannel].standard_deviation+=
+            (double) p->opacity*p->opacity;
+        }
+      if (image->colorspace == CMYKColorspace)
+        {
+          if (indexes[x] < channel_statistics[BlackChannel].minima)
+            channel_statistics[BlackChannel].minima=indexes[x];
+          if (indexes[x] > channel_statistics[BlackChannel].maxima)
+            channel_statistics[BlackChannel].maxima=indexes[x];
+          channel_statistics[BlackChannel].mean+=indexes[x];
+          channel_statistics[BlackChannel].standard_deviation+=
+            (double) indexes[x]*indexes[x];
+        }
+      x++;
+      p++;
     }
+  }
   area=(double) image->columns*image->rows;
   for (i=0; i < AllChannels; i++)
   {
