@@ -113,8 +113,15 @@ static inline size_t CheckOverflowException(const size_t length,
   const size_t extend)
 {
   if ((length+extend) < length)
-    ThrowMagickFatalException(ResourceLimitFatalError,"UnableToAcquireString",
-      strerror(errno));
+    {
+      char
+        *message;
+
+      message=GetExceptionMessage(errno);
+      ThrowMagickFatalException(ResourceLimitFatalError,
+        "MemoryAllocationFailed",message);
+      message=(char *) RelinquishMagickMemory(message);
+    }
   return(length+extend);
 }
 
@@ -136,7 +143,7 @@ MagickExport char *AcquireString(const char *source)
       source);
   *destination='\0';
   if (source != (char *) NULL)
-    (void) strcpy(destination,source);
+    (void) CopyMagickString(destination,source,length*sizeof(*destination));
   return(destination);
 }
 
@@ -169,8 +176,15 @@ MagickExport StringInfo *AcquireStringInfo(const size_t length)
 
   string_info=(StringInfo *) AcquireMagickMemory(sizeof(*string_info));
   if (string_info == (StringInfo *) NULL)
-    ThrowMagickFatalException(ResourceLimitFatalError,"UnableToAcquireString",
-      strerror(errno));
+    {
+      char
+        *message;
+
+      message=GetExceptionMessage(errno);
+      ThrowMagickFatalException(ResourceLimitFatalError,
+        "MemoryAllocationFailed",message);
+      message=(char *) RelinquishMagickMemory(message);
+    }
   (void) ResetMagickMemory(string_info,0,sizeof(*string_info));
   string_info->signature=MagickSignature;
   string_info->length=length;
@@ -183,8 +197,15 @@ MagickExport StringInfo *AcquireStringInfo(const size_t length)
       string_info->datum=(unsigned char *)
         AcquireMagickMemory(length*sizeof(*string_info->datum));
       if (string_info->datum == (unsigned char *) NULL)
-        ThrowMagickFatalException(ResourceLimitFatalError,
-          "UnableToAcquireString",strerror(errno));
+        {
+          char
+            *message;
+
+          message=GetExceptionMessage(errno);
+          ThrowMagickFatalException(ResourceLimitFatalError,
+            "MemoryAllocationFailed",message);
+          message=(char *) RelinquishMagickMemory(message);
+        }
     }
   return(string_info);
 }
@@ -239,7 +260,7 @@ MagickExport char *CloneString(char **destination,const char *source)
   if (*destination == (char *) NULL)
     ThrowMagickFatalException(ResourceLimitFatalError,"UnableToAcquireString",
       source);
-  (void) strcpy(*destination,source);
+  (void) CopyMagickString(*destination,source,length*sizeof(*destination));
   return(*destination);
 }
 
@@ -362,7 +383,6 @@ MagickExport int CompareStringInfo(const StringInfo *target,
 %
 %    o length: The length of the destination string.
 %
-%
 */
 MagickExport size_t ConcatenateMagickString(char *destination,
   const char *source,const size_t length)
@@ -380,6 +400,9 @@ MagickExport size_t ConcatenateMagickString(char *destination,
   size_t
     count;
 
+  assert(destination != (char *) NULL);
+  assert(source != (const char *) NULL);
+  assert(length >= 1);
   p=source;
   q=destination;
   i=length;
@@ -453,7 +476,8 @@ MagickExport MagickBooleanType ConcatenateString(char **destination,
   if (*destination == (char *) NULL)
     ThrowMagickFatalException(ResourceLimitFatalError,
       "UnableToConcatenateString",source);
-  (void) strcat(*destination,source);
+  (void) ConcatenateMagickString(*destination,source,length*
+    sizeof(*destination));
   return(MagickTrue);
 }
 
@@ -471,9 +495,9 @@ MagickExport MagickBooleanType ConcatenateString(char **destination,
 %  ConcatenateStringInfo() concatenates the source string to the destination
 %  string.
 %
-%  The format of the ConcatentateStringInfo method is:
+%  The format of the ConcatenateStringInfo method is:
 %
-%      void ConcatentateStringInfo(StringInfo *string_info,
+%      void ConcatenateStringInfo(StringInfo *string_info,
 %        const StringInfo *source)
 %
 %  A description of each parameter follows:
@@ -645,7 +669,7 @@ MagickExport char *ConstantString(const char *source)
       source);
   *destination='\0';
   if (source != (char *) NULL)
-    (void) strcpy(destination,source);
+    (void) CopyMagickString(destination,source,length*sizeof(*destination));
   return(destination);
 }
 
@@ -677,7 +701,6 @@ MagickExport char *ConstantString(const char *source)
 %
 %    o length: The length of the destination string.
 %
-%
 */
 MagickExport size_t CopyMagickString(char *destination,const char *source,
   const size_t length)
@@ -692,6 +715,9 @@ MagickExport size_t CopyMagickString(char *destination,const char *source,
   register size_t
     i;
 
+  assert(destination != (char *) NULL);
+  assert(source != (const char *) NULL);
+  assert(length >= 1);
   p=source;
   q=destination;
   i=length;
@@ -724,7 +750,7 @@ MagickExport size_t CopyMagickString(char *destination,const char *source,
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  DestroyString() zeros memory associated with a string.
+%  DestroyString() destroys memory associated with a string.
 %
 %  The format of the DestroyString method is:
 %
@@ -754,7 +780,7 @@ MagickExport char *DestroyString(char *string)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  DestroyStringInfo() zeros memory associated with the StringInfo structure.
+%  DestroyStringInfo() destroys memory associated with the StringInfo structure.
 %
 %  The format of the DestroyStringInfo method is:
 %
@@ -971,6 +997,49 @@ MagickExport StringInfo *FileToStringInfo(const char *filename,
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%  F o r m a t M a g i c k S i z e                                            %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  FormatMagickSize() converts a size to a human readable format, for example,
+%  14kb, 234mb, 2.7gb, or 3.0tb.  Scaling is done by repetitively dividing by
+%  1024.
+%
+%  The format of the FormatMagickSize method is:
+%
+%      long FormatMagickSize(const MagickSizeType size,char *format)
+%
+%  A description of each parameter follows:
+%
+%    o size:  convert this size to a human readable format.
+%
+%    o format:  human readable format.
+%
+*/
+MagickExport long FormatMagickSize(const MagickSizeType size,char *format)
+{
+  double
+    length;
+
+  register long
+    i;
+
+  static char
+    *units[7] = { "", "kb", "mb", "gb", "tb", "pb", "eb" };
+
+  length=(double) ((MagickOffsetType) (size/2))*2.0;
+  for (i=0; (length > 1024.0) && (i < 6); i++)
+    length/=1024.0;
+  return(FormatMagickString(format,MaxTextExtent,"%g%s",length,units[i]));
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %  F o r m a t M a g i c k S t r i n g                                        %
 %                                                                             %
 %                                                                             %
@@ -1088,6 +1157,40 @@ MagickExport long FormatMagickTime(const time_t time,const size_t length,
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   G e t E n v i r o n m e n t V a l u e                                     %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  GetEnvironmentValue() returns the environment string that matches the
+%  specified name.
+%
+%  The format of the GetEnvironmentValue method is:
+%
+%      char *GetEnvironmentValue(const char *name)
+%
+%  A description of each parameter follows:
+%
+%    o name: the environment name.
+%
+*/
+MagickExport char *GetEnvironmentValue(const char *name)
+{
+  const char
+    *environment;
+
+  environment=getenv(name);
+  if (environment == (const char *) NULL)
+    return((char *) NULL);
+  return(ConstantString(environment));
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   L o c a l e C o m p a r e                                                 %
 %                                                                             %
 %                                                                             %
@@ -1511,8 +1614,15 @@ MagickExport void SetStringInfoLength(StringInfo *string_info,
     string_info->datum=(unsigned char *) ResizeMagickMemory(string_info->datum,
       (length+MaxTextExtent)*sizeof(*string_info->datum));
   if (string_info->datum == (unsigned char *) NULL)
-    ThrowMagickFatalException(ResourceLimitFatalError,"UnableToAcquireString",
-      strerror(errno));
+    {
+      char
+        *message;
+
+      message=GetExceptionMessage(errno);
+      ThrowMagickFatalException(ResourceLimitFatalError,
+        "MemoryAllocationFailed",message);
+      message=(char *) RelinquishMagickMemory(message);
+    }
 }
 
 /*
@@ -1623,10 +1733,17 @@ MagickExport char *StringInfoToString(const StringInfo *string_info)
   length=CheckOverflowException(string_info->length,MaxTextExtent);
   string=(char *) AcquireMagickMemory(length*sizeof(*string));
   if (string == (char *) NULL)
-    ThrowMagickFatalException(ResourceLimitFatalError,"UnableToAcquireString",
-      strerror(errno));
+    {
+      char
+        *message;
+
+      message=GetExceptionMessage(errno);
+      ThrowMagickFatalException(ResourceLimitFatalError,
+        "MemoryAllocationFailed",message);
+      message=(char *) RelinquishMagickMemory(message);
+    }
   (void) CopyMagickString(string,(char *) string_info->datum,
-    string_info->length+1);
+    length*sizeof(*string));
   return(string);
 }
 
@@ -2041,8 +2158,7 @@ MagickExport MagickBooleanType SubstituteString(char **buffer,
   result_length=0;
   destination_offset=0;
   replace_length=strlen(replace);
-  search_length=strlen(search);
-  while (match != (char *) NULL)
+  for (search_length=strlen(search); match != (char *) NULL; )
   {
     /*
       Copy portion before match.
@@ -2063,28 +2179,29 @@ MagickExport MagickBooleanType SubstituteString(char **buffer,
         (void) CopyMagickString(result+destination_offset,source,copy_length+1);
         destination_offset+=copy_length;
       }
-      /*
-        Copy replacement.
-      */
-      result_length+=replace_length;
-      if ((result_length+MaxTextExtent) >= allocate_length)
-        {
-          allocate_length+=replace_length;
-          result=(char *) ResizeMagickMemory(result,
-            (allocate_length+MaxTextExtent)*sizeof(*result));
-          if (result == (char *) NULL)
-            ThrowMagickFatalException(ResourceLimitFatalError,
-              "UnableToAcquireString",search);
-        }
-      (void) strcat(result+destination_offset,replace);
-      destination_offset+=replace_length;
-      /*
-        Find next match.
-      */
-      source=match;
-      source+=search_length;
-      match=strstr(source,search);
-    }
+    /*
+      Copy replacement.
+    */
+    result_length+=replace_length;
+    if ((result_length+MaxTextExtent) >= allocate_length)
+      {
+        allocate_length+=replace_length;
+        result=(char *) ResizeMagickMemory(result,(allocate_length+
+          MaxTextExtent)*sizeof(*result));
+        if (result == (char *) NULL)
+          ThrowMagickFatalException(ResourceLimitFatalError,
+            "UnableToAcquireString",search);
+      }
+    (void) ConcatenateMagickString(result+destination_offset,replace,
+      (allocate_length+MaxTextExtent)*sizeof(*result));
+    destination_offset+=replace_length;
+    /*
+      Find next match.
+    */
+    source=match;
+    source+=search_length;
+    match=strstr(source,search);
+  }
   /*
     Copy remaining string.
   */
@@ -2099,7 +2216,8 @@ MagickExport MagickBooleanType SubstituteString(char **buffer,
         ThrowMagickFatalException(ResourceLimitFatalError,
           "UnableToAcquireString",search);
     }
-  (void) strcat(result+destination_offset,source);
+  (void) ConcatenateMagickString(result+destination_offset,source,
+    (allocate_length+MaxTextExtent-destination_offset)*sizeof(*result));
   (void) RelinquishMagickMemory(*buffer);
   *buffer=result;
   return(MagickTrue);
