@@ -251,7 +251,7 @@ MagickExport MagickBooleanType GlobExpression(const char *expression,
       /*
         Determine if pattern is a scene, i.e. img0001.pcd[2].
       */
-      image_info=CloneImageInfo((ImageInfo *) NULL);
+      image_info=AcquireImageInfo();
       (void) CopyMagickString(image_info->filename,pattern,MaxTextExtent);
       GetExceptionInfo(&exception);
       (void) SetImageInfo(image_info,MagickTrue,&exception);
