@@ -1101,6 +1101,9 @@ MagickExport Image *RollImage(const Image *image,const long x_offset,
 MagickExport Image *ShaveImage(const Image *image,
   const RectangleInfo *shave_info,ExceptionInfo *exception)
 {
+  Image
+    *shave_image;
+
   RectangleInfo
     geometry;
 
@@ -1114,9 +1117,16 @@ MagickExport Image *ShaveImage(const Image *image,
   SetGeometry(image,&geometry);
   geometry.width-=2*shave_info->width;
   geometry.height-=2*shave_info->height;
-  geometry.x=(long) shave_info->width;
-  geometry.y=(long) shave_info->height;
-  return(CropImage(image,&geometry,exception));
+  geometry.x=(long) shave_info->width+image->page.x;
+  geometry.y=(long) shave_info->height+image->page.y;
+  shave_image=CropImage(image,&geometry,exception);
+  if (shave_image == (Image *) NULL)
+    return((Image *) NULL);
+  shave_image->page.width-=2*shave_info->width;
+  shave_image->page.height-=2*shave_info->height;
+  shave_image->page.x-=shave_info->width;
+  shave_image->page.y-=shave_info->height;
+  return(shave_image);
 }
 
 /*
