@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -13,10 +13,10 @@
   See the License for the specific language governing permissions and
   limitations under the License.
 
-  ImageMagick image transform methods.
+  MagickCore image transform methods.
 */
-#ifndef _MAGICK_TRANSFORM_H
-#define _MAGICK_TRANSFORM_H
+#ifndef _MAGICKCORE_TRANSFORM_H
+#define _MAGICKCORE_TRANSFORM_H
 
 #if defined(__cplusplus) || defined(c_plusplus)
 extern "C" {
@@ -24,17 +24,18 @@ extern "C" {
 
 extern MagickExport Image
   *ChopImage(const Image *,const RectangleInfo *,ExceptionInfo *),
-  *CoalesceImages(const Image *,ExceptionInfo *),
   *ConsolidateCMYKImages(const Image *,ExceptionInfo *),
   *CropImage(const Image *,const RectangleInfo *,ExceptionInfo *),
-  *DeconstructImages(const Image *,ExceptionInfo *),
-  *FlattenImages(const Image *,ExceptionInfo *),
+  *FlattenImages(Image *,ExceptionInfo *),
   *FlipImage(const Image *,ExceptionInfo *),
   *FlopImage(const Image *,ExceptionInfo *),
-  *MosaicImages(const Image *,ExceptionInfo *),
+  *MosaicImages(Image *,ExceptionInfo *),
   *RollImage(const Image *,const long,const long,ExceptionInfo *),
   *ShaveImage(const Image *,const RectangleInfo *,ExceptionInfo *),
   *SpliceImage(const Image *,const RectangleInfo *,ExceptionInfo *),
+  *TransposeImage(const Image *,ExceptionInfo *),
+  *TransverseImage(const Image *,ExceptionInfo *),
+  *FlopImage(const Image *,ExceptionInfo *),
   *TrimImage(const Image *,ExceptionInfo *);
 
 extern MagickExport MagickBooleanType
