@@ -49,9 +49,6 @@
 #include "magick/hashmap.h"
 #include "magick/log.h"
 #include "magick/memory_.h"
-#if defined(__WINDOWS__)
-# include "magick/nt-feature.h"
-#endif
 #include "magick/option.h"
 #include "magick/semaphore.h"
 #include "magick/splay-tree.h"
@@ -59,6 +56,12 @@
 #include "magick/type.h"
 #include "magick/token.h"
 #include "magick/utility.h"
+#if defined(HasFONTCONFIG)
+# include "fontconfig/fontconfig.h"
+#endif
+#if defined(__WINDOWS__)
+# include "magick/nt-feature.h"
+#endif
 
 /*
   Define declarations.
@@ -152,9 +155,6 @@ MagickExport void DestroyTypeList(void)
 MagickExport const TypeInfo *GetTypeInfo(const char *name,
   ExceptionInfo *exception)
 {
-  register const TypeInfo
-    *p;
-
   assert(exception != (ExceptionInfo *) NULL);
   if ((type_list == (SplayTreeInfo *) NULL) ||
       (instantiate_type == MagickFalse))
@@ -168,20 +168,7 @@ MagickExport const TypeInfo *GetTypeInfo(const char *name,
       ResetSplayTreeIterator(type_list);
       return((const TypeInfo *) GetNextValueInSplayTree(type_list));
     }
-  /*
-    Search for requested type.
-  */
-  AcquireSemaphoreInfo(&type_semaphore);
-  ResetSplayTreeIterator(type_list);
-  p=(const TypeInfo *) GetNextValueInSplayTree(type_list);
-  while (p != (const TypeInfo *) NULL)
-  {
-    if (LocaleCompare(name,p->name) == 0)
-      break;
-    p=(const TypeInfo *) GetNextValueInSplayTree(type_list);
-  }
-  RelinquishSemaphoreInfo(type_semaphore);
-  return(p);
+  return((const TypeInfo *) GetValueFromSplayTree(type_list,name));
 }
 
 /*
@@ -613,6 +600,140 @@ MagickExport char **GetTypeList(const char *pattern,unsigned long *number_fonts,
 %    o exception: Return any errors or warnings in this structure.
 %
 */
+
+#if defined(HasFONTCONFIG)
+MagickExport MagickBooleanType LoadFontConfigFonts(SplayTreeInfo *type_list,
+  ExceptionInfo *exception)
+{
+  char
+    extension[MaxTextExtent],
+    name[MaxTextExtent];
+
+  FcChar8
+    *family,
+    *file,
+    *style;
+   
+  FcFontSet
+    *font_set;
+
+  FcObjectSet
+    *object_set;
+
+  FcPattern
+    *pattern;
+ 
+  FcResult
+    status;
+
+  int
+    slant,
+    width,
+    weight;
+ 
+  register long
+    i;
+
+  TypeInfo
+    *type_info;
+  
+  /*
+    Load system fonts.
+  */
+  (void) FcInit();
+  object_set=FcObjectSetBuild(FC_FAMILY,FC_STYLE,FC_SLANT,FC_WIDTH,FC_WEIGHT,
+    FC_FILE,(char *) NULL);
+  pattern=FcPatternCreate();
+  font_set=FcFontList(0,pattern,object_set);
+  FcPatternDestroy(pattern);
+  FcObjectSetDestroy(object_set);
+  if (font_set == (FcFontSet *) NULL)
+    {
+      FcFini();
+      return(MagickFalse);
+    }
+  for (i=0; i < (long) font_set->nfont; i++)
+  {
+    status=FcPatternGetString(font_set->fonts[i],FC_FAMILY,0,&family);
+    status|=FcPatternGetString(font_set->fonts[i],FC_STYLE,0,&style);
+    status|=FcPatternGetInteger(font_set->fonts[i],FC_SLANT,0,&slant);
+    status|=FcPatternGetInteger(font_set->fonts[i],FC_WIDTH,0,&width);
+    status|=FcPatternGetInteger(font_set->fonts[i],FC_WEIGHT,0,&weight);
+    status|=FcPatternGetString(font_set->fonts[i],FC_FILE,0,&file);
+    if (status != FcResultMatch)
+      continue;
+    *extension='\0';
+    GetPathComponent((const char *) file,ExtensionPath,extension);
+    if ((*extension != '\0') && (LocaleCompare(extension,"gz") == 0))
+      continue;
+    type_info=(TypeInfo *) AcquireMagickMemory(sizeof(*type_info));
+    if (type_info == (TypeInfo *) NULL)
+      continue;
+    (void) ResetMagickMemory(type_info,0,sizeof(*type_info));
+    type_info->path=ConstantString("System Fonts");
+    type_info->signature=MagickSignature;
+    (void) CopyMagickString(name,(const char *) family,MaxTextExtent);
+    (void) ConcatenateMagickString(name," ",MaxTextExtent);
+    (void) ConcatenateMagickString(name,(const char *) style,MaxTextExtent);
+    type_info->name=ConstantString(name);
+    (void) SubstituteString(&type_info->name," ","-");
+    (void) SubstituteString(&type_info->name,"-L-","-");
+    (void) SubstituteString(&type_info->name,"semicondensed","SemiCondensed");
+    type_info->family=ConstantString((const char *) family);
+    (void) SubstituteString(&type_info->family," L","");
+    type_info->style=NormalStyle;
+    if (slant == FC_SLANT_ITALIC)
+      type_info->style=ItalicStyle;
+    if (slant == FC_SLANT_OBLIQUE)
+      type_info->style=ObliqueStyle;
+    type_info->stretch=NormalStretch;
+    if (width >= FC_WIDTH_ULTRACONDENSED)
+      type_info->stretch=UltraCondensedStretch;
+    if (width >= FC_WIDTH_EXTRACONDENSED)
+      type_info->stretch=ExtraCondensedStretch;
+    if (width >= FC_WIDTH_CONDENSED)
+      type_info->stretch=CondensedStretch;
+    if (width >= FC_WIDTH_SEMICONDENSED)
+      type_info->stretch=SemiCondensedStretch;
+    if (width >= FC_WIDTH_NORMAL)
+      type_info->stretch=NormalStretch;
+    if (width >= FC_WIDTH_SEMIEXPANDED)
+      type_info->stretch=SemiExpandedStretch;
+    if (width >= FC_WIDTH_EXPANDED)
+      type_info->stretch=ExpandedStretch;
+    if (width >= FC_WIDTH_EXTRAEXPANDED)
+      type_info->stretch=ExtraExpandedStretch;
+    if (width >= FC_WIDTH_ULTRAEXPANDED)
+      type_info->stretch=UltraExpandedStretch;
+    type_info->weight=400;
+    if (weight >= FC_WEIGHT_THIN)
+      type_info->weight=100;
+    if (weight >= FC_WEIGHT_EXTRALIGHT)
+      type_info->weight=200;
+    if (weight >= FC_WEIGHT_LIGHT)
+      type_info->weight=300;
+    if (weight >= FC_WEIGHT_NORMAL)
+      type_info->weight=400;
+    if (weight >= FC_WEIGHT_MEDIUM)
+      type_info->weight=500;
+    if (weight >= FC_WEIGHT_DEMIBOLD)
+      type_info->weight=600;
+    if (weight >= FC_WEIGHT_BOLD)
+      type_info->weight=700;
+    if (weight >= FC_WEIGHT_EXTRABOLD)
+      type_info->weight=800;
+    if (weight >= FC_WEIGHT_BLACK)
+      type_info->weight=900;
+    type_info->glyphs=ConstantString((const char *) file);
+    (void) AddValueToSplayTree(type_list,ConstantString(type_info->name),
+      type_info);
+  }
+  FcFontSetDestroy(font_set);
+  FcFini();
+  return(MagickTrue);
+}
+#endif
+
 static MagickBooleanType InitializeTypeList(ExceptionInfo *exception)
 {
   if ((type_list == (SplayTreeInfo *) NULL) &&
@@ -625,12 +746,15 @@ static MagickBooleanType InitializeTypeList(ExceptionInfo *exception)
           (void) LoadTypeLists(MagickTypeFilename,exception);
 #if defined(__WINDOWS__)
           (void) NTLoadTypeLists(type_list,exception);
+#endif
+#if defined(HasFONTCONFIG)
+          (void) LoadFontConfigFonts(type_list,exception);
 #endif
           instantiate_type=MagickTrue;
         }
       RelinquishSemaphoreInfo(type_semaphore);
     }
-  return((MagickBooleanType) (type_list != (SplayTreeInfo *) NULL));
+  return(type_list != (SplayTreeInfo *) NULL ? MagickTrue : MagickFalse);
 }
 
 /*
@@ -696,7 +820,7 @@ MagickExport MagickBooleanType ListTypeInfo(FILE *file,ExceptionInfo *exception)
       {
         if (type_info[i]->path != (char *) NULL)
           (void) fprintf(file,"\nPath: %s\n\n",type_info[i]->path);
-        (void) fprintf(file,"%-32.32s %-23.23s %-7.7s %-8s %-3s\n",
+        (void) fprintf(file,"%-32.32s %-22.22s %-7.7s %-8.8s  %-3s\n",
           "Name","Family","Style","Stretch","Weight");
         (void) fprintf(file,"--------------------------------------------------"
           "------------------------------\n");
@@ -711,7 +835,7 @@ MagickExport MagickBooleanType ListTypeInfo(FILE *file,ExceptionInfo *exception)
     style=MagickOptionToMnemonic(MagickStyleOptions,type_info[i]->style);
     stretch=MagickOptionToMnemonic(MagickStretchOptions,type_info[i]->stretch);
     (void) FormatMagickString(weight,MaxTextExtent,"%lu",type_info[i]->weight);
-    (void) fprintf(file,"%-32.32s %-23.23s %-7.7s %-9s %-3s\n",name,family,
+    (void) fprintf(file,"%-32.32s %-22.22s %-7.7s %-9.9s %6s\n",name,family,
       style,stretch,weight);
   }
   (void) fflush(file);
@@ -873,13 +997,18 @@ static MagickBooleanType LoadTypeList(const char *xml,const char *filename,
                     path[MaxTextExtent],
                     *xml;
 
+                  ExceptionInfo
+                    *sans_exception;
+
                   *path='\0';
                   GetPathComponent(filename,HeadPath,path);
                   if (*path != '\0')
                     (void) ConcatenateMagickString(path,DirectorySeparator,
                       MaxTextExtent);
                   (void) ConcatenateMagickString(path,token,MaxTextExtent);
-                  xml=FileToString(path,~0,exception);
+                  sans_exception=AcquireExceptionInfo();
+                  xml=FileToString(path,~0,sans_exception);
+                  sans_exception=DestroyExceptionInfo(sans_exception);
                   status|=LoadTypeList(xml,path,depth+1,exception);
                   xml=(char *) RelinquishMagickMemory(xml);
                 }
@@ -1085,8 +1214,8 @@ static MagickBooleanType LoadTypeLists(const char *filename,
 #if defined(UseEmbeddableMagick)
   return(LoadTypeList(TypeMap,"built-in",0,exception));
 #else
-  const char
-    *p;
+  char
+    *font_path;
 
   const StringInfo
     *option;
@@ -1106,8 +1235,8 @@ static MagickBooleanType LoadTypeLists(const char *filename,
     option=(const StringInfo *) GetNextValueInLinkedList(options);
   }
   options=DestroyConfigureOptions(options);
-  p=getenv("MAGICK_FONT_PATH");
-  if (p != (const char *) NULL)
+  font_path=GetEnvironmentValue("MAGICK_FONT_PATH");
+  if (font_path != (char *) NULL)
     {
       char
         path[MaxTextExtent],
@@ -1116,7 +1245,7 @@ static MagickBooleanType LoadTypeLists(const char *filename,
       /*
         Search MAGICK_FONT_PATH.
       */
-      (void) FormatMagickString(path,MaxTextExtent,"%s%s%s",p,
+      (void) FormatMagickString(path,MaxTextExtent,"%s%s%s",font_path,
         DirectorySeparator,filename);
       option=FileToString(path,~0,exception);
       if (option != (void *) NULL)
@@ -1124,6 +1253,7 @@ static MagickBooleanType LoadTypeLists(const char *filename,
           status|=LoadTypeList(option,path,0,exception);
           option=(char *) RelinquishMagickMemory(option);
         }
+      font_path=(char *) RelinquishMagickMemory(font_path);
     }
   if ((type_list == (SplayTreeInfo *) NULL) || 
       (GetNumberOfNodesInSplayTree(type_list) == 0))
