@@ -729,7 +729,9 @@ MagickExport MagickBooleanType ExpandFilenames(int *argc,char ***argv)
     if (IsGlob(filename) == MagickFalse)
       continue;
     GetPathComponent(option,MagickPath,magick);
-    if (LocaleCompare(magick,"VID") == 0)
+    if ((LocaleCompare(magick,"CAPTION") == 0) ||
+        (LocaleCompare(magick,"LABEL") == 0) ||
+        (LocaleCompare(magick,"VID") == 0))
       continue;
     GetPathComponent(option,HeadPath,path);
     GetPathComponent(option,SubimagePath,subimage);
