@@ -141,7 +141,7 @@ static char
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  AddChildToXMLTree() adds a child tag at an offset relative to the start of
-%  the parent tag's character content.  This method returns the child tag.
+%  the parent tag's character content.  Return the child tag.
 %
 %  The format of the AddChildToXMLTree method is:
 %
@@ -161,9 +161,7 @@ MagickExport XMLTreeInfo *AddChildToXMLTree(XMLTreeInfo *xml_info,
   const char *tag,const size_t offset)
 {
   XMLTreeInfo
-    *child,
-    *head,
-    *node;
+    *child;
 
   if (xml_info == (XMLTreeInfo *) NULL)
     return((XMLTreeInfo *) NULL);
@@ -173,55 +171,10 @@ MagickExport XMLTreeInfo *AddChildToXMLTree(XMLTreeInfo *xml_info,
   (void) ResetMagickMemory(child,0,sizeof(*child));
   child->tag=ConstantString(tag);
   child->attributes=sentinel;
-  child->offset=offset;
-  child->parent=xml_info;
   child->content=ConstantString("");
   child->debug=IsEventLogging();
   child->signature=MagickSignature;
-  if (xml_info->child == (XMLTreeInfo *) NULL)
-    xml_info->child=child;
-  else
-    {
-      head=xml_info->child;
-      if (head->offset > offset)
-        {
-          child->ordered=head;
-          xml_info->child=child;
-        }
-      else
-        {
-          node=head;
-          while ((node->ordered != (XMLTreeInfo *) NULL) &&
-                 (node->ordered->offset <= offset))
-            node=node->ordered;
-          child->ordered=node->ordered;
-          node->ordered=child;
-        }
-      node=head;
-      while ((node->sibling != (XMLTreeInfo *) NULL) &&
-             (strcmp(node->tag,tag) != 0))
-        node=node->sibling;
-      if ((strcmp(node->tag,tag) == 0) && (node->offset <= offset))
-        {
-          while ((node->next != (XMLTreeInfo *) NULL) &&
-                 (node->next->offset <= offset))
-            node=node->next;
-          child->next=node->next;
-          node->next=child;
-        }
-      else
-        {
-          if (node->offset > offset)
-            child->next=node;
-          node=head;
-          while ((node->sibling != (XMLTreeInfo *) NULL) &&
-                 (node->sibling->offset <= offset))
-            node=node->sibling;
-          child->sibling=node->sibling;
-          node->sibling=child;
-        }
-    }
-  return(child);
+  return(InsertTagIntoXMLTree(xml_info,child,offset));
 }
 
 /*
@@ -396,12 +349,8 @@ MagickExport char *CanonicalXMLContent(const char *content,
   if (utf8 == (unsigned char *) NULL)
     return((char *) NULL);
   for (p=utf8; *p != '\0'; p++)
-  {
-    if (*p < 0x07)
+    if ((*p < 0x20) && (*p != 0x09) && (*p != 0x0a) && (*p != 0x0d))
       break;
-    if ((*p > 0x0d) && (*p < 0x20))
-      break;
-  }
   if (*p != '\0')
     {
       /*
@@ -990,6 +939,101 @@ MagickExport const char *GetXMLTreeTag(XMLTreeInfo *xml_info)
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   I n s e r t I n t o T a g X M L T r e e                                   %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  InsertTagIntoXMLTree() inserts a tag at an offset relative to the start of
+%  the parent tag's character content.  This method returns the child tag.
+%
+%  The format of the InsertTagIntoXMLTree method is:
+%
+%      XMLTreeInfo *InsertTagIntoXMLTree(XMLTreeInfo *xml_info,
+%        XMLTreeInfo *child,const size_t offset)
+%
+%  A description of each parameter follows:
+%
+%    o xml_info: The xml info.
+%
+%    o child: The child tag.
+%
+%    o offset: The tag offset.
+%
+*/
+MagickExport XMLTreeInfo *InsertTagIntoXMLTree(XMLTreeInfo *xml_info,
+  XMLTreeInfo *child,const size_t offset)
+{
+  XMLTreeInfo
+    *head,
+    *node,
+    *previous;
+
+  child->ordered=(XMLTreeInfo *) NULL;
+  child->sibling=(XMLTreeInfo *) NULL;
+  child->next=(XMLTreeInfo *) NULL;
+  child->offset=offset;
+  child->parent=xml_info;
+  if (xml_info->child == (XMLTreeInfo *) NULL)
+    {
+      xml_info->child=child;
+      return(child);
+    }
+  head=xml_info->child;
+  if (head->offset > offset)
+    {
+      child->ordered=head;
+      xml_info->child=child;
+    }
+  else
+    {
+      node=head;
+      while ((node->ordered != (XMLTreeInfo *) NULL) &&
+             (node->ordered->offset <= offset))
+        node=node->ordered;
+      child->ordered=node->ordered;
+      node->ordered=child;
+    }
+  previous=(XMLTreeInfo *) NULL;
+  node=head;
+  while ((node != (XMLTreeInfo *) NULL) && (strcmp(node->tag,child->tag) != 0))
+  {
+    previous=node;
+    node=node->sibling;
+  }
+  if ((node != (XMLTreeInfo *) NULL) && (node->offset <= offset))
+    {
+      while ((node->next != (XMLTreeInfo *) NULL) &&
+             (node->next->offset <= offset))
+        node=node->next;
+      child->next=node->next;
+      node->next=child;
+    }
+  else
+    {
+      if ((previous != (XMLTreeInfo *) NULL) && (node != (XMLTreeInfo *) NULL))
+        previous->sibling=node->sibling;
+      child->next=node;
+      previous=(XMLTreeInfo *) NULL;
+      node=head;
+      while ((node != (XMLTreeInfo *) NULL) && (node->offset <= offset))
+      {
+        previous=node;
+        node=node->sibling;
+      }
+      child->sibling=node;
+      if (previous != (XMLTreeInfo *) NULL)
+        previous->sibling=child;
+    }
+  return(child);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   N e w X M L T r e e                                                       %
 %                                                                             %
 %                                                                             %
@@ -1243,7 +1287,7 @@ static char *ParseEntities(char *xml,char **entities,char state)
       for (xml=p; *xml != '\0'; xml++)
       {
         i=(long) strspn(xml," ");
-        if (i != '\0')
+        if (i != 0)
           (void) CopyMagickMemory(xml,xml+i,strlen(xml+i)+1);
         while ((*xml != '\0') && (*xml != ' '))
           xml++;
@@ -2054,25 +2098,25 @@ MagickExport XMLTreeInfo *NewXMLTreeTag(const char *tag)
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%   R e m o v e T a g F r o m X M L T r e e                                   %
+%   P a r s e T a g F r o m X M L T r e e                                     %
 %                                                                             %
 %                                                                             %
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  RemoveTagFromXMLTree() removes a tag from the xml-tree along with all its
+%  PruneTagFromXMLTree() prunes a tag from the xml-tree along with all its
 %  subtags.
 %
-%  The format of the RemoveTagFromXMLTree method is:
+%  The format of the PruneTagFromXMLTree method is:
 %
-%      void RemoveTagFromXMLTree(XMLTreeInfo *xml_info)
+%      void PruneTagFromXMLTree(XMLTreeInfo *xml_info)
 %
 %  A description of each parameter follows:
 %
 %    o xml_info: The xml info.
 %
 */
-MagickExport void RemoveTagFromXMLTree(XMLTreeInfo *xml_info)
+MagickExport XMLTreeInfo *PruneTagFromXMLTree(XMLTreeInfo *xml_info)
 {
   XMLTreeInfo
     *node;
@@ -2112,7 +2156,9 @@ MagickExport void RemoveTagFromXMLTree(XMLTreeInfo *xml_info)
         }
     }
   xml_info->ordered=(XMLTreeInfo *) NULL;
-  xml_info=DestroyXMLTree(xml_info);
+  xml_info->sibling=(XMLTreeInfo *) NULL;
+  xml_info->next=(XMLTreeInfo *) NULL;
+  return(xml_info);
 }
 
 /*
@@ -2131,7 +2177,7 @@ MagickExport void RemoveTagFromXMLTree(XMLTreeInfo *xml_info)
 %
 %  The format of the SetXMLTreeAttribute method is:
 %
-%      void SetXMLTreeAttribute(XMLTreeInfo *xml_info,const char *tag,
+%      XMLTreeInfo *SetXMLTreeAttribute(XMLTreeInfo *xml_info,const char *tag,
 %        const char *value)
 %
 %  A description of each parameter follows:
@@ -2143,8 +2189,8 @@ MagickExport void RemoveTagFromXMLTree(XMLTreeInfo *xml_info)
 %    o value:  The attribute value.
 %
 */
-MagickExport void SetXMLTreeAttribute(XMLTreeInfo *xml_info,const char *tag,
-  const char *value)
+MagickExport XMLTreeInfo *SetXMLTreeAttribute(XMLTreeInfo *xml_info,
+  const char *tag,const char *value)
 {
   long
     j;
@@ -2169,7 +2215,7 @@ MagickExport void SetXMLTreeAttribute(XMLTreeInfo *xml_info,const char *tag,
         Add new attribute tag.
       */
       if (value == (const char *) NULL)
-        return;
+        return(xml_info);
       if (xml_info->attributes != sentinel)
         xml_info->attributes=(char **) ResizeMagickMemory(
           xml_info->attributes,(size_t) (i+4)*sizeof(*xml_info->attributes));
@@ -2197,7 +2243,7 @@ MagickExport void SetXMLTreeAttribute(XMLTreeInfo *xml_info,const char *tag,
   if (value != (const char *) NULL)
     {
       xml_info->attributes[i+1]=ConstantString(value);
-      return;
+      return(xml_info);
     }
   if (xml_info->attributes[i] != (char *) NULL)
     xml_info->attributes[i]=(char *) RelinquishMagickMemory(
@@ -2212,6 +2258,7 @@ MagickExport void SetXMLTreeAttribute(XMLTreeInfo *xml_info,const char *tag,
   (void) CopyMagickMemory(xml_info->attributes[j+1]+(i/2),
     xml_info->attributes[j+1]+(i/2)+1,(size_t) (j/2)-(i/2)*
     sizeof(*xml_info->attributes));
+  return(xml_info);
 }
 
 /*
@@ -2402,8 +2449,8 @@ static char *XMLTreeTagToXML(XMLTreeInfo *xml_info,char **source,size_t *length,
   while ((content[offset] != '\0') && (offset < xml_info->offset))
     offset++;
   if (xml_info->ordered != (XMLTreeInfo *) NULL)
-    content=XMLTreeTagToXML(xml_info->ordered,source,length,max_length,(size_t)
-      offset,attributes);
+    content=XMLTreeTagToXML(xml_info->ordered,source,length,max_length,offset,
+      attributes);
   else
     content=EncodePredefinedEntities(content+offset,-1,source,length,max_length,
       MagickFalse);
