@@ -103,6 +103,7 @@ int main(int argc,char **argv)
     *image_info;
 
   MagickBooleanType
+    regard_warnings,
     status;
 
   register long
@@ -110,6 +111,7 @@ int main(int argc,char **argv)
 
   InitializeMagick(*argv);
   GetExceptionInfo(&exception);
+  regard_warnings=MagickFalse;
   for (i=1; i < (long) argc; i++)
   {
     option=argv[i];
@@ -117,6 +119,8 @@ int main(int argc,char **argv)
       continue;
     if ((LocaleCompare("debug",option+1) == 0) && (i < (long) (argc-1)))
       (void) SetLogEventMask(argv[++i]);
+    if (LocaleCompare("-regard-warnings",option+1) == 0)
+      regard_warnings=MagickTrue;
     if ((LocaleCompare("version",option+1) == 0) ||
         (LocaleCompare("-version",option+1) == 0))
       {
@@ -126,14 +130,17 @@ int main(int argc,char **argv)
         exit(0);
       }
   }
-  image_info=CloneImageInfo((ImageInfo *) NULL);
+  image_info=AcquireImageInfo();
   status=AnimateImageCommand(image_info,argc,argv,(char **) NULL,&exception);
-  if ((status == MagickFalse) && (exception.severity != UndefinedException))
-    CatchException(&exception);
+  if ((status == MagickFalse) || (exception.severity != UndefinedException))
+    {
+      if ((exception.severity < ErrorException) &&
+          (regard_warnings == MagickFalse))
+        status=MagickTrue;
+      CatchException(&exception);
+    }
   image_info=DestroyImageInfo(image_info);
   (void) DestroyExceptionInfo(&exception);
   DestroyMagick();
-  if ((status == MagickFalse) && (exception.severity > ErrorException))
-    return(1);
-  return(0);
+  return(status == MagickFalse ? 1 : 0);
 }
