@@ -18,7 +18,7 @@
 %                            December 2003                                    %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -47,7 +47,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <time.h>
-#include "magick/ImageMagick.h"
+#include "wand/MagickWand.h"
 #if defined(__WINDOWS__)
 #include <windows.h>
 #endif
@@ -78,6 +78,7 @@ int main(int argc,char **argv)
     *image_info;
 
   MagickBooleanType
+    regard_warnings,
     status;
 
   register long
@@ -85,6 +86,7 @@ int main(int argc,char **argv)
 
   InitializeMagick(*argv);
   GetExceptionInfo(&exception);
+  regard_warnings=MagickFalse;
   for (i=1; i < (long) argc; i++)
   {
     option=argv[i];
@@ -92,7 +94,10 @@ int main(int argc,char **argv)
       continue;
     if ((LocaleCompare("debug",option+1) == 0) && (i < (long) (argc-1)))
       (void) SetLogEventMask(argv[++i]);
-    if (LocaleCompare("version",option+1) == 0)
+    if (LocaleCompare("-regard-warnings",option+1) == 0)
+      regard_warnings=MagickTrue;
+    if ((LocaleCompare("version",option+1) == 0) ||
+        (LocaleCompare("-version",option+1) == 0))
       {
         (void) fprintf(stdout,"Version: %s\n",
           GetMagickVersion((unsigned long *) NULL));
@@ -100,11 +105,16 @@ int main(int argc,char **argv)
         exit(0);
       }
   }
-  image_info=CloneImageInfo((ImageInfo *) NULL);
+  image_info=AcquireImageInfo();
   text=(char *) NULL;
   status=CompareImageCommand(image_info,argc,argv,&text,&exception);
-  if ((status == MagickFalse) && (exception.severity != UndefinedException))
-    CatchException(&exception);
+  if ((status == MagickFalse) || (exception.severity != UndefinedException))
+    {
+      if ((exception.severity < ErrorException) &&
+          (regard_warnings == MagickFalse))
+        status=MagickTrue;
+      CatchException(&exception);
+    }
   if (text != (char *) NULL)
     {
       (void) fputs(text,stdout);
@@ -112,9 +122,7 @@ int main(int argc,char **argv)
       text=(char *) RelinquishMagickMemory(text);
     }
   image_info=DestroyImageInfo(image_info);
-  DestroyExceptionInfo(&exception);
+  (void) DestroyExceptionInfo(&exception);
   DestroyMagick();
-  if ((status == MagickFalse) && (exception.severity > ErrorException))
-    return(1);
-  return(0);
+  return(status == MagickFalse ? 1 : 0);
 }
