@@ -81,6 +81,7 @@ int main(int argc,char **argv)
     *image_info;
 
   MagickBooleanType
+    regard_warnings,
     status;
 
   register long
@@ -88,6 +89,7 @@ int main(int argc,char **argv)
 
   InitializeMagick(*argv);
   GetExceptionInfo(&exception);
+  regard_warnings=MagickFalse;
   for (i=1; i < (long) argc; i++)
   {
     option=argv[i];
@@ -95,6 +97,8 @@ int main(int argc,char **argv)
       continue;
     if ((LocaleCompare("debug",option+1) == 0) && (i < (long) (argc-1)))
       (void) SetLogEventMask(argv[++i]);
+    if (LocaleCompare("-regard-warnings",option+1) == 0)
+      regard_warnings=MagickTrue;
     if ((LocaleCompare("version",option+1) == 0) ||
         (LocaleCompare("-version",option+1) == 0))
       {
@@ -104,11 +108,12 @@ int main(int argc,char **argv)
         exit(0);
       }
   }
-  image_info=CloneImageInfo((ImageInfo *) NULL);
+  image_info=AcquireImageInfo();
   status=ConvertImageCommand(image_info,argc,argv,(char **) NULL,&exception);
   if ((status == MagickFalse) || (exception.severity != UndefinedException))
     {
-      if (exception.severity < ErrorException)
+      if ((exception.severity < ErrorException) &&
+          (regard_warnings == MagickFalse))
         status=MagickTrue;
       CatchException(&exception);
     }
