@@ -77,6 +77,7 @@ int main(int argc,char **argv)
     *image_info;
 
   MagickBooleanType
+    regard_warnings,
     status;
 
   register long
@@ -84,6 +85,7 @@ int main(int argc,char **argv)
 
   InitializeMagick(*argv);
   GetExceptionInfo(&exception);
+  regard_warnings=MagickFalse;
   for (i=1; i < (long) argc; i++)
   {
     option=argv[i];
@@ -91,6 +93,8 @@ int main(int argc,char **argv)
       continue;
     if ((LocaleCompare("debug",option+1) == 0) && (i < (long) (argc-1)))
       (void) SetLogEventMask(argv[++i]);
+    if (LocaleCompare("-regard-warnings",option+1) == 0)
+      regard_warnings=MagickTrue;
     if ((LocaleCompare("version",option+1) == 0) ||
         (LocaleCompare("-version",option+1) == 0))
       {
@@ -100,12 +104,13 @@ int main(int argc,char **argv)
         exit(0);
       }
   }
-  image_info=CloneImageInfo((ImageInfo *) NULL);
+  image_info=AcquireImageInfo();
   text=(char *) NULL;
   status=IdentifyImageCommand(image_info,argc,argv,&text,&exception);
   if ((status == MagickFalse) || (exception.severity != UndefinedException))
     {
-      if (exception.severity < ErrorException)
+      if ((exception.severity < ErrorException) &&
+          (regard_warnings == MagickFalse))
         status=MagickTrue;
       CatchException(&exception);
     }
