@@ -137,6 +137,9 @@ static void AnimateUsage(void)
       "-monochrome          transform image to black and white",
       "-pause               seconds to pause before reanimating",
       "-page geometry       size and location of an image canvas (setting)",
+      "-quantize colorspace reduce colors in this colorspace",
+      "-quiet               suppress all error or warning messages",
+      "-regard-warnings     pay attention to warning messages",
       "-remote command      execute a command in an remote display process",
       "-repage geometry     size and location of an image canvas (operator)",
       "-resize geometry     resize the image",
@@ -586,7 +589,6 @@ WandExport MagickBooleanType AnimateImageCommand(ImageInfo *image_info,
             long
               colorspace;
 
-            quantize_info->colorspace=UndefinedColorspace;
             if (*option == '+')
               break;
             i++;
@@ -597,12 +599,6 @@ WandExport MagickBooleanType AnimateImageCommand(ImageInfo *image_info,
             if (colorspace < 0)
               ThrowAnimateException(OptionError,"UnrecognizedColorspace",
                 argv[i]);
-            quantize_info->colorspace=(ColorspaceType) colorspace;
-            if (quantize_info->colorspace == GRAYColorspace)
-              {
-                quantize_info->number_colors=256;
-                quantize_info->colorspace=GRAYColorspace;
-              }
             break;
           }
         if (LocaleCompare("crop",option+1) == 0)
@@ -972,8 +968,40 @@ WandExport MagickBooleanType AnimateImageCommand(ImageInfo *image_info,
           }
         ThrowAnimateException(OptionError,"UnrecognizedOption",option);
       }
+      case 'q':
+      {
+        if (LocaleCompare("quantize",option+1) == 0)
+          {
+            long
+              colorspace;
+
+            quantize_info->colorspace=UndefinedColorspace;
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) argc)
+              ThrowAnimateException(OptionError,"MissingArgument",option);
+            colorspace=ParseMagickOption(MagickColorspaceOptions,
+              MagickFalse,argv[i]);
+            if (colorspace < 0)
+              ThrowAnimateException(OptionError,"UnrecognizedColorspace",
+                argv[i]);
+            quantize_info->colorspace=(ColorspaceType) colorspace;
+            if (quantize_info->colorspace == GRAYColorspace)
+              {
+                quantize_info->number_colors=256;
+                quantize_info->colorspace=GRAYColorspace;
+              }
+            break;
+          }
+        if (LocaleCompare("quiet",option+1) == 0)
+          break;
+        ThrowAnimateException(OptionError,"UnrecognizedOption",option);
+      }
       case 'r':
       {
+        if (LocaleCompare("regard-warnings",option+1) == 0)
+          break;
         if (LocaleCompare("remote",option+1) == 0)
           {
             i++;
