@@ -98,6 +98,7 @@ static void CompareUsage(void)
       "-depth value         image depth",
       "-extract geometry    extract area from image",
       "-format \"string\"     output formatted image characteristics",
+      "-fuzz distance       colors within this distance are considered equal",
       "-help                print program options",
       "-identify            identify the format and characteristics of the image",
       "-interlace type      type of image interlacing scheme",
@@ -107,7 +108,9 @@ static void CompareUsage(void)
       "-monitor             monitor progress",
       "-profile filename    add, delete, or apply an image profile",
       "-quality value       JPEG/MIFF/PNG compression level",
+      "-quantize colorspace reduce colors in this colorspace",
       "-quiet               suppress all error or warning messages",
+      "-regard-warnings     pay attention to warning messages",
       "-sampling-factor geometry",
       "                     horizontal and vertical sampling factor",
       "-set attribute value set an image attribute",
@@ -427,6 +430,17 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
             format=argv[i];
             break;
           }
+        if (LocaleCompare("fuzz",option+1) == 0)
+          {
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) (argc-1))
+              ThrowCompareException(OptionError,"MissingArgument",option);
+            if (IsGeometry(argv[i]) == MagickFalse)
+              ThrowCompareInvalidArgumentException(option,argv[i]);
+            break;
+          }
         ThrowCompareException(OptionError,"UnrecognizedOption",option)
       }
       case 'h':
@@ -539,10 +553,33 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
               ThrowCompareInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("quantize",option+1) == 0)
+          {
+            long
+              colorspace;
+
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) (argc-1))
+              ThrowCompareException(OptionError,"MissingArgument",option);
+            colorspace=ParseMagickOption(MagickColorspaceOptions,MagickFalse,
+              argv[i]);
+            if (colorspace < 0)
+              ThrowCompareException(OptionError,"UnrecognizedColorspace",
+                argv[i]);
+            break;
+          }
         if (LocaleCompare("quiet",option+1) == 0)
           break;
         ThrowCompareException(OptionError,"UnrecognizedOption",option)
       }
+      case 'r':
+      {
+        if (LocaleCompare("regard-warnings",option+1) == 0)
+          break;
+        ThrowCompareException(OptionError,"UnrecognizedOption",option)
+      }
       case 's':
       {
         if (LocaleCompare("sampling-factor",option+1) == 0)
