@@ -267,8 +267,10 @@ static void CompositeUsage(void)
       "-page geometry       size and location of an image canvas (setting)",
       "-profile filename    add ICM or IPTC information profile to image",
       "-quality value       JPEG/MIFF/PNG compression level",
+      "-quantize colorspace reduce colors in this colorspace",
       "-quiet               suppress all error or warning messages",
       "-red-primary point   chromaticity red primary point",
+      "-regard-warnings     pay attention to warning messages",
       "-rotate degrees      apply Paeth rotation to the image",
       "-repage geometry     size and location of an image canvas (operator)",
       "-resize geometry     resize the image",
@@ -331,7 +333,7 @@ static void RelinquishCompositeOptions(CompositeOptions *option_info)
       RelinquishMagickMemory(option_info->watermark_geometry);
 }
 
-MagickExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
+WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
   int argc,char **argv,char **metadata,ExceptionInfo *exception)
 {
 #define NotInitialized  (unsigned int) (~0)
@@ -418,8 +420,15 @@ MagickExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
   ReadCommandlLine(argc,&argv);
   status=ExpandFilenames(&argc,&argv);
   if (status == MagickFalse)
-    ThrowCompositeException(ResourceLimitError,"MemoryAllocationFailed",
-      strerror(errno));
+    {
+      char
+        *message;
+
+      message=GetExceptionMessage(errno);
+      ThrowCompositeException(ResourceLimitError,"MemoryAllocationFailed",
+        message);
+      message=(char *) RelinquishMagickMemory(message);
+    }
   for (i=1; i < (long) (argc-1); i++)
   {
     option=argv[i];
@@ -455,6 +464,8 @@ MagickExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
         */
         MogrifyImageStack(image_stack[k],MagickTrue,pend);
         filename=argv[i];
+        if ((LocaleCompare(filename,"--") == 0) && (i < (argc-1)))
+          filename=argv[++i];
         (void) CopyMagickString(image_info->filename,filename,MaxTextExtent);
         image=ReadImage(image_info,exception);
         status&=(image != (Image *) NULL) &&
@@ -1014,6 +1025,23 @@ MagickExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
               ThrowCompositeInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("quantize",option+1) == 0)
+          {
+            long
+              colorspace;
+
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) argc)
+              ThrowCompositeException(OptionError,"MissingArgument",option);
+            colorspace=ParseMagickOption(MagickColorspaceOptions,
+              MagickFalse,argv[i]);
+            if (colorspace < 0)
+              ThrowCompositeException(OptionError,"UnrecognizedColorspace",
+                argv[i]);
+            break;
+          }
         if (LocaleCompare("quiet",option+1) == 0)
           break;
         ThrowCompositeException(OptionError,"UnrecognizedOption",option)
@@ -1031,6 +1059,8 @@ MagickExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
               ThrowCompositeInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("regard-warnings",option+1) == 0)
+          break;
         if (LocaleCompare("render",option+1) == 0)
           break;
         if (LocaleCompare("repage",option+1) == 0)
@@ -1159,7 +1189,7 @@ MagickExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
         if (LocaleCompare("tile",option+1) == 0)
           {
             option_info.tile=(*option == '-') ? MagickTrue : MagickFalse;
-            (void) strcpy(argv[i]+1,"{0}");
+            (void) CopyMagickString(argv[i]+1,"sans0",MaxTextExtent);
             break;
           }
         if (LocaleCompare("transform",option+1) == 0)
@@ -1302,7 +1332,7 @@ MagickExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
   }
   if (k != 0)
     ThrowCompositeException(OptionError,"UnbalancedParenthesis",argv[i]);
-  if (i != (long) (argc-1))
+  if (i-- != (long) (argc-1))
     ThrowCompositeException(OptionError,"MissingAnImageFilename",argv[i]);
   if ((image_stack[k] == (Image *) NULL) ||
       (GetImageListLength(image_stack[k]) < 2))
@@ -1321,12 +1351,33 @@ MagickExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
       if (status == MagickFalse)
         GetImageException(composite_image,exception);
     }
+  composite_image=CloneImage(composite_image,0,0,MagickTrue,exception);
+  if (composite_image == (Image *) NULL)
+    {
+      char
+        *message;
+
+      message=GetExceptionMessage(errno);
+      ThrowCompositeException(ResourceLimitError,"MemoryAllocationFailed",
+        message);
+      message=(char *) RelinquishMagickMemory(message);
+    }
+  (void) TransformImage(&composite_image,(char *) NULL,
+    composite_image->geometry);
   image=CloneImage(image,0,0,MagickTrue,exception);
   if (image == (Image *) NULL)
-    ThrowCompositeException(ResourceLimitError,"MemoryAllocationFailed",
-      strerror(errno));
+    {
+      char
+        *message;
+
+      message=GetExceptionMessage(errno);
+      ThrowCompositeException(ResourceLimitError,"MemoryAllocationFailed",
+        message);
+      message=(char *) RelinquishMagickMemory(message);
+    }
   status&=CompositeImageList(image_info,&image,composite_image,&option_info,
     exception);
+  composite_image=DestroyImage(composite_image);
   /*
     Write composite images.
   */
@@ -1336,14 +1387,22 @@ MagickExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
       char
         *text;
 
-      text=TranslateText(image_info,image,format);
+      text=InterpretImageAttributes(image_info,image,format);
       if (text == (char *) NULL)
-        ThrowCompositeException(ResourceLimitError,"MemoryAllocationFailed",
-          strerror(errno));
+        {
+          char
+            *message;
+
+          message=GetExceptionMessage(errno);
+          ThrowCompositeException(ResourceLimitError,"MemoryAllocationFailed",
+            message);
+          message=(char *) RelinquishMagickMemory(message);
+        }
       (void) ConcatenateString(&(*metadata),text);
       (void) ConcatenateString(&(*metadata),"\n");
       text=(char *) RelinquishMagickMemory(text);
     }
+  image=DestroyImage(image);
   RelinquishCompositeOptions(&option_info);
   DestroyComposite();
   return(status != 0 ? MagickTrue : MagickFalse);
