@@ -55,9 +55,15 @@
   Define declarations.
 */
 #define ThrowFileException(exception,severity,tag,context) \
+{ \
+  char \
+    *message; \
+ \
+  message=GetExceptionMessage(errno); \
   (void) ThrowMagickException(exception,GetMagickModule(),severity,tag, \
-    "`%s': %s",context,strerror(errno));
-
+    "`%s': %s",context,message); \
+  message=(char *) RelinquishMagickMemory(message); \
+}
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
@@ -135,6 +141,10 @@ static void ConvertUsage(void)
   static const char
     *options[]=
     {
+      "-adaptive-blur geometry",
+      "                     adaptively blur pixels; decrease effect near edges",
+      "-adaptive-sharpen geometry",
+      "                     adaptively sharpen pixels; increase effect near edges",
       "-adjoin              join images into a single multi-image file",
       "-affine matrix       affine transform matrix",
       "-annotate geometry text",
@@ -142,11 +152,14 @@ static void ConvertUsage(void)
       "-antialias           remove pixel-aliasing",
       "-append              append an image sequence",
       "-authenticate value  decrypt image with this password",
+      "-auto-orient         automatically orient image",
       "-average             average an image sequence",
       "-background color    background color",
       "-bias value          add bias when convolving an image",
+      "-black-point-compensation",
+      "                     use black point compensation",
       "-black-threshold value",
-      "                     forces all pixels below the threshold into black",
+      "                     force all pixels below the threshold into black",
       "-blue-primary point  chromaticity blue primary point",
       "-blur geometry       blur the image",
       "-border geometry     surround image with a border of color",
@@ -168,7 +181,7 @@ static void ConvertUsage(void)
       "-compress type       type of pixel compression when writing the image",
       "-contrast            enhance or reduce the image contrast",
       "-contrast-stretch geometry",
-      "                     improve the contrast in an image by `stretching' the range of intensity values",
+      "                     improve contrast by `stretching' the intensity range",
       "-convolve coefficients",
       "                     apply a convolution kernel to the image",
       "-crop geometry       cut out a rectangular region of the image",
@@ -200,10 +213,10 @@ static void ConvertUsage(void)
       "-fill color          color to use when filling a graphic primitive",
       "-filter type         use this filter when resizing an image",
       "-flatten             flatten a sequence of images",
-      "-flip                flip image in the vertical direction",
+      "-flip                flip image vertically",
       "-floodfill geometry color",
       "                     floodfill the image with color",
-      "-flop                flop image in the horizontal direction",
+      "-flop                flop image horizontally",
       "-font name           render text with this font",
       "-format \"string\"     output formatted image characteristics",
       "-frame geometry      surround image with an ornamental border",
@@ -222,6 +235,7 @@ static void ConvertUsage(void)
       "-interlace type      type of image interlacing scheme",
       "-label name          assign a label to an image",
       "-lat geometry        local adaptive thresholding",
+      "-layers method       optimize or compare image layers",
       "-level value         adjust the level of image contrast",
       "-limit type value    pixel cache resource limit",
       "-log format          format of debugging information",
@@ -251,14 +265,18 @@ static void ConvertUsage(void)
       "-pointsize value     font point size",
       "-posterize levels    reduce the image to a limited number of color levels",
       "-preview type        image preview type",
+      "-print string        interpret string and print to console",
+      "-process arguments   process the image with a custom image filter",
       "-profile filename    add, delete, or apply an image profile",
       "-quality value       JPEG/MIFF/PNG compression level",
+      "-quantize colorspace reduce colors in this colorspace",
       "-quiet               suppress all error or warning messages",
       "-radial-blur angle   radial blur the image",
       "-raise value         lighten/darken image edges to create a 3-D effect",
       "-random-threshold low,high",
       "                     random threshold the image",
       "-red-primary point   chromaticity red primary point",
+      "-regard-warnings     pay attention to warning messages",
       "-region geometry     apply options to a portion of the image",
       "-render              render vector graphics",
       "-repage geometry     size and location of an image canvas",
@@ -282,9 +300,10 @@ static void ConvertUsage(void)
       "-sharpen geometry    sharpen the image",
       "-shave geometry      shave pixels from the image edges",
       "-shear geometry      slide one edge of the image along the X or Y axis",
-      "-sigmodial-contrast geometry",
+      "-sigmoidal-contrast geometry",
       "                     lightness rescaling using sigmoidal contrast enhancement",
       "-size geometry       width and height of image",
+      "-sketch geometry     simulate a pencil sketch",
       "-solarize threshold  negate all pixels above the threshold level",
       "-splice geometry     splice the background color into the image",
       "-spread amount       displace image pixels by a random amount",
@@ -303,10 +322,13 @@ static void ConvertUsage(void)
       "-tint value          tint the image with the fill color",
       "-transform           affine transform image",
       "-transparent color   make this color transparent within the image",
+      "-transpose           flip image vertically and rotate 90 degrees",
+      "-transverse          flop image horizontally and rotate 270 degrees",
       "-treedepth value     color tree depth",
       "-trim                trim image edges",
       "-type type           image type",
       "-undercolor color    annotation bounding box color",
+      "-unique-colors       discard all but one of any pixel color",
       "-units type          the units of image resolution",
       "-unsharp geometry    sharpen the image",
       "-verbose             print detailed information about the image",
@@ -319,7 +341,7 @@ static void ConvertUsage(void)
       "-weight type         render text with this font weight",
       "-white-point point   chromaticity white point",
       "-white-threshold value",
-      "                     forces all pixels above the threshold into white",
+      "                     force all pixels above the threshold into white",
       "-write filename      write images to this file",
       (char *) NULL
     };
@@ -421,8 +443,15 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
   ReadCommandlLine(argc,&argv);
   status=ExpandFilenames(&argc,&argv);
   if (status == MagickFalse)
-    ThrowConvertException(ResourceLimitError,"MemoryAllocationFailed",
-      strerror(errno));
+    {
+      char
+        *message;
+
+      message=GetExceptionMessage(errno);
+      ThrowConvertException(ResourceLimitError,"MemoryAllocationFailed",
+        message);
+      message=(char *) RelinquishMagickMemory(message);
+    }
   if ((argc > 2) && (LocaleCompare("-concatenate",argv[1]) == 0))
     return(ConcatenateImages(argc,argv,exception));
   for (i=1; i < (long) (argc-1); i++)
@@ -460,6 +489,8 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
         */
         MogrifyImageStack(image_stack[k],MagickTrue,pend);
         filename=argv[i];
+        if ((LocaleCompare(filename,"--") == 0) && (i < (argc-1)))
+          filename=argv[++i];
         (void) CopyMagickString(image_info->filename,filename,MaxTextExtent);
         if (image_info->ping != MagickFalse)
           image=PingImage(image_info,exception);
@@ -477,6 +508,24 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
     {
       case 'a':
       {
+        if (LocaleCompare("adaptive-blur",option+1) == 0)
+          {
+            i++;
+            if (i == (long) (argc-1))
+              ThrowConvertException(OptionError,"MissingArgument",option);
+            if (IsGeometry(argv[i]) == MagickFalse)
+              ThrowConvertInvalidArgumentException(option,argv[i]);
+            break;
+          }
+        if (LocaleCompare("adaptive-sharpen",option+1) == 0)
+          {
+            i++;
+            if (i == (long) (argc-1))
+              ThrowConvertException(OptionError,"MissingArgument",option);
+            if (IsGeometry(argv[i]) == MagickFalse)
+              ThrowConvertInvalidArgumentException(option,argv[i]);
+            break;
+          }
         if (LocaleCompare("adjoin",option+1) == 0)
           break;
         if (LocaleCompare("affine",option+1) == 0)
@@ -517,6 +566,8 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
               ThrowConvertException(OptionError,"MissingArgument",option);
             break;
           }
+        if (LocaleCompare("auto-orient",option+1) == 0)
+          break;
         if (LocaleCompare("average",option+1) == 0)
           break;
         ThrowConvertException(OptionError,"UnrecognizedOption",option)
@@ -543,6 +594,8 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
               ThrowConvertInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("black-point-compensation",option+1) == 0)
+          break;
         if (LocaleCompare("black-threshold",option+1) == 0)
           {
             if (*option == '+')
@@ -1308,6 +1361,22 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
               ThrowConvertInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("layers",option+1) == 0)
+          {
+            long
+              type;
+
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) (argc-1))
+              ThrowConvertException(OptionError,"MissingArgument",option);
+            type=ParseMagickOption(MagickLayersOptions,MagickFalse,argv[i]);
+            if (type < 0)
+              ThrowConvertException(OptionError,"UnrecognizedLayerType",
+                argv[i]);
+            break;
+          }
         if (LocaleCompare("level",option+1) == 0)
           {
             i++;
@@ -1609,6 +1678,15 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
                 argv[i]);
             break;
           }
+        if (LocaleCompare("print",option+1) == 0)
+          {
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) (argc-1))
+              ThrowConvertException(OptionError,"MissingArgument",option);
+            break;
+          }
         if (LocaleCompare("process",option+1) == 0)
           {
             if (*option == '+')
@@ -1640,6 +1718,23 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
               ThrowConvertInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("quantize",option+1) == 0)
+          {
+            long
+              colorspace;
+
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) (argc-1))
+              ThrowConvertException(OptionError,"MissingArgument",option);
+            colorspace=ParseMagickOption(MagickColorspaceOptions,
+              MagickFalse,argv[i]);
+            if (colorspace < 0)
+              ThrowConvertException(OptionError,"UnrecognizedColorspace",
+                argv[i]);
+            break;
+          }
         if (LocaleCompare("quiet",option+1) == 0)
           break;
         ThrowConvertException(OptionError,"UnrecognizedOption",option)
@@ -1686,6 +1781,8 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
               ThrowConvertInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("regard-warnings",option+1) == 0)
+          break;
         if (LocaleCompare("region",option+1) == 0)
           {
             if (*option == '+')
@@ -1921,6 +2018,17 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
               ThrowConvertInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("sketch",option+1) == 0)
+          {
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) (argc-1))
+              ThrowConvertException(OptionError,"MissingArgument",option);
+            if (IsGeometry(argv[i]) == MagickFalse)
+              ThrowConvertInvalidArgumentException(option,argv[i]);
+            break;
+          }
         if (LocaleCompare("solarize",option+1) == 0)
           {
             if (*option == '+')
@@ -2107,6 +2215,10 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
               ThrowConvertException(OptionError,"MissingArgument",option);
             break;
           }
+        if (LocaleCompare("transpose",option+1) == 0)
+          break;
+        if (LocaleCompare("transverse",option+1) == 0)
+          break;
         if (LocaleCompare("treedepth",option+1) == 0)
           {
             if (*option == '+')
@@ -2149,6 +2261,8 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
               ThrowConvertException(OptionError,"MissingArgument",option);
             break;
           }
+        if (LocaleCompare("unique-colors",option+1) == 0)
+          break;
         if (LocaleCompare("units",option+1) == 0)
           {
             long
@@ -2288,7 +2402,7 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
   }
   if (k != 0)
     ThrowConvertException(OptionError,"UnbalancedParenthesis",argv[i]);
-  if (i != (long) (argc-1))
+  if (i-- != (long) (argc-1))
     ThrowConvertException(OptionError,"MissingAnImageFilename",argv[argc-1]);
   if (image_stack[k] == (Image *) NULL)
     ThrowConvertException(OptionError,"MissingAnImageFilename",argv[argc-1]);
@@ -2301,10 +2415,17 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
       char
         *text;
 
-      text=TranslateText(image_info,image_stack[k],format);
+      text=InterpretImageAttributes(image_info,image_stack[k],format);
       if (text == (char *) NULL)
-        ThrowConvertException(ResourceLimitError,"MemoryAllocationFailed",
-          strerror(errno));
+        {
+          char
+            *message;
+
+          message=GetExceptionMessage(errno);
+          ThrowConvertException(ResourceLimitError,"MemoryAllocationFailed",
+            message);
+          message=(char *) RelinquishMagickMemory(message);
+        }
       (void) ConcatenateString(&(*metadata),text);
       text=(char *) RelinquishMagickMemory(text);
     }
