@@ -105,6 +105,7 @@ static void DisplayUsage(void)
     {
       "-antialias           remove pixel-aliasing",
       "-authenticate value  decrypt image with this password",
+      "-auto-orient         automatically orient image",
       "-backdrop            display image centered on a backdrop",
       "-border geometry     surround image with a border of color",
       "-channel type        apply option to select image channels",
@@ -156,8 +157,10 @@ static void DisplayUsage(void)
       "-page geometry       size and location of an image canvas",
       "-profile filename    add, delete, or apply an image profile",
       "-quality value       JPEG/MIFF/PNG compression level",
+      "-quantize colorspace reduce colors in this colorspace",
       "-quiet               suppress all error or warning messages",
       "-raise value         lighten/darken image edges to create a 3-D effect",
+      "-regard-warnings     pay attention to warning messages",
       "-remote command      execute a command in an remote display process",
       "-repage geometry     size and location of an image canvas (operator)",
       "-resize geometry     resize the image",
@@ -183,7 +186,7 @@ static void DisplayUsage(void)
       "-virtual-pixel method",
       "                     virtual pixel access method",
       "-window id           display image to background of this window",
-      "-window_group id     exit program when this window id is destroyed",
+      "-window-group id     exit program when this window id is destroyed",
       "-write filename      write image to a file",
       (char *) NULL
     };
@@ -217,7 +220,7 @@ static void DisplayUsage(void)
   exit(0);
 }
 
-MagickExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
+WandExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
   int argc,char **argv,char **wand_unused(metadata),ExceptionInfo *exception)
 {
 #if defined(HasX11)
@@ -232,7 +235,8 @@ MagickExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
     } \
   for ( ; k >= 0; k--) \
     image_stack[k]=DestroyImageList(image_stack[k]); \
-  image_marker=(unsigned long *) RelinquishMagickMemory(image_marker); \
+  if (image_marker != (unsigned long *) NULL) \
+    image_marker=(unsigned long *) RelinquishMagickMemory(image_marker); \
   for (i=0; i < (long) argc; i++) \
     argv[i]=(char *) RelinquishMagickMemory(argv[i]); \
   argv=(char **) RelinquishMagickMemory(argv); \
@@ -311,14 +315,11 @@ MagickExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
   first_scene=0;
   j=1;
   k=0;
+  image_marker=(unsigned long *) NULL;
   image_stack[k]=NewImageList();
   image_number=0;
   last_image=0;
   last_scene=0;
-  image_marker=(unsigned long *)
-    AcquireMagickMemory((argc+1)*sizeof(*image_marker));
-  for (i=0; i <= argc; i++)
-    image_marker[i]=(unsigned long) argc;
   option=(char *) NULL;
   pend=MagickFalse;
   resource_database=(XrmDatabase) NULL;
@@ -326,17 +327,35 @@ MagickExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
   server_name=(char *) NULL;
   state=0;
   status=MagickTrue;
-  if (image_marker == (unsigned long *) NULL)
-    ThrowDisplayException(ResourceLimitError,"MemoryAllocationFailed",
-      strerror(errno));
-  /*
-    Check for server name specified on the command line.
-  */
   ReadCommandlLine(argc,&argv);
   status=ExpandFilenames(&argc,&argv);
   if (status == MagickFalse)
-    ThrowDisplayException(ResourceLimitError,"MemoryAllocationFailed",
-      strerror(errno));
+    {
+      char
+        *message;
+
+      message=GetExceptionMessage(errno);
+      ThrowDisplayException(ResourceLimitError,"MemoryAllocationFailed",
+        message);
+      message=(char *) RelinquishMagickMemory(message);
+    }
+  image_marker=(unsigned long *)
+    AcquireMagickMemory((argc+1)*sizeof(*image_marker));
+  if (image_marker == (unsigned long *) NULL)
+    {
+      char
+        *message;
+
+      message=GetExceptionMessage(errno);
+      ThrowDisplayException(ResourceLimitError,"MemoryAllocationFailed",
+        message);
+      message=(char *) RelinquishMagickMemory(message);
+    }
+  for (i=0; i <= argc; i++)
+    image_marker[i]=(unsigned long) argc;
+  /*
+    Check for server name specified on the command line.
+  */
   for (i=1; i < (long) argc; i++)
   {
     /*
@@ -386,16 +405,16 @@ MagickExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
   image_info->quality=(unsigned long) atol(resource_value);
   resource_value=XGetResourceInstance(resource_database,GetClientName(),
     "verbose","False");
-  image_info->verbose=IsTrue(resource_value);
+  image_info->verbose=IsMagickTrue(resource_value);
   resource_value=XGetResourceInstance(resource_database,GetClientName(),
     "dither","True");
-  quantize_info->dither=IsTrue(resource_value);
+  quantize_info->dither=IsMagickTrue(resource_value);
   /*
     Parse command line.
   */
   iteration=0;
   iterations=0;
-  for (i=1; ((i <= argc) && ((state & ExitState) == 0)); i++)
+  for (i=1; ((i <= (long) argc) && ((state & ExitState) == 0)); i++)
   {
     if (i < (long) argc)
       option=argv[i];
@@ -407,11 +426,11 @@ MagickExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
           option="logo:";
         else
           {
-            char
+            int
               c;
 
             c=getc(stdin);
-            if ((int) c == EOF)
+            if (c == EOF)
               break;
             else
               {
@@ -449,10 +468,19 @@ MagickExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
         MogrifyImageStack(image_stack[k],MagickFalse,pend);
         for (scene=first_scene; scene <= last_scene ; scene++)
         {
+          const char
+            *filename;
+
           /*
             Read image.
           */
-          (void) CopyMagickString(image_info->filename,option,MaxTextExtent);
+          filename=option;
+          if ((LocaleCompare(filename,"--") == 0) && (i < (argc-1)))
+            {
+              option=argv[++i];
+              filename=option;
+            }
+          (void) CopyMagickString(image_info->filename,filename,MaxTextExtent);
           if (first_scene != last_scene)
             {
               char
@@ -461,8 +489,8 @@ MagickExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
               /*
                 Form filename for multi-part images.
               */
-              (void) FormatMagickString(filename,MaxTextExtent,
-                image_info->filename,scene);
+              (void) InterpretImageFilename(filename,MaxTextExtent,
+                image_info->filename,(int) scene);
               if (LocaleCompare(filename,image_info->filename) == 0)
                 (void) FormatMagickString(filename,MaxTextExtent,"%s.%lu",
                   image_info->filename,scene);
@@ -634,6 +662,8 @@ MagickExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
               ThrowDisplayException(OptionError,"MissingArgument",option);
             break;
           }
+        if (LocaleCompare("auto-orient",option+1) == 0)
+          break;
         ThrowDisplayException(OptionError,"UnrecognizedOption",option);
       }
       case 'b':
@@ -765,7 +795,6 @@ MagickExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
             long
               colorspace;
 
-            quantize_info->colorspace=UndefinedColorspace;
             if (*option == '+')
               break;
             i++;
@@ -776,9 +805,6 @@ MagickExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
             if (colorspace < 0)
               ThrowDisplayException(OptionError,"UnrecognizedColorspace",
                 argv[i]);
-            quantize_info->colorspace=(ColorspaceType) colorspace;
-            if (quantize_info->colorspace == GRAYColorspace)
-              quantize_info->number_colors=256;
             break;
           }
         if (LocaleCompare("comment",option+1) == 0)
@@ -1053,7 +1079,7 @@ MagickExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
             resource_info.image_geometry=(char *) NULL;
             if (*option == '+')
               break;
-            (void) strcpy(argv[i]+1,"{1}");
+            (void) CopyMagickString(argv[i]+1,"sans",MaxTextExtent);
             i++;
             if (i == (long) argc)
               ThrowDisplayException(OptionError,"MissingArgument",option);
@@ -1195,7 +1221,7 @@ MagickExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
             resource_info.map_type=(char *) NULL;
             if (*option == '+')
               break;
-            (void) strcpy(argv[i]+1,"{1}");
+            (void) CopyMagickString(argv[i]+1,"sans",MaxTextExtent);
             i++;
             if (i == (long) argc)
               ThrowDisplayException(OptionError,"MissingArgument",option);
@@ -1280,6 +1306,30 @@ MagickExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
               ThrowDisplayInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("quantize",option+1) == 0)
+          {
+            long
+              colorspace;
+
+            quantize_info->colorspace=UndefinedColorspace;
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) argc)
+              ThrowDisplayException(OptionError,"MissingArgument",option);
+            colorspace=ParseMagickOption(MagickColorspaceOptions,
+              MagickFalse,argv[i]);
+            if (colorspace < 0)
+              ThrowDisplayException(OptionError,"UnrecognizedColorspace",
+                argv[i]);
+            quantize_info->colorspace=(ColorspaceType) colorspace;
+            if (quantize_info->colorspace == GRAYColorspace)
+              {
+                quantize_info->number_colors=256;
+                quantize_info->colorspace=GRAYColorspace;
+              }
+            break;
+          }
         if (LocaleCompare("quiet",option+1) == 0)
           break;
         ThrowDisplayException(OptionError,"UnrecognizedOption",option);
@@ -1295,6 +1345,8 @@ MagickExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
               ThrowDisplayInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("regard-warnings",option+1) == 0)
+          break;
         if (LocaleCompare("remote",option+1) == 0)
           {
             i++;
@@ -1373,6 +1425,11 @@ MagickExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
               ThrowDisplayInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("sans",option+1) == 0)
+          {
+            i++;
+            break;
+          }
         if (LocaleCompare("scenes",option+1) == 0)
           {
             first_scene=0;
@@ -1457,7 +1514,7 @@ MagickExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
       }
       case 't':
       {
-        if (LocaleCompare("text_font",option+1) == 0)
+        if (LocaleCompare("text-font",option+1) == 0)
           {
             resource_info.text_font=(char *) NULL;
             if (*option == '+')
@@ -1590,7 +1647,7 @@ MagickExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
             resource_info.window_id=argv[i];
             break;
           }
-        if (LocaleCompare("window_group",option+1) == 0)
+        if (LocaleCompare("window-group",option+1) == 0)
           {
             resource_info.window_group=(char *) NULL;
             if (*option == '+')
