@@ -412,13 +412,13 @@ int main ( int argc, char **argv )
   GetExceptionInfo( &exception );
   FormatMagickString(size, MaxTextExtent, "%dx%d", columns, rows);
   (void) CloneString(&image_info->size,size);
-  strcpy( image_info->filename, "xc:white");
-  canvas = ReadImage ( image_info, &exception );
+  (void) CopyMagickString(image_info->filename,"xc:white",MaxTextExtent);
+  canvas=ReadImage ( image_info, &exception );
   if (exception.severity >= ErrorException)
     CatchException(&exception);
   if ( canvas == (Image *)NULL )
     {
-      (void) printf ( "Failed to read canvas image %s\n", image_info->filename );
+      (void) printf ( "Failed to read canvas image %s\n",image_info->filename);
       exit(1);
     }
 
