@@ -93,6 +93,7 @@ static void IdentifyUsage(void)
   static const char
     *options[]=
     {
+      "-antialias           remove pixel-aliasing",
       "-authenticate value  decrypt image with this password",
       "-channel type        apply option to select image channels",
       "-crop geometry       cut out a rectangular region of the image",
@@ -114,6 +115,7 @@ static void IdentifyUsage(void)
       "-monitor             monitor progress",
       "-ping                efficiently determine image attributes",
       "-quiet               suppress all error or warning messages",
+      "-regard-warnings     pay attention to warning messages",
       "-sampling-factor geometry",
       "                     horizontal and vertical sampling factor",
       "-set attribute value set an image attribute",
@@ -317,6 +319,21 @@ WandExport MagickBooleanType IdentifyImageCommand(ImageInfo *image_info,
     pend=image_stack[k] != (Image *) NULL ? MagickTrue : MagickFalse;
     switch (*(option+1))
     {
+      case 'a':
+      {
+        if (LocaleCompare("antialias",option+1) == 0)
+          break;
+        if (LocaleCompare("authenticate",option+1) == 0)
+          {
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) (argc-1))
+              ThrowIdentifyException(OptionError,"MissingArgument",option);
+            break;
+          }
+        ThrowIdentifyException(OptionError,"UnrecognizedOption",option)
+      }
       case 'c':
       {
         if (LocaleCompare("cache",option+1) == 0)
@@ -332,20 +349,18 @@ WandExport MagickBooleanType IdentifyImageCommand(ImageInfo *image_info,
           }
         if (LocaleCompare("channel",option+1) == 0)
           {
-            if (*option == '-')
-              {
-                long
-                  channel;
+            long
+              channel;
 
-                i++;
-                if (i == (long) (argc-1))
-                  ThrowIdentifyException(OptionError,"MissingArgument",option);
-                channel=ParseChannelOption(argv[i]);
-                if (channel < 0)
-                  ThrowIdentifyException(OptionError,"UnrecognizedChannelType",
-                    argv[i]);
-                break;
-              }
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) (argc-1))
+              ThrowIdentifyException(OptionError,"MissingArgument",option);
+            channel=ParseChannelOption(argv[i]);
+            if (channel < 0)
+              ThrowIdentifyException(OptionError,"UnrecognizedChannelType",
+                argv[i]);
             break;
           }
         if (LocaleCompare("crop",option+1) == 0)
@@ -551,6 +566,12 @@ WandExport MagickBooleanType IdentifyImageCommand(ImageInfo *image_info,
           break;
         ThrowIdentifyException(OptionError,"UnrecognizedOption",option)
       }
+      case 'r':
+      {
+        if (LocaleCompare("regard-warnings",option+1) == 0)
+          break;
+        ThrowIdentifyException(OptionError,"UnrecognizedOption",option)
+      }
       case 's':
       {
         if (LocaleCompare("sampling-factor",option+1) == 0)
