@@ -143,7 +143,9 @@ static void ImportUsage(void)
       "-pause value         seconds delay between snapshots",
       "-pointsize value     font point size",
       "-quality value       JPEG/MIFF/PNG compression level",
+      "-quantize colorspace reduce colors in this colorspace",
       "-quiet               suppress all error or warning messages",
+      "-regard-warnings     pay attention to warning messages",
       "-repage geometry     size and location of an image canvas",
       "-resize geometry     resize the image",
       "-rotate degrees      apply Paeth rotation to the image",
@@ -531,7 +533,6 @@ WandExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
             long
               colorspace;
 
-            quantize_info->colorspace=UndefinedColorspace;
             if (*option == '+')
               break;
             i++;
@@ -542,12 +543,6 @@ WandExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
             if (colorspace < 0)
               ThrowImportException(OptionError,"UnrecognizedColorspace",
                 argv[i]);
-            quantize_info->colorspace=(ColorspaceType) colorspace;
-            if (quantize_info->colorspace == GRAYColorspace)
-              {
-                quantize_info->number_colors=256;
-                quantize_info->colorspace=GRAYColorspace;
-              }
             break;
           }
         if (LocaleCompare("comment",option+1) == 0)
@@ -932,12 +927,38 @@ WandExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
               ThrowImportInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("quantize",option+1) == 0)
+          {
+            long
+              colorspace;
+
+            quantize_info->colorspace=UndefinedColorspace;
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) argc)
+              ThrowImportException(OptionError,"MissingArgument",option);
+            colorspace=ParseMagickOption(MagickColorspaceOptions,MagickFalse,
+              argv[i]);
+            if (colorspace < 0)
+              ThrowImportException(OptionError,"UnrecognizedColorspace",
+                argv[i]);
+            quantize_info->colorspace=(ColorspaceType) colorspace;
+            if (quantize_info->colorspace == GRAYColorspace)
+              {
+                quantize_info->number_colors=256;
+                quantize_info->colorspace=GRAYColorspace;
+              }
+            break;
+          }
         if (LocaleCompare("quiet",option+1) == 0)
           break;
         ThrowImportException(OptionError,"UnrecognizedOption",option);
       }
       case 'r':
       {
+        if (LocaleCompare("regard-warnings",option+1) == 0)
+          break;
         if (LocaleCompare("repage",option+1) == 0)
           {
             if (*option == '+')
