@@ -57,6 +57,7 @@ extern WandExport InterlaceType
 extern WandExport MagickBooleanType
   MagickGetPage(MagickWand *,unsigned long *,unsigned long *,long *,long *),
   MagickGetSize(const MagickWand *,unsigned long *,unsigned long *),
+  MagickGetSizeOffset(const MagickWand *,long *),
   MagickSetBackgroundColor(MagickWand *,const PixelWand *),
   MagickSetCompression(MagickWand *,const CompressionType),
   MagickSetCompressionQuality(MagickWand *,const unsigned long),
@@ -71,6 +72,8 @@ extern WandExport MagickBooleanType
   MagickSetResourceLimit(const ResourceType type,const unsigned long limit),
   MagickSetSamplingFactors(MagickWand *,const unsigned long,const double *),
   MagickSetSize(MagickWand *,const unsigned long,const unsigned long),
+  MagickSetSizeOffset(MagickWand *,const unsigned long,const unsigned long,
+    const long),
   MagickSetType(MagickWand *,const ImageType);
 
 extern WandExport MagickProgressMonitor
