@@ -59,6 +59,12 @@ extern WandExport InterlaceType
   MagickGetImageInterlaceScheme(MagickWand *);
 
 extern WandExport MagickBooleanType
+  MagickAdaptiveBlurImage(MagickWand *,const double,const double),
+  MagickAdaptiveBlurImageChannel(MagickWand *,const ChannelType,const double,
+    const double),
+  MagickAdaptiveSharpenImage(MagickWand *,const double,const double),
+  MagickAdaptiveSharpenImageChannel(MagickWand *,const ChannelType,const double,
+    const double),
   MagickAdaptiveThresholdImage(MagickWand *,const unsigned long,
     const unsigned long,const long),
   MagickAddImage(MagickWand *,const MagickWand *),
@@ -167,14 +173,17 @@ extern WandExport MagickBooleanType
   MagickOilPaintImage(MagickWand *,const double),
   MagickPaintOpaqueImage(MagickWand *,const PixelWand *,const PixelWand *,
     const double),
+  MagickPaintOpaqueImageChannel(MagickWand *,const ChannelType,
+    const PixelWand *,const PixelWand *,const double),
   MagickPaintTransparentImage(MagickWand *,const PixelWand *,const Quantum,
     const double),
   MagickPingImage(MagickWand *,const char *),
+  MagickPingImageBlob(MagickWand *,const void *,const size_t),
+  MagickPingImageFile(MagickWand *,FILE *),
   MagickPosterizeImage(MagickWand *,const unsigned long,
     const MagickBooleanType),
   MagickPreviousImage(MagickWand *),
-  MagickProfileImage(MagickWand *,const char *,const void *,
-    const unsigned long),
+  MagickProfileImage(MagickWand *,const char *,const void *,const size_t),
   MagickQuantizeImage(MagickWand *,const unsigned long,const ColorspaceType,
     const unsigned long,const MagickBooleanType,const MagickBooleanType),
   MagickQuantizeImages(MagickWand *,const unsigned long,const ColorspaceType,
@@ -187,7 +196,7 @@ extern WandExport MagickBooleanType
   MagickRandomThresholdImageChannel(MagickWand *,const ChannelType,const double,
     const double),
   MagickReadImage(MagickWand *,const char *),
-  MagickReadImageBlob(MagickWand *,const void *,const size_t length),
+  MagickReadImageBlob(MagickWand *,const void *,const size_t),
   MagickReadImageFile(MagickWand *,FILE *),
   MagickReduceNoiseImage(MagickWand *,const double),
   MagickRemoveImage(MagickWand *),
@@ -199,6 +208,8 @@ extern WandExport MagickBooleanType
   MagickRotateImage(MagickWand *,const PixelWand *,const double),
   MagickSampleImage(MagickWand *,const unsigned long,const unsigned long),
   MagickScaleImage(MagickWand *,const unsigned long,const unsigned long),
+  MagickSegmentImage(MagickWand *,const ColorspaceType,const MagickBooleanType,
+    const double,const double),
   MagickSeparateImageChannel(MagickWand *,const ChannelType),
   MagickSepiaToneImage(MagickWand *,const double),
   MagickSetImage(MagickWand *,const MagickWand *),
@@ -231,8 +242,7 @@ extern WandExport MagickBooleanType
     const long,const long),
   MagickSetImagePixels(MagickWand *,const long,const long,const unsigned long,
     const unsigned long,const char *,const StorageType,const void *),
-  MagickSetImageProfile(MagickWand *,const char *,const void *,
-    const unsigned long),
+  MagickSetImageProfile(MagickWand *,const char *,const void *,const size_t),
   MagickSetImageRedPrimary(MagickWand *,const double,const double),
   MagickSetImageRenderingIntent(MagickWand *,const RenderingIntent),
   MagickSetImageResolution(MagickWand *,const double,const double),
@@ -255,6 +265,7 @@ extern WandExport MagickBooleanType
     const double,const double),
   MagickSigmoidalContrastImageChannel(MagickWand *,const ChannelType,
     const MagickBooleanType,const double,const double),
+  MagickSketchImage(MagickWand *,const double,const double,const double),
   MagickSolarizeImage(MagickWand *,const double),
   MagickSpliceImage(MagickWand *,const unsigned long,const unsigned long,
     const long,const long),
@@ -262,10 +273,13 @@ extern WandExport MagickBooleanType
   MagickStripImage(MagickWand *),
   MagickSwirlImage(MagickWand *,const double),
   MagickTintImage(MagickWand *,const PixelWand *,const PixelWand *),
+  MagickTransposeImage(MagickWand *),
+  MagickTransverseImage(MagickWand *),
   MagickThresholdImage(MagickWand *,const double),
   MagickThresholdImageChannel(MagickWand *,const ChannelType,const double),
   MagickThumbnailImage(MagickWand *,const unsigned long,const unsigned long),
   MagickTrimImage(MagickWand *,const double),
+  MagickUniqueImageColors(MagickWand *),
   MagickUnsharpMaskImage(MagickWand *,const double,const double,const double,
     const double),
   MagickUnsharpMaskImageChannel(MagickWand *,const ChannelType,const double,
@@ -295,6 +309,7 @@ extern WandExport MagickWand
     const MetricType,double *),
   *MagickCompareImages(MagickWand *,const MagickWand *,const MetricType,
     double *),
+  *MagickCompareImageLayers(MagickWand *,const MagickLayerMethod),
   *MagickDeconstructImages(MagickWand *),
   *MagickFlattenImages(MagickWand *),
   *MagickFxImage(MagickWand *,const char *),
@@ -306,6 +321,7 @@ extern WandExport MagickWand
   *MagickMosaicImages(MagickWand *),
   *MagickMontageImage(MagickWand *,const DrawingWand *,const char *,
     const char *,const MontageMode,const char *),
+  *MagickOptimizeImageLayers(MagickWand *),
   *MagickPreviewImages(MagickWand *wand,const PreviewType),
   *MagickSteganoImage(MagickWand *,const MagickWand *,const long),
   *MagickStereoImage(MagickWand *,const MagickWand *),
@@ -325,8 +341,8 @@ extern WandExport ResolutionType
 extern WandExport unsigned char
   *MagickGetImageBlob(MagickWand *,size_t *),
   *MagickGetImagesBlob(MagickWand *,size_t *),
-  *MagickGetImageProfile(MagickWand *,const char *,unsigned long *),
-  *MagickRemoveImageProfile(MagickWand *,const char *,unsigned long *);
+  *MagickGetImageProfile(MagickWand *,const char *,size_t *),
+  *MagickRemoveImageProfile(MagickWand *,const char *,size_t *);
 
 extern WandExport unsigned long
   MagickGetImageColors(MagickWand *),
