@@ -102,7 +102,7 @@ WandExport void ClearMagickWand(MagickWand *wand)
   wand->images=DestroyImageList(wand->images);
   (void) DestroyExceptionInfo(&wand->exception);
   wand->quantize_info=CloneQuantizeInfo((QuantizeInfo *) NULL);
-  wand->image_info=CloneImageInfo((ImageInfo *) NULL);
+  wand->image_info=AcquireImageInfo();
   GetExceptionInfo(&wand->exception);
   wand->debug=IsEventLogging();
 }
@@ -141,8 +141,15 @@ WandExport MagickWand *CloneMagickWand(const MagickWand *wand)
     (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",wand->name);
   clone_wand=(MagickWand *) AcquireMagickMemory(sizeof(*clone_wand));
   if (clone_wand == (MagickWand *) NULL)
-    ThrowWandFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
-      strerror(errno));
+    {
+      char
+        *message;
+
+      message=GetExceptionMessage(errno);
+      ThrowWandFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
+        message);
+      message=(char *) RelinquishMagickMemory(message);
+    }
   (void) ResetMagickMemory(clone_wand,0,sizeof(*clone_wand));
   clone_wand->id=AcquireWandId();
   (void) FormatMagickString(clone_wand->name,MaxTextExtent,"MagickWand-%lu",
@@ -692,7 +699,6 @@ WandExport char **MagickQueryFormats(const char *pattern,
 WandExport void *MagickRelinquishMemory(void *memory)
 {
   (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
-  assert(memory != (void *) NULL);
   return(RelinquishMagickMemory(memory));
 }
 
@@ -927,14 +933,21 @@ WandExport MagickWand *NewMagickWand(void)
     ThrowWandFatalException(WandError,"QuantumDepthMismatch",quantum);
   wand=(MagickWand *) AcquireMagickMemory(sizeof(*wand));
   if (wand == (MagickWand *) NULL)
-    ThrowWandFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
-      strerror(errno));
+    {
+      char
+        *message;
+
+      message=GetExceptionMessage(errno);
+      ThrowWandFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
+        message);
+      message=(char *) RelinquishMagickMemory(message);
+    }
   (void) ResetMagickMemory(wand,0,sizeof(*wand));
   wand->id=AcquireWandId();
   (void) FormatMagickString(wand->name,MaxTextExtent,"%s-%lu",MagickWandId,
     wand->id);
   GetExceptionInfo(&wand->exception);
-  wand->image_info=CloneImageInfo((ImageInfo *) NULL);
+  wand->image_info=AcquireImageInfo();
   wand->quantize_info=CloneQuantizeInfo((QuantizeInfo *) NULL);
   wand->images=NewImageList();
   wand->debug=IsEventLogging();
