@@ -144,8 +144,10 @@ static void MontageUsage(void)
       "-pointsize value     font point size",
       "-profile filename    add, delete, or apply an image profile",
       "-quality value       JPEG/MIFF/PNG compression level",
+      "-quantize colorspace reduce colors in this colorspace",
       "-quiet               suppress all error or warning messages",
       "-red-primary point   chromaticity red primary point",
+      "-regard-warnings     pay attention to warning messages",
       "-repage geometry     size and location of an image canvas (operator)",
       "-resize geometry     resize the image",
       "-rotate degrees      apply Paeth rotation to the image",
@@ -293,8 +295,15 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
   ReadCommandlLine(argc,&argv);
   status=ExpandFilenames(&argc,&argv);
   if (status == MagickFalse)
-    ThrowMontageException(ResourceLimitError,"MemoryAllocationFailed",
-      strerror(errno));
+    {
+      char
+        *message;
+
+      message=GetExceptionMessage(errno);
+      ThrowMontageException(ResourceLimitError,"MemoryAllocationFailed",
+        message);
+      message=(char *) RelinquishMagickMemory(message);
+    }
   for (i=1; i < (long) (argc-1); i++)
   {
     option=argv[i];
@@ -328,10 +337,16 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
         MogrifyImageStack(image_stack[k],MagickTrue,pend);
         for (scene=first_scene; scene <= last_scene ; scene++)
         {
+          char
+            *filename;
+
           /*
             Option is a file name: begin by reading image from specified file.
           */
-          (void) CopyMagickString(image_info->filename,argv[i],MaxTextExtent);
+          filename=argv[i];
+          if ((LocaleCompare(filename,"--") == 0) && (i < (argc-1)))
+            filename=argv[++i];
+          (void) CopyMagickString(image_info->filename,filename,MaxTextExtent);
           if (first_scene != last_scene)
             {
               char
@@ -340,8 +355,8 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
               /*
                 Form filename for multi-part images.
               */
-              (void) FormatMagickString(filename,MaxTextExtent,
-                image_info->filename,scene);
+              (void) InterpretImageFilename(filename,MaxTextExtent,
+                image_info->filename,(int) scene);
               if (LocaleCompare(filename,image_info->filename) == 0)
                 (void) FormatMagickString(filename,MaxTextExtent,"%s.%lu",
                   image_info->filename,scene);
@@ -490,20 +505,18 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
           }
         if (LocaleCompare("channel",option+1) == 0)
           {
-            if (*option == '+')
-              {
-                long
-                  channel;
+            long
+              channel;
 
-                i++;
-                if (i == (long) (argc-1))
-                  ThrowMontageException(OptionError,"MissingArgument",option);
-                channel=ParseChannelOption(argv[i]);
-                if (channel < 0)
-                  ThrowMontageException(OptionError,"UnrecognizedChannelType",
-                    argv[i]);
-                break;
-              }
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) (argc-1))
+              ThrowMontageException(OptionError,"MissingArgument",option);
+            channel=ParseChannelOption(argv[i]);
+            if (channel < 0)
+              ThrowMontageException(OptionError,"UnrecognizedChannelType",
+                argv[i]);
             break;
           }
         if (LocaleCompare("clone",option+1) == 0)
@@ -553,7 +566,6 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
             long
               colorspace;
 
-            quantize_info.colorspace=UndefinedColorspace;
             if (*option == '+')
               break;
             i++;
@@ -564,12 +576,6 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
             if (colorspace < 0)
               ThrowMontageException(OptionError,"UnrecognizedColorspace",
                 argv[i]);
-            quantize_info.colorspace=(ColorspaceType) colorspace;
-            if (quantize_info.colorspace == GRAYColorspace)
-              {
-                quantize_info.colorspace=GRAYColorspace;
-                quantize_info.number_colors=256;
-              }
             break;
           }
         if (LocaleCompare("comment",option+1) == 0)
@@ -815,7 +821,7 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
           }
         if (LocaleCompare("frame",option+1) == 0)
           {
-            (void) strcpy(argv[i]+1,"{1}");
+            (void) CopyMagickString(argv[i]+1,"sans",MaxTextExtent);
             (void) CloneString(&montage_info->frame,(char *) NULL);
             if (*option == '+')
               break;
@@ -1081,6 +1087,30 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
               ThrowMontageInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("quantize",option+1) == 0)
+          {
+            long
+              colorspace;
+
+            quantize_info.colorspace=UndefinedColorspace;
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) argc)
+              ThrowMontageException(OptionError,"MissingArgument",option);
+            colorspace=ParseMagickOption(MagickColorspaceOptions,
+              MagickFalse,argv[i]);
+            if (colorspace < 0)
+              ThrowMontageException(OptionError,"UnrecognizedColorspace",
+                argv[i]);
+            quantize_info.colorspace=(ColorspaceType) colorspace;
+            if (quantize_info.colorspace == GRAYColorspace)
+              {
+                quantize_info.colorspace=GRAYColorspace;
+                quantize_info.number_colors=256;
+              }
+            break;
+          }
         if (LocaleCompare("quiet",option+1) == 0)
           break;
         ThrowMontageException(OptionError,"UnrecognizedOption",option)
@@ -1098,6 +1128,8 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
               ThrowMontageInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("regard-warnings",option+1) == 0)
+          break;
         if (LocaleCompare("render",option+1) == 0)
           break;
         if (LocaleCompare("repage",option+1) == 0)
@@ -1177,7 +1209,7 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
         if (LocaleCompare("shadow",option+1) == 0)
           {
             montage_info->shadow=(*option == '-') ? MagickTrue : MagickFalse;
-            (void) strcpy(argv[i]+1,"{0}");
+            (void) CopyMagickString(argv[i]+1,"sans0",MaxTextExtent);
             break;
           }
         if (LocaleCompare("sharpen",option+1) == 0)
@@ -1264,7 +1296,7 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
           }
         if (LocaleCompare("tile",option+1) == 0)
           {
-            (void) strcpy(argv[i]+1,"{1}");
+            (void) CopyMagickString(argv[i]+1,"sans",MaxTextExtent);
             (void) CloneString(&montage_info->tile,(char *) NULL);
             if (*option == '+')
               break;
@@ -1422,13 +1454,14 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
   }
   if (k != 0)
     ThrowMontageException(OptionError,"UnbalancedParenthesis",argv[i]);
-  if (i != (long) (argc-1))
+  if (i-- != (long) (argc-1))
     ThrowMontageException(OptionError,"MissingAnImageFilename",argv[i]);
   if (image_stack[k] == (Image *) NULL)
     ThrowMontageException(OptionError,"MissingAnImageFilename",argv[argc-1]);
   MogrifyImageStack(image_stack[k],MagickTrue,MagickTrue);
   (void) CopyMagickString(montage_info->filename,argv[argc-1],MaxTextExtent);
-  montage_image=MontageImages(image_stack[k],montage_info,exception);
+  montage_image=MontageImageList(image_info,montage_info,image_stack[k],
+    exception);
   if (montage_image == (Image *) NULL)
     status=MagickFalse;
   else
@@ -1446,10 +1479,17 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
           char
             *text;
 
-          text=TranslateText(image_info,montage_image,format);
+          text=InterpretImageAttributes(image_info,montage_image,format);
           if (text == (char *) NULL)
-            ThrowMontageException(ResourceLimitError,"MemoryAllocationFailed",
-              strerror(errno));
+            {
+              char
+                *message;
+
+              message=GetExceptionMessage(errno);
+              ThrowMontageException(ResourceLimitError,"MemoryAllocationFailed",
+                message);
+              message=(char *) RelinquishMagickMemory(message);
+            }
           (void) ConcatenateString(&(*metadata),text);
           (void) ConcatenateString(&(*metadata),"\n");
           text=(char *) RelinquishMagickMemory(text);
