@@ -160,7 +160,7 @@ WandExport PixelIterator *DestroyPixelIterator(PixelIterator *iterator)
   assert(iterator->signature == WandSignature);
   if (iterator->debug != MagickFalse)
     (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",iterator->name);
-  CloseCacheView(iterator->view);
+  iterator->view=CloseCacheView(iterator->view);
   iterator->pixel_wand=DestroyPixelWands(iterator->pixel_wand,
     iterator->region.width);
   (void) DestroyExceptionInfo(&iterator->exception);
@@ -260,8 +260,15 @@ WandExport PixelIterator *NewPixelIterator(MagickWand *wand)
     return((PixelIterator *) NULL);
   iterator=(PixelIterator *) AcquireMagickMemory(sizeof(*iterator));
   if (iterator == (PixelIterator *) NULL)
-    ThrowWandFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
-      strerror(errno));
+    {
+      char
+        *message;
+
+      message=GetExceptionMessage(errno);
+      ThrowWandFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
+        message);
+      message=(char *) RelinquishMagickMemory(message);
+    }
   (void) ResetMagickMemory(iterator,0,sizeof(*iterator));
   iterator->id=AcquireWandId();
   (void) FormatMagickString(iterator->name,MaxTextExtent,"%s-%lu",
@@ -376,8 +383,15 @@ WandExport PixelIterator *NewPixelRegionIterator(MagickWand *wand,const long x,
     return((PixelIterator *) NULL);
   iterator=(PixelIterator *) AcquireMagickMemory(sizeof(*iterator));
   if (iterator == (PixelIterator *) NULL)
-    ThrowWandFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
-      strerror(errno));
+    {
+      char
+        *message;
+
+      message=GetExceptionMessage(errno);
+      ThrowWandFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
+        message);
+      message=(char *) RelinquishMagickMemory(message);
+    }
   (void) ResetMagickMemory(iterator,0,sizeof(*iterator));
   iterator->id=AcquireWandId();
   (void) FormatMagickString(iterator->name,MaxTextExtent,"%s-%lu",
@@ -508,8 +522,15 @@ WandExport char *PixelGetIteratorException(const PixelIterator *iterator,
   *severity=iterator->exception.severity;
   description=(char *) AcquireMagickMemory(2*MaxTextExtent);
   if (description == (char *) NULL)
-    ThrowWandFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
-      strerror(errno));
+    {
+      char
+        *message;
+
+      message=GetExceptionMessage(errno);
+      ThrowWandFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
+        message);
+      message=(char *) RelinquishMagickMemory(message);
+    }
   *description='\0';
   if (iterator->exception.reason != (char *) NULL)
     (void) CopyMagickString(description,GetLocaleExceptionMessage(
