@@ -65,8 +65,6 @@ extern "C" {
 #  pragma message("BCBMagick lib DLL export interface")
 #  define _WANDDLL_
 #  define _WANDLIB_
-#  define SupportMagickModules
-#  undef BuildMagickModules
 #endif
 
 #if defined(__WINDOWS__)
@@ -351,13 +349,13 @@ extern size_t
 #define O_BINARY  0x00
 #endif
 
-#if defined(HasLTDL) || (defined(__WINDOWS__) && defined(_DLL))
-#  define SupportMagickModules
+#if defined(HasLTDL) || (defined(__WINDOWS__) && defined(_DLL) && !defined(_LIB))
+#  define SupportWandModules
 #endif
 
 #if defined(_WANDMOD_)
-# undef BuildMagickModules
-# define BuildMagickModules
+# undef BuildWandModules
+# define BuildWandModules
 #endif
 
 /*
