@@ -17,7 +17,7 @@
 %                                 May  2004                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -40,10 +40,9 @@
   Include declarations.
 */
 #include "wand/studio.h"
-#include "wand/magick-wand.h"
+#include "wand/MagickWand.h"
 #include "wand/magick-wand-private.h"
 #include "wand/wand.h"
-#include "magick/ImageMagick.h"
 
 static SplayTreeInfo
   *wand_ids = (SplayTreeInfo *) NULL;
